@@ -36,63 +36,60 @@ main(int argc, char *argv[])
   Progname = argv[0];
 
   while (--argc && (*++argv)[0] == '-')
+  {
+    c = *++argv[0];
+    cstring = argv[0];
+    size_t len = strlen(cstring);
+    switch (c)
     {
-      c = *++argv[0];
-      cstring = argv[0];
-      size_t len = strlen(cstring);
-      switch (c)
+      case 'd':
+        if (!strncmp(cstring, "debug", len)) { debug = 1; }
+        break;
+      case 'h':
+        if (!strncmp(cstring, "help", len))
         {
-        case 'd':
-          if (!strncmp(cstring, "debug", len))
-            {
-              debug = 1;
-            }
-          break;
-        case 'h':
-          if (!strncmp(cstring, "help", len))
-            {
-              usage();
-              return EXIT_SUCCESS;
-            }
-          break;
-        case 'v':
-          if (!strncmp(cstring, "version", len))
-            {
-              version();
-              return EXIT_SUCCESS;
-            }
-          break;
-        default:
           usage();
-          fprintf(stderr, "illegal option %s\n", cstring);
-          return EXIT_FAILURE;
+          return EXIT_SUCCESS;
         }
+        break;
+      case 'v':
+        if (!strncmp(cstring, "version", len))
+        {
+          version();
+          return EXIT_SUCCESS;
+        }
+        break;
+      default:
+        usage();
+        fprintf(stderr, "illegal option %s\n", cstring);
+        return EXIT_FAILURE;
     }
+  }
 
   if (argc)
-    {
-      ifile = argv[0];
-      argc--;
-    }
+  {
+    ifile = argv[0];
+    argc--;
+  }
   if (argc)
-    {
-      ofile = (++argv)[0];
-      argc--;
-    }
+  {
+    ofile = (++argv)[0];
+    argc--;
+  }
 
   if (ifile == NULL || ofile == NULL)
-    {
-      usage();
-      fprintf(stderr, "missing filenames\n");
-      return EXIT_FAILURE;
-    }
+  {
+    usage();
+    fprintf(stderr, "missing filenames\n");
+    return EXIT_FAILURE;
+  }
 
   if (debug)
-    {
-      fprintf(stderr, "\n");
-      if (ifile) fprintf(stderr, "  < %s  \n", ifile);
-      if (ofile) fprintf(stderr, "  > %s\n\n", ofile);
-    }
+  {
+    fprintf(stderr, "\n");
+    if (ifile) fprintf(stderr, "  < %s  \n", ifile);
+    if (ofile) fprintf(stderr, "  > %s\n\n", ofile);
+  }
   /*
   if ( debug ) cdiDebug(debug);
   */
