@@ -13,6 +13,10 @@
 #define HAVE_NETCDF5 1
 #endif
 
+#if defined HAVE_NETCDF4 && HAVE_DECL_NC_INQ_VAR_FILTER_IDS && HAVE_DECL_NCAUX_H5FILTERSPEC_PARSELIST
+#define HAVE_NC4FILTER 1
+#endif
+
 #endif
 
 #endif
