@@ -50,10 +50,7 @@ cdiPioClientUpdateResHList()
   int sendRPCData = (clientRank == groupLeader);
   char *msgBuffer = NULL;
   int msgSize = 0, msgBufPos = 0;
-  if (sendRPCData)
-    {
-      msgBufPos = reshPackBufferCreate(&msgBuffer, &msgSize, &comm);
-    }
+  if (sendRPCData) { msgBufPos = reshPackBufferCreate(&msgBuffer, &msgSize, &comm); }
 #ifdef HAVE_PPM_DIST_ARRAY_H
   else
     cdiPioDistGridPackAssist();
@@ -77,45 +74,42 @@ cdiPioClientStreamOpen(const char *filename, char filemode, int filetype, stream
   (void) recordBufIsToBeCreated;
   int fileID = 0;
   if (filemode == 'w')
+  {
+    int streamID = streamptr->self;
+    reshSetStatus(streamID, &streamOps, reshGetStatus(streamID, &streamOps) & ~RESH_SYNC_BIT);
+    struct ResHListUpdate rup = cdiPioClientUpdateResHList();
+    MPI_Comm comm = rup.comm;
+    int collRank = rup.collRank;
+    if (rup.sendRPCData)
     {
-      int streamID = streamptr->self;
-      reshSetStatus(streamID, &streamOps, reshGetStatus(streamID, &streamOps) & ~RESH_SYNC_BIT);
-      struct ResHListUpdate rup = cdiPioClientUpdateResHList();
-      MPI_Comm comm = rup.comm;
-      int collRank = rup.collRank;
-      if (rup.sendRPCData)
-        {
-          unsigned char *msgBuffer = rup.msgBuffer;
-          int msgSize = rup.msgSize;
-          int size;
-          size_t filename_len = strlen(filename);
-          xassert(filename_len < (size_t) (INT_MAX - rup.msgPos));
-          int soHdr[3] = { streamptr->self, filetype, (int) filename_len };
-          xmpi(MPI_Pack_size(3, MPI_INT, comm, &size));
-          msgSize += size;
-          xmpi(MPI_Pack_size(1, MPI_CHAR, comm, &size));
-          msgSize += size;
-          xmpi(MPI_Pack_size((int) filename_len, MPI_CHAR, comm, &size));
-          msgSize += size;
-          /* optimize to pos + size */
-          msgBuffer = Realloc(msgBuffer, (size_t) msgSize);
-          xmpi(MPI_Pack(soHdr, 3, MPI_INT, msgBuffer, msgSize, &rup.msgPos, comm));
-          xmpi(MPI_Pack(&filemode, 1, MPI_CHAR, msgBuffer, msgSize, &rup.msgPos, comm));
-          xmpi(MPI_Pack((void *) filename, (int) filename_len, MPI_CHAR, msgBuffer, msgSize, &rup.msgPos, comm));
-          xmpi(MPI_Sendrecv(msgBuffer, msgSize, MPI_PACKED, collRank, STREAMOPEN, &fileID, 1, MPI_INT, collRank, STREAMOPEN, comm,
-                            MPI_STATUS_IGNORE));
-          Free(msgBuffer);
-        }
-      else
-        {
-          xmpi(MPI_Recv(&fileID, 1, MPI_INT, collRank, STREAMOPEN, comm, MPI_STATUS_IGNORE));
-        }
-      if (fileID >= 0)
-        {
-          streamptr->filetype = filetype;
-          cdiPioClientStreamWinInit(streamID);
-        }
+      unsigned char *msgBuffer = rup.msgBuffer;
+      int msgSize = rup.msgSize;
+      int size;
+      size_t filename_len = strlen(filename);
+      xassert(filename_len < (size_t) (INT_MAX - rup.msgPos));
+      int soHdr[3] = { streamptr->self, filetype, (int) filename_len };
+      xmpi(MPI_Pack_size(3, MPI_INT, comm, &size));
+      msgSize += size;
+      xmpi(MPI_Pack_size(1, MPI_CHAR, comm, &size));
+      msgSize += size;
+      xmpi(MPI_Pack_size((int) filename_len, MPI_CHAR, comm, &size));
+      msgSize += size;
+      /* optimize to pos + size */
+      msgBuffer = Realloc(msgBuffer, (size_t) msgSize);
+      xmpi(MPI_Pack(soHdr, 3, MPI_INT, msgBuffer, msgSize, &rup.msgPos, comm));
+      xmpi(MPI_Pack(&filemode, 1, MPI_CHAR, msgBuffer, msgSize, &rup.msgPos, comm));
+      xmpi(MPI_Pack((void *) filename, (int) filename_len, MPI_CHAR, msgBuffer, msgSize, &rup.msgPos, comm));
+      xmpi(MPI_Sendrecv(msgBuffer, msgSize, MPI_PACKED, collRank, STREAMOPEN, &fileID, 1, MPI_INT, collRank, STREAMOPEN, comm,
+                        MPI_STATUS_IGNORE));
+      Free(msgBuffer);
     }
+    else { xmpi(MPI_Recv(&fileID, 1, MPI_INT, collRank, STREAMOPEN, comm, MPI_STATUS_IGNORE)); }
+    if (fileID >= 0)
+    {
+      streamptr->filetype = filetype;
+      cdiPioClientStreamWinInit(streamID);
+    }
+  }
   else
     xabort("cdiPIO read support not implemented");
   return fileID;
@@ -127,19 +121,19 @@ checkVlistForPIO(int vlistID)
   int nVars = vlistNvars(vlistID);
   int varShape[3];
   for (int varID = 0; varID < nVars; ++varID)
+  {
+    cdiPioQueryVarDims(varShape, vlistID, varID);
+    intmax_t size = 1;
+    for (size_t i = 0; i < 3; ++i) size *= varShape[i];
+    if (size > XT_INT_MAX)
     {
-      cdiPioQueryVarDims(varShape, vlistID, varID);
-      intmax_t size = 1;
-      for (size_t i = 0; i < 3; ++i) size *= varShape[i];
-      if (size > XT_INT_MAX)
-        {
-          errno = EOVERFLOW;
-          SysError("CDI Variable too large for YAXT,"
-                   " use configure with larger index type\n"
-                   "vlistID=%d, varID=%d, variable size=%zu",
-                   vlistID, varID, (size_t) size);
-        }
+      errno = EOVERFLOW;
+      SysError("CDI Variable too large for YAXT,"
+               " use configure with larger index type\n"
+               "vlistID=%d, varID=%d, variable size=%zu",
+               vlistID, varID, (size_t) size);
     }
+  }
 }
 
 static void
@@ -156,22 +150,22 @@ cdiPioClientStreamDefVlist_(int streamID, int vlistID)
   cdiPioClientStreamDefVlistCommon(streamID, vlistID);
   struct ResHListUpdate rup = cdiPioClientUpdateResHList();
   if (rup.sendRPCData)
+  {
+    MPI_Comm comm = rup.comm;
+    unsigned char *msgBuffer = rup.msgBuffer;
+    /* optimize: pos + size */
+    int msgSize = rup.msgSize;
     {
-      MPI_Comm comm = rup.comm;
-      unsigned char *msgBuffer = rup.msgBuffer;
-      /* optimize: pos + size */
-      int msgSize = rup.msgSize;
-      {
-        int size;
-        xmpi(MPI_Pack_size(defVlistNInts, MPI_INT, comm, &size));
-        msgSize += size;
-      }
-      msgBuffer = Realloc(msgBuffer, (size_t) msgSize);
-      int msgData[defVlistNInts] = { streamID, streamInqVlist(streamID) };
-      xmpi(MPI_Pack(&msgData, defVlistNInts, MPI_INT, msgBuffer, msgSize, &rup.msgPos, comm));
-      xmpi(MPI_Send(msgBuffer, rup.msgPos, MPI_PACKED, rup.collRank, STREAMDEFVLIST, comm));
-      Free(msgBuffer);
+      int size;
+      xmpi(MPI_Pack_size(defVlistNInts, MPI_INT, comm, &size));
+      msgSize += size;
     }
+    msgBuffer = Realloc(msgBuffer, (size_t) msgSize);
+    int msgData[defVlistNInts] = { streamID, streamInqVlist(streamID) };
+    xmpi(MPI_Pack(&msgData, defVlistNInts, MPI_INT, msgBuffer, msgSize, &rup.msgPos, comm));
+    xmpi(MPI_Send(msgBuffer, rup.msgPos, MPI_PACKED, rup.collRank, STREAMDEFVLIST, comm));
+    Free(msgBuffer);
+  }
   struct collSpec cspec = {
     .numClients = rup.numClients, .numServers = rup.numColl, .sendRPCData = rup.sendRPCData, .partDesc = NULL, .conversion = NULL
   };
@@ -190,20 +184,20 @@ sizePartDescPresetPack(size_t nVars, const struct partDescPreset clientDeco, boo
     packSize += (int) nVars * sizeXtUID;
   }
   for (size_t varIdx = 0; varIdx < nVars; ++varIdx)
-    {
-      Xt_uid uid = uids[varIdx];
-      for (size_t j = 0; j < varIdx; ++j)
-        if (uids[j] != uid)
-          ;
-        else
-          {
-            isDuplicate[varIdx] = true;
-            goto next_index_list;
-          }
-      isDuplicate[varIdx] = false;
-      packSize += (int) xt_idxlist_get_pack_size(partDesc[varIdx], comm);
-    next_index_list:;
-    }
+  {
+    Xt_uid uid = uids[varIdx];
+    for (size_t j = 0; j < varIdx; ++j)
+      if (uids[j] != uid)
+        ;
+      else
+      {
+        isDuplicate[varIdx] = true;
+        goto next_index_list;
+      }
+    isDuplicate[varIdx] = false;
+    packSize += (int) xt_idxlist_get_pack_size(partDesc[varIdx], comm);
+  next_index_list:;
+  }
   return packSize;
 }
 
@@ -215,10 +209,10 @@ packPartDescPreset(void *packBuf, int bufSize, size_t nVars, struct partDescPres
   Xt_idxlist *partDesc = clientDeco.lists;
   int position = 0;
   for (size_t varIdx = 0; varIdx < nVars; ++varIdx)
-    {
-      xmpi(MPI_Pack((void *) (uids + varIdx), 1, YAXT_UID_DT, packBuf, bufSize, &position, comm));
-      if (!isDuplicate[varIdx]) xt_idxlist_pack(partDesc[varIdx], packBuf, bufSize, &position, comm);
-    }
+  {
+    xmpi(MPI_Pack((void *) (uids + varIdx), 1, YAXT_UID_DT, packBuf, bufSize, &position, comm));
+    if (!isDuplicate[varIdx]) xt_idxlist_pack(partDesc[varIdx], packBuf, bufSize, &position, comm);
+  }
   return position;
 }
 
@@ -239,60 +233,60 @@ cdiPioStreamDefDecomposedVlist(int streamID, int vlistID, const Xt_idxlist partD
   bool *partDescDuplicates = Malloc(nVars * sizeof(*partDescDuplicates));
   int listPackSizeTotal = sizePartDescPresetPack(nVars, clientDeco, partDescDuplicates, comm);
   if (rup.sendRPCData)
+  {
+    unsigned char *msgBuffer = rup.msgBuffer;
+    /* optimize: pos + size */
+    int msgSize = rup.msgSize;
+    /* TODO: find size of idxlists for packing */
+    int(*listPackSizes) = Malloc((size_t) numClientsInGroup * sizeof(*listPackSizes));
+    listPackSizes[0] = listPackSizeTotal;
+    MPI_Request *req = (numClientsInGroup - 1) ? Malloc((size_t) (numClientsInGroup - 1) * sizeof(*req)) : NULL;
+    for (int rank = rup.clientRank + 1; rank <= lastClientInGroup; ++rank)
     {
-      unsigned char *msgBuffer = rup.msgBuffer;
-      /* optimize: pos + size */
-      int msgSize = rup.msgSize;
-      /* TODO: find size of idxlists for packing */
-      int(*listPackSizes) = Malloc((size_t) numClientsInGroup * sizeof(*listPackSizes));
-      listPackSizes[0] = listPackSizeTotal;
-      MPI_Request *req = (numClientsInGroup - 1) ? Malloc((size_t) (numClientsInGroup - 1) * sizeof(*req)) : NULL;
-      for (int rank = rup.clientRank + 1; rank <= lastClientInGroup; ++rank)
-        {
-          size_t rankOfs = (size_t) (rank - clientRank);
-          xmpi(MPI_Irecv(listPackSizes + rankOfs, 1, MPI_INT, rank, IDXLIST_PRESET_SIZE, aggComm, req + rankOfs - 1));
-        }
-      xmpi(MPI_Waitall(numClientsInGroup - 1, req, MPI_STATUSES_IGNORE));
-      for (int rank = rup.clientRank; rank <= lastClientInGroup; ++rank)
-        {
-          size_t rankOfs = (size_t) (rank - clientRank);
-          msgSize += listPackSizes[rankOfs];
-        }
-      {
-        int size;
-        xmpi(MPI_Pack_size(defVlistNInts + (int) nVars, MPI_INT, comm, &size));
-        msgSize += size;
-      }
-      /* size of extra packaging:  */
-      msgBuffer = Realloc(msgBuffer, (size_t) msgSize);
-      int msgData[defVlistNInts] = { streamID, streamInqVlist(streamID) };
-      xmpi(MPI_Pack(&msgData, defVlistNInts, MPI_INT, msgBuffer, msgSize, &rup.msgPos, comm));
-      xmpi(MPI_Pack((int *) conversion, (int) nVars, MPI_INT, msgBuffer, msgSize, &rup.msgPos, comm));
-      rup.msgPos += packPartDescPreset(msgBuffer + rup.msgPos, listPackSizeTotal, nVars, clientDeco, partDescDuplicates, comm);
-      for (int rank = rup.clientRank + 1; rank <= lastClientInGroup; ++rank)
-        {
-          size_t rankOfs = (size_t) (rank - clientRank);
-          int clientPackSize = listPackSizes[rankOfs];
-          xmpi(MPI_Irecv(msgBuffer + rup.msgPos, clientPackSize, MPI_PACKED, rank, IDXLIST_PRESET, aggComm, req + rankOfs - 1));
-          rup.msgPos += clientPackSize;
-        }
-      xmpi(MPI_Waitall(numClientsInGroup - 1, req, MPI_STATUSES_IGNORE));
-      xmpi(MPI_Send(msgBuffer, rup.msgPos, MPI_PACKED, collRank, STREAM_DEF_DECOMPOSED_VLIST, comm));
-      Free(msgBuffer);
-      Free(req);
-      Free(listPackSizes);
+      size_t rankOfs = (size_t) (rank - clientRank);
+      xmpi(MPI_Irecv(listPackSizes + rankOfs, 1, MPI_INT, rank, IDXLIST_PRESET_SIZE, aggComm, req + rankOfs - 1));
     }
+    xmpi(MPI_Waitall(numClientsInGroup - 1, req, MPI_STATUSES_IGNORE));
+    for (int rank = rup.clientRank; rank <= lastClientInGroup; ++rank)
+    {
+      size_t rankOfs = (size_t) (rank - clientRank);
+      msgSize += listPackSizes[rankOfs];
+    }
+    {
+      int size;
+      xmpi(MPI_Pack_size(defVlistNInts + (int) nVars, MPI_INT, comm, &size));
+      msgSize += size;
+    }
+    /* size of extra packaging:  */
+    msgBuffer = Realloc(msgBuffer, (size_t) msgSize);
+    int msgData[defVlistNInts] = { streamID, streamInqVlist(streamID) };
+    xmpi(MPI_Pack(&msgData, defVlistNInts, MPI_INT, msgBuffer, msgSize, &rup.msgPos, comm));
+    xmpi(MPI_Pack((int *) conversion, (int) nVars, MPI_INT, msgBuffer, msgSize, &rup.msgPos, comm));
+    rup.msgPos += packPartDescPreset(msgBuffer + rup.msgPos, listPackSizeTotal, nVars, clientDeco, partDescDuplicates, comm);
+    for (int rank = rup.clientRank + 1; rank <= lastClientInGroup; ++rank)
+    {
+      size_t rankOfs = (size_t) (rank - clientRank);
+      int clientPackSize = listPackSizes[rankOfs];
+      xmpi(MPI_Irecv(msgBuffer + rup.msgPos, clientPackSize, MPI_PACKED, rank, IDXLIST_PRESET, aggComm, req + rankOfs - 1));
+      rup.msgPos += clientPackSize;
+    }
+    xmpi(MPI_Waitall(numClientsInGroup - 1, req, MPI_STATUSES_IGNORE));
+    xmpi(MPI_Send(msgBuffer, rup.msgPos, MPI_PACKED, collRank, STREAM_DEF_DECOMPOSED_VLIST, comm));
+    Free(msgBuffer);
+    Free(req);
+    Free(listPackSizes);
+  }
   else
-    {
-      int groupLeader = rup.groupLeader;
-      MPI_Request req[2];
-      unsigned char *ilPackBuf = Malloc((size_t) listPackSizeTotal);
-      int position = packPartDescPreset(ilPackBuf, listPackSizeTotal, nVars, clientDeco, partDescDuplicates, comm);
-      xmpi(MPI_Isend(&position, 1, MPI_INT, groupLeader, IDXLIST_PRESET_SIZE, aggComm, req));
-      xmpi(MPI_Isend(ilPackBuf, position, MPI_PACKED, groupLeader, IDXLIST_PRESET, aggComm, req + 1));
-      xmpi(MPI_Waitall(2, req, MPI_STATUSES_IGNORE));
-      Free(ilPackBuf);
-    }
+  {
+    int groupLeader = rup.groupLeader;
+    MPI_Request req[2];
+    unsigned char *ilPackBuf = Malloc((size_t) listPackSizeTotal);
+    int position = packPartDescPreset(ilPackBuf, listPackSizeTotal, nVars, clientDeco, partDescDuplicates, comm);
+    xmpi(MPI_Isend(&position, 1, MPI_INT, groupLeader, IDXLIST_PRESET_SIZE, aggComm, req));
+    xmpi(MPI_Isend(ilPackBuf, position, MPI_PACKED, groupLeader, IDXLIST_PRESET, aggComm, req + 1));
+    xmpi(MPI_Waitall(2, req, MPI_STATUSES_IGNORE));
+    Free(ilPackBuf);
+  }
   Free(partDescDuplicates);
   struct collSpec cspec = { .numClients = rup.numClients,
                             .numServers = rup.numColl,
@@ -316,7 +310,7 @@ cdiPioClientStreamWriteVar_(int streamID, int varID, int memtype, const void *da
     xabort("data type does not match pre-declared conversion for stream %d,"
            " variable ID %d!",
            streamID, varID);
-  cdiPioStreamWriteVarPart_(streamID, varID, memtype, data, numMissVals, clientDeco.lists[varID]);
+  cdiPioStreamWriteVarPart_(streamID, varID, memtype, data, (SizeType) numMissVals, clientDeco.lists[varID]);
 }
 
 static struct cdiPioIdxlistCache *clientIdxlistCache;
@@ -329,12 +323,12 @@ cdiPioClientStreamWriteVarChunk_(int streamID, int varID, int memtype, const int
   if (memtype != MEMTYPE_DOUBLE && memtype != MEMTYPE_FLOAT) Error("Writing of type data %d not implemented!", memtype);
   int vlistID = streamInqVlist(streamID);
   if (indexOfID(&seenStreamWriteVarChunk, vlistID) == SIZE_MAX)
-    {
-      insertID(&seenStreamWriteVarChunk, vlistID);
-      int nvars = vlistNvars(vlistID);
-      neededClientIdxlistCacheSize += (size_t) nvars;
-      clientIdxlistCache = cdiPioIdxlistCacheResize(clientIdxlistCache, neededClientIdxlistCacheSize);
-    }
+  {
+    insertID(&seenStreamWriteVarChunk, vlistID);
+    int nvars = vlistNvars(vlistID);
+    neededClientIdxlistCacheSize += (size_t) nvars;
+    clientIdxlistCache = cdiPioIdxlistCacheResize(clientIdxlistCache, neededClientIdxlistCacheSize);
+  }
   int size = vlistInqVarSize(vlistID, varID), varShape[3];
   int ndims = cdiPioQueryVarDims(varShape, vlistID, varID);
   Xt_int varShapeXt[3], origin[3] = { 0, 0, 0 };
@@ -342,10 +336,10 @@ cdiPioClientStreamWriteVarChunk_(int streamID, int varID, int memtype, const int
   if (ndims == 3)
     for (int i = 0; i < 3; ++i) varShapeXt[i] = varShape[i];
   else
-    {
-      varShapeXt[0] = varShape[0];
-      varShapeXt[1] = varShape[2];
-    }
+  {
+    varShapeXt[0] = varShape[0];
+    varShapeXt[1] = varShape[2];
+  }
   for (int i = 0; i < ndims; ++i) chunkShape[i] = rect[i][1] - rect[i][0] + 1;
   size_t varSize = (size_t) varShape[0] * (size_t) varShape[1] * (size_t) varShape[2];
   xassert(varSize == (size_t) size);
@@ -385,31 +379,31 @@ cdiPioClientStreamClose(stream_t *streamptr, int recordBufIsToBeDeleted)
   struct ResHListUpdate rup = cdiPioClientUpdateResHList();
   bool needsFlush = cdiPioClientStreamNeedsFlush(streamID);
   if (rup.sendRPCData)
+  {
+    MPI_Comm comm = rup.comm;
+    unsigned char *msgBuffer = rup.msgBuffer;
+    int msgSize = rup.msgSize;
     {
-      MPI_Comm comm = rup.comm;
-      unsigned char *msgBuffer = rup.msgBuffer;
-      int msgSize = rup.msgSize;
-      {
-        int size;
-        xmpi(MPI_Pack_size(1, MPI_INT, comm, &size));
-        msgSize += size;
-      }
-      /* optimize: pos + size */
-      msgBuffer = Realloc(msgBuffer, (size_t) msgSize);
-      xmpi(MPI_Pack(&streamptr->self, 1, MPI_INT, msgBuffer, msgSize, &rup.msgPos, comm));
-      int tag = needsFlush ? STREAMFLUSHCLOSE : STREAMCLOSE;
-      xmpi(MPI_Send(msgBuffer, rup.msgPos, MPI_PACKED, collRank, tag, comm));
-      Free(msgBuffer);
+      int size;
+      xmpi(MPI_Pack_size(1, MPI_INT, comm, &size));
+      msgSize += size;
     }
+    /* optimize: pos + size */
+    msgBuffer = Realloc(msgBuffer, (size_t) msgSize);
+    xmpi(MPI_Pack(&streamptr->self, 1, MPI_INT, msgBuffer, msgSize, &rup.msgPos, comm));
+    int tag = needsFlush ? STREAMFLUSHCLOSE : STREAMCLOSE;
+    xmpi(MPI_Send(msgBuffer, rup.msgPos, MPI_PACKED, collRank, tag, comm));
+    Free(msgBuffer);
+  }
   if (needsFlush) cdiPioClientStreamWinPost(streamID);
   cdiPioClientStreamWinDestroy(streamID);
   if (recordBufIsToBeDeleted) switch (streamptr->filetype)
-      {
+    {
 #ifdef HAVE_LIBGRIB
       case CDI_FILETYPE_GRB:
       case CDI_FILETYPE_GRB2: gribContainersDelete(streamptr); break;
 #endif
-      }
+    }
 }
 
 static void
@@ -433,12 +427,12 @@ static void
 cdiPioClientVlistDestroy_(int vlistID, bool assertInternal)
 {
   if (indexOfID(&seenStreamWriteVarChunk, vlistID) != SIZE_MAX)
-    {
-      int nvars = vlistNvars(vlistID);
-      neededClientIdxlistCacheSize -= (size_t) nvars;
-      clientIdxlistCache = cdiPioIdxlistCacheResize(clientIdxlistCache, neededClientIdxlistCacheSize);
-      removeID(&seenStreamWriteVarChunk, vlistID);
-    }
+  {
+    int nvars = vlistNvars(vlistID);
+    neededClientIdxlistCacheSize -= (size_t) nvars;
+    clientIdxlistCache = cdiPioIdxlistCacheResize(clientIdxlistCache, neededClientIdxlistCacheSize);
+    removeID(&seenStreamWriteVarChunk, vlistID);
+  }
   cdiVlistDestroy_(vlistID, assertInternal);
 }
 
