@@ -5,14 +5,19 @@
 #include <stdio.h>
 #include <stdlib.h>
 
-#include "pio_comm.h"
+#include <mpi.h>
+#include <yaxt.h>
+
 #include "cdi.h"
 #include "dmemory.h"
+
+#include "pio.h"
+#include "pio_comm.h"
 #include "pio_util.h"
 
 #include "cdipio.h"
 
-typedef struct
+struct cdiPioComms
 {
   int IOMode;
   int isProcIO;
@@ -56,17 +61,14 @@ typedef struct
    * sequence they have on their own communicator.
    */
   MPI_Comm collClientIntraComm;
-} pioInfo_t;
+};
 
-static pioInfo_t *info = NULL;
-
-static void setupCollectorInterComm(pioInfo_t *p, int isCollector, MPI_Comm localGroupComm, int globRankOfGroupLeader[2]);
+static void setupCollectorInterComm(struct cdiPioComms *p, int isCollector, MPI_Comm localGroupComm, int globRankOfGroupLeader[2]);
 
 static void
-pioInfoInit(pioInfo_t *p, MPI_Comm commGlob, int clientServerRole)
+pioInfoInit(struct cdiPioComms *p, MPI_Comm commGlob, int clientServerRole)
 {
-  xassert(info != NULL && commGlob != MPI_COMM_NULL);
-  p->IOMode = -1;
+  xassert(p && commGlob != MPI_COMM_NULL);
 
   xmpi(MPI_Comm_dup(commGlob, &p->commGlob));
   xmpi(MPI_Comm_size(p->commGlob, &p->sizeGlob));
@@ -95,22 +97,22 @@ pioInfoInit(pioInfo_t *p, MPI_Comm commGlob, int clientServerRole)
     };
     int globRankOfGroupLeader[numGroups] = { 0, 0 };
     if (isProcIO)
-      {
-        p->commPio = temp;
-        xmpi(MPI_Comm_rank(temp, &p->rankPio));
-        p->commCalc = MPI_COMM_NULL;
-        p->rankCalc = -1;
-        if (p->rankPio == 0) globRankOfGroupLeader[PIO] = p->rankGlob;
-      }
+    {
+      p->commPio = temp;
+      xmpi(MPI_Comm_rank(temp, &p->rankPio));
+      p->commCalc = MPI_COMM_NULL;
+      p->rankCalc = -1;
+      if (p->rankPio == 0) globRankOfGroupLeader[PIO] = p->rankGlob;
+    }
     else
-      {
-        p->commPio = MPI_COMM_NULL;
-        p->rankPio = -1;
-        p->commCalc = temp;
-        xmpi(MPI_Comm_rank(temp, &p->rankCalc));
-        xmpi(MPI_Comm_size(temp, &p->sizeCalc));
-        if (p->rankCalc == 0) globRankOfGroupLeader[Client] = p->rankGlob;
-      }
+    {
+      p->commPio = MPI_COMM_NULL;
+      p->rankPio = -1;
+      p->commCalc = temp;
+      xmpi(MPI_Comm_rank(temp, &p->rankCalc));
+      xmpi(MPI_Comm_size(temp, &p->sizeCalc));
+      if (p->rankCalc == 0) globRankOfGroupLeader[Client] = p->rankGlob;
+    }
     int nProcsIO;
     {
       enum
@@ -127,31 +129,42 @@ pioInfoInit(pioInfo_t *p, MPI_Comm commGlob, int clientServerRole)
       globRankOfGroupLeader[1] = iBuf[3];
     }
     if (isProcIO)
+    {
+      MPI_Group pioGroup, collGroup;
+      int collRange[1][3] = { { 0, p->sizeColl - 1, 1 } };
+      xmpi(MPI_Comm_group(p->commPio, &pioGroup));
+      xmpi(MPI_Group_range_incl(pioGroup, 1, collRange, &collGroup));
+      xmpi(MPI_Comm_create(p->commPio, collGroup, &temp));
+      if (isCollector)
       {
-        MPI_Group pioGroup, collGroup;
-        int collRange[1][3] = { { 0, p->sizeColl - 1, 1 } };
-        xmpi(MPI_Comm_group(p->commPio, &pioGroup));
-        xmpi(MPI_Group_range_incl(pioGroup, 1, collRange, &collGroup));
-        xmpi(MPI_Comm_create(p->commPio, collGroup, &temp));
-        if (isCollector) xmpi(MPI_Comm_rank(temp, &p->rankColl));
-        xmpi(MPI_Group_free(&pioGroup));
-        xmpi(MPI_Group_free(&collGroup));
-        p->commColl = temp;
+        xmpi(MPI_Comm_rank(temp, &p->rankColl));
+        xt_mpi_comm_mark_exclusive(temp);
       }
+      xmpi(MPI_Group_free(&pioGroup));
+      xmpi(MPI_Group_free(&collGroup));
+      p->commColl = temp;
+    }
     if (isCollector || !isProcIO)
       setupCollectorInterComm(p, isCollector, temp, globRankOfGroupLeader);
     else /* isProcIO && !isCollector */
-      {
-        p->pioInterComm = MPI_COMM_NULL;
-        p->collClientIntraComm = MPI_COMM_NULL;
-        p->remoteGroup = MPI_GROUP_NULL;
-      }
+    {
+      p->pioInterComm = MPI_COMM_NULL;
+      p->collClientIntraComm = MPI_COMM_NULL;
+      p->remoteGroup = MPI_GROUP_NULL;
+    }
+
+    /* match output method and process distribution */
+    int IOMode = p->IOMode, sizeGlob = p->sizeGlob;
+    if (((IOMode != PIO_NONE && (nProcsIO <= 0 || nProcsIO > sizeGlob - 1))) || (IOMode == PIO_NONE && nProcsIO != 1))
+      xabort("DISTRIBUTION OF TASKS ON PROCS IS NOT VALID.\n"
+             "nProcsIO=%d, sizeGlob=%d\n",
+             nProcsIO, sizeGlob);
   }
 }
 
 /* create client <-> collector intercomm and fill-in related information */
 static void
-setupCollectorInterComm(pioInfo_t *p, int isCollector, MPI_Comm localGroupComm, int globRankOfGroupLeader[2])
+setupCollectorInterComm(struct cdiPioComms *p, int isCollector, MPI_Comm localGroupComm, int globRankOfGroupLeader[2])
 {
   xmpi(MPI_Intercomm_create(localGroupComm, 0, p->commGlob, globRankOfGroupLeader[isCollector], 1, &p->pioInterComm));
   xmpi(MPI_Intercomm_merge(p->pioInterComm, isCollector, &p->collClientIntraComm));
@@ -160,211 +173,216 @@ setupCollectorInterComm(pioInfo_t *p, int isCollector, MPI_Comm localGroupComm,
   xmpi(MPI_Comm_group(p->collClientIntraComm, &collClientGroup));
   int numClients = p->sizeCalc, numColl = p->sizeColl;
   if (isCollector)
-    {
-      int collRank = p->rankColl;
-      remoteRanksRange[0] = cdiPioClientRangeStart(collRank, numClients, numColl);
-      remoteRanksRange[1] = cdiPioClientRangeStart(collRank + 1, numClients, numColl) - 1;
-    }
+  {
+    int collRank = p->rankColl;
+    remoteRanksRange[0] = cdiPioClientRangeStart(collRank, numClients, numColl);
+    remoteRanksRange[1] = cdiPioClientRangeStart(collRank + 1, numClients, numColl) - 1;
+  }
   else /* !isProcIO i.e. is client */
-    {
-      int clientRank = p->rankCalc;
-      int collRank = cdiPioCollRank(clientRank, numClients, numColl);
-      remoteRanksRange[1] = remoteRanksRange[0] = numClients + collRank;
-    }
+  {
+    int clientRank = p->rankCalc;
+    int collRank = cdiPioCollRank(clientRank, numClients, numColl);
+    remoteRanksRange[1] = remoteRanksRange[0] = numClients + collRank;
+  }
   remoteRanksRange[2] = 1;
   xmpi(MPI_Group_range_incl(collClientGroup, 1, &remoteRanksRange, &p->remoteGroup));
   xmpi(MPI_Group_free(&collClientGroup));
 }
 
-int
+void
 cdiPioCommInit(MPI_Comm commGlob, int IOMode, int clientServerRole)
 {
-  xassert(info == NULL && IOMode >= PIO_MINIOMODE && IOMode <= PIO_MAXIOMODE);
-  info = Malloc(sizeof(*info));
-  pioInfoInit(info, commGlob, clientServerRole);
+  xassert(IOMode >= PIO_MINIOMODE && IOMode <= PIO_MAXIOMODE);
+  if (cdiPioExtraNSKeys[cdiPioEKComms] == 0) cdiPioExtraNSKeys[cdiPioEKComms] = cdiNamespaceSwitchNewKey();
+  struct cdiPioComms *info = Malloc(sizeof(*info));
+  namespaceSwitchSet(cdiPioExtraNSKeys[cdiPioEKComms], NSSW_DATA(info));
   info->IOMode = IOMode;
-  return info->sizePio;
+  pioInfoInit(info, commGlob, clientServerRole);
 }
 
 void
 cdiPioCommFinalize(void)
 {
-  xassert(info != NULL);
+  xassert(cdiPioExtraNSKeys[cdiPioEKComms] != 0);
+  struct cdiPioComms *info = namespaceSwitchGet(cdiPioExtraNSKeys[cdiPioEKComms]).data;
 
-  MPI_Comm *comms[]
-      = { &info->commGlob, &info->commPio, &info->commColl, &info->commCalc, &info->pioInterComm, &info->collClientIntraComm };
+  {
+    MPI_Comm *comms[]
+        = { &info->commGlob, &info->commPio, &info->commColl, &info->commCalc, &info->pioInterComm, &info->collClientIntraComm };
 
-  for (size_t i = 0; i < sizeof(comms) / sizeof(comms[0]); ++i)
-    if (*comms[i] != MPI_COMM_NULL) xmpi(MPI_Comm_free(comms[i]));
+    for (size_t i = 0; i < sizeof(comms) / sizeof(comms[0]); ++i)
+      if (*comms[i] != MPI_COMM_NULL) xmpi(MPI_Comm_free(comms[i]));
+  }
 
-  MPI_Group *groups[] = { &info->remoteGroup };
-  for (size_t i = 0; i < sizeof(groups) / sizeof(groups[0]); ++i)
-    if (*groups[i] != MPI_GROUP_NULL) xmpi(MPI_Group_free(groups[i]));
+  {
+    MPI_Group *groups[] = { &info->remoteGroup };
+    for (size_t i = 0; i < sizeof(groups) / sizeof(groups[0]); ++i)
+      if (*groups[i] != MPI_GROUP_NULL) xmpi(MPI_Group_free(groups[i]));
+  }
 
   Free(info);
-  info = NULL;
+  namespaceSwitchSet(cdiPioExtraNSKeys[cdiPioEKComms], NSSW_DATA(NULL));
 }
 
 MPI_Comm
 commInqCommGlob(void)
 {
-  xassert(info != NULL && info->commGlob != MPI_COMM_NULL);
+  struct cdiPioComms *info = namespaceSwitchGet(cdiPioExtraNSKeys[cdiPioEKComms]).data;
+  xassert(info && info->commGlob != MPI_COMM_NULL);
   return info->commGlob;
 }
 
 int
 commInqSizeGlob(void)
 {
-  xassert(info != NULL && info->sizeGlob != CDI_UNDEFID);
+  struct cdiPioComms *info = namespaceSwitchGet(cdiPioExtraNSKeys[cdiPioEKComms]).data;
+  xassert(info && info->sizeGlob != CDI_UNDEFID);
   return info->sizeGlob;
 }
 
 int
 commInqRankGlob(void)
 {
-  xassert(info != NULL && info->rankGlob != CDI_UNDEFID);
+  struct cdiPioComms *info = namespaceSwitchGet(cdiPioExtraNSKeys[cdiPioEKComms]).data;
+  xassert(info && info->rankGlob != -1);
   return info->rankGlob;
 }
 
-int
-commInqRootGlob(void)
-{
-  xassert(info != NULL && info->root != CDI_UNDEFID);
-  return info->root;
-}
-
-int
-cdiPioInqCollectorOfClient(void)
-{
-  xassert(info != NULL);
-  int clientRank = commInqRankModel(), numClients = cdiPioCommInqSizeClients(), numServers = commInqSizeColl(),
-      numClientsPerServer = (numClients + numServers - 1) / numServers, collRank = clientRank / numClientsPerServer;
-  return (!info->isProcIO) ? collRank : -1;
-}
-
 MPI_Group
 cdiPioInqRemoteGroup(void)
 {
-  xassert(info != NULL);
+  struct cdiPioComms *info = namespaceSwitchGet(cdiPioExtraNSKeys[cdiPioEKComms]).data;
+  xassert(info);
   return info->remoteGroup;
 }
 
 int
 commInqIsProcIO(void)
 {
-  xassert(info != NULL && info->isProcIO != CDI_UNDEFID);
+  struct cdiPioComms *info = namespaceSwitchGet(cdiPioExtraNSKeys[cdiPioEKComms]).data;
+  xassert(info && info->isProcIO != CDI_UNDEFID);
   return info->isProcIO;
 }
 
 int
 commInqIOMode(void)
 {
+  struct cdiPioComms *info
+      = cdiPioExtraNSKeys[cdiPioEKComms] == 0 ? NULL : namespaceSwitchGet(cdiPioExtraNSKeys[cdiPioEKComms]).data;
   return info != NULL ? info->IOMode : PIO_NONE;
 }
 
 MPI_Comm
 commInqCommPio(void)
 {
-  xassert(info != NULL && info->commPio != MPI_COMM_NULL && info->isProcIO == 1);
+  struct cdiPioComms *info = namespaceSwitchGet(cdiPioExtraNSKeys[cdiPioEKComms]).data;
+  xassert(info && info->commPio != MPI_COMM_NULL && info->isProcIO == 1);
   return info->commPio;
 }
 
 int
 commInqSizePio(void)
 {
-  xassert(info != NULL && info->sizePio > 0);
+  struct cdiPioComms *info = namespaceSwitchGet(cdiPioExtraNSKeys[cdiPioEKComms]).data;
+  xassert(info && info->sizePio > 0);
   return info->sizePio;
 }
 
 MPI_Comm
 commInqCommModel(void)
 {
-  xassert(info != NULL && info->commCalc != MPI_COMM_NULL && info->isProcIO == 0);
+  struct cdiPioComms *info = namespaceSwitchGet(cdiPioExtraNSKeys[cdiPioEKComms]).data;
+  xassert(info && info->commCalc != MPI_COMM_NULL && info->isProcIO == 0);
   return info->commCalc;
 }
 
 int
 commInqRankPio(void)
 {
-  xassert(info != NULL && info->rankPio >= 0 && info->isProcIO == 1);
+  struct cdiPioComms *info = namespaceSwitchGet(cdiPioExtraNSKeys[cdiPioEKComms]).data;
+  xassert(info && info->rankPio >= 0 && info->isProcIO == 1);
   return info->rankPio;
 }
 
 int
 commInqRankModel(void)
 {
-  xassert(info != NULL && info->rankCalc >= 0 && info->isProcIO == 0);
+  struct cdiPioComms *info = namespaceSwitchGet(cdiPioExtraNSKeys[cdiPioEKComms]).data;
+  xassert(info && info->rankCalc >= 0 && info->isProcIO == 0);
   return info->rankCalc;
 }
 
 int
 cdiPioCommInqSizeClients(void)
 {
-  xassert(info != NULL && info->sizeCalc >= 0);
+  struct cdiPioComms *info = namespaceSwitchGet(cdiPioExtraNSKeys[cdiPioEKComms]).data;
+  xassert(info && info->sizeCalc >= 0);
   return info->sizeCalc;
 }
 
 MPI_Comm
 commInqCommColl(void)
 {
-  xassert(info != NULL && info->commColl != MPI_COMM_NULL);
+  struct cdiPioComms *info = namespaceSwitchGet(cdiPioExtraNSKeys[cdiPioEKComms]).data;
+  xassert(info && info->commColl != MPI_COMM_NULL);
   return info->commColl;
 }
 
 int
 commInqSizeColl(void)
 {
-  xassert(info != NULL && info->sizeColl >= 0);
+  struct cdiPioComms *info = namespaceSwitchGet(cdiPioExtraNSKeys[cdiPioEKComms]).data;
+  xassert(info && info->sizeColl >= 0);
   return info->sizeColl;
 }
 
 int
 commInqRankColl(void)
 {
-  xassert(info != NULL);
+  struct cdiPioComms *info = namespaceSwitchGet(cdiPioExtraNSKeys[cdiPioEKComms]).data;
+  xassert(info);
   return info->rankColl;
 }
 
 MPI_Comm
 cdiPioInqInterComm(void)
 {
-  xassert(info != NULL);
+  struct cdiPioComms *info = namespaceSwitchGet(cdiPioExtraNSKeys[cdiPioEKComms]).data;
+  xassert(info);
   return info->pioInterComm;
 }
 
 MPI_Comm
 cdiPioInqCollClientIntraComm(void)
 {
-  xassert(info != NULL);
+  struct cdiPioComms *info = namespaceSwitchGet(cdiPioExtraNSKeys[cdiPioEKComms]).data;
+  xassert(info);
   return info->collClientIntraComm;
 }
 
 int
 commInqSpecialRank(void)
 {
-  xassert(info != NULL);
+  struct cdiPioComms *info = namespaceSwitchGet(cdiPioExtraNSKeys[cdiPioEKComms]).data;
+  xassert(info);
   return info->sizeColl;
 }
 
 MPI_Comm
 commInqCommCalc(void)
 {
-  xassert(info != NULL && info->commCalc != MPI_COMM_NULL);
+  struct cdiPioComms *info = namespaceSwitchGet(cdiPioExtraNSKeys[cdiPioEKComms]).data;
+  xassert(info && info->commCalc != MPI_COMM_NULL);
   return info->commCalc;
 }
 
-int
-commInqNProcsColl(void)
-{
-  xassert(info != NULL && info->sizeColl != CDI_UNDEFID);
-  return info->sizeColl;
-}
-
 void
 commPrint(FILE *fp)
 {
   if (ddebug == 0) return;
 
+  struct cdiPioComms *info = namespaceSwitchGet(cdiPioExtraNSKeys[cdiPioEKComms]).data;
+
   xassert(info != NULL);
 
   fprintf(fp, "\n");
@@ -376,7 +394,6 @@ commPrint(FILE *fp)
   fprintf(fp, "# commGlob    = %d\n", (int) MPI_Comm_c2f(info->commGlob));
   fprintf(fp, "# sizeGlob    = %d\n", info->sizeGlob);
   fprintf(fp, "# rankGlob    = %d\n", info->rankGlob);
-  fprintf(fp, "# root        = %d\n", info->root);
   fprintf(fp, "#\n");
   fprintf(fp, "# commPio     = %d\n", (int) MPI_Comm_c2f(info->commPio));
   fprintf(fp, "# sizePio     = %d\n", info->sizePio);
