@@ -40,10 +40,10 @@ mapSearchStr(const struct intCodeStrMap map[], size_t mapSize, const char *str)
   size_t retval = SIZE_MAX;
   for (size_t i = 0; i < mapSize; ++i)
     if (!strcmp(str, map[i].text))
-      {
-        retval = i;
-        break;
-      }
+    {
+      retval = i;
+      break;
+    }
   return retval;
 }
 
@@ -53,10 +53,10 @@ mapSearchCode(const struct intCodeStrMap map[], size_t mapSize, int code)
   size_t retval = SIZE_MAX;
   for (size_t i = 0; i < mapSize; ++i)
     if (code == map[i].code)
-      {
-        retval = i;
-        break;
-      }
+    {
+      retval = i;
+      break;
+    }
   return retval;
 }
 
@@ -164,16 +164,16 @@ findWriteAccumBufsize()
   size_t buffersize = (size_t) 16 * 1024 * 1024;
   const char *p = getenv("BUFSIZE");
   if (p)
+  {
+    char *end;
+    long temp = strtol(p, &end, 0);
+    if ((errno == ERANGE && (temp == LONG_MAX || temp == LONG_MIN)) || (errno != 0 && temp == 0))
     {
-      char *end;
-      long temp = strtol(p, &end, 0);
-      if ((errno == ERANGE && (temp == LONG_MAX || temp == LONG_MIN)) || (errno != 0 && temp == 0))
-        {
-          perror("failed to parse BUFSIZE environment variable");
-        }
-      else if (temp > 0 && (unsigned long) temp > buffersize)
-        buffersize = (unsigned long) temp;
+      perror("failed to parse BUFSIZE environment variable");
     }
+    else if (temp > 0 && (unsigned long) temp > buffersize)
+      buffersize = (unsigned long) temp;
+  }
   return buffersize;
 }
 
@@ -255,10 +255,7 @@ void
 cdiPioConfSetCallBackActions(int confResH, int trigger, void (*callback)(void))
 {
   struct cdiPioConf *conf = reshGetVal(confResH, &cdiPioConfOps);
-  if (trigger >= 0 && trigger < CDIPIO_NUM_CALLBACKS)
-    {
-      conf->callbacks[trigger] = callback;
-    }
+  if (trigger >= 0 && trigger < CDIPIO_NUM_CALLBACKS) { conf->callbacks[trigger] = callback; }
   else
     Error("invalid trigger callback query: %d", trigger);
 }
@@ -267,10 +264,7 @@ void (*cdiPioConfGetCallBackActions(int confResH, int trigger))(void)
 {
   void (*callback)(void) = (void (*)(void)) 0;
   struct cdiPioConf *conf = reshGetVal(confResH, &cdiPioConfOps);
-  if (trigger >= 0 && trigger < CDIPIO_NUM_CALLBACKS)
-    {
-      callback = conf->callbacks[trigger];
-    }
+  if (trigger >= 0 && trigger < CDIPIO_NUM_CALLBACKS) { callback = conf->callbacks[trigger]; }
   else
     Error("invalid trigger callback query: %d", trigger);
   return callback;
