@@ -8,11 +8,10 @@
 int iegInqContents(stream_t *streamptr);
 int iegInqTimestep(stream_t *streamptr, int tsID);
 
-int iegInqRecord(stream_t *streamptr, int *varID, int *levelID);
-void iegDefRecord(stream_t *streamptr);
-void iegCopyRecord(stream_t *streamptr2, stream_t *streamptr1);
-void ieg_read_record(stream_t *streamptr, int memtype, void *data, size_t *numMissVals);
-void ieg_write_record(stream_t *streamptr, int memtype, const void *data);
+void iegDefField(stream_t *streamptr);
+void iegCopyField(stream_t *streamptr2, stream_t *streamptr1);
+void ieg_read_field(stream_t *streamptr, int memtype, void *data, size_t *numMissVals);
+void ieg_write_field(stream_t *streamptr, int memtype, const void *data);
 
 void iegReadVarDP(stream_t *streamptr, int varID, double *data, size_t *numMissVals);
 void iegWriteVarDP(stream_t *streamptr, int varID, const double *data);
