@@ -24,7 +24,7 @@
 #include "field_functions.h"
 
 static double
-dayofyear(int calendar, const CdiDateTime &vDateTime)
+dayofyear(int calendar, CdiDateTime const &vDateTime)
 {
   constexpr int month_360[12] = { 30, 30, 30, 30, 30, 30, 30, 30, 30, 30, 30, 30 };
   constexpr int month_365[12] = { 31, 28, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31 };
@@ -39,10 +39,10 @@ dayofyear(int calendar, const CdiDateTime &vDateTime)
 
   double doy = 0.0;
   for (int im = 1; im < month; ++im)
-    {
-      auto dpm = (dpy == 360) ? month_360 : ((dpy == 365) ? month_365 : month_366);
-      if (im <= 12) doy += dpm[im - 1];
-    }
+  {
+    auto dpm = (dpy == 360) ? month_360 : ((dpy == 365) ? month_365 : month_366);
+    if (im <= 12) doy += dpm[im - 1];
+  }
 
   doy += (day - 1);
   doy += (second + minute * 60 + hour * 3600) / 86400.0;
@@ -76,18 +76,18 @@ public:
   };
   inline static RegisterEntry<Arithdays> registration = RegisterEntry<Arithdays>(module);
 
-  int MULDOY;
+private:
+  int MULDOY{};
 
-  CdoStreamID streamID1;
-  int taxisID1;
+  CdoStreamID streamID1{};
+  CdoStreamID streamID2{};
+  int taxisID1{ CDI_UNDEFID };
+  int taxisID2{ CDI_UNDEFID };
 
-  CdoStreamID streamID2;
-  int taxisID2;
-
-  int operatorID;
-  int operfunc;
-  int operfunc2;
-  int calendar;
+  int operatorID{};
+  int operfunc{};
+  int operfunc2{};
+  int calendar{};
 
   VarList varList1;
 
@@ -127,46 +127,45 @@ public:
 
     int tsID = 0;
     while (true)
+    {
+      auto numFields = cdo_stream_inq_timestep(streamID1, tsID);
+      if (numFields == 0) break;
+
+      auto vDateTime = taxisInqVdatetime(taxisID1);
+
+      cdo_taxis_copy_timestep(taxisID2, taxisID1);
+      cdo_def_timestep(streamID2, tsID);
+
+      int year, month, day;
+      cdiDate_decode(vDateTime.date, &year, &month, &day);
+
+      double rconst;
+      if (operatorID == MULDOY)
+        rconst = dayofyear(calendar, vDateTime);
+      else
+        rconst = (operfunc2 == Func_Month) ? days_per_month(calendar, year, month) : days_per_year(calendar, year);
+
+      if (Options::cdoVerbose) cdo_print("calendar %d  year %d  month %d  result %g", calendar, year, month, rconst);
+
+      for (int fieldID = 0; fieldID < numFields; ++fieldID)
       {
-        auto numFields = cdo_stream_inq_timestep(streamID1, tsID);
-        if (numFields == 0) break;
+        auto [varID, levelID] = cdo_inq_field(streamID1);
+        field.init(varList1.vars[varID]);
+        cdo_read_field(streamID1, field);
 
-        auto vDateTime = taxisInqVdatetime(taxisID1);
+        fieldc_function(field, rconst, operfunc);
 
-        cdo_taxis_copy_timestep(taxisID2, taxisID1);
-        cdo_def_timestep(streamID2, tsID);
-
-        int year, month, day;
-        cdiDate_decode(vDateTime.date, &year, &month, &day);
-
-        double rconst;
-        if (operatorID == MULDOY)
-          rconst = dayofyear(calendar, vDateTime);
-        else
-          rconst = (operfunc2 == Func_Month) ? days_per_month(calendar, year, month) : days_per_year(calendar, year);
-
-        if (Options::cdoVerbose) cdo_print("calendar %d  year %d  month %d  result %g", calendar, year, month, rconst);
-
-        for (int fieldID = 0; fieldID < numFields; ++fieldID)
-          {
-            auto [varID, levelID] = cdo_inq_field(streamID1);
-            field.init(varList1.vars[varID]);
-            cdo_read_field(streamID1, field);
-
-            fieldc_function(field, rconst, operfunc);
-
-            cdo_def_field(streamID2, varID, levelID);
-            cdo_write_field(streamID2, field);
-          }
-
-        tsID++;
+        cdo_def_field(streamID2, varID, levelID);
+        cdo_write_field(streamID2, field);
       }
+
+      tsID++;
+    }
   }
 
   void
   close() override
   {
-
     cdo_stream_close(streamID2);
     cdo_stream_close(streamID1);
   }
