@@ -55,7 +55,7 @@ cmor_check_init(std::vector<CmorVar> &cmorVars)
 }
 
 void
-cmor_check_eval(int vlistID, const std::vector<CmorVar> &cmorVars)
+cmor_check_eval(int vlistID, std::vector<CmorVar> const &cmorVars)
 {
   int numVars = cmorVars.size();
   for (int varID = 0; varID < numVars; ++varID)
