@@ -30,16 +30,16 @@ public:
   };
   inline static RegisterEntry<Change_e5slm> registration = RegisterEntry<Change_e5slm>(module);
 
-  int numFields;
-  size_t numMissVals;
+private:
+  int numFields{};
+  size_t numMissVals{};
 
-  CdoStreamID streamID1;
-  int taxisID1;
+  CdoStreamID streamID1{};
+  CdoStreamID streamID2{};
+  int taxisID1{ CDI_UNDEFID };
+  int taxisID2{ CDI_UNDEFID };
 
-  CdoStreamID streamID2;
-  int taxisID2;
-
-  size_t gridsize;
+  size_t gridsize{};
 
   Varray<double> array;
   Varray<double> cland;
@@ -104,31 +104,31 @@ public:
     codes = std::vector<short>(numVars);
 
     for (int varID = 0; varID < numVars; ++varID)
+    {
+      auto const &var = varList1.vars[varID];
+      if (gridsize != var.gridsize) cdo_abort("gridsize differ!");
+
+      auto code = var.code;
+      if (code < 0)
       {
-        const auto &var = varList1.vars[varID];
-        if (gridsize != var.gridsize) cdo_abort("gridsize differ!");
-
-        auto code = var.code;
-        if (code < 0)
-          {
-            // clang-format off
-            if      (var.name == "SLM")       code = 172;
-            else if (var.name == "ALAKE")     code = 99;
-            else if (var.name == "WS")        code = 140;
-            else if (var.name == "AZ0")       code = 173;
-            else if (var.name == "ALB")       code = 174;
-            else if (var.name == "VGRAT")     code = 198;
-            else if (var.name == "FOREST")    code = 212;
-            else if (var.name == "FAO")       code = 226;
-            else if (var.name == "WSMX")      code = 229;
-            else if (var.name == "GLAC")      code = 232;
-            else if (var.name == "VLTCLIM")   code = 71;
-            else if (var.name == "VGRATCLIM") code = 70;
-            // clang-format on
-          }
-
-        codes[varID] = code;
+        // clang-format off
+        if      (var.name == "SLM")       code = 172;
+        else if (var.name == "ALAKE")     code = 99;
+        else if (var.name == "WS")        code = 140;
+        else if (var.name == "AZ0")       code = 173;
+        else if (var.name == "ALB")       code = 174;
+        else if (var.name == "VGRAT")     code = 198;
+        else if (var.name == "FOREST")    code = 212;
+        else if (var.name == "FAO")       code = 226;
+        else if (var.name == "WSMX")      code = 229;
+        else if (var.name == "GLAC")      code = 232;
+        else if (var.name == "VLTCLIM")   code = 71;
+        else if (var.name == "VGRATCLIM") code = 70;
+        // clang-format on
       }
+
+      codes[varID] = code;
+    }
   }
 
   void
@@ -136,46 +136,46 @@ public:
   {
     int tsID = 0;
     while ((numFields = cdo_stream_inq_timestep(streamID1, tsID)))
+    {
+      cdo_taxis_copy_timestep(taxisID2, taxisID1);
+      cdo_def_timestep(streamID2, tsID);
+
+      for (int fieldID = 0; fieldID < numFields; ++fieldID)
       {
-        cdo_taxis_copy_timestep(taxisID2, taxisID1);
-        cdo_def_timestep(streamID2, tsID);
+        auto [varID, levelID] = cdo_inq_field(streamID1);
+        cdo_read_field(streamID1, array.data(), &numMissVals);
 
-        for (int fieldID = 0; fieldID < numFields; ++fieldID)
-          {
-            auto [varID, levelID] = cdo_inq_field(streamID1);
-            cdo_read_field(streamID1, array.data(), &numMissVals);
+        auto code = codes[varID];
+        if (code == 172)
+        {
+          cdo_print("SLM changed!");
+          for (size_t i = 0; i < gridsize; ++i) array[i] = cland[i];
+        }
+        else if (code == 99)
+        {
+          cdo_print("ALAKE set all values to zero!");
+          for (size_t i = 0; i < gridsize; ++i) array[i] = 0;
+        }
+        else if (code == 232)
+        {
+          cdo_print("GLAC set sea points to %g!", array[0]);
+          for (size_t i = 0; i < gridsize; ++i)
+            if (cland[i] < 0.5) array[i] = array[0];
+        }
+        else if (code == 70 || code == 71 || code == 140 || code == 173 || code == 174 || code == 198 || code == 200 || code == 212
+                 || code == 226 || code == 229)
+        {
+          cdo_print("Code %d set sea points to %g!", code, array[0]);
+          for (size_t i = 0; i < gridsize; ++i)
+            if (lsea[i]) array[i] = array[0];
+        }
 
-            auto code = codes[varID];
-            if (code == 172)
-              {
-                cdo_print("SLM changed!");
-                for (size_t i = 0; i < gridsize; ++i) array[i] = cland[i];
-              }
-            else if (code == 99)
-              {
-                cdo_print("ALAKE set all values to zero!");
-                for (size_t i = 0; i < gridsize; ++i) array[i] = 0;
-              }
-            else if (code == 232)
-              {
-                cdo_print("GLAC set sea points to %g!", array[0]);
-                for (size_t i = 0; i < gridsize; ++i)
-                  if (cland[i] < 0.5) array[i] = array[0];
-              }
-            else if (code == 70 || code == 71 || code == 140 || code == 173 || code == 174 || code == 198 || code == 200
-                     || code == 212 || code == 226 || code == 229)
-              {
-                cdo_print("Code %d set sea points to %g!", code, array[0]);
-                for (size_t i = 0; i < gridsize; ++i)
-                  if (lsea[i]) array[i] = array[0];
-              }
-
-            cdo_def_field(streamID2, varID, levelID);
-            cdo_write_field(streamID2, array.data(), numMissVals);
-          }
-
-        tsID++;
+        cdo_def_field(streamID2, varID, levelID);
+        cdo_write_field(streamID2, array.data(), numMissVals);
       }
+
+      tsID++;
+    }
   }
 
   void
