@@ -38,19 +38,22 @@ static Varray<double> gl_data;
 
 static int Done = 0;
 
-static int com_help(const std::string &);
-static int com_list(const std::string &);
-static int com_quit(const std::string &);
-static int com_stat(const std::string &);
-static int com_set(const std::string &);
-static int com_vars(const std::string &);
+static int com_help(std::string const &);
+static int com_list(std::string const &);
+static int com_quit(std::string const &);
+static int com_stat(std::string const &);
+static int com_set(std::string const &);
+static int com_vars(std::string const &);
 
+namespace
+{
 struct command_t
 {
-  int (*func)(const std::string &);  // Function to call to do the job.
+  int (*func)(std::string const &);  // Function to call to do the job.
   const std::string name;            // User printable name of the function.
   const std::string doc;             // Documentation for this function.
 };
+}  // namespace
 
 static const std::vector<command_t> commands = { { com_help, "help", "Display this text" },
                                                  { com_help, "?", "Synonym for 'help'" },
@@ -76,42 +79,42 @@ valid_argument(char *caller, char *arg)
 */
 // Print out help for ARG, or for all of the commands if ARG is not present.
 static int
-com_help(const std::string &arg)
+com_help(std::string const &arg)
 {
   int printed = 0;
 
   for (int i = 0; i < ncommands; ++i)
+  {
+    if (arg.empty() || (arg == commands[i].name))
     {
-      if (arg.empty() || (arg == commands[i].name))
-        {
-          printf("%s\t\t%s.\n", commands[i].name.c_str(), commands[i].doc.c_str());
-          printed++;
-        }
+      printf("%s\t\t%s.\n", commands[i].name.c_str(), commands[i].doc.c_str());
+      printed++;
     }
+  }
 
   if (!printed)
+  {
+    printf("No commands match '%s'. Possibilties are:\n", arg.c_str());
+    for (int i = 0; i < ncommands; ++i)
     {
-      printf("No commands match '%s'. Possibilties are:\n", arg.c_str());
-      for (int i = 0; i < ncommands; ++i)
-        {
-          if (printed == 6)  // Print in six columns
-            {
-              printed = 0;
-              printf("\n");
-            }
-          printf("%s\t", commands[i].name.c_str());
-          printed++;
-        }
-
-      if (printed) printf("\n");
+      if (printed == 6)  // Print in six columns
+      {
+        printed = 0;
+        printf("\n");
+      }
+      printf("%s\t", commands[i].name.c_str());
+      printed++;
     }
 
+    if (printed) printf("\n");
+  }
+
   return 0;
 }
 
 // List the file(s) named in arg
 static int
-com_list(const std::string &arg)
+com_list(std::string const &arg)
 {
   (void) (arg);
 
@@ -120,7 +123,7 @@ com_list(const std::string &arg)
 
 // The user wishes to quit using this program. Just set DONE non-zero.
 static int
-com_quit(const std::string &arg)
+com_quit(std::string const &arg)
 {
   (void) (arg);
 
@@ -130,46 +133,46 @@ com_quit(const std::string &arg)
 }
 
 static int
-com_stat(const std::string &arg)
+com_stat(std::string const &arg)
 {
   (void) (arg);  // unused
 
-  const auto &var = varList.vars[gl_varID];
+  auto const &var = varList.vars[gl_varID];
   auto name = var.name.c_str();
 
   auto tsID2 = gl_tsID2;
   if (tsID2 == -1) tsID2 = (gl_numSteps != -1) ? gl_numSteps - 1 : INT_MAX - 1;
 
   for (int tsID = gl_tsID1; tsID <= tsID2; ++tsID)
+  {
+    auto numFields = streamInqTimestep(gl_streamID, tsID);
+    if (numFields == 0)
     {
-      auto numFields = streamInqTimestep(gl_streamID, tsID);
-      if (numFields == 0)
-        {
-          if (gl_numSteps == -1)
-            gl_numSteps = tsID;
-          else
-            fprintf(stderr, "Timestep %d out of range!\n", tsID + 1);
-          break;
-        }
+      if (gl_numSteps == -1)
+        gl_numSteps = tsID;
       else
-        {
-          cdo::timer stepTimer;
-
-          auto nlevels = var.nlevels;
-          auto gridsize = var.gridsize;
-          auto missval = var.missval;
-
-          auto levelID = (nlevels > 1) ? gl_levelID : 0;
-
-          size_t numMissVals;
-          streamReadVarSlice(gl_streamID, gl_varID, levelID, gl_data.data(), &numMissVals);
-
-          auto mmm = varray_min_max_mean_mv(gl_data, gridsize, missval);
-
-          fprintf(stdout, "%s:  z=%d  t=%d  size=%zu numMissVals=%zu  min=%.5g mean=%.5g max=%.5g [%.2fs]\n", name, levelID + 1,
-                  tsID + 1, gridsize, numMissVals, mmm.min, mmm.mean, mmm.max, stepTimer.elapsed());
-        }
+        fprintf(stderr, "Timestep %d out of range!\n", tsID + 1);
+      break;
     }
+    else
+    {
+      cdo::timer stepTimer;
+
+      auto nlevels = var.nlevels;
+      auto gridsize = var.gridsize;
+      auto missval = var.missval;
+
+      auto levelID = (nlevels > 1) ? gl_levelID : 0;
+
+      size_t numMissVals;
+      streamReadVarSlice(gl_streamID, gl_varID, levelID, gl_data.data(), &numMissVals);
+
+      auto mmm = varray_min_max_mean_mv(gl_data, gridsize, missval);
+
+      fprintf(stdout, "%s:  z=%d  t=%d  size=%zu numMissVals=%zu  min=%.5g mean=%.5g max=%.5g [%.2fs]\n", name, levelID + 1,
+              tsID + 1, gridsize, numMissVals, mmm.min, mmm.mean, mmm.max, stepTimer.elapsed());
+    }
+  }
 
   return 0;
 }
@@ -181,10 +184,10 @@ paramWarning(const char *name, const char *cstring, const char *endptr)
 }
 
 int
-param2int(const std::string &str)
+param2int(std::string const &str)
 {
   char *endptr = nullptr;
-  int ival = (int) strtol(str.c_str(), &endptr, 10);
+  int ival = (int) std::strtol(str.c_str(), &endptr, 10);
   if (*endptr) paramWarning("Integer", str.c_str(), endptr);
   return ival;
 }
@@ -193,10 +196,10 @@ static int
 check_tsID(int tsID)
 {
   if (gl_numSteps >= 0 && (tsID < -1 || tsID >= gl_numSteps))
-    {
-      fprintf(stdout, "t=%d out of range (max=%d)!\n", (tsID >= 0) ? tsID + 1 : tsID, gl_numSteps);
-      return 1;
-    }
+  {
+    fprintf(stdout, "t=%d out of range (max=%d)!\n", (tsID >= 0) ? tsID + 1 : tsID, gl_numSteps);
+    return 1;
+  }
 
   return 0;
 }
@@ -217,10 +220,10 @@ check_levelID(int levelID)
 {
   auto nlevels = varList.vars[gl_varID].nlevels;
   if (levelID >= nlevels)
-    {
-      fprintf(stdout, "z=%d out of range (max=%d)!\n", levelID + 1, nlevels);
-      return 1;
-    }
+  {
+    fprintf(stdout, "z=%d out of range (max=%d)!\n", levelID + 1, nlevels);
+    return 1;
+  }
 
   return 0;
 }
@@ -238,10 +241,10 @@ static int
 check_varID(int varID)
 {
   if (varID < 0 || varID >= (int) varList.numVars())
-    {
-      fprintf(stdout, "varID out of range (max=%d)!\n", (int) varList.numVars());
-      return 1;
-    }
+  {
+    fprintf(stdout, "varID out of range (max=%d)!\n", (int) varList.numVars());
+    return 1;
+  }
 
   return 0;
 }
@@ -256,19 +259,19 @@ set_varID(int varID)
 }
 
 static void
-set_t(const std::vector<std::string> &argv)
+set_t(std::vector<std::string> const &argv)
 {
   auto argc = argv.size();
   if (argc == 1)
-    {
-      fprintf(stdout, "  set %s: Too few arguments\n", argv[0].c_str());
-      return;
-    }
+  {
+    fprintf(stdout, "  set %s: Too few arguments\n", argv[0].c_str());
+    return;
+  }
   else if (argc > 3)
-    {
-      fprintf(stdout, "  set %s: Too many arguments\n", argv[0].c_str());
-      return;
-    }
+  {
+    fprintf(stdout, "  set %s: Too many arguments\n", argv[0].c_str());
+    return;
+  }
 
   auto t1 = param2int(argv[1]);
   auto t2 = (argc == 3) ? param2int(argv[2]) : t1;
@@ -276,67 +279,67 @@ set_t(const std::vector<std::string> &argv)
 }
 
 static void
-set_z(const std::vector<std::string> &argv)
+set_z(std::vector<std::string> const &argv)
 {
   auto argc = argv.size();
   if (argc == 1)
-    {
-      fprintf(stdout, "  set %s: Too few arguments\n", argv[0].c_str());
-      return;
-    }
+  {
+    fprintf(stdout, "  set %s: Too few arguments\n", argv[0].c_str());
+    return;
+  }
   else if (argc > 2)
-    {
-      fprintf(stdout, "  set %s: Too many arguments\n", argv[0].c_str());
-      return;
-    }
+  {
+    fprintf(stdout, "  set %s: Too many arguments\n", argv[0].c_str());
+    return;
+  }
 
   auto z = param2int(argv[1]);
   set_levelID(z - 1);
 }
 
 static void
-set_var(const std::vector<std::string> &argv)
+set_var(std::vector<std::string> const &argv)
 {
   auto argc = argv.size();
   if (argc == 1)
-    {
-      fprintf(stdout, "  set %s: Too few arguments\n", argv[0].c_str());
-      return;
-    }
+  {
+    fprintf(stdout, "  set %s: Too few arguments\n", argv[0].c_str());
+    return;
+  }
   else if (argc > 2)
-    {
-      fprintf(stdout, "  set %s: Too many arguments\n", argv[0].c_str());
-      return;
-    }
+  {
+    fprintf(stdout, "  set %s: Too many arguments\n", argv[0].c_str());
+    return;
+  }
 
   auto &name = argv[1];
   auto lfound = false;
   for (int varID = 0; varID < gl_numVars; ++varID)
+  {
+    if (name == varList.vars[varID].name)
     {
-      if (name == varList.vars[varID].name)
-        {
-          lfound = true;
-          set_varID(varID);
-          break;
-        }
+      lfound = true;
+      set_varID(varID);
+      break;
     }
+  }
 
   if (!lfound)
-    {
-      fprintf(stdout, "  set %s: Variable name <%s> not found!\n", argv[0].c_str(), name.c_str());
-      return;
-    }
+  {
+    fprintf(stdout, "  set %s: Variable name <%s> not found!\n", argv[0].c_str(), name.c_str());
+    return;
+  }
 }
 
 static int
-com_set(const std::string &arg)
+com_set(std::string const &arg)
 {
   printf("com_set: >%s<\n", arg.c_str());
   if (arg.empty())
-    {
-      fprintf(stdout, "  command set: argument missing!\n");
-      return -1;
-    }
+  {
+    fprintf(stdout, "  command set: argument missing!\n");
+    return -1;
+  }
 
   std::istringstream iss(arg);
   std::vector<std::string> argv(std::istream_iterator<std::string>{ iss }, std::istream_iterator<std::string>());
@@ -353,20 +356,20 @@ com_set(const std::string &arg)
 }
 
 static int
-com_vars(const std::string &arg)
+com_vars(std::string const &arg)
 {
   char paramstr[32];
 
   printf("com_vars: %s %d\n", arg.c_str(), gl_numVars);
 
   for (int varID = 0; varID < gl_numVars; ++varID)
-    {
-      const auto &var = varList.vars[varID];
-      cdiParamToString(var.param, paramstr, sizeof(paramstr));
+  {
+    auto const &var = varList.vars[varID];
+    cdiParamToString(var.param, paramstr, sizeof(paramstr));
 
-      fprintf(stdout, "varID=%3d, param=%s, name=%s, longname=\"%s\", units=\"%s\"\n", varID + 1, paramstr, var.name.c_str(),
-              var.longname.c_str(), var.units.c_str());
-    }
+    fprintf(stdout, "varID=%3d, param=%s, name=%s, longname=\"%s\", units=\"%s\"\n", varID + 1, paramstr, var.name.c_str(),
+            var.longname.c_str(), var.units.c_str());
+  }
 
   return 0;
 }
@@ -375,7 +378,7 @@ com_vars(const std::string &arg)
  * name.
  */
 static const command_t *
-find_command(const std::string &name)
+find_command(std::string const &name)
 {
   for (int i = 0; i < ncommands; ++i)
     if (name == commands[i].name) return &commands[i];
@@ -385,7 +388,7 @@ find_command(const std::string &name)
 
 // Execute a command line.
 static int
-execute_line(const std::string &line)
+execute_line(std::string const &line)
 {
   if (line.empty()) return 0;
 
@@ -400,10 +403,10 @@ execute_line(const std::string &line)
 
   const command_t *command = find_command(word);
   if (!command)
-    {
-      fprintf(stderr, "%s: No such command!\n", word.c_str());
-      return -1;
-    }
+  {
+    fprintf(stderr, "%s: No such command!\n", word.c_str());
+    return -1;
+  }
   // Get argument to command, if any.
   while (std::isspace(line[i])) i++;
 
@@ -415,7 +418,7 @@ execute_line(const std::string &line)
 }
 
 std::string
-trim(const std::string &str, const std::string &chars = "\t\n\v\f\r ")
+trim(std::string const &str, std::string const &chars = "\t\n\v\f\r ")
 {
   auto first = str.find_first_not_of(chars);
   if (std::string::npos == first) return str;
@@ -432,31 +435,31 @@ peakRSS_string()
   char memstring[32] = { "" };
   size_t memmax = getPeakRSS();
   if (memmax)
+  {
+    size_t muindex = 0;
+    static const char *mu[] = { "B", "KB", "MB", "GB", "TB", "PB" };
+    static const size_t nmu = sizeof(mu) / sizeof(char *);
+    while (memmax > 9999 && muindex < nmu - 1)
     {
-      size_t muindex = 0;
-      static const char *mu[] = { "B", "KB", "MB", "GB", "TB", "PB" };
-      static const size_t nmu = sizeof(mu) / sizeof(char *);
-      while (memmax > 9999 && muindex < nmu - 1)
-        {
-          memmax /= 1024;
-          muindex++;
-        }
-      std::snprintf(memstring, sizeof(memstring), "%zu%s", memmax, mu[muindex]);
+      memmax /= 1024;
+      muindex++;
     }
+    std::snprintf(memstring, sizeof(memstring), "%zu%s", memmax, mu[muindex]);
+  }
 
   return memstring;
 }
 
 static void
-read_line(const std::string &p_prompt, std::string &line)
+read_line(std::string const &p_prompt, std::string &line)
 {
   fputs(p_prompt.c_str(), stdout);
   if (Options::cdoVerbose)
-    {
-      fputs(" [", stdout);
-      fputs(peakRSS_string().c_str(), stdout);
-      fputs("]", stdout);
-    }
+  {
+    fputs(" [", stdout);
+    fputs(peakRSS_string().c_str(), stdout);
+    fputs("]", stdout);
+  }
   fputs("> ", stdout);
   fflush(stdout);
 
@@ -489,16 +492,16 @@ run_demo()
   gl_tsID1 = 0;
   gl_tsID2 = -1;
   for (int varID = 0; varID < gl_numVars; ++varID)
+  {
+    auto const &var = varList.vars[varID];
+    auto nlevels = var.nlevels;
+    for (int levelID = 0; levelID < nlevels; ++levelID)
     {
-      const auto &var = varList.vars[varID];
-      auto nlevels = var.nlevels;
-      for (int levelID = 0; levelID < nlevels; ++levelID)
-        {
-          set_varID(varID);
-          set_levelID(levelID);
-          com_stat(var.name);
-        }
+      set_varID(varID);
+      set_levelID(levelID);
+      com_stat(var.name);
     }
+  }
 }
 
 class Command : public Process
@@ -521,14 +524,14 @@ public:
   {
 
     if (cdo_operator_argc() == 1)
-      {
-        if (cdo_operator_argv(0) == "auto")
-          mode_auto = true;
-        else if (cdo_operator_argv(0) == "demo")
-          mode_demo = true;
-        else
-          cdo_abort("Unsupported parameter: %s", cdo_operator_argv(0));
-      }
+    {
+      if (cdo_operator_argv(0) == "auto")
+        mode_auto = true;
+      else if (cdo_operator_argv(0) == "demo")
+        mode_demo = true;
+      else
+        cdo_abort("Unsupported parameter: %s", cdo_operator_argv(0));
+    }
 
     gl_streamID = streamOpenRead(cdo_get_stream_name(0));
 
@@ -540,16 +543,16 @@ public:
   {
     if (mode_demo) { run_demo(); }
     else
+    {
+      // Loop reading and executing lines until the user quits.
+      const std::string custom_prompt = "cdo cmd";
+      while (!Done)
       {
-        // Loop reading and executing lines until the user quits.
-        const std::string custom_prompt = "cdo cmd";
-        while (!Done)
-          {
-            std::string line;
-            read_line(custom_prompt, line);
-            execute_line(trim(line));
-          }
+        std::string line;
+        read_line(custom_prompt, line);
+        execute_line(trim(line));
       }
+    }
   }
 
   void
