@@ -23,19 +23,20 @@
 #include "param_conversion.h"
 #include "field_functions.h"
 
-static auto func_compc = [](auto hasMissvals, auto n, auto mv, auto &v, const auto cVal, auto binary_operator) {
+static auto func_compc = [](auto hasMissvals, auto n, auto mv, auto &v, const auto cVal, auto binary_operator)
+{
   if (hasMissvals)
-    {
-      auto constantIsMissval = fp_is_equal(cVal, mv);
-      if (std::isnan(mv))
-        for (size_t i = 0; i < n; ++i) v[i] = (fp_is_equal(v[i], mv) || constantIsMissval) ? mv : binary_operator(v[i], cVal);
-      else
-        for (size_t i = 0; i < n; ++i) v[i] = (is_equal(v[i], mv) || constantIsMissval) ? mv : binary_operator(v[i], cVal);
-    }
+  {
+    auto constantIsMissval = fp_is_equal(cVal, mv);
+    if (std::isnan(mv))
+      for (size_t i = 0; i < n; ++i) v[i] = (fp_is_equal(v[i], mv) || constantIsMissval) ? mv : binary_operator(v[i], cVal);
+    else
+      for (size_t i = 0; i < n; ++i) v[i] = (is_equal(v[i], mv) || constantIsMissval) ? mv : binary_operator(v[i], cVal);
+  }
   else
-    {
-      for (size_t i = 0; i < n; ++i) v[i] = binary_operator(v[i], cVal);
-    }
+  {
+    for (size_t i = 0; i < n; ++i) v[i] = binary_operator(v[i], cVal);
+  }
 };
 
 template <typename T>
@@ -81,14 +82,14 @@ public:
   };
   inline static RegisterEntry<Compc> registration = RegisterEntry<Compc>(module);
 
-  CdoStreamID streamID1;
-  int taxisID1;
+private:
+  CdoStreamID streamID1{};
+  CdoStreamID streamID2{};
+  int taxisID1{ CDI_UNDEFID };
+  int taxisID2{ CDI_UNDEFID };
 
-  CdoStreamID streamID2;
-  int taxisID2;
-
-  int operFunc;
-  double rconst;
+  int operFunc{};
+  double rconst{};
 
   VarList varList1;
 
@@ -128,36 +129,36 @@ public:
 
     int tsID = 0;
     while (true)
+    {
+      auto numFields = cdo_stream_inq_timestep(streamID1, tsID);
+      if (numFields == 0) break;
+
+      cdo_taxis_copy_timestep(taxisID2, taxisID1);
+      cdo_def_timestep(streamID2, tsID);
+
+      for (int fieldID = 0; fieldID < numFields; ++fieldID)
       {
-        auto numFields = cdo_stream_inq_timestep(streamID1, tsID);
-        if (numFields == 0) break;
+        auto [varID, levelID] = cdo_inq_field(streamID1);
+        auto const &var = varList1.vars[varID];
+        field.init(var);
+        cdo_read_field(streamID1, field);
 
-        cdo_taxis_copy_timestep(taxisID2, taxisID1);
-        cdo_def_timestep(streamID2, tsID);
+        auto missval = field.missval;
+        auto numMissVals = field.numMissVals;
+        auto hasMissvals = (numMissVals > 0 || fp_is_equal(rconst, missval));
 
-        for (int fieldID = 0; fieldID < numFields; ++fieldID)
-          {
-            auto [varID, levelID] = cdo_inq_field(streamID1);
-            const auto &var = varList1.vars[varID];
-            field.init(var);
-            cdo_read_field(streamID1, field);
+        if (numMissVals > 0) cdo_check_missval(missval, var.name);
 
-            auto missval = field.missval;
-            auto numMissVals = field.numMissVals;
-            auto hasMissvals = (numMissVals > 0 || fp_is_equal(rconst, missval));
+        comp_function(field, operFunc, hasMissvals, rconst);
 
-            if (numMissVals > 0) cdo_check_missval(missval, var.name);
+        if (hasMissvals > 0) field_num_mv(field);
 
-            comp_function(field, operFunc, hasMissvals, rconst);
-
-            if (hasMissvals > 0) field_num_mv(field);
-
-            cdo_def_field(streamID2, varID, levelID);
-            cdo_write_field(streamID2, field);
-          }
-
-        tsID++;
+        cdo_def_field(streamID2, varID, levelID);
+        cdo_write_field(streamID2, field);
       }
+
+      tsID++;
+    }
   }
 
   void
