@@ -20,7 +20,7 @@
 #include "cdo_fill.h"
 
 static void
-operator_IFTHEN(size_t n, double mv1, double mv2, const Varray<double> &vIn1, const Varray<double> &vIn2, Varray<double> &vOut)
+operator_IFTHEN(size_t n, double mv1, double mv2, Varray<double> const &vIn1, Varray<double> const &vIn2, Varray<double> &vOut)
 {
   if (std::isnan(mv1))
     for (size_t i = 0; i < n; ++i) vOut[i] = (fp_is_not_equal(vIn1[i], mv1) && fp_is_not_equal(vIn1[i], 0.0)) ? vIn2[i] : mv2;
@@ -29,7 +29,7 @@ operator_IFTHEN(size_t n, double mv1, double mv2, const Varray<double> &vIn1, co
 }
 
 static void
-operator_IFNOTTHEN(size_t n, double mv1, double mv2, const Varray<double> &vIn1, const Varray<double> &vIn2, Varray<double> &vOut)
+operator_IFNOTTHEN(size_t n, double mv1, double mv2, Varray<double> const &vIn1, Varray<double> const &vIn2, Varray<double> &vOut)
 {
   if (std::isnan(mv1))
     for (size_t i = 0; i < n; ++i) vOut[i] = (fp_is_not_equal(vIn1[i], mv1) && fp_is_equal(vIn1[i], 0.0)) ? vIn2[i] : mv2;
@@ -58,21 +58,20 @@ public:
   };
   inline static RegisterEntry<Cond> registration = RegisterEntry<Cond>(module);
 
-  int IFTHEN, IFNOTTHEN;
+private:
+  int IFTHEN{}, IFNOTTHEN{};
   int filltype = FILL_NONE;
   double missval1 = -9.E33;
   Varray2D<size_t> varnumMissVals1;
   Varray2D<double> vardata1;
 
-  CdoStreamID streamID1;
+  CdoStreamID streamID1{};
+  CdoStreamID streamID2{};
+  CdoStreamID streamID3{};
+  int taxisID2{ CDI_UNDEFID };
+  int taxisID3{};
 
-  CdoStreamID streamID2;
-  int taxisID2;
-
-  CdoStreamID streamID3;
-  int taxisID3;
-
-  int operatorID;
+  int operatorID{};
 
   VarList varList1;
   VarList varList2;
@@ -105,10 +104,10 @@ public:
     if (ntsteps2 == 0) ntsteps2 = 1;
 
     if (vlistNumFields(vlistID1) == 1 && vlistNumFields(vlistID2) != 1)
-      {
-        filltype = FILL_REC;
-        cdo_print("Filling up stream1 >%s< by copying the first field.", cdo_get_stream_name(0));
-      }
+    {
+      filltype = FILL_REC;
+      cdo_print("Filling up stream1 >%s< by copying the first field.", cdo_get_stream_name(0));
+    }
 
     varList1 = VarList(vlistID1);
     varList2 = VarList(vlistID2);
@@ -124,15 +123,15 @@ public:
     if (Options::cdoVerbose) cdo_print("Number of timesteps: file1 %d, file2 %d", ntsteps1, ntsteps2);
 
     if (filltype == FILL_NONE)
+    {
+      if (ntsteps1 == 1 && ntsteps2 != 1)
       {
-        if (ntsteps1 == 1 && ntsteps2 != 1)
-          {
-            filltype = FILL_TS;
-            cdo_print("Filling up stream1 >%s< by copying the first timestep.", cdo_get_stream_name(0));
+        filltype = FILL_TS;
+        cdo_print("Filling up stream1 >%s< by copying the first timestep.", cdo_get_stream_name(0));
 
-            cdo_fill_ts(vlistID1, vardata1, varnumMissVals1);
-          }
+        cdo_fill_ts(vlistID1, vardata1, varnumMissVals1);
       }
+    }
   }
 
   void
@@ -144,72 +143,72 @@ public:
 
     int tsID = 0;
     while (true)
+    {
+      auto numFields = cdo_stream_inq_timestep(streamID2, tsID);
+      if (numFields == 0) break;
+
+      if (tsID == 0 || filltype == FILL_NONE)
       {
-        auto numFields = cdo_stream_inq_timestep(streamID2, tsID);
-        if (numFields == 0) break;
+        auto numFields2 = cdo_stream_inq_timestep(streamID1, tsID);
+        if (numFields2 == 0) cdo_abort("Input streams have different number of timesteps!");
+      }
+
+      cdo_taxis_copy_timestep(taxisID3, taxisID2);
+      cdo_def_timestep(streamID3, tsID);
+
+      for (int fieldID = 0; fieldID < numFields; ++fieldID)
+      {
+        auto [varID, levelID] = cdo_inq_field(streamID2);
+        size_t numMissVals1 = 0, numMissVals2;
+        cdo_read_field(streamID2, &varrayIn2[0], &numMissVals2);
 
         if (tsID == 0 || filltype == FILL_NONE)
+        {
+          if (fieldID == 0 || filltype != FILL_REC)
           {
-            auto numFields2 = cdo_stream_inq_timestep(streamID1, tsID);
-            if (numFields2 == 0) cdo_abort("Input streams have different number of timesteps!");
+            auto [varIDx, levelIDx] = cdo_inq_field(streamID1);
+            cdo_read_field(streamID1, &varrayIn1[0], &numMissVals1);
+            varID = varIDx;
+            levelID = levelIDx;
           }
 
-        cdo_taxis_copy_timestep(taxisID3, taxisID2);
-        cdo_def_timestep(streamID3, tsID);
-
-        for (int fieldID = 0; fieldID < numFields; ++fieldID)
+          if (filltype == FILL_TS)
           {
-            auto [varID, levelID] = cdo_inq_field(streamID2);
-            size_t numMissVals1 = 0, numMissVals2;
-            cdo_read_field(streamID2, &varrayIn2[0], &numMissVals2);
-
-            if (tsID == 0 || filltype == FILL_NONE)
-              {
-                if (fieldID == 0 || filltype != FILL_REC)
-                  {
-                    auto [varIDx, levelIDx] = cdo_inq_field(streamID1);
-                    cdo_read_field(streamID1, &varrayIn1[0], &numMissVals1);
-                    varID = varIDx;
-                    levelID = levelIDx;
-                  }
-
-                if (filltype == FILL_TS)
-                  {
-                    auto gridsize = varList1.vars[varID].gridsize;
-                    auto offset = gridsize * levelID;
-                    array_copy(gridsize, &varrayIn1[0], &vardata1[varID][offset]);
-                    varnumMissVals1[varID][levelID] = numMissVals1;
-                  }
-              }
-            else if (filltype == FILL_TS)
-              {
-                auto gridsize = varList1.vars[varID].gridsize;
-                auto offset = gridsize * levelID;
-                array_copy(gridsize, &vardata1[varID][offset], &varrayIn1[0]);
-                numMissVals1 = varnumMissVals1[varID][levelID];
-              }
-
-            const auto &var1 = varList1.vars[varID];
-            const auto &var2 = varList2.vars[varID];
-            auto ngp = var2.gridsize;
-            auto missval2 = var2.missval;
-            if (fieldID == 0 || filltype != FILL_REC) missval1 = var1.missval;
-
-            if (numMissVals1 > 0) cdo_check_missval(missval1, var1.name);
-
-            // clang-format off
-            if      (operatorID == IFTHEN)    operator_IFTHEN(ngp, missval1, missval2, varrayIn1, varrayIn2, varrayOut);
-            else if (operatorID == IFNOTTHEN) operator_IFNOTTHEN(ngp, missval1, missval2, varrayIn1, varrayIn2, varrayOut);
-            else cdo_abort("Operator not implemented!");
-            // clang-format on
-
-            auto numMissVals3 = varray_num_mv(ngp, varrayOut, missval2);
-            cdo_def_field(streamID3, varID, levelID);
-            cdo_write_field(streamID3, varrayOut.data(), numMissVals3);
+            auto gridsize = varList1.vars[varID].gridsize;
+            auto offset = gridsize * levelID;
+            array_copy(gridsize, &varrayIn1[0], &vardata1[varID][offset]);
+            varnumMissVals1[varID][levelID] = numMissVals1;
           }
+        }
+        else if (filltype == FILL_TS)
+        {
+          auto gridsize = varList1.vars[varID].gridsize;
+          auto offset = gridsize * levelID;
+          array_copy(gridsize, &vardata1[varID][offset], &varrayIn1[0]);
+          numMissVals1 = varnumMissVals1[varID][levelID];
+        }
 
-        tsID++;
+        auto const &var1 = varList1.vars[varID];
+        auto const &var2 = varList2.vars[varID];
+        auto ngp = var2.gridsize;
+        auto missval2 = var2.missval;
+        if (fieldID == 0 || filltype != FILL_REC) missval1 = var1.missval;
+
+        if (numMissVals1 > 0) cdo_check_missval(missval1, var1.name);
+
+        // clang-format off
+        if      (operatorID == IFTHEN)    operator_IFTHEN(ngp, missval1, missval2, varrayIn1, varrayIn2, varrayOut);
+        else if (operatorID == IFNOTTHEN) operator_IFNOTTHEN(ngp, missval1, missval2, varrayIn1, varrayIn2, varrayOut);
+        else cdo_abort("Operator not implemented!");
+        // clang-format on
+
+        auto numMissVals3 = varray_num_mv(ngp, varrayOut, missval2);
+        cdo_def_field(streamID3, varID, levelID);
+        cdo_write_field(streamID3, varrayOut.data(), numMissVals3);
       }
+
+      tsID++;
+    }
   }
 
   void
