@@ -39,6 +39,7 @@ public:
   };
   inline static RegisterEntry<Cond2> registration = RegisterEntry<Cond2>(module);
 
+private:
   int filltype = FILL_NONE;
   double missval1 = -9.E33;
   size_t numMissVals1 = 0;
@@ -47,10 +48,10 @@ public:
 
   CdoStreamID streamID1;
   CdoStreamID streamID2;
-  int taxisID2{ CDI_UNDEFID };
   CdoStreamID streamID3;
   CdoStreamID streamID4;
-  int taxisID4;
+  int taxisID2{ CDI_UNDEFID };
+  int taxisID4{};
 
   VarList varList1;
   VarList varList2;
@@ -81,10 +82,10 @@ public:
     if (ntsteps2 == 0) ntsteps2 = 1;
 
     if (vlistNumFields(vlistID1) == 1 && vlistNumFields(vlistID2) != 1)
-      {
-        filltype = FILL_REC;
-        cdo_print("Filling up stream1 >%s< by copying the first field.", cdo_get_stream_name(0));
-      }
+    {
+      filltype = FILL_REC;
+      cdo_print("Filling up stream1 >%s< by copying the first field.", cdo_get_stream_name(0));
+    }
 
     varList1 = VarList(vlistID1);
     varList2 = VarList(vlistID2);
@@ -110,15 +111,15 @@ public:
       cdo_print("Number of timesteps: file1 %d, file2 %d, file3 %d", ntsteps1, ntsteps2, vlistNtsteps(vlistID3));
 
     if (filltype == FILL_NONE)
+    {
+      if (ntsteps1 == 1 && ntsteps2 != 1)
       {
-        if (ntsteps1 == 1 && ntsteps2 != 1)
-          {
-            filltype = FILL_TS;
-            cdo_print("Filling up stream1 >%s< by copying the first timestep.", cdo_get_stream_name(0));
+        filltype = FILL_TS;
+        cdo_print("Filling up stream1 >%s< by copying the first timestep.", cdo_get_stream_name(0));
 
-            cdo_fill_ts(vlistID1, vardata1, varnumMissVals1);
-          }
+        cdo_fill_ts(vlistID1, vardata1, varnumMissVals1);
       }
+    }
   }
 
   void
@@ -126,75 +127,75 @@ public:
   {
     int tsID = 0;
     while (true)
-      {
-        auto numFields = cdo_stream_inq_timestep(streamID2, tsID);
-        if (numFields == 0) break;
+    {
+      auto numFields = cdo_stream_inq_timestep(streamID2, tsID);
+      if (numFields == 0) break;
 
-        auto numFields3 = cdo_stream_inq_timestep(streamID3, tsID);
-        if (numFields3 == 0) cdo_abort("Input streams have different number of timesteps!");
+      auto numFields3 = cdo_stream_inq_timestep(streamID3, tsID);
+      if (numFields3 == 0) cdo_abort("Input streams have different number of timesteps!");
+
+      if (tsID == 0 || filltype == FILL_NONE)
+      {
+        auto numFields2 = cdo_stream_inq_timestep(streamID1, tsID);
+        if (numFields2 == 0) cdo_abort("Input streams have different number of timesteps!");
+      }
+
+      cdo_taxis_copy_timestep(taxisID4, taxisID2);
+      cdo_def_timestep(streamID4, tsID);
+
+      for (int fieldID = 0; fieldID < numFields; ++fieldID)
+      {
+        (void) cdo_inq_field(streamID2);
+        size_t numMissVals;
+        cdo_read_field(streamID2, &array2[0], &numMissVals);
+
+        auto [varID, levelID] = cdo_inq_field(streamID3);
+        cdo_read_field(streamID3, &array3[0], &numMissVals);
 
         if (tsID == 0 || filltype == FILL_NONE)
+        {
+          if (fieldID == 0 || filltype != FILL_REC)
           {
-            auto numFields2 = cdo_stream_inq_timestep(streamID1, tsID);
-            if (numFields2 == 0) cdo_abort("Input streams have different number of timesteps!");
+            auto [varIDx, levelIDx] = cdo_inq_field(streamID1);
+            cdo_read_field(streamID1, &array1[0], &numMissVals1);
+            varID = varIDx;
+            levelID = levelIDx;
           }
 
-        cdo_taxis_copy_timestep(taxisID4, taxisID2);
-        cdo_def_timestep(streamID4, tsID);
-
-        for (int fieldID = 0; fieldID < numFields; ++fieldID)
+          if (filltype == FILL_TS)
           {
-            (void) cdo_inq_field(streamID2);
-            size_t numMissVals;
-            cdo_read_field(streamID2, &array2[0], &numMissVals);
-
-            auto [varID, levelID] = cdo_inq_field(streamID3);
-            cdo_read_field(streamID3, &array3[0], &numMissVals);
-
-            if (tsID == 0 || filltype == FILL_NONE)
-              {
-                if (fieldID == 0 || filltype != FILL_REC)
-                  {
-                    auto [varIDx, levelIDx] = cdo_inq_field(streamID1);
-                    cdo_read_field(streamID1, &array1[0], &numMissVals1);
-                    varID = varIDx;
-                    levelID = levelIDx;
-                  }
-
-                if (filltype == FILL_TS)
-                  {
-                    auto gridsize = varList1.vars[varID].gridsize;
-                    auto offset = gridsize * levelID;
-                    array_copy(gridsize, &array1[0], &vardata1[varID][offset]);
-                    varnumMissVals1[varID][levelID] = numMissVals1;
-                  }
-              }
-            else if (filltype == FILL_TS)
-              {
-                auto gridsize = varList1.vars[varID].gridsize;
-                auto offset = gridsize * levelID;
-                array_copy(gridsize, &vardata1[varID][offset], &array1[0]);
-                numMissVals1 = varnumMissVals1[varID][levelID];
-              }
-
-            auto const &var1 = varList1.vars[varID];
-            auto const &var2 = varList2.vars[varID];
-            auto gridsize = var2.gridsize;
-            auto missval2 = var2.missval;
-            if (fieldID == 0 || filltype != FILL_REC) missval1 = var1.missval;
-
-            if (numMissVals1 > 0) cdo_check_missval(missval1, var1.name);
-
-            for (size_t i = 0; i < gridsize; ++i)
-              array4[i] = fp_is_equal(array1[i], missval1) ? missval2 : !fp_is_equal(array1[i], 0.) ? array2[i] : array3[i];
-
-            numMissVals = varray_num_mv(gridsize, array4, missval2);
-            cdo_def_field(streamID4, varID, levelID);
-            cdo_write_field(streamID4, array4.data(), numMissVals);
+            auto gridsize = varList1.vars[varID].gridsize;
+            auto offset = gridsize * levelID;
+            array_copy(gridsize, &array1[0], &vardata1[varID][offset]);
+            varnumMissVals1[varID][levelID] = numMissVals1;
           }
+        }
+        else if (filltype == FILL_TS)
+        {
+          auto gridsize = varList1.vars[varID].gridsize;
+          auto offset = gridsize * levelID;
+          array_copy(gridsize, &vardata1[varID][offset], &array1[0]);
+          numMissVals1 = varnumMissVals1[varID][levelID];
+        }
 
-        tsID++;
+        auto const &var1 = varList1.vars[varID];
+        auto const &var2 = varList2.vars[varID];
+        auto gridsize = var2.gridsize;
+        auto missval2 = var2.missval;
+        if (fieldID == 0 || filltype != FILL_REC) missval1 = var1.missval;
+
+        if (numMissVals1 > 0) cdo_check_missval(missval1, var1.name);
+
+        for (size_t i = 0; i < gridsize; ++i)
+          array4[i] = fp_is_equal(array1[i], missval1) ? missval2 : !fp_is_equal(array1[i], 0.) ? array2[i] : array3[i];
+
+        numMissVals = varray_num_mv(gridsize, array4, missval2);
+        cdo_def_field(streamID4, varID, levelID);
+        cdo_write_field(streamID4, array4.data(), numMissVals);
       }
+
+      tsID++;
+    }
   }
 
   void
