@@ -58,17 +58,17 @@ public:
   };
   inline static RegisterEntry<Condc> registration = RegisterEntry<Condc>(module);
 
-  int IFTHENC, IFNOTTHENC;
-  CdoStreamID streamID1;
-  int taxisID1;
+private:
+  int IFTHENC{}, IFNOTTHENC{};
+  int taxisID1{ CDI_UNDEFID };
+  CdoStreamID streamID1{};
+  CdoStreamID streamID2{};
+  int taxisID2{ CDI_UNDEFID };
 
-  CdoStreamID streamID2;
-  int taxisID2;
+  int operatorID{};
+  double rconst{};
 
-  int operatorID;
-  double rconst;
-
-  VarList varList1;
+  VarList varList1{};
 
 public:
   void
@@ -106,40 +106,40 @@ public:
 
     int tsID = 0;
     while (true)
+    {
+      auto numFields = cdo_stream_inq_timestep(streamID1, tsID);
+      if (numFields == 0) break;
+
+      cdo_taxis_copy_timestep(taxisID2, taxisID1);
+      cdo_def_timestep(streamID2, tsID);
+
+      for (int fieldID = 0; fieldID < numFields; ++fieldID)
       {
-        auto numFields = cdo_stream_inq_timestep(streamID1, tsID);
-        if (numFields == 0) break;
+        auto [varID, levelID] = cdo_inq_field(streamID1);
+        auto const &var = varList1.vars[varID];
+        field.init(var);
+        cdo_read_field(streamID1, field);
 
-        cdo_taxis_copy_timestep(taxisID2, taxisID1);
-        cdo_def_timestep(streamID2, tsID);
+        auto numMissVals = field.numMissVals;
+        if (numMissVals > 0) cdo_check_missval(field.missval, var.name);
 
-        for (int fieldID = 0; fieldID < numFields; ++fieldID)
-          {
-            auto [varID, levelID] = cdo_inq_field(streamID1);
-            const auto &var = varList1.vars[varID];
-            field.init(var);
-            cdo_read_field(streamID1, field);
+        auto func_ifthenc = [&](auto &v, auto n, double mv) { operator_IFTHENC(n, mv, v, rconst); };
+        auto func_ifnotthenc = [&](auto &v, auto n, double mv) { operator_IFNOTTHENC(n, mv, v, rconst); };
 
-            auto numMissVals = field.numMissVals;
-            if (numMissVals > 0) cdo_check_missval(field.missval, var.name);
+        // clang-format off
+        if      (operatorID == IFTHENC)    field_operation(func_ifthenc, field, field.size, field.missval);
+        else if (operatorID == IFNOTTHENC) field_operation(func_ifnotthenc, field, field.size, field.missval);
+        else cdo_abort("Operator not implemented!");
+        // clang-format on
 
-            auto func_ifthenc = [&](auto &v, auto n, double mv) { operator_IFTHENC(n, mv, v, rconst); };
-            auto func_ifnotthenc = [&](auto &v, auto n, double mv) { operator_IFNOTTHENC(n, mv, v, rconst); };
+        if (numMissVals > 0) field_num_mv(field);
 
-            // clang-format off
-            if      (operatorID == IFTHENC)    field_operation(func_ifthenc, field, field.size, field.missval);
-            else if (operatorID == IFNOTTHENC) field_operation(func_ifnotthenc, field, field.size, field.missval);
-            else cdo_abort("Operator not implemented!");
-            // clang-format on
-
-            if (numMissVals > 0) field_num_mv(field);
-
-            cdo_def_field(streamID2, varID, levelID);
-            cdo_write_field(streamID2, field);
-          }
-
-        tsID++;
+        cdo_def_field(streamID2, varID, levelID);
+        cdo_write_field(streamID2, field);
       }
+
+      tsID++;
+    }
   }
 
   void
