@@ -37,18 +37,17 @@ public:
   };
   inline static RegisterEntry<Dayarith> registration = RegisterEntry<Dayarith>(module);
 
-  CdoStreamID streamID1;
-  int taxisID1;
-
-  CdoStreamID streamID2;
-  int taxisID2;
+  CdoStreamID streamID1{};
+  CdoStreamID streamID2{};
+  int taxisID1{ CDI_UNDEFID };
+  int taxisID2{ CDI_UNDEFID };
 
   CdoStreamID streamID3;
-  int taxisID3;
+  int taxisID3{};
 
-  int operfunc;
+  int operfunc{};
 
-  VarList varList1;
+  VarList varList1{};
   Field field;
   FieldVector2D varsData2;
 
@@ -92,56 +91,56 @@ public:
     int tsID = 0;
     int tsID2 = 0;
     while (true)
+    {
+      auto numFields = cdo_stream_inq_timestep(streamID1, tsID);
+      if (numFields == 0) break;
+
+      auto vDate1 = taxisInqVdatetime(taxisID1).date;
+
+      if (!cdiDate_isEQ(vDate1, vDate2))
       {
-        auto numFields = cdo_stream_inq_timestep(streamID1, tsID);
-        if (numFields == 0) break;
+        int year1, month1, day1;
+        cdiDate_decode(vDate1, &year1, &month1, &day1);
+        if (Options::cdoVerbose) cdo_print("Process: Year=%4d  Month=%2d  Day=%2d", year1, month1, day1);
 
-        auto vDate1 = taxisInqVdatetime(taxisID1).date;
+        auto numFields2 = cdo_stream_inq_timestep(streamID2, tsID2);
+        if (numFields2 == 0) cdo_abort("Missing year=%4d mon=%2d day=%2d in %s!", year1, month1, day1, cdo_get_stream_name(1));
 
+        vDate2 = taxisInqVdatetime(taxisID2).date;
         if (!cdiDate_isEQ(vDate1, vDate2))
-          {
-            int year1, month1, day1;
-            cdiDate_decode(vDate1, &year1, &month1, &day1);
-            if (Options::cdoVerbose) cdo_print("Process: Year=%4d  Month=%2d  Day=%2d", year1, month1, day1);
+        {
+          int year2, month2, day2;
+          cdiDate_decode(vDate2, &year2, &month2, &day2);
+          cdo_abort("Timestep %d in %s has wrong date! Current year=%4d mon=%2d day=%2d, expected year=%4d mon=%2d day=%2d",
+                    tsID2 + 1, cdo_get_stream_name(1), year2, month2, day2, year1, month1, day1);
+        }
 
-            auto numFields2 = cdo_stream_inq_timestep(streamID2, tsID2);
-            if (numFields2 == 0) cdo_abort("Missing year=%4d mon=%2d day=%2d in %s!", year1, month1, day1, cdo_get_stream_name(1));
+        for (int fieldID = 0; fieldID < numFields2; ++fieldID)
+        {
+          auto [varID, levelID] = cdo_inq_field(streamID2);
+          cdo_read_field(streamID2, varsData2[varID][levelID]);
+        }
 
-            vDate2 = taxisInqVdatetime(taxisID2).date;
-            if (!cdiDate_isEQ(vDate1, vDate2))
-              {
-                int year2, month2, day2;
-                cdiDate_decode(vDate2, &year2, &month2, &day2);
-                cdo_abort("Timestep %d in %s has wrong date! Current year=%4d mon=%2d day=%2d, expected year=%4d mon=%2d day=%2d",
-                          tsID2 + 1, cdo_get_stream_name(1), year2, month2, day2, year1, month1, day1);
-              }
-
-            for (int fieldID = 0; fieldID < numFields2; ++fieldID)
-              {
-                auto [varID, levelID] = cdo_inq_field(streamID2);
-                cdo_read_field(streamID2, varsData2[varID][levelID]);
-              }
-
-            tsID2++;
-          }
-
-        cdo_taxis_copy_timestep(taxisID3, taxisID1);
-        cdo_def_timestep(streamID3, tsID);
-
-        for (int fieldID = 0; fieldID < numFields; ++fieldID)
-          {
-            auto [varID, levelID] = cdo_inq_field(streamID1);
-            field.init(varList1.vars[varID]);
-            cdo_read_field(streamID1, field);
-
-            field2_function(field, varsData2[varID][levelID], operfunc);
-
-            cdo_def_field(streamID3, varID, levelID);
-            cdo_write_field(streamID3, field);
-          }
-
-        tsID++;
+        tsID2++;
       }
+
+      cdo_taxis_copy_timestep(taxisID3, taxisID1);
+      cdo_def_timestep(streamID3, tsID);
+
+      for (int fieldID = 0; fieldID < numFields; ++fieldID)
+      {
+        auto [varID, levelID] = cdo_inq_field(streamID1);
+        field.init(varList1.vars[varID]);
+        cdo_read_field(streamID1, field);
+
+        field2_function(field, varsData2[varID][levelID], operfunc);
+
+        cdo_def_field(streamID3, varID, levelID);
+        cdo_write_field(streamID3, field);
+      }
+
+      tsID++;
+    }
   }
 
   void
