@@ -18,7 +18,7 @@
 
 template <typename T>
 static void
-varray_deltat(size_t len, const Varray<T> &v0, const Varray<T> &v1, Varray<T> &v2, double factor, double mv)
+varray_deltat(size_t len, Varray<T> const &v0, Varray<T> const &v1, Varray<T> &v2, double factor, double mv)
 {
   assert(len > 0);
   assert(v0.size() > 0);
@@ -28,18 +28,12 @@ varray_deltat(size_t len, const Varray<T> &v0, const Varray<T> &v1, Varray<T> &v
   assert(len <= v1.size());
   assert(len <= v2.size());
 
-  for (size_t i = 0; i < len; ++i)
-    {
-      if (fp_is_equal(v0[i], mv) || fp_is_equal(v1[i], mv))
-        v2[i] = mv;
-      else
-        v2[i] = (v1[i] - v0[i]) * factor;
-    }
+  for (size_t i = 0; i < len; ++i) { v2[i] = (fp_is_equal(v0[i], mv) || fp_is_equal(v1[i], mv)) ? mv : (v1[i] - v0[i]) * factor; }
 }
 
 template <typename T>
 static void
-varray_deltat(size_t len, const Varray<T> &v0, const Varray<T> &v1, Varray<T> &v2, double factor)
+varray_deltat(size_t len, Varray<T> const &v0, Varray<T> const &v1, Varray<T> &v2, double factor)
 {
   assert(len > 0);
 
@@ -47,26 +41,26 @@ varray_deltat(size_t len, const Varray<T> &v0, const Varray<T> &v1, Varray<T> &v
 }
 
 void
-field_deltat(const Field &field0, const Field &field1, Field &field2, double factor)
+field_deltat(Field const &field0, Field const &field1, Field &field2, double factor)
 {
   if (field1.memType != field2.memType) cdo_abort("Interal error, memType of field1 and field2 differ!");
 
   if (field1.numMissVals || field0.numMissVals)
-    {
-      if (field1.memType == MemType::Float)
-        varray_deltat(field1.size, field0.vec_f, field1.vec_f, field2.vec_f, factor, field1.missval);
-      else
-        varray_deltat(field1.size, field0.vec_d, field1.vec_d, field2.vec_d, factor, field1.missval);
+  {
+    if (field1.memType == MemType::Float)
+      varray_deltat(field1.size, field0.vec_f, field1.vec_f, field2.vec_f, factor, field1.missval);
+    else
+      varray_deltat(field1.size, field0.vec_d, field1.vec_d, field2.vec_d, factor, field1.missval);
 
-      field2.numMissVals = field_num_mv(field2);
-    }
+    field2.numMissVals = field_num_mv(field2);
+  }
   else
-    {
-      if (field1.memType == MemType::Float)
-        varray_deltat(field1.size, field0.vec_f, field1.vec_f, field2.vec_f, factor);
-      else
-        varray_deltat(field1.size, field0.vec_d, field1.vec_d, field2.vec_d, factor);
-    }
+  {
+    if (field1.memType == MemType::Float)
+      varray_deltat(field1.size, field0.vec_f, field1.vec_f, field2.vec_f, factor);
+    else
+      varray_deltat(field1.size, field0.vec_d, field1.vec_d, field2.vec_d, factor);
+  }
 }
 
 class Deltat : public Process
@@ -84,14 +78,14 @@ public:
   inline static RegisterEntry<Deltat> registration = RegisterEntry<Deltat>(module);
 
 private:
-  CdoStreamID streamID1;
-  CdoStreamID streamID2;
+  CdoStreamID streamID1{};
+  CdoStreamID streamID2{};
 
-  int taxisID1;
-  int taxisID2;
-  int calendar;
-  VarList varList1;
-  bool ldivdt;
+  int taxisID1{ CDI_UNDEFID };
+  int taxisID2{ CDI_UNDEFID };
+  int calendar{ CDI_UNDEFID };
+  VarList varList1{};
+  bool ldivdt{ false };
 
 public:
   void
@@ -114,6 +108,8 @@ public:
     calendar = taxisInqCalendar(taxisID1);
 
     varList1 = VarList(vlistID1);
+    auto numSteps = varList1.numSteps();
+    if (numSteps > 1) vlistDefNtsteps(vlistID2, numSteps - 1);
 
     streamID2 = cdo_open_write(1);
     cdo_def_vlist(streamID2, vlistID2);
@@ -132,46 +128,46 @@ public:
     auto julianDate0 = julianDate_encode(calendar, taxisInqVdatetime(taxisID1));
 
     for (int fieldID = 0; fieldID < numFields; ++fieldID)
-      {
-        auto [varID, levelID] = cdo_inq_field(streamID1);
-        cdo_read_field(streamID1, varsData[varID][levelID]);
-      }
+    {
+      auto [varID, levelID] = cdo_inq_field(streamID1);
+      cdo_read_field(streamID1, varsData[varID][levelID]);
+    }
 
     tsID++;
     int tsID2 = 0;
     while (true)
+    {
+      numFields = cdo_stream_inq_timestep(streamID1, tsID);
+      if (numFields == 0) break;
+
+      auto julianDate1 = julianDate_encode(calendar, taxisInqVdatetime(taxisID1));
+      auto idtInSec = ldivdt ? 1.0 / julianDate_to_seconds(julianDate_sub(julianDate1, julianDate0)) : 1.0;
+      julianDate0 = julianDate1;
+
+      cdo_taxis_copy_timestep(taxisID2, taxisID1);
+      cdo_def_timestep(streamID2, tsID2);
+
+      for (int fieldID = 0; fieldID < numFields; ++fieldID)
       {
-        numFields = cdo_stream_inq_timestep(streamID1, tsID);
-        if (numFields == 0) break;
+        auto [varID, levelID] = cdo_inq_field(streamID1);
+        auto const &var1 = varList1.vars[varID];
+        field1.init(var1);
+        cdo_read_field(streamID1, field1);
 
-        auto julianDate1 = julianDate_encode(calendar, taxisInqVdatetime(taxisID1));
-        auto idtInSec = ldivdt ? 1.0 / julianDate_to_seconds(julianDate_sub(julianDate1, julianDate0)) : 1.0;
-        julianDate0 = julianDate1;
+        auto &field0 = varsData[varID][levelID];
 
-        cdo_taxis_copy_timestep(taxisID2, taxisID1);
-        cdo_def_timestep(streamID2, tsID2);
+        field2.init(var1);
+        field_deltat(field0, field1, field2, idtInSec);
 
-        for (int fieldID = 0; fieldID < numFields; ++fieldID)
-          {
-            auto [varID, levelID] = cdo_inq_field(streamID1);
-            const auto &var1 = varList1.vars[varID];
-            field1.init(var1);
-            cdo_read_field(streamID1, field1);
+        field_copy(field1, field0);
 
-            auto &field0 = varsData[varID][levelID];
-
-            field2.init(var1);
-            field_deltat(field0, field1, field2, idtInSec);
-
-            field_copy(field1, field0);
-
-            cdo_def_field(streamID2, varID, levelID);
-            cdo_write_field(streamID2, field2);
-          }
-
-        tsID++;
-        tsID2++;
+        cdo_def_field(streamID2, varID, levelID);
+        cdo_write_field(streamID2, field2);
       }
+
+      tsID++;
+      tsID2++;
+    }
   }
 
   void
