@@ -14,25 +14,25 @@
 
 template <typename T>
 static void
-calc_full_depth(size_t gridsize, size_t nlevels, const Varray<T> &thick_c, const Varray<T> &stretch_c, const Varray<T> &zos,
+calc_full_depth(size_t gridsize, size_t nlevels, Varray<T> const &thick_c, Varray<T> const &stretch_c, Varray<T> const &zos,
                 Varray<T> &fullDepth)
 {
-  ranges::fill_n(fullDepth.begin(), gridsize, 0.0);
+  std::ranges::fill_n(fullDepth.begin(), gridsize, 0.0);
 
   for (size_t k = 1; k < nlevels; ++k)
-    {
-      auto depth = &fullDepth[k * gridsize];
-      auto depthm1 = &fullDepth[(k - 1) * gridsize];
-      auto thickm1 = &thick_c[(k - 1) * gridsize];
-      for (size_t i = 0; i < gridsize; ++i) depth[i] = depthm1[i] + stretch_c[i] * thickm1[i];
-    }
+  {
+    auto depth = &fullDepth[k * gridsize];
+    auto depthm1 = &fullDepth[(k - 1) * gridsize];
+    auto thickm1 = &thick_c[(k - 1) * gridsize];
+    for (size_t i = 0; i < gridsize; ++i) depth[i] = depthm1[i] + stretch_c[i] * thickm1[i];
+  }
 
   for (size_t k = 0; k < nlevels; ++k)
-    {
-      auto depth = &fullDepth[k * gridsize];
-      auto thick = &thick_c[k * gridsize];
-      for (size_t i = 0; i < gridsize; ++i) depth[i] += 0.5 * stretch_c[i] * thick[i] - zos[i];
-    }
+  {
+    auto depth = &fullDepth[k * gridsize];
+    auto thick = &thick_c[k * gridsize];
+    for (size_t i = 0; i < gridsize; ++i) depth[i] += 0.5 * stretch_c[i] * thick[i] - zos[i];
+  }
 }
 
 static void
@@ -61,14 +61,14 @@ public:
   };
   inline static RegisterEntry<Depth> registration = RegisterEntry<Depth>(module);
 
-  CdoStreamID streamID1;
-  int taxisID1;
+private:
+  CdoStreamID streamID1{};
+  CdoStreamID streamID2{};
+  int taxisID1{ CDI_UNDEFID };
+  int taxisID2{ CDI_UNDEFID };
 
-  CdoStreamID streamID2;
-  int taxisID2;
-
-  int nlevels;
-  int depthID;
+  int numLevels{};
+  int depthID{};
   int thickID = -1, zosID = -1, stretchID = -1, draftaveID = -1;
 
   Field3DVector vardata1;
@@ -88,30 +88,29 @@ public:
     VarList varList1(vlistID1);
     varList_set_unique_memtype(varList1);
 
-    auto nvars = vlistNvars(vlistID1);
+    auto numVars = varList1.numVars();
+    for (int varID = 0; varID < numVars; ++varID)
+    {
+      auto varname = string_to_lower(varList1.vars[varID].name);
 
-    for (int varID = 0; varID < nvars; ++varID)
-      {
-        auto varname = string_to_lower(varList1.vars[varID].name);
-
-        // clang-format off
-        if      (varname == "prism_thick_c") thickID = varID;
-        else if (varname == "stretch_c")     stretchID = varID;
-        else if (varname == "zos")           zosID = varID;
-        else if (varname == "draftave")      draftaveID = varID;
-        // clang-format on
-      }
+      // clang-format off
+      if      (varname == "prism_thick_c") thickID = varID;
+      else if (varname == "stretch_c")     stretchID = varID;
+      else if (varname == "zos")           zosID = varID;
+      else if (varname == "draftave")      draftaveID = varID;
+      // clang-format on
+    }
 
     if (Options::cdoVerbose)
-      {
-        cdo_print("Found:");
-        // clang-format off
-        if (-1 != thickID)    cdo_print("  %s -> %s", "prism thickness at cells", varList1.vars[thickID].name);
-        if (-1 != stretchID)  cdo_print("  %s -> %s", "zstar surface stretch at cell center", varList1.vars[stretchID].name);
-        if (-1 != zosID)      cdo_print("  %s -> %s", "zstar sfc elevation at cell center", varList1.vars[zosID].name);
-        if (-1 != draftaveID) cdo_print("  %s -> %s", "draftave", varList1.vars[draftaveID].name);
-        // clang-format on
-      }
+    {
+      cdo_print("Found:");
+      // clang-format off
+      if (-1 != thickID)    cdo_print("  %s -> %s", "prism thickness at cells", varList1.vars[thickID].name);
+      if (-1 != stretchID)  cdo_print("  %s -> %s", "zstar surface stretch at cell center", varList1.vars[stretchID].name);
+      if (-1 != zosID)      cdo_print("  %s -> %s", "zstar sfc elevation at cell center", varList1.vars[zosID].name);
+      if (-1 != draftaveID) cdo_print("  %s -> %s", "draftave", varList1.vars[draftaveID].name);
+      // clang-format on
+    }
 
     if (-1 == thickID) cdo_abort("prism_thick_c not found!");
     if (-1 == stretchID) cdo_abort("stretch_c not found!");
@@ -119,7 +118,7 @@ public:
     if (-1 == draftaveID) cdo_warning("draftave not found, set to zero!");
 
     auto zaxisID = varList1.vars[thickID].zaxisID;
-    nlevels = varList1.vars[thickID].nlevels;
+    numLevels = varList1.vars[thickID].nlevels;
 
     auto numGrids = vlistNumGrids(vlistID1);
     if (numGrids > 1) cdo_abort("Too many different grids!");
@@ -128,7 +127,7 @@ public:
     auto gridID = vlistGrid(vlistID1, index);
 
     auto vlistID2 = vlistCreate();
-    vlistDefNtsteps(vlistID2, vlistNtsteps(vlistID1));
+    vlistDefNtsteps(vlistID2, varList1.numSteps());
     vlistDefTaxis(vlistID2, taxisID2);
 
     depthID = vlistDefVar(vlistID2, gridID, zaxisID, TIME_VARYING);
@@ -137,9 +136,9 @@ public:
     cdiDefKeyString(vlistID2, depthID, CDI_KEY_STDNAME, "depth");
     cdiDefKeyString(vlistID2, depthID, CDI_KEY_LONGNAME, "depth_below_sea");
 
-    vardata1 = Field3DVector(nvars);
+    vardata1 = Field3DVector(numVars);
 
-    for (int varID = 0; varID < nvars; ++varID) vardata1[varID].init(varList1.vars[varID]);
+    for (int varID = 0; varID < numVars; ++varID) vardata1[varID].init(varList1.vars[varID]);
 
     fullDepth.init(varList1.vars[thickID]);
 
@@ -152,32 +151,32 @@ public:
   {
     int tsID = 0;
     while (true)
+    {
+      auto numFields = cdo_stream_inq_timestep(streamID1, tsID);
+      if (numFields == 0) break;
+
+      cdo_taxis_copy_timestep(taxisID2, taxisID1);
+      cdo_def_timestep(streamID2, tsID);
+
+      for (int fieldID = 0; fieldID < numFields; ++fieldID)
       {
-        auto numFields = cdo_stream_inq_timestep(streamID1, tsID);
-        if (numFields == 0) break;
-
-        cdo_taxis_copy_timestep(taxisID2, taxisID1);
-        cdo_def_timestep(streamID2, tsID);
-
-        for (int fieldID = 0; fieldID < numFields; ++fieldID)
-          {
-            auto [varID, levelID] = cdo_inq_field(streamID1);
-            size_t numMissVals;
-            cdo_read_field(streamID1, vardata1[varID], levelID, &numMissVals);
-            if (numMissVals) cdo_abort("Missing values unsupported!");
-          }
-
-        if (-1 != draftaveID) field2_add(vardata1[zosID], vardata1[draftaveID]);
-        calc_full_depth(vardata1[thickID], vardata1[stretchID], vardata1[zosID], fullDepth);
-
-        for (int levelID = 0; levelID < nlevels; ++levelID)
-          {
-            cdo_def_field(streamID2, depthID, levelID);
-            cdo_write_field(streamID2, fullDepth, levelID, 0);
-          }
-
-        tsID++;
+        auto [varID, levelID] = cdo_inq_field(streamID1);
+        size_t numMissVals;
+        cdo_read_field(streamID1, vardata1[varID], levelID, &numMissVals);
+        if (numMissVals) cdo_abort("Missing values unsupported!");
       }
+
+      if (-1 != draftaveID) field2_add(vardata1[zosID], vardata1[draftaveID]);
+      calc_full_depth(vardata1[thickID], vardata1[stretchID], vardata1[zosID], fullDepth);
+
+      for (int levelID = 0; levelID < numLevels; ++levelID)
+      {
+        cdo_def_field(streamID2, depthID, levelID);
+        cdo_write_field(streamID2, fullDepth, levelID, 0);
+      }
+
+      tsID++;
+    }
   }
 
   void
