@@ -29,15 +29,18 @@
 #include "pmlist.h"
 #include "progress.h"
 
+namespace
+{
 struct DiffResult
 {
-  size_t nvals{ 0 };
-  size_t ndiff{ 0 };
-  double absm{ 0.0 };
-  double relm{ 0.0 };
-  bool dsgn{ false };
-  bool zero{ false };
+  size_t nvals{};
+  size_t ndiff{};
+  double absm{};
+  double relm{};
+  bool dsgn{};
+  bool zero{};
 };
+}  // namespace
 
 static inline void
 diff_kernel(double v1, double v2, DiffResult &result)
@@ -64,37 +67,39 @@ diff_kernel_mv(double v1, double v2, double missval1, double missval2, DiffResul
   auto v1IsMissval = fp_is_equal(v1, missval1);
   auto v2IsMissval = fp_is_equal(v2, missval2);
   if (v1IsNan != v2IsNan)
-    {
-      result.ndiff++;
-      result.relm = 1.0;
-    }
+  {
+    result.ndiff++;
+    result.relm = 1.0;
+  }
   else if (!v1IsMissval && !v2IsMissval) { diff_kernel(v1, v2, result); }
   else if (v1IsMissval != v2IsMissval)
-    {
-      result.ndiff++;
-      result.relm = 1.0;
-    }
+  {
+    result.ndiff++;
+    result.relm = 1.0;
+  }
 }
 
 static DiffResult
-diff(size_t n, const Field &field1, const Field &field2)
+diff(size_t n, Field const &field1, Field const &field2)
 {
   DiffResult diffParam;
   auto hasMissvals = (field1.numMissVals || field2.numMissVals);
   if (hasMissvals)
+  {
+    auto func = [&](auto const &v1, auto const &v2, double mv1, double mv2)
     {
-      auto func = [&](const auto &v1, const auto &v2, double mv1, double mv2) {
-        for (size_t i = 0; i < n; ++i) { diff_kernel_mv(v1[i], v2[i], mv1, mv2, diffParam); }
-      };
-      field_operation2(func, field1, field2, field1.missval, field2.missval);
-    }
+      for (size_t i = 0; i < n; ++i) { diff_kernel_mv(v1[i], v2[i], mv1, mv2, diffParam); }
+    };
+    field_operation2(func, field1, field2, field1.missval, field2.missval);
+  }
   else
+  {
+    auto func = [&](auto const &v1, auto const &v2)
     {
-      auto func = [&](const auto &v1, const auto &v2) {
-        for (size_t i = 0; i < n; ++i) { diff_kernel(v1[i], v2[i], diffParam); }
-      };
-      field_operation2(func, field1, field2);
-    }
+      for (size_t i = 0; i < n; ++i) { diff_kernel(v1[i], v2[i], diffParam); }
+    };
+    field_operation2(func, field1, field2);
+  }
 
   return diffParam;
 }
@@ -106,41 +111,40 @@ diff_kernel2(double v1, double v2, DiffResult &result)
   if (absdiff > 0.0) result.ndiff++;
 
   auto vv = v1 * v2;
-  if (vv < 0.0)
-    result.dsgn = true;
-  else if (is_equal(vv, 0.0))
-    result.zero = true;
+  if (vv < 0.0) { result.dsgn = true; }
+  else if (is_equal(vv, 0.0)) { result.zero = true; }
   else
-    {
-      auto error = std::fabs(absdiff / v1);
-      result.absm = std::max(result.absm, error);
-      result.relm += error;
-      result.nvals++;
-    }
+  {
+    auto error = std::fabs(absdiff / v1);
+    result.absm = std::max(result.absm, error);
+    result.relm += error;
+    result.nvals++;
+  }
 }
 
 static DiffResult
-diff2(size_t n, const Field &field1, const Field &field2)
+diff2(size_t n, Field const &field1, Field const &field2)
 {
   DiffResult diffParam;
   auto hasMissvals = (field1.numMissVals || field2.numMissVals);
   if (hasMissvals)
-    {
-      /*
+  {
+    /*
     auto func = [&](auto &v1, auto &v2, double mv1, double mv2) {
       for (size_t i = 0; i < n; ++i) { diff_kernel_mv(v1[i], v2[i], mv1, mv2, diffParam); }
     };
     field_operation2(func, field1, field2, field1.missval, field2.missval);
     */
-    }
+  }
   else
+  {
+    auto func = [&](auto const &v1, auto const &v2)
     {
-      auto func = [&](const auto &v1, const auto &v2) {
-        for (size_t i = 0; i < n; ++i) { diff_kernel2(v1[i], v2[i], diffParam); }
-      };
-      field_operation2(func, field1, field2);
-      if (diffParam.nvals > 0) diffParam.relm /= diffParam.nvals;
-    }
+      for (size_t i = 0; i < n; ++i) { diff_kernel2(v1[i], v2[i], diffParam); }
+    };
+    field_operation2(func, field1, field2);
+    if (diffParam.nvals > 0) diffParam.relm /= diffParam.nvals;
+  }
 
   return diffParam;
 }
@@ -148,7 +152,8 @@ diff2(size_t n, const Field &field1, const Field &field2)
 static void
 use_real_part(Field &field)
 {
-  auto func = [](auto &v) {
+  auto func = [](auto &v)
+  {
     auto n = v.size() / 2;
     for (size_t i = 0; i < n; ++i) v[i] = v[i * 2];
   };
@@ -156,7 +161,9 @@ use_real_part(Field &field)
   return field_operation(func, field);
 }
 
-struct DiffParam
+namespace
+{
+struct Parameter
 {
   double absLimit{ 0.0 };
   double absLimit2{ 1.e-3 };
@@ -167,51 +174,52 @@ struct DiffParam
   int numDiffFields2{ 0 };
   bool printHeader{ true };
 };
+}  // namespace
 
-static DiffParam
+static Parameter
 get_parameter(void)
 {
-  DiffParam params;
+  Parameter params;
 
-  auto pargc = cdo_operator_argc();
-  if (pargc)
+  auto numArgs = cdo_operator_argc();
+  if (numArgs)
+  {
+    auto const &argList = cdo_get_oper_argv();
+
+    KVList kvlist;
+    kvlist.name = cdo_module_name();
+    if (kvlist.parse_arguments(argList) != 0) cdo_abort("Parse error!");
+    if (Options::cdoVerbose) kvlist.print();
+
+    for (auto const &kv : kvlist)
     {
-      const auto &pargv = cdo_get_oper_argv();
+      auto const &key = kv.key;
+      if (kv.nvalues > 1) cdo_abort("Too many values for parameter key >%s<!", key);
+      if (kv.nvalues < 1) cdo_abort("Missing value for parameter key >%s<!", key);
+      auto const &value = kv.values[0];
 
-      KVList kvlist;
-      kvlist.name = cdo_module_name();
-      if (kvlist.parse_arguments(pargv) != 0) cdo_abort("Parse error!");
-      if (Options::cdoVerbose) kvlist.print();
-
-      for (const auto &kv : kvlist)
-        {
-          const auto &key = kv.key;
-          if (kv.nvalues > 1) cdo_abort("Too many values for parameter key >%s<!", key);
-          if (kv.nvalues < 1) cdo_abort("Missing value for parameter key >%s<!", key);
-          const auto &value = kv.values[0];
-
-          // clang-format off
-          if      (key == "abslim")   params.absLimit = parameter_to_double(value);
-          else if (key == "abslim2")  params.absLimit2 = parameter_to_double(value);
-          else if (key == "rellim")   params.relLimit = parameter_to_double(value);
-          else if (key == "maxcount") params.maxDiffFields = parameter_to_int(value);
-          else if (key == "names")
-            {
-              if      (value == "left")      params.mapFlag = MapFlag::Left;
-              else if (value == "right")     params.mapFlag = MapFlag::Right;
-              else if (value == "intersect") params.mapFlag = MapFlag::Intersect;
-              else cdo_abort("Invalid value for key >%s< (names=<left/right/intersect>)", key, value);
-            }
-          else cdo_abort("Invalid parameter key >%s<!", key);
-          // clang-format on
-        }
+      // clang-format off
+      if      (key == "abslim")   params.absLimit = parameter_to_double(value);
+      else if (key == "abslim2")  params.absLimit2 = parameter_to_double(value);
+      else if (key == "rellim")   params.relLimit = parameter_to_double(value);
+      else if (key == "maxcount") params.maxDiffFields = parameter_to_int(value);
+      else if (key == "names")
+      {
+        if      (value == "left")      params.mapFlag = MapFlag::Left;
+        else if (value == "right")     params.mapFlag = MapFlag::Right;
+        else if (value == "intersect") params.mapFlag = MapFlag::Intersect;
+        else cdo_abort("Invalid value for key >%s< (names=<left/right/intersect>)", key, value);
+      }
+      else cdo_abort("Invalid parameter key >%s<!", key);
+      // clang-format on
     }
+  }
 
   return params;
 }
 
 static void
-print_header(int operfunc, DiffParam &params)
+print_header(int operfunc, Parameter &params)
 {
   params.printHeader = false;
 
@@ -227,7 +235,7 @@ print_header(int operfunc, DiffParam &params)
 }
 
 static void
-print_header2(int operfunc, DiffParam &params)
+print_header2(int operfunc, Parameter &params)
 {
   params.printHeader = false;
 
@@ -243,8 +251,8 @@ print_header2(int operfunc, DiffParam &params)
 }
 
 void
-print_diff(const Field &field1, const Field &field2, int fieldNumber, CdoVar const &var1, int levelID, int operfunc,
-           CdiDateTime const &vDateTime, DiffParam &params, int operfunc2, const DiffResult &dr)
+print_diff(Field const &field1, Field const &field2, int fieldNumber, CdoVar const &var1, int levelID, int operfunc,
+           CdiDateTime const &vDateTime, Parameter &params, int operfunc2, const DiffResult &dr)
 {
   if (params.printHeader) (operfunc2 == 0) ? print_header(operfunc, params) : print_header2(operfunc, params);
 
@@ -275,9 +283,9 @@ print_diff(const Field &field1, const Field &field2, int fieldNumber, CdoVar con
 
   set_text_color(stdout, BRIGHT, GREEN);
   // clang-format off
-          if      (operfunc == Func_Name)  fprintf(stdout, "%-11s", var1.name.c_str());
-          else if (operfunc == Func_Param) fprintf(stdout, "%-11s", paramstr);
-          else if (operfunc == Func_Code)  fprintf(stdout, "%4d", var1.code);
+  if      (operfunc == Func_Name)  fprintf(stdout, "%-11s", var1.name.c_str());
+  else if (operfunc == Func_Param) fprintf(stdout, "%-11s", paramstr);
+  else if (operfunc == Func_Code)  fprintf(stdout, "%4d", var1.code);
   // clang-format on
   reset_text_color(stdout);
 
@@ -286,34 +294,34 @@ print_diff(const Field &field1, const Field &field2, int fieldNumber, CdoVar con
 
 static void
 compare_fields(Field &field1, Field &field2, int fieldNumber, CdoVar &var1, int levelID, int operfunc, CdiDateTime vDateTime,
-               DiffParam &params, int operfunc2, cdo::Progress &progress)
+               Parameter &params, int operfunc2, cdo::Progress &progress)
 {
   size_t numNANs1 = (Options::fast || std::isnan(field1.missval)) ? 0 : field_num_NANs(field1);
   var1.counter += numNANs1;
   if (numNANs1 && field1.numMissVals == 0)
-    {
-      field1.missval = cdo::NaN();
-      field1.numMissVals = numNANs1;
-    }
+  {
+    field1.missval = cdo::NaN();
+    field1.numMissVals = numNANs1;
+  }
   size_t numNANs2 = (Options::fast || std::isnan(field2.missval)) ? 0 : field_num_NANs(field2);
   var1.counter += numNANs2;
   if (numNANs2 && field2.numMissVals == 0)
-    {
-      field2.missval = cdo::NaN();
-      field2.numMissVals = numNANs2;
-    }
+  {
+    field2.missval = cdo::NaN();
+    field2.numMissVals = numNANs2;
+  }
 
   auto dr = (operfunc2 == 0) ? diff(var1.gridsize, field1, field2) : diff2(var1.gridsize, field1, field2);
 
   auto checkRelativeLimit = true;
   if (!Options::silentMode || Options::cdoVerbose)
+  {
+    if (dr.absm > params.absLimit || (checkRelativeLimit && dr.relm >= params.relLimit) || Options::cdoVerbose)
     {
-      if (dr.absm > params.absLimit || (checkRelativeLimit && dr.relm >= params.relLimit) || Options::cdoVerbose)
-        {
-          progress.update(1);
-          print_diff(field1, field2, fieldNumber, var1, levelID, operfunc, vDateTime, params, operfunc2, dr);
-        }
+      progress.update(1);
+      print_diff(field1, field2, fieldNumber, var1, levelID, operfunc, vDateTime, params, operfunc2, dr);
     }
+  }
 
   if (dr.absm > params.absLimit || (checkRelativeLimit && dr.relm >= params.relLimit)) params.numDiffFields++;
   if (dr.absm > params.absLimit2 || (checkRelativeLimit && dr.relm >= params.relLimit)) params.numDiffFields2++;
@@ -339,20 +347,21 @@ public:
   };
   inline static RegisterEntry<Diff> registration = RegisterEntry<Diff>(module);
 
-  int operfunc;
-  int operfunc2;
+private:
+  int operfunc{};
+  int operfunc2{};
 
-  DiffParam params;
+  Parameter params{};
 
-  CdoStreamID streamID1;
-  CdoStreamID streamID2;
+  CdoStreamID streamID1{};
+  CdoStreamID streamID2{};
 
-  int taxisID;
+  int taxisID{};
 
-  std::map<int, int> mapOfVarIDs;
+  std::map<int, int> mapOfVarIDs{};
 
-  VarList varList1;
-  VarList varList2;
+  VarList varList1{};
+  VarList varList2{};
 
 public:
   void
@@ -383,10 +392,10 @@ public:
     varList2 = VarList(vlistID2);
 
     if (params.mapFlag == MapFlag::Undefined)
-      {
-        varList_compare(varList1, varList2);
-        for (const auto &var : varList1.vars) mapOfVarIDs[var.ID] = var.ID;
-      }
+    {
+      varList_compare(varList1, varList2);
+      for (auto const &var : varList1.vars) mapOfVarIDs[var.ID] = var.ID;
+    }
     else { varList_map(varList1, varList2, params.mapFlag, mapOfVarIDs); }
 
     taxisID = vlistInqTaxis(vlistID1);
@@ -396,7 +405,7 @@ public:
   run() override
   {
     auto runAsync = (Options::CDO_Async_Read > 0);
-    auto task = runAsync ? std::make_unique<WorkerThread>() : nullptr;
+    auto workerThread = runAsync ? std::make_unique<WorkerThread>() : nullptr;
     auto numTasks = runAsync ? 2 : 1;
 
     FieldVector fieldVector1(numTasks);
@@ -409,118 +418,118 @@ public:
     int numFields, numFields2;
     int tsID = 0;
     while (true)
+    {
+      auto stopRead = false;
+
+      numFields = cdo_stream_inq_timestep(streamID1, tsID);
+      auto vDateTime = taxisInqVdatetime(taxisID);
+
+      numFields2 = cdo_stream_inq_timestep(streamID2, tsID);
+
+      if (numFields == 0 || numFields2 == 0) break;
+
+      if (numSteps1 > 1 && params.numDiffFields == 0) progress.update((tsID + 1.0) / numSteps1);
+
+      int fieldID2next = 0;
+
+      for (int fieldID = 0; fieldID < numFields; ++fieldID)
       {
-        auto stopRead = false;
+        auto [varID1, levelID] = cdo_inq_field(streamID1);
 
-        numFields = cdo_stream_inq_timestep(streamID1, tsID);
-        auto vDateTime = taxisInqVdatetime(taxisID);
+        auto it = mapOfVarIDs.find(varID1);
+        if (it == mapOfVarIDs.end())
+        {
+          if (params.mapFlag == MapFlag::Right || params.mapFlag == MapFlag::Intersect) continue;
+          cdo_abort("Internal problem (tsID=%d fieldID=%d): varID1=%d not found!", tsID + 1, fieldID + 1, varID1);
+        }
 
-        numFields2 = cdo_stream_inq_timestep(streamID2, tsID);
-
-        if (numFields == 0 || numFields2 == 0) break;
-
-        if (numSteps1 > 1 && params.numDiffFields == 0) progress.update((tsID + 1.0) / numSteps1);
-
-        int fieldID2next = 0;
-
-        for (int fieldID = 0; fieldID < numFields; ++fieldID)
+        int varID2 = 0;
+        for (; fieldID2next < numFields2; ++fieldID2next)
+        {
+          auto [varID2x, levelID2x] = cdo_inq_field(streamID2);
+          varID2 = varID2x;
+          if (it->second == varID2)
           {
-            auto [varID1, levelID] = cdo_inq_field(streamID1);
-
-            auto it = mapOfVarIDs.find(varID1);
-            if (it == mapOfVarIDs.end())
-              {
-                if (params.mapFlag == MapFlag::Right || params.mapFlag == MapFlag::Intersect) continue;
-                cdo_abort("Internal problem (tsID=%d fieldID=%d): varID1=%d not found!", tsID + 1, fieldID + 1, varID1);
-              }
-
-            int varID2 = 0;
-            for (; fieldID2next < numFields2; ++fieldID2next)
-              {
-                auto [varID2x, levelID2x] = cdo_inq_field(streamID2);
-                varID2 = varID2x;
-                if (it->second == varID2)
-                  {
-                    ++fieldID2next;
-                    break;
-                  }
-              }
-
-            if (it->second != varID2 && fieldID2next == numFields2)
-              cdo_abort("Internal problem (tsID=%d fieldID=%d): varID2=%d not found in second stream!", tsID + 1, fieldID + 1,
-                        it->second);
-
-            auto &var1 = varList1.vars[varID1];
-            auto &var2 = varList2.vars[varID2];
-
-            auto taskNum = numSets % numTasks;
-            auto &field1 = fieldVector1[taskNum];
-            auto &field2 = fieldVector2[taskNum];
-
-            field1.init(var1);
-            cdo_read_field(streamID1, field1);
-            if (var1.nwpv == CDI_COMP) use_real_part(field1);
-
-            field2.init(var2);
-            cdo_read_field(streamID2, field2);
-            if (var2.nwpv == CDI_COMP) use_real_part(field2);
-
-            if (runAsync && numSets > 0)
-              {
-                task->wait();
-                // clang-format off
-                if (params.numDiffFields >= params.maxDiffFields) { stopRead = true; break; }
-                // clang-format on
-              }
-
-            std::function<void()> compare_fields_func
-                = std::bind(compare_fields, std::ref(field1), std::ref(field2), numSets + 1, std::ref(var1), levelID, operfunc,
-                            vDateTime, std::ref(params), operfunc2, std::ref(progress));
-            runAsync ? task->doAsync(compare_fields_func) : compare_fields_func();
-
-            if (not runAsync)
-              {
-                // clang-format off
-                if (params.numDiffFields >= params.maxDiffFields) { stopRead = true; break; }
-                // clang-format on
-              }
-
-            numSets++;
+            ++fieldID2next;
+            break;
           }
+        }
 
-        if (stopRead) break;
+        if (it->second != varID2 && fieldID2next == numFields2)
+          cdo_abort("Internal problem (tsID=%d fieldID=%d): varID2=%d not found in second stream!", tsID + 1, fieldID + 1,
+                    it->second);
 
-        tsID++;
+        auto &var1 = varList1.vars[varID1];
+        auto &var2 = varList2.vars[varID2];
+
+        auto taskNum = numSets % numTasks;
+        auto &field1 = fieldVector1[taskNum];
+        auto &field2 = fieldVector2[taskNum];
+
+        field1.init(var1);
+        cdo_read_field(streamID1, field1);
+        if (var1.nwpv == CDI_COMP) use_real_part(field1);
+
+        field2.init(var2);
+        cdo_read_field(streamID2, field2);
+        if (var2.nwpv == CDI_COMP) use_real_part(field2);
+
+        if (runAsync && numSets > 0)
+        {
+          workerThread->wait();
+          // clang-format off
+          if (params.numDiffFields >= params.maxDiffFields) { stopRead = true; break; }
+          // clang-format on
+        }
+
+        std::function<void()> compare_fields_task
+            = std::bind(compare_fields, std::ref(field1), std::ref(field2), numSets + 1, std::ref(var1), levelID, operfunc,
+                        vDateTime, std::ref(params), operfunc2, std::ref(progress));
+        runAsync ? workerThread->doAsync(compare_fields_task) : compare_fields_task();
+
+        if (not runAsync)
+        {
+          // clang-format off
+          if (params.numDiffFields >= params.maxDiffFields) { stopRead = true; break; }
+          // clang-format on
+        }
+
+        numSets++;
       }
 
-    if (runAsync) task->wait();
+      if (stopRead) break;
+
+      tsID++;
+    }
+
+    if (runAsync) workerThread->wait();
 
     if (params.numDiffFields > 0)
-      {
-        Options::cdoExitStatus = 1;
+    {
+      Options::cdoExitStatus = 1;
 
-        set_text_color(stdout, BRIGHT, RED);
-        fprintf(stdout, "  %d of %d fields differ", params.numDiffFields, numSets);
-        reset_text_color(stdout);
-        fprintf(stdout, "\n");
+      set_text_color(stdout, BRIGHT, RED);
+      fprintf(stdout, "  %d of %d fields differ", params.numDiffFields, numSets);
+      reset_text_color(stdout);
+      fprintf(stdout, "\n");
 
-        if (params.numDiffFields != params.numDiffFields2 && params.absLimit < params.absLimit2)
-          fprintf(stdout, "  %d of %d fields differ more than %g\n", params.numDiffFields2, numSets, params.absLimit2);
-        //  fprintf(stdout, "  %d of %d fields differ more then one thousandth\n", nprec, ngrec);
-      }
+      if (params.numDiffFields != params.numDiffFields2 && params.absLimit < params.absLimit2)
+        fprintf(stdout, "  %d of %d fields differ more than %g\n", params.numDiffFields2, numSets, params.absLimit2);
+      //  fprintf(stdout, "  %d of %d fields differ more then one thousandth\n", nprec, ngrec);
+    }
 
     if (numFields == 0 && numFields2 > 0) cdo_warning("stream2 has more time steps than stream1!");
     if (numFields > 0 && numFields2 == 0) cdo_warning("stream1 has more time steps than stream2!");
 
     for (auto const &var : varList1.vars)
+    {
+      if (var.counter > 0)
       {
-        if (var.counter > 0)
-          {
-            cdo_warning("%s contains %zu NaNs which are not treated as missing values. "
-                        "This can lead to incorrect CDO results in all other arithmetic functions!",
-                        var.name, var.counter);
-          }
+        cdo_warning("%s contains %zu NaNs which are not treated as missing values. "
+                    "This can lead to incorrect CDO results in all other arithmetic functions!",
+                    var.name, var.counter);
       }
+    }
   }
 
   void
