@@ -62,7 +62,7 @@ static const char R95P_LONGNAME[]
    for each day of year
    the day of each window day */
 static void
-windowDays(int dayOfYear, std::vector<int> &wdays, const std::vector<bool> &wdaysRead, int MaxDays, int ndates, int sumboot)
+windowDays(int dayOfYear, std::vector<int> &wdays, std::vector<bool> const &wdaysRead, int MaxDays, int ndates, int sumboot)
 {
   int wdayOfYear = dayOfYear;
   for (int gobackDays = ceil(ndates / 2. - 1); gobackDays != 0; gobackDays--)
@@ -93,7 +93,7 @@ windowDays(int dayOfYear, std::vector<int> &wdays, const std::vector<bool> &wday
 
 static void
 writeTimesteps(int MaxMonths, int recentYear, FieldVector3D &cei, int frequency, int taxisID4, const CdoStreamID &streamID4,
-               int *otsID, const VarList &varList1, const std::vector<FieldInfo> &fieldInfoList, const std::vector<int> &tempdpm,
+               int *otsID, VarList const &varList1, std::vector<FieldInfo> const &fieldInfoList, std::vector<int> const &tempdpm,
                int tempdpy, int func2)
 {
   const int maxRecs = fieldInfoList.size();
@@ -135,8 +135,8 @@ writeTimesteps(int MaxMonths, int recentYear, FieldVector3D &cei, int frequency,
 
 static void
 calculateOuterPeriod(Field &field, int MaxMonths, int recentYear, int endOfCalc, FieldVector3D &cei, FieldVector3D &varsPtemp,
-                     int frequency, int taxisID4, const CdoStreamID &streamID4, int *otsID, const VarList &varList1,
-                     const std::vector<FieldInfo> &fieldInfoList, int selection, int func2)
+                     int frequency, int taxisID4, const CdoStreamID &streamID4, int *otsID, VarList const &varList1,
+                     std::vector<FieldInfo> const &fieldInfoList, int selection, int func2)
 {
   if (cdo_assert_files_only() == false) cdo_abort("This operator can't be combined with other operators!");
 
@@ -358,7 +358,7 @@ etccdi_op(ETCCDI_REQUEST &request)
           field2D_init(varsPtemp[dayOfYear], varList2, FIELD_VEC);
           hsets[dayOfYear].create(numVars);
 
-          for (const auto &var : varList1.vars) hsets[dayOfYear].createVarLevels(var.ID, var.nlevels, var.gridsize);
+          for (auto const &var : varList1.vars) hsets[dayOfYear].createVarLevels(var.ID, var.nlevels, var.gridsize);
         }
 
       for (int fieldID = 0; fieldID < numFields; ++fieldID)
@@ -459,7 +459,7 @@ etccdi_op(ETCCDI_REQUEST &request)
 
   for (int varID = 0; varID < numVars; ++varID)
     {
-      const auto &var1 = varList1.vars[varID];
+      auto const &var1 = varList1.vars[varID];
       if (var1.isConstant) continue;
       for (int levelID = 0; levelID < var1.nlevels; ++levelID)
         {
@@ -509,7 +509,7 @@ etccdi_op(ETCCDI_REQUEST &request)
     {
       for (int varID = 0; varID < numVars; ++varID)
         {
-          const auto &var1 = varList1.vars[varID];
+          auto const &var1 = varList1.vars[varID];
           if (var1.isConstant) continue;
           for (int levelID = 0; levelID < var1.nlevels; ++levelID)
             {
