@@ -1,18 +1,8 @@
 /*
-  This file is part of CDO. CDO is a collection of Operators to
-  manipulate and analyse Climate model Data.
+  This file is part of CDO. CDO is a collection of Operators to manipulate and analyse Climate model Data.
 
-  Copyright (C) 2003-2020 Uwe Schulzweida, <uwe.schulzweida AT mpimet.mpg.de>
-  See COPYING file for copying and redistribution conditions.
+  Author: Uwe Schulzweida
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; version 2 of the License.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-  GNU General Public License for more details.
 */
 
 #ifdef HAVE_CONFIG_H
@@ -70,8 +60,8 @@ iniatts(ATTS *atts)
 }
 
 static void
-inivar(VAR &var, int gridtype, int zaxistype, int code, const std::string &name, const std::string &longname,
-       const std::string &units)
+inivar(VAR &var, int gridtype, int zaxistype, int code, std::string const &name, std::string const &longname,
+       std::string const &units)
 {
   var.gridtype = gridtype;
   var.zaxistype = zaxistype;
@@ -194,53 +184,53 @@ import_e5ml(const char *filename, std::vector<VAR> &vars)
 
   size_t start[3], count[3];
   for (int iv = 0; iv < nvars_ml; iv++)
+  {
+    size_t nvals = 0;
+
+    auto gridtype = vars[iv].gridtype;
+
+    if (gridtype == GRID_GAUSSIAN)
     {
-      size_t nvals = 0;
-
-      auto gridtype = vars[iv].gridtype;
-
-      if (gridtype == GRID_GAUSSIAN)
-        {
-          vars[iv].gridID = gridIDgp;
-          nvals += nlon * nlat;
-        }
-      else
-        {
-          vars[iv].gridID = gridIDsp;
-          nvals += nsp * 2;
-        }
-
-      vars[iv].zaxisID = zaxisIDml;
-      vars[iv].gridsize = nvals;
-      vars[iv].nlev = nlev;
-
-      vars[iv].ptr = new double[nlev * nvals];
-
-      for (int i = 0; i < nlev; ++i)
-        {
-          if (gridtype == GRID_GAUSSIAN)
-            {
-              start[0] = 0;
-              start[1] = i;
-              start[2] = 0;
-              count[0] = nlat;
-              count[1] = 1;
-              count[2] = nlon;
-            }
-          else
-            {
-              start[0] = 0;
-              start[1] = 0;
-              start[2] = i;
-              count[0] = nsp;
-              count[1] = 2;
-              count[2] = 1;
-            }
-
-          nce(nc_inq_varid(nc_file_id, vars[iv].name.c_str(), &nc_var_id));
-          nce(nc_get_vara_double(nc_file_id, nc_var_id, start, count, vars[iv].ptr + i * nvals));
-        }
+      vars[iv].gridID = gridIDgp;
+      nvals += nlon * nlat;
     }
+    else
+    {
+      vars[iv].gridID = gridIDsp;
+      nvals += nsp * 2;
+    }
+
+    vars[iv].zaxisID = zaxisIDml;
+    vars[iv].gridsize = nvals;
+    vars[iv].nlev = nlev;
+
+    vars[iv].ptr = new double[nlev * nvals];
+
+    for (int i = 0; i < nlev; ++i)
+    {
+      if (gridtype == GRID_GAUSSIAN)
+      {
+        start[0] = 0;
+        start[1] = i;
+        start[2] = 0;
+        count[0] = nlat;
+        count[1] = 1;
+        count[2] = nlon;
+      }
+      else
+      {
+        start[0] = 0;
+        start[1] = 0;
+        start[2] = i;
+        count[0] = nsp;
+        count[1] = 2;
+        count[2] = 1;
+      }
+
+      nce(nc_inq_varid(nc_file_id, vars[iv].name.c_str(), &nc_var_id));
+      nce(nc_get_vara_double(nc_file_id, nc_var_id, start, count, vars[iv].ptr + i * nvals));
+    }
+  }
 
   // read lsp
 
@@ -284,17 +274,17 @@ export_e5ml(const char *filename, const std::vector<VAR> &vars, int nvars, int v
   timestr[0] = 0;
 
   if (date_and_time_in_sec != -1)
-    {
-      auto date_and_time = localtime(&date_and_time_in_sec);
-      (void) strftime(timestr, sizeof(timestr), "%d/%m/%Y %H:%M", date_and_time);
-    }
+  {
+    auto date_and_time = localtime(&date_and_time_in_sec);
+    (void) strftime(timestr, sizeof(timestr), "%d/%m/%Y %H:%M", date_and_time);
+  }
 
   const char *username = getenv("LOGNAME");
   if (username == nullptr)
-    {
-      username = getenv("USER");
-      if (username == nullptr) username = "unknown";
-    }
+  {
+    username = getenv("USER");
+    if (username == nullptr) username = "unknown";
+  }
 
   int n2 = 2;
   int lon = 0;
@@ -305,30 +295,30 @@ export_e5ml(const char *filename, const std::vector<VAR> &vars, int nvars, int v
   int nvclev = 0;
   int gridIDgp = -1, zaxisIDml = -1;
   for (int varid = 0; varid < nvars; ++varid)
+  {
+    auto gridtype = vars[varid].gridtype;
+    auto zaxistype = vars[varid].zaxistype;
+
+    if (gridtype == GRID_GAUSSIAN && lat == 0)
     {
-      auto gridtype = vars[varid].gridtype;
-      auto zaxistype = vars[varid].zaxistype;
-
-      if (gridtype == GRID_GAUSSIAN && lat == 0)
-        {
-          gridIDgp = vars[varid].gridID;
-          lon = gridInqXsize(vars[varid].gridID);
-          lat = gridInqYsize(vars[varid].gridID);
-        }
-      else if (gridtype == GRID_SPECTRAL && nsp == 0)
-        {
-          nsp = gridInqSize(vars[varid].gridID);
-          nsp = nsp / 2;
-        }
-
-      if (zaxistype == ZAXIS_HYBRID && nlev == 0)
-        {
-          zaxisIDml = vars[varid].zaxisID;
-          nlev = zaxisInqSize(vars[varid].zaxisID);
-          nlevp1 = nlev + 1;
-          nvclev = nlev + 1;
-        }
+      gridIDgp = vars[varid].gridID;
+      lon = gridInqXsize(vars[varid].gridID);
+      lat = gridInqYsize(vars[varid].gridID);
     }
+    else if (gridtype == GRID_SPECTRAL && nsp == 0)
+    {
+      nsp = gridInqSize(vars[varid].gridID);
+      nsp = nsp / 2;
+    }
+
+    if (zaxistype == ZAXIS_HYBRID && nlev == 0)
+    {
+      zaxisIDml = vars[varid].zaxisID;
+      nlev = zaxisInqSize(vars[varid].zaxisID);
+      nlevp1 = nlev + 1;
+      nvclev = nlev + 1;
+    }
+  }
 
   if (lat == 0) cdo_abort("Gaussian grid not found!");
   if (nsp == 0) cdo_abort("Spectral data not found!");
@@ -341,13 +331,13 @@ export_e5ml(const char *filename, const std::vector<VAR> &vars, int nvars, int v
 
   int writemode = NC_CLOBBER;
   if (data_size * 8 > 2147000000)
-    {
+  {
 #if defined(NC_64BIT_OFFSET)
-      writemode = NC_CLOBBER | NC_64BIT_OFFSET;
+    writemode = NC_CLOBBER | NC_64BIT_OFFSET;
 #else
-      cdoWarning("Datasize > 2GB and NC_64BIT_OFFSET not available!");
+    cdoWarning("Datasize > 2GB and NC_64BIT_OFFSET not available!");
 #endif
-    }
+  }
 
   // create file
   int nc_file_id;
@@ -505,85 +495,85 @@ export_e5ml(const char *filename, const std::vector<VAR> &vars, int nvars, int v
 
   size_t start[3], count[3];
   for (int varid = 0; varid < nvars; varid++)
+  {
+    size_t nvals = 0;
+
+    auto code = vars[varid].code;
+    auto gridtype = vars[varid].gridtype;
+
+    auto ilev = zaxisInqSize(vars[varid].zaxisID);
+
+    if (ilev == 1)
     {
-      size_t nvals = 0;
-
-      auto code = vars[varid].code;
-      auto gridtype = vars[varid].gridtype;
-
-      auto ilev = zaxisInqSize(vars[varid].zaxisID);
-
-      if (ilev == 1)
-        {
-          if (code == 152)
-            {
-              lspid = varid;
-              if (gridtype != GRID_SPECTRAL) cdo_abort("%s has wrong gridtype!", vars[varid].name);
-            }
-          continue;
-        }
-
-      if (nlev != ilev) cdo_abort("Unexpected number of level %d!", ilev);
-
-      int dimidsp[9];
-      if (gridtype == GRID_GAUSSIAN)
-        {
-          nvals = nlon * nlat;
-
-          dimidsp[0] = lat_dimid;
-          dimidsp[1] = nlev_dimid;
-          dimidsp[2] = lon_dimid;
-        }
-      else if (gridtype == GRID_SPECTRAL)
-        {
-          nvals = nsp * 2;
-
-          dimidsp[0] = nsp_dimid;
-          dimidsp[1] = n2_dimid;
-
-          if (vars[varid].name == "STP" || vars[varid].name == "T")
-            dimidsp[2] = nlevp1_dimid;
-          else
-            dimidsp[2] = nlev_dimid;
-        }
-      else
-        cdo_abort("Unsupported grid!");
-
-      nce(nc_redef(nc_file_id));
-      nce(nc_def_var(nc_file_id, vars[varid].name.c_str(), NC_DOUBLE, 3, dimidsp, &nc_var_id));
-      if (vars[varid].longname.size())
-        nce(nc_put_att_text(nc_file_id, nc_var_id, "long_name", vars[varid].longname.size(), vars[varid].longname.c_str()));
-      if (vars[varid].units.size())
-        nce(nc_put_att_text(nc_file_id, nc_var_id, "units", vars[varid].units.size(), vars[varid].units.c_str()));
-      nce(nc_enddef(nc_file_id));
-
-      if (dimidsp[2] == nlevp1_dimid) nc_stpid = nc_var_id;
-
-      for (int i = 0; i < nlev; ++i)
-        {
-          if (gridtype == GRID_GAUSSIAN)
-            {
-              start[0] = 0;
-              start[1] = i;
-              start[2] = 0;
-              count[0] = nlat;
-              count[1] = 1;
-              count[2] = nlon;
-            }
-          else
-            {
-              start[0] = 0;
-              start[1] = 0;
-              start[2] = i;
-              count[0] = nsp;
-              count[1] = 2;
-              count[2] = 1;
-            }
-
-          nce(nc_put_vara_double(nc_file_id, nc_var_id, start, count, vars[varid].ptr + i * nvals));
-        }
+      if (code == 152)
+      {
+        lspid = varid;
+        if (gridtype != GRID_SPECTRAL) cdo_abort("%s has wrong gridtype!", vars[varid].name);
+      }
+      continue;
     }
 
+    if (nlev != ilev) cdo_abort("Unexpected number of level %d!", ilev);
+
+    int dimidsp[9];
+    if (gridtype == GRID_GAUSSIAN)
+    {
+      nvals = nlon * nlat;
+
+      dimidsp[0] = lat_dimid;
+      dimidsp[1] = nlev_dimid;
+      dimidsp[2] = lon_dimid;
+    }
+    else if (gridtype == GRID_SPECTRAL)
+    {
+      nvals = nsp * 2;
+
+      dimidsp[0] = nsp_dimid;
+      dimidsp[1] = n2_dimid;
+
+      if (vars[varid].name == "STP" || vars[varid].name == "T")
+        dimidsp[2] = nlevp1_dimid;
+      else
+        dimidsp[2] = nlev_dimid;
+    }
+    else
+      cdo_abort("Unsupported grid!");
+
+    nce(nc_redef(nc_file_id));
+    nce(nc_def_var(nc_file_id, vars[varid].name.c_str(), NC_DOUBLE, 3, dimidsp, &nc_var_id));
+    if (vars[varid].longname.size())
+      nce(nc_put_att_text(nc_file_id, nc_var_id, "long_name", vars[varid].longname.size(), vars[varid].longname.c_str()));
+    if (vars[varid].units.size())
+      nce(nc_put_att_text(nc_file_id, nc_var_id, "units", vars[varid].units.size(), vars[varid].units.c_str()));
+    nce(nc_enddef(nc_file_id));
+
+    if (dimidsp[2] == nlevp1_dimid) nc_stpid = nc_var_id;
+
+    for (int i = 0; i < nlev; ++i)
+    {
+      if (gridtype == GRID_GAUSSIAN)
+      {
+        start[0] = 0;
+        start[1] = i;
+        start[2] = 0;
+        count[0] = nlat;
+        count[1] = 1;
+        count[2] = nlon;
+      }
+      else
+      {
+        start[0] = 0;
+        start[1] = 0;
+        start[2] = i;
+        count[0] = nsp;
+        count[1] = 2;
+        count[2] = 1;
+      }
+
+      nce(nc_put_vara_double(nc_file_id, nc_var_id, start, count, vars[varid].ptr + i * nvals));
+    }
+  }
+
   if (lspid == -1) cdo_abort("LSP not found!");
   if (nc_stpid == -1) cdo_abort("STP not found!");
 
@@ -625,65 +615,65 @@ public:
 
     int ntr = 0;
     for (int varID = 0; varID < numVars; ++varID)
+    {
+      auto const &var1 = varList1.vars[varID];
+      auto code = var1.code;
+      auto name = var1.name;
+      auto longname = var1.longname;
+      auto units = var1.units;
+
+      if (code < 0) code = 0;
+      if (name.substr(0, 3) == "var")
       {
-        const auto &var1 = varList1.vars[varID];
-        auto code = var1.code;
-        auto name = var1.name;
-        auto longname = var1.longname;
-        auto units = var1.units;
-
-        if (code < 0) code = 0;
-        if (name.substr(0, 3) == "var")
+        if (code > 0)
+        {
+          if (code == 133)
           {
-            if (code > 0)
-              {
-                if (code == 133)
-                  {
-                    name = "Q";
-                    longname = "specific humidity";
-                    units = "kg/kg";
-                  }
-                if (code == 138)
-                  {
-                    name = "SVO";
-                    longname = "vorticity";
-                    units = "1/s";
-                  }
-                if (code == 155)
-                  {
-                    name = "SD";
-                    longname = "divergence";
-                    units = "1/s";
-                  }
-                if (code == 130)
-                  {
-                    name = "STP";
-                    longname = "temperature";
-                    units = "K";
-                  }
-                if (code == 152)
-                  {
-                    name = "LSP";
-                    longname = "log surface pressure";
-                  }
-              }
+            name = "Q";
+            longname = "specific humidity";
+            units = "kg/kg";
           }
-        else if (name.substr(0, 3) == "LSP")
-          code = 152;
-
-        if (var1.zaxisType == GRID_SPECTRAL && ntr == 0) ntr = gridInqTrunc(var1.gridID);
-
-        auto zaxisType = var1.zaxisType;
-        if (zaxisType == ZAXIS_HYBRID && var1.nlevels == 1) zaxisType = ZAXIS_SURFACE;
-
-        inivar(vars[varID], var1.gridType, zaxisType, code, name, longname, units);
-
-        vars[varID].gridID = var1.gridID;
-        vars[varID].zaxisID = var1.zaxisID;
-        vars[varID].gridsize = var1.gridsize;
-        vars[varID].nlev = var1.nlevels;
-        vars[varID].ptr = new double[var1.nlevels * var1.gridsize];
+          if (code == 138)
+          {
+            name = "SVO";
+            longname = "vorticity";
+            units = "1/s";
+          }
+          if (code == 155)
+          {
+            name = "SD";
+            longname = "divergence";
+            units = "1/s";
+          }
+          if (code == 130)
+          {
+            name = "STP";
+            longname = "temperature";
+            units = "K";
+          }
+          if (code == 152)
+          {
+            name = "LSP";
+            longname = "log surface pressure";
+          }
+        }
       }
+      else if (name.substr(0, 3) == "LSP")
+        code = 152;
+
+      if (var1.zaxisType == GRID_SPECTRAL && ntr == 0) ntr = gridInqTrunc(var1.gridID);
+
+      auto zaxisType = var1.zaxisType;
+      if (zaxisType == ZAXIS_HYBRID && var1.nlevels == 1) zaxisType = ZAXIS_SURFACE;
+
+      inivar(vars[varID], var1.gridType, zaxisType, code, name, longname, units);
+
+      vars[varID].gridID = var1.gridID;
+      vars[varID].zaxisID = var1.zaxisID;
+      vars[varID].gridsize = var1.gridsize;
+      vars[varID].nlev = var1.nlevels;
+      vars[varID].ptr = new double[var1.nlevels * var1.gridsize];
+    }
 
     auto numFields = cdo_stream_inq_timestep(streamID1, 0);
     auto vDateTime = taxisInqVdatetime(taxisID);
@@ -691,19 +681,19 @@ public:
     auto vdate = cdiDate_get(vDateTime.date);
     auto vtime = cdiTime_get(vDateTime.time);
     if (vdate == 0)
-      {
-        vdate = 19890101;
-        vtime = 120000;
-      }
+    {
+      vdate = 19890101;
+      vtime = 120000;
+    }
 
     for (int fieldID = 0; fieldID < numFields; ++fieldID)
-      {
-        auto [varID, levelID] = cdo_inq_field(streamID1);
+    {
+      auto [varID, levelID] = cdo_inq_field(streamID1);
 
-        auto gridsize = vars[varID].gridsize;
-        size_t numMissVals;
-        cdo_read_field(streamID1, vars[varID].ptr + levelID * gridsize, &numMissVals);
-      }
+      auto gridsize = vars[varID].gridsize;
+      size_t numMissVals;
+      cdo_read_field(streamID1, vars[varID].ptr + levelID * gridsize, &numMissVals);
+    }
 
     cdo_stream_close(streamID1);
 
@@ -724,20 +714,20 @@ public:
     vlistDefNtsteps(vlistID2, 0);
 
     for (int iv = 0; iv < numVars; iv++)
-      {
-        int varID = vlistDefVar(vlistID2, vars[iv].gridID, vars[iv].zaxisID, TIME_CONSTANT);
-        if (vars[iv].code > 0) vlistDefVarCode(vlistID2, varID, vars[iv].code);
-        if (vars[iv].name.size()) cdiDefKeyString(vlistID2, varID, CDI_KEY_NAME, vars[iv].name.c_str());
-        if (vars[iv].longname.size()) cdiDefKeyString(vlistID2, varID, CDI_KEY_LONGNAME, vars[iv].longname.c_str());
-        if (vars[iv].units.size()) cdiDefKeyString(vlistID2, varID, CDI_KEY_UNITS, vars[iv].units.c_str());
-        vlistDefVarDatatype(vlistID2, varID, CDI_DATATYPE_FLT64);
-      }
+    {
+      int varID = vlistDefVar(vlistID2, vars[iv].gridID, vars[iv].zaxisID, TIME_CONSTANT);
+      if (vars[iv].code > 0) vlistDefVarCode(vlistID2, varID, vars[iv].code);
+      if (vars[iv].name.size()) cdiDefKeyString(vlistID2, varID, CDI_KEY_NAME, vars[iv].name.c_str());
+      if (vars[iv].longname.size()) cdiDefKeyString(vlistID2, varID, CDI_KEY_LONGNAME, vars[iv].longname.c_str());
+      if (vars[iv].units.size()) cdiDefKeyString(vlistID2, varID, CDI_KEY_UNITS, vars[iv].units.c_str());
+      vlistDefVarDatatype(vlistID2, varID, CDI_DATATYPE_FLT64);
+    }
 
     for (int iatt = 0; iatt < atts.natxt; ++iatt)
-      {
-        // printf("%s: %s\n", atts.atxtname[iatt], atts.atxtentry[iatt]);
-        cdiDefAttTxt(vlistID2, CDI_GLOBAL, atts.atxtname[iatt], (int) std::strlen(atts.atxtentry[iatt]) + 1, atts.atxtentry[iatt]);
-      }
+    {
+      // printf("%s: %s\n", atts.atxtname[iatt], atts.atxtentry[iatt]);
+      cdiDefAttTxt(vlistID2, CDI_GLOBAL, atts.atxtname[iatt], (int) std::strlen(atts.atxtentry[iatt]) + 1, atts.atxtentry[iatt]);
+    }
 
     auto taxisID = cdo_taxis_create(TAXIS_ABSOLUTE);
     vlistDefTaxis(vlistID2, taxisID);
@@ -752,16 +742,16 @@ public:
     cdo_def_timestep(streamID2, tsID);
 
     for (int varID = 0; varID < numVars; ++varID)
-      {
-        auto gridsize = vars[varID].gridsize;
-        auto nlev = vars[varID].nlev;
+    {
+      auto gridsize = vars[varID].gridsize;
+      auto nlev = vars[varID].nlev;
 
-        for (int levelID = 0; levelID < nlev; ++levelID)
-          {
-            cdo_def_field(streamID2, varID, levelID);
-            cdo_write_field(streamID2, vars[varID].ptr + levelID * gridsize, 0);
-          }
+      for (int levelID = 0; levelID < nlev; ++levelID)
+      {
+        cdo_def_field(streamID2, varID, levelID);
+        cdo_write_field(streamID2, vars[varID].ptr + levelID * gridsize, 0);
       }
+    }
 
     cdo_stream_close(streamID2);
 
