@@ -36,26 +36,25 @@ public:
   inline static RegisterEntry<Eofcoeff3d> registration = RegisterEntry<Eofcoeff3d>(module);
 
   double missval1 = -999, missval2 = -999;
-  int numFields;
+  int numFields{};
 
-  CdoStreamID streamID1;
-  CdoStreamID streamID2;
+  CdoStreamID streamID1{};
+  CdoStreamID streamID2{};
 
-  int vlistID1;
-  int vlistID2;
+  int vlistID1{ CDI_UNDEFID };
+  int vlistID2{ CDI_UNDEFID };
 
   VarList varList1;
   VarList varList2;
 
-  int gridID1;
+  int gridID1{};
 
-  int taxisID2;
+  int taxisID2{ CDI_UNDEFID };
 
-  size_t gridsizeMax;
-  int numVars;
-  int neof;
-  int numLevels;
-  int taxisID3;
+  size_t gridsizeMax{};
+  int numVars{};
+  int numLevels{};
+  int taxisID3{};
 
   std::string fileSuffix;
   FieldVector3D eof;
@@ -101,30 +100,32 @@ public:
   void
   run() override
   {
+    int neof = 0;
+
     {
       int eofID = 0;
       while (1)
+      {
+        numFields = cdo_stream_inq_timestep(streamID1, eofID);
+        if (numFields == 0) break;
+
+        for (int fieldID = 0; fieldID < numFields; ++fieldID)
         {
-          numFields = cdo_stream_inq_timestep(streamID1, eofID);
-          if (numFields == 0) break;
+          auto [varID, levelID] = cdo_inq_field(streamID1);
+          missval1 = varList1.vars[varID].missval;
+          eof[varID][levelID].resize((eofID == 0) ? 1 : eofID + 1);
+          eof[varID][levelID][eofID].grid = gridID1;
+          eof[varID][levelID][eofID].missval = missval1;
+          eof[varID][levelID][eofID].resize(gridsizeMax);
+          std::ranges::fill(eof[varID][levelID][eofID].vec_d, missval1);
 
-          for (int fieldID = 0; fieldID < numFields; ++fieldID)
-            {
-              auto [varID, levelID] = cdo_inq_field(streamID1);
-              missval1 = varList1.vars[varID].missval;
-              eof[varID][levelID].resize((eofID == 0) ? 1 : eofID + 1);
-              eof[varID][levelID][eofID].grid = gridID1;
-              eof[varID][levelID][eofID].missval = missval1;
-              eof[varID][levelID][eofID].resize(gridsizeMax);
-              ranges::fill(eof[varID][levelID][eofID].vec_d, missval1);
+          if (varID >= numVars) cdo_abort("Internal error - varID >= nvars");
+          if (levelID >= numLevels) cdo_abort("Internal error - levelID >= nlevs");
 
-              if (varID >= numVars) cdo_abort("Internal error - varID >= nvars");
-              if (levelID >= numLevels) cdo_abort("Internal error - levelID >= nlevs");
-
-              cdo_read_field(streamID1, eof[varID][levelID][eofID]);
-            }
-          eofID++;
+          cdo_read_field(streamID1, eof[varID][levelID][eofID]);
         }
+        eofID++;
+      }
 
       neof = eofID;
     }
@@ -162,17 +163,13 @@ public:
 
     streamIDs = std::vector<CdoStreamID>(neof);
     for (int eofID = 0; eofID < neof; eofID++)
-      {
-        auto fileName = cdo_get_obase() + string_format("%5.5i", eofID);
-        if (fileSuffix.size() > 0) fileName += fileSuffix;
+    {
+      auto fileName = cdo_get_obase() + string_format("%5.5i", eofID);
+      if (fileSuffix.size() > 0) fileName += fileSuffix;
 
-        streamIDs[eofID] = open_write(fileName.c_str());
-
-        if (Options::cdoVerbose)
-          cdo_print("opened %s ('w')  as stream%i for %i. eof", fileName, streamIDs[eofID]->get_id(), eofID + 1);
-
-        cdo_def_vlist(streamIDs[eofID], vlistID3);
-      }
+      streamIDs[eofID] = open_write(fileName);
+      cdo_def_vlist(streamIDs[eofID], vlistID3);
+    }
 
     // ALLOCATE temporary fields for data read and write
     Field in;
@@ -180,81 +177,81 @@ public:
     in.grid = gridID1;
     FieldVector2D out(numVars);
     for (int varID = 0; varID < numVars; ++varID)
+    {
+      out[varID].resize(neof);
+      for (int eofID = 0; eofID < neof; eofID++)
       {
-        out[varID].resize(neof);
-        for (int eofID = 0; eofID < neof; eofID++)
-          {
-            out[varID][eofID].missval = missval1;
-            out[varID][eofID].numMissVals = 0;
-            out[varID][eofID].resize(1);
-          }
+        out[varID][eofID].missval = missval1;
+        out[varID][eofID].numMissVals = 0;
+        out[varID][eofID].resize(1);
       }
+    }
 
     int tsID = 0;
     while (1)
+    {
+      numFields = cdo_stream_inq_timestep(streamID2, tsID);
+      if (numFields == 0) break;
+
+      for (int varID = 0; varID < numVars; ++varID)
+        for (int eofID = 0; eofID < neof; eofID++)
+        {
+          out[varID][eofID].vec_d[0] = 0;
+          out[varID][eofID].grid = gridID3;
+          out[varID][eofID].missval = missval2;
+        }
+
+      cdo_taxis_copy_timestep(taxisID3, taxisID2);
+
+      for (int fieldID = 0; fieldID < numFields; ++fieldID)
       {
-        numFields = cdo_stream_inq_timestep(streamID2, tsID);
-        if (numFields == 0) break;
-
-        for (int varID = 0; varID < numVars; ++varID)
-          for (int eofID = 0; eofID < neof; eofID++)
-            {
-              out[varID][eofID].vec_d[0] = 0;
-              out[varID][eofID].grid = gridID3;
-              out[varID][eofID].missval = missval2;
-            }
-
-        cdo_taxis_copy_timestep(taxisID3, taxisID2);
-
-        for (int fieldID = 0; fieldID < numFields; ++fieldID)
-          {
-            auto [varID, levelID] = cdo_inq_field(streamID2);
-            cdo_read_field(streamID2, in);
-            missval2 = varList2.vars[varID].missval;
-
-            for (int eofID = 0; eofID < neof; eofID++)
-              {
-                if (fieldID == 0) cdo_def_timestep(streamIDs[eofID], tsID);
-
-                // size_t numMissVals = 0;
-                for (size_t i = 0; i < gridsizeMax; ++i)
-                  {
-                    if (!fp_is_equal(in.vec_d[i], missval2) && !fp_is_equal(eof[varID][levelID][eofID].vec_d[i], missval1))
-                      {
-                        // out[varID][eofID].vec_d[0] += w[i]*in.vec_d[i]*eof[varID][levelID][eofID].vec_d[i];
-                        out[varID][eofID].vec_d[0] += in.vec_d[i] * eof[varID][levelID][eofID].vec_d[i];
-                      }
-                    // else { numMissVals += 1; }
-                  }
-                /*
-                if ( numMissVals ) {
-                  out[varID][eofID].numMissVals=1;
-                  out[varID][eofID].vec_d[0] = missval2;
-                }
-                */
-              }
-
-            if (varID >= numVars) cdo_abort("Internal error - varID >= nvars");
-            if (levelID >= numLevels) cdo_abort("Internal error - levelID >= nlevs");
-          }
+        auto [varID, levelID] = cdo_inq_field(streamID2);
+        cdo_read_field(streamID2, in);
+        missval2 = varList2.vars[varID].missval;
 
         for (int eofID = 0; eofID < neof; eofID++)
-          {
-            for (int varID = 0; varID < numVars; ++varID)
-              {
-                cdo_def_field(streamIDs[eofID], varID, 0);
-                cdo_write_field(streamIDs[eofID], out[varID][eofID]);
-              }
-          }
+        {
+          if (fieldID == 0) cdo_def_timestep(streamIDs[eofID], tsID);
 
-        tsID++;
+          // size_t numMissVals = 0;
+          for (size_t i = 0; i < gridsizeMax; ++i)
+          {
+            if (!fp_is_equal(in.vec_d[i], missval2) && !fp_is_equal(eof[varID][levelID][eofID].vec_d[i], missval1))
+            {
+              // out[varID][eofID].vec_d[0] += w[i]*in.vec_d[i]*eof[varID][levelID][eofID].vec_d[i];
+              out[varID][eofID].vec_d[0] += in.vec_d[i] * eof[varID][levelID][eofID].vec_d[i];
+            }
+            // else { numMissVals += 1; }
+          }
+          /*
+          if ( numMissVals ) {
+            out[varID][eofID].numMissVals=1;
+            out[varID][eofID].vec_d[0] = missval2;
+          }
+          */
+        }
+
+        if (varID >= numVars) cdo_abort("Internal error - varID >= nvars");
+        if (levelID >= numLevels) cdo_abort("Internal error - levelID >= nlevs");
       }
+
+      for (int eofID = 0; eofID < neof; eofID++)
+      {
+        for (int varID = 0; varID < numVars; ++varID)
+        {
+          cdo_def_field(streamIDs[eofID], varID, 0);
+          cdo_write_field(streamIDs[eofID], out[varID][eofID]);
+        }
+      }
+
+      tsID++;
+    }
   }
 
   void
   close() override
   {
-    for (int eofID = 0; eofID < neof; eofID++) cdo_stream_close(streamIDs[eofID]);
+    for (auto const &streamID : streamIDs) cdo_stream_close(streamID);
 
     cdo_stream_close(streamID2);
     cdo_stream_close(streamID1);
