@@ -32,19 +32,19 @@ public:
 
   int lastgrid = -1;
 
-  CdoStreamID streamID1;
-  CdoStreamID streamID2;
-  CdoStreamID streamID3;
+  CdoStreamID streamID1{};
+  CdoStreamID streamID2{};
+  CdoStreamID streamID3{};
 
-  int taxisID1;
-  int taxisID3;
+  int taxisID1{ CDI_UNDEFID };
+  int taxisID3{};
 
   int gridID3 = -1;
 
-  VarList varList1;
-  VarList varList2;
+  VarList varList1{};
+  VarList varList2{};
 
-  bool needWeights;
+  bool needWeights{};
 
 public:
   void
@@ -108,54 +108,53 @@ public:
 
     int tsID = 0;
     while (true)
+    {
+      auto numFields = cdo_stream_inq_timestep(streamID1, tsID);
+      if (numFields == 0) break;
+
+      auto numFields2 = cdo_stream_inq_timestep(streamID2, tsID);
+      if (numFields2 == 0) cdo_abort("Input streams have different number of timesteps!");
+
+      cdo_taxis_copy_timestep(taxisID3, taxisID1);
+
+      cdo_def_timestep(streamID3, tsID);
+
+      while (numFields--)
       {
-        auto numFields = cdo_stream_inq_timestep(streamID1, tsID);
-        if (numFields == 0) break;
+        (void) cdo_inq_field(streamID1);
+        cdo_read_field(streamID1, field1);
+        auto [varID, levelID] = cdo_inq_field(streamID2);
+        cdo_read_field(streamID2, field2);
 
-        auto numFields2 = cdo_stream_inq_timestep(streamID2, tsID);
-        if (numFields2 == 0) cdo_abort("Input streams have different number of timesteps!");
+        auto const &var1 = varList1.vars[varID];
+        auto const &var2 = varList2.vars[varID];
+        field1.grid = var1.gridID;
+        field2.grid = var2.gridID;
 
-        cdo_taxis_copy_timestep(taxisID3, taxisID1);
-
-        cdo_def_timestep(streamID3, tsID);
-
-        while (numFields--)
+        if (needWeights && field1.grid != lastgrid)
+        {
+          lastgrid = field1.grid;
+          field1.weightv[0] = 1;
+          if (field1.size > 1)
           {
-            (void) cdo_inq_field(streamID1);
-            cdo_read_field(streamID1, field1);
-            auto [varID, levelID] = cdo_inq_field(streamID2);
-            cdo_read_field(streamID2, field2);
-
-            const auto &var1 = varList1.vars[varID];
-            const auto &var2 = varList2.vars[varID];
-            field1.grid = var1.gridID;
-            field2.grid = var2.gridID;
-
-            if (needWeights && field1.grid != lastgrid)
-              {
-                lastgrid = field1.grid;
-                field1.weightv[0] = 1;
-                if (field1.size > 1)
-                  {
-                    auto wstatus = gridcell_weights(field1.grid, field1.weightv);
-                    if (wstatus != 0 && tsID == 0 && levelID == 0)
-                      cdo_warning("Grid cell bounds not available, using constant grid cell area weights for variable %s!",
-                                  var1.name);
-                  }
-              }
-
-            field1.missval = var1.missval;
-            field2.missval = var1.missval;
-            field3.missval = var1.missval;
-
-            field_rms(field1, field2, field3);
-
-            cdo_def_field(streamID3, varID, levelID);
-            cdo_write_field(streamID3, field3);
+            auto wstatus = gridcell_weights(field1.grid, field1.weightv);
+            if (wstatus != 0 && tsID == 0 && levelID == 0)
+              cdo_warning("Grid cell bounds not available, using constant grid cell area weights for variable %s!", var1.name);
           }
+        }
 
-        tsID++;
+        field1.missval = var1.missval;
+        field2.missval = var1.missval;
+        field3.missval = var1.missval;
+
+        field_rms(field1, field2, field3);
+
+        cdo_def_field(streamID3, varID, levelID);
+        cdo_write_field(streamID3, field3);
       }
+
+      tsID++;
+    }
   }
 
   void
