@@ -29,19 +29,14 @@ public:
     .constraints = { 2, 1, NoRestriction },
   };
   inline static RegisterEntry<Gengrid> registration = RegisterEntry<Gengrid>(module);
-  size_t numMissVals1, numMissVals2;
-  double missval = 0;
 
-  CdoStreamID streamID3;
-  size_t gridsize;
-
-  Varray<double> array3;
+  CdoStreamID streamID3{};
+  size_t gridsize{};
 
 public:
   void
   init() override
   {
-
     operator_check_argc(0);
 
     auto streamID1 = cdo_open_read(0);
@@ -60,11 +55,11 @@ public:
     auto ysize = gridInqYsize(gridID1);
 
     Varray<double> array1(gridsize), array2(gridsize);
-    array3 = Varray<double>(gridsize);
 
     cdo_stream_inq_timestep(streamID1, 0);
     cdo_stream_inq_timestep(streamID2, 0);
 
+    size_t numMissVals1, numMissVals2;
     (void) cdo_inq_field(streamID1);
     cdo_read_field(streamID1, array1.data(), &numMissVals1);
     (void) cdo_inq_field(streamID2);
@@ -77,13 +72,14 @@ public:
 
     if (numMissVals1 || numMissVals2) cdo_abort("Missing values unsupported!");
 
-    auto gridID3 = gridCreate(GRID_CURVILINEAR, gridsize);
+    auto gridType = (ysize == 0) ? GRID_UNSTRUCTURED : GRID_CURVILINEAR;
+    auto gridID3 = gridCreate(gridType, gridsize);
 
     if (Options::cdoVerbose) cdo_print("xsize %zu  ysize %zu", xsize, ysize);
-    if (xsize * ysize != gridsize) cdo_abort("xsize*ysize != gridsize");
+    if (gridType == GRID_CURVILINEAR && xsize * ysize != gridsize) cdo_abort("xsize*ysize != gridsize");
 
-    gridDefXsize(gridID3, xsize);
-    gridDefYsize(gridID3, ysize);
+    if (gridType == GRID_CURVILINEAR) gridDefXsize(gridID3, xsize);
+    if (gridType == GRID_CURVILINEAR) gridDefYsize(gridID3, ysize);
     gridDefXvals(gridID3, array1.data());
     gridDefYvals(gridID3, array2.data());
 
@@ -97,21 +93,20 @@ public:
 
     // check units
     if (xmm.min > -4 && xmm.max < 8 && ymm.min > -2 && ymm.max < 2)
-      {
-        cdiDefKeyString(gridID3, CDI_XAXIS, CDI_KEY_UNITS, "radians");
-        cdiDefKeyString(gridID3, CDI_YAXIS, CDI_KEY_UNITS, "radians");
-      }
+    {
+      cdiDefKeyString(gridID3, CDI_XAXIS, CDI_KEY_UNITS, "radians");
+      cdiDefKeyString(gridID3, CDI_YAXIS, CDI_KEY_UNITS, "radians");
+    }
     else if (xmm.min > -181 && xmm.max < 361 && ymm.min > -91 && ymm.max < 91)
-      {
-        // default is degrees
-      }
+    {
+      // default is degrees
+    }
     else { cdo_abort("Units undefined!"); }
 
     auto zaxisID3 = zaxis_from_name("surface");
 
     auto vlistID3 = vlistCreate();
     vlistDefVar(vlistID3, gridID3, zaxisID3, TIME_CONSTANT);
-    vlistDefVarMissval(vlistID3, 0, missval);
     cdiDefKeyString(vlistID3, 0, CDI_KEY_NAME, "dummy");
     vlistDefVarDatatype(vlistID3, 0, CDI_DATATYPE_INT8);
 
@@ -122,17 +117,18 @@ public:
 
     cdo_def_vlist(streamID3, vlistID3);
   }
+
   void
   run() override
   {
     int tsID = 0;
     cdo_def_timestep(streamID3, tsID);
 
-    for (size_t i = 0; i < gridsize; ++i) array3[i] = missval;
-
     cdo_def_field(streamID3, 0, 0);
+    Varray<double> array3(gridsize, 0);
     cdo_write_field(streamID3, array3.data(), gridsize);
   }
+
   void
   close() override
   {
