@@ -12,21 +12,24 @@
 #include <mpim_grid.h>
 #include "griddes.h"
 
+namespace
+{
 struct grid_type
 {
-  int gridID;
-  long size;
-  long numCorners;
-  Varray<double> cell_corner_lon;
-  Varray<double> cell_corner_lat;
+  int gridID{};
+  long size{};
+  long numCorners{};
+  Varray<double> cell_corner_lon{};
+  Varray<double> cell_corner_lat{};
 };
 
 struct cellsearch_type
 {
-  grid_type *srcGrid;
-  grid_type *tgtGrid;
-  Varray<float> src_cell_bound_box;
+  grid_type *srcGrid{};
+  grid_type *tgtGrid{};
+  Varray<float> src_cell_bound_box{};
 };
+}  // namespace
 
 static grid_type *
 grid_new(int gridID, const char *txt)
@@ -35,18 +38,18 @@ grid_new(int gridID, const char *txt)
   auto gridtype = gridInqType(gridID);
 
   if (gridtype == GRID_GME)
-    {
-      lgrid_destroy = true;
-      auto gridID_gme = gridToUnstructured(gridID, NeedCorners::Yes);
-      gridCompress(gridID_gme);
-      gridID = gridID_gme;
-    }
+  {
+    lgrid_destroy = true;
+    auto gridID_gme = gridToUnstructured(gridID, NeedCorners::Yes);
+    gridCompress(gridID_gme);
+    gridID = gridID_gme;
+  }
 
   if (gridtype != GRID_UNSTRUCTURED && gridtype != GRID_CURVILINEAR)
-    {
-      lgrid_destroy = true;
-      gridID = gridToCurvilinear(gridID, NeedCorners::Yes);
-    }
+  {
+    lgrid_destroy = true;
+    gridID = gridToCurvilinear(gridID, NeedCorners::Yes);
+  }
 
   if (!gridHasCoordinates(gridID)) cdo_abort("%s grid corner missing!", txt);
 
@@ -77,7 +80,7 @@ grid_delete(grid_type *grid)
 }
 
 static void
-boundbox_from_corners1r(long ic, long nc, const Varray<double> &cornerLon, const Varray<double> &cornerLat, float *bound_box)
+boundbox_from_corners1r(long ic, long nc, Varray<double> const &cornerLon, Varray<double> const &cornerLat, float *bound_box)
 {
   auto inc = ic * nc;
 
@@ -90,15 +93,15 @@ boundbox_from_corners1r(long ic, long nc, const Varray<double> &cornerLon, const
   bound_box[3] = clon;
 
   for (long j = 1; j < nc; ++j)
-    {
-      clat = cornerLat[inc + j];
-      clon = cornerLon[inc + j];
+  {
+    clat = cornerLat[inc + j];
+    clon = cornerLon[inc + j];
 
-      if (clat < bound_box[0]) bound_box[0] = clat;
-      if (clat > bound_box[1]) bound_box[1] = clat;
-      if (clon < bound_box[2]) bound_box[2] = clon;
-      if (clon > bound_box[3]) bound_box[3] = clon;
-    }
+    if (clat < bound_box[0]) bound_box[0] = clat;
+    if (clat > bound_box[1]) bound_box[1] = clat;
+    if (clon < bound_box[2]) bound_box[2] = clon;
+    if (clon > bound_box[3]) bound_box[3] = clon;
+  }
 
   /*
   if ( std::fabs(bound_box[3] - bound_box[2]) > PI )
@@ -110,29 +113,29 @@ boundbox_from_corners1r(long ic, long nc, const Varray<double> &cornerLon, const
 }
 
 static void
-boundbox_from_corners(long size, long nc, const Varray<double> &cornerLon, const Varray<double> &cornerLat,
+boundbox_from_corners(long size, long nc, Varray<double> const &cornerLon, Varray<double> const &cornerLat,
                       Varray<float> &bound_box)
 {
   for (long i = 0; i < size; ++i)
+  {
+    auto i4 = i << 2;  // *4
+    auto inc = i * nc;
+    auto clat = cornerLat[inc];
+    auto clon = cornerLon[inc];
+    bound_box[i4] = clat;
+    bound_box[i4 + 1] = clat;
+    bound_box[i4 + 2] = clon;
+    bound_box[i4 + 3] = clon;
+    for (long j = 1; j < nc; ++j)
     {
-      auto i4 = i << 2;  // *4
-      auto inc = i * nc;
-      auto clat = cornerLat[inc];
-      auto clon = cornerLon[inc];
-      bound_box[i4] = clat;
-      bound_box[i4 + 1] = clat;
-      bound_box[i4 + 2] = clon;
-      bound_box[i4 + 3] = clon;
-      for (long j = 1; j < nc; ++j)
-        {
-          clat = cornerLat[inc + j];
-          clon = cornerLon[inc + j];
-          if (clat < bound_box[i4]) bound_box[i4] = clat;
-          if (clat > bound_box[i4 + 1]) bound_box[i4 + 1] = clat;
-          if (clon < bound_box[i4 + 2]) bound_box[i4 + 2] = clon;
-          if (clon > bound_box[i4 + 3]) bound_box[i4 + 3] = clon;
-        }
+      clat = cornerLat[inc + j];
+      clon = cornerLon[inc + j];
+      if (clat < bound_box[i4]) bound_box[i4] = clat;
+      if (clat > bound_box[i4 + 1]) bound_box[i4 + 1] = clat;
+      if (clon < bound_box[i4 + 2]) bound_box[i4 + 2] = clon;
+      if (clon > bound_box[i4 + 3]) bound_box[i4 + 3] = clon;
     }
+  }
 }
 
 static cellsearch_type *
@@ -162,7 +165,7 @@ search_cells(cellsearch_type *cellsearch, long tgtCellIndex, long *srchIndices)
 {
   const grid_type *srcGrid = cellsearch->srcGrid;
   const grid_type *tgtGrid = cellsearch->tgtGrid;
-  const auto &src_cell_bound_box = cellsearch->src_cell_bound_box;
+  auto const &src_cell_bound_box = cellsearch->src_cell_bound_box;
 
   float tgt_cell_bound_box[4];
   boundbox_from_corners1r(tgtCellIndex, tgtGrid->numCorners, tgtGrid->cell_corner_lon, tgtGrid->cell_corner_lat,
@@ -175,17 +178,17 @@ search_cells(cellsearch_type *cellsearch, long tgtCellIndex, long *srchIndices)
 
   long numSearchCells = 0;
   for (long srcCellIndex = 0; srcCellIndex < srcGrid->size; ++srcCellIndex)
+  {
+    auto srcCellIndexM4 = srcCellIndex << 2;
+    if ((src_cell_bound_box[srcCellIndexM4 + 2] <= bound_box_lon2) && (src_cell_bound_box[srcCellIndexM4 + 3] >= bound_box_lon1))
     {
-      auto srcCellIndexM4 = srcCellIndex << 2;
-      if ((src_cell_bound_box[srcCellIndexM4 + 2] <= bound_box_lon2) && (src_cell_bound_box[srcCellIndexM4 + 3] >= bound_box_lon1))
-        {
-          if ((src_cell_bound_box[srcCellIndexM4] <= bound_box_lat2) && (src_cell_bound_box[srcCellIndexM4 + 1] >= bound_box_lat1))
-            {
-              srchIndices[numSearchCells] = srcCellIndex;
-              numSearchCells++;
-            }
-        }
+      if ((src_cell_bound_box[srcCellIndexM4] <= bound_box_lat2) && (src_cell_bound_box[srcCellIndexM4 + 1] >= bound_box_lat1))
+      {
+        srchIndices[numSearchCells] = srcCellIndex;
+        numSearchCells++;
+      }
     }
+  }
 
   return numSearchCells;
 }
@@ -201,15 +204,15 @@ cell_search(int gridIDsrc, int gridIDtgt)
   cellsearch_type *cellsearch = cellsearch_new(srcGrid, tgtGrid);
 
   for (long tgtCellIndex = 0; tgtCellIndex < tgtGrid->size; ++tgtCellIndex)
-    {
-      long numSearchCells = search_cells(cellsearch, tgtCellIndex, srchIndices.data());
+  {
+    long numSearchCells = search_cells(cellsearch, tgtCellIndex, srchIndices.data());
 
-      if (Options::cdoVerbose && numSearchCells > 0)
-        {
-          printf("tgt cell %ld: found %ld src cells\n", tgtCellIndex, numSearchCells);
-          for (long n = 0; n < numSearchCells; ++n) printf("   %ld: %ld\n", n + 1, srchIndices[n]);
-        }
+    if (Options::cdoVerbose && numSearchCells > 0)
+    {
+      printf("tgt cell %ld: found %ld src cells\n", tgtCellIndex, numSearchCells);
+      for (long n = 0; n < numSearchCells; ++n) printf("   %ld: %ld\n", n + 1, srchIndices[n]);
     }
+  }
 
   cellsearch_delete(cellsearch);
   grid_delete(srcGrid);
