@@ -34,7 +34,7 @@ humidityIndex(double t, double e, double r, double missval)
 }
 
 static void
-farexpr(Field &field1, const Field &field2, const Field &field3, double (*expression)(double, double, double, double))
+farexpr(Field &field1, Field const &field2, Field const &field3, double (*expression)(double, double, double, double))
 {
   auto grid1 = field1.grid;
   auto grid2 = field2.grid;
@@ -47,18 +47,18 @@ farexpr(Field &field1, const Field &field2, const Field &field3, double (*expres
   if (len != gridInqSize(grid2) || len != gridInqSize(grid3)) cdo_abort("Fields have different gridsize (%s)", __func__);
 
   if (field1.numMissVals || field2.numMissVals || field3.numMissVals)
-    {
-      for (size_t i = 0; i < len; ++i)
-        if (fp_is_equal(field1.vec_d[i], missval1) || fp_is_equal(field2.vec_d[i], missval2)
-            || fp_is_equal(field3.vec_d[i], missval3))
-          field1.vec_d[i] = missval1;
-        else
-          field1.vec_d[i] = expression(field1.vec_d[i], field2.vec_d[i], field3.vec_d[i], missval1);
-    }
+  {
+    for (size_t i = 0; i < len; ++i)
+      if (fp_is_equal(field1.vec_d[i], missval1) || fp_is_equal(field2.vec_d[i], missval2)
+          || fp_is_equal(field3.vec_d[i], missval3))
+        field1.vec_d[i] = missval1;
+      else
+        field1.vec_d[i] = expression(field1.vec_d[i], field2.vec_d[i], field3.vec_d[i], missval1);
+  }
   else
-    {
-      for (size_t i = 0; i < len; ++i) field1.vec_d[i] = expression(field1.vec_d[i], field2.vec_d[i], field3.vec_d[i], missval1);
-    }
+  {
+    for (size_t i = 0; i < len; ++i) field1.vec_d[i] = expression(field1.vec_d[i], field2.vec_d[i], field3.vec_d[i], missval1);
+  }
 
   field_num_mv(field1);
 }
@@ -77,25 +77,25 @@ public:
   };
   inline static RegisterEntry<Hi> registration = RegisterEntry<Hi>(module);
 
-  CdoStreamID streamID1;
-  CdoStreamID streamID2;
-  CdoStreamID streamID3;
-  CdoStreamID streamID4;
+  CdoStreamID streamID1{};
+  CdoStreamID streamID2{};
+  CdoStreamID streamID3{};
+  CdoStreamID streamID4{};
 
-  int vlistID1;
-  int vlistID2;
-  int vlistID3;
-  int vlistID4;
+  int vlistID1{ CDI_UNDEFID };
+  int vlistID2{ CDI_UNDEFID };
+  int vlistID3{};
+  int vlistID4{};
 
-  int taxisID1;
+  int taxisID1{ CDI_UNDEFID };
   // int taxisID2
   // int taxisID3
-  int taxisID4;
-  int varID4;
+  int taxisID4{};
+  int varID4{};
 
-  VarList varList1;
-  VarList varList2;
-  VarList varList3;
+  VarList varList1{};
+  VarList varList2{};
+  VarList varList3{};
 
 public:
   void
@@ -165,44 +165,44 @@ public:
 
     int tsID = 0;
     while (true)
+    {
+      auto numFields = cdo_stream_inq_timestep(streamID1, tsID);
+      if (numFields == 0) break;
+
+      auto numFields2 = cdo_stream_inq_timestep(streamID2, tsID);
+      auto numFields3 = cdo_stream_inq_timestep(streamID3, tsID);
+      if (numFields2 == 0 || numFields3 == 0) cdo_abort("Input streams have different number of timesteps!");
+
+      cdo_taxis_copy_timestep(taxisID4, taxisID1);
+      cdo_def_timestep(streamID4, tsID);
+
+      for (int fieldID = 0; fieldID < numFields; ++fieldID)
       {
-        auto numFields = cdo_stream_inq_timestep(streamID1, tsID);
-        if (numFields == 0) break;
+        auto [varID1, levelID1] = cdo_inq_field(streamID1);
+        field1.init(varList1.vars[varID1]);
+        cdo_read_field(streamID1, field1);
 
-        auto numFields2 = cdo_stream_inq_timestep(streamID2, tsID);
-        auto numFields3 = cdo_stream_inq_timestep(streamID3, tsID);
-        if (numFields2 == 0 || numFields3 == 0) cdo_abort("Input streams have different number of timesteps!");
+        auto [varID2, levelID2] = cdo_inq_field(streamID2);
+        field2.init(varList2.vars[varID2]);
+        cdo_read_field(streamID2, field2);
 
-        cdo_taxis_copy_timestep(taxisID4, taxisID1);
-        cdo_def_timestep(streamID4, tsID);
+        auto [varID3, levelID3] = cdo_inq_field(streamID3);
+        field3.init(varList3.vars[varID3]);
+        cdo_read_field(streamID3, field3);
 
-        for (int fieldID = 0; fieldID < numFields; ++fieldID)
-          {
-            auto [varID1, levelID1] = cdo_inq_field(streamID1);
-            field1.init(varList1.vars[varID1]);
-            cdo_read_field(streamID1, field1);
+        if (varID1 != varID2 || varID1 != varID3 || levelID1 != levelID2 || levelID1 != levelID3)
+          cdo_abort("Input streams have different structure!");
 
-            auto [varID2, levelID2] = cdo_inq_field(streamID2);
-            field2.init(varList2.vars[varID2]);
-            cdo_read_field(streamID2, field2);
+        if (varID1 != FIRST_VAR) continue;
 
-            auto [varID3, levelID3] = cdo_inq_field(streamID3);
-            field3.init(varList3.vars[varID3]);
-            cdo_read_field(streamID3, field3);
+        farexpr(field1, field2, field3, humidityIndex);
 
-            if (varID1 != varID2 || varID1 != varID3 || levelID1 != levelID2 || levelID1 != levelID3)
-              cdo_abort("Input streams have different structure!");
-
-            if (varID1 != FIRST_VAR) continue;
-
-            farexpr(field1, field2, field3, humidityIndex);
-
-            cdo_def_field(streamID4, varID4, levelID1);
-            cdo_write_field(streamID4, field1);
-          }
-
-        tsID++;
+        cdo_def_field(streamID4, varID4, levelID1);
+        cdo_write_field(streamID4, field1);
       }
+
+      tsID++;
+    }
   }
 
   void
