@@ -38,15 +38,15 @@ init_amsr_day(int vlistID, int gridID, int zaxisID, int numVars)
   constexpr double xminval[] = { 0., -3., 0., 0., 0., 0. };
 
   for (int i = 0; i < numVars; ++i)
-    {
-      int varID = vlistDefVar(vlistID, gridID, zaxisID, TIME_VARYING);
-      cdiDefKeyString(vlistID, varID, CDI_KEY_NAME, name[i]);
-      cdiDefKeyString(vlistID, varID, CDI_KEY_UNITS, units[i]);
-      vlistDefVarDatatype(vlistID, varID, CDI_DATATYPE_INT16);
-      vlistDefVarMissval(vlistID, varID, 254);
-      cdiDefKeyFloat(vlistID, varID, CDI_KEY_SCALEFACTOR, xscale[i]);
-      cdiDefKeyFloat(vlistID, varID, CDI_KEY_ADDOFFSET, xminval[i]);
-    }
+  {
+    int varID = vlistDefVar(vlistID, gridID, zaxisID, TIME_VARYING);
+    cdiDefKeyString(vlistID, varID, CDI_KEY_NAME, name[i]);
+    cdiDefKeyString(vlistID, varID, CDI_KEY_UNITS, units[i]);
+    vlistDefVarDatatype(vlistID, varID, CDI_DATATYPE_INT16);
+    vlistDefVarMissval(vlistID, varID, 254);
+    cdiDefKeyFloat(vlistID, varID, CDI_KEY_SCALEFACTOR, xscale[i]);
+    cdiDefKeyFloat(vlistID, varID, CDI_KEY_ADDOFFSET, xminval[i]);
+  }
 }
 
 static void
@@ -82,54 +82,54 @@ init_amsr_averaged(int vlistID, int gridID, int zaxisID, int nvars)
   constexpr double xminval[] = { -3., 0., 0., 0., 0. };
 
   for (int i = 0; i < nvars; ++i)
-    {
-      // varID = vlistDefVar(vlistID, gridID, zaxisID, TIME_CONSTANT);
-      int varID = vlistDefVar(vlistID, gridID, zaxisID, TIME_VARYING);
-      cdiDefKeyString(vlistID, varID, CDI_KEY_NAME, name[i]);
-      cdiDefKeyString(vlistID, varID, CDI_KEY_UNITS, units[i]);
-      vlistDefVarDatatype(vlistID, varID, CDI_DATATYPE_INT16);
-      vlistDefVarMissval(vlistID, varID, 254);
-      cdiDefKeyFloat(vlistID, varID, CDI_KEY_SCALEFACTOR, xscale[i]);
-      cdiDefKeyFloat(vlistID, varID, CDI_KEY_ADDOFFSET, xminval[i]);
-    }
+  {
+    // varID = vlistDefVar(vlistID, gridID, zaxisID, TIME_CONSTANT);
+    int varID = vlistDefVar(vlistID, gridID, zaxisID, TIME_VARYING);
+    cdiDefKeyString(vlistID, varID, CDI_KEY_NAME, name[i]);
+    cdiDefKeyString(vlistID, varID, CDI_KEY_UNITS, units[i]);
+    vlistDefVarDatatype(vlistID, varID, CDI_DATATYPE_INT16);
+    vlistDefVarMissval(vlistID, varID, 254);
+    cdiDefKeyFloat(vlistID, varID, CDI_KEY_SCALEFACTOR, xscale[i]);
+    cdiDefKeyFloat(vlistID, varID, CDI_KEY_ADDOFFSET, xminval[i]);
+  }
 }
 
 static void
-read_amsr(FILE *fp, const VarList &varList, Varray2D<double> &data, size_t *numMissVals)
+read_amsr(FILE *fp, VarList const &varList, Varray2D<double> &data, size_t *numMissVals)
 {
   std::vector<unsigned char> amsr_data;
 
-  for (const auto &var : varList.vars)
+  for (auto const &var : varList.vars)
+  {
+    amsr_data.resize(var.gridsize);
+    size_t size = std::fread(amsr_data.data(), 1, var.gridsize, fp);
+    if (size != var.gridsize) cdo_abort("Read error!");
+
+    double xminval = 0.0, xscale = 1.0;
+    cdiInqKeyFloat(varList.vlistID, var.ID, CDI_KEY_SCALEFACTOR, &xscale);
+    cdiInqKeyFloat(varList.vlistID, var.ID, CDI_KEY_ADDOFFSET, &xminval);
+
+    numMissVals[var.ID] = 0;
+    for (size_t i = 0; i < var.gridsize; ++i)
     {
-      amsr_data.resize(var.gridsize);
-      size_t size = fread(amsr_data.data(), 1, var.gridsize, fp);
-      if (size != var.gridsize) cdo_abort("Read error!");
-
-      double xminval = 0.0, xscale = 1.0;
-      cdiInqKeyFloat(varList.vlistID, var.ID, CDI_KEY_SCALEFACTOR, &xscale);
-      cdiInqKeyFloat(varList.vlistID, var.ID, CDI_KEY_ADDOFFSET, &xminval);
-
-      numMissVals[var.ID] = 0;
-      for (size_t i = 0; i < var.gridsize; ++i)
-        {
-          if (amsr_data[i] <= 250) { data[var.ID][i] = amsr_data[i] * xscale + xminval; }
-          else
-            {
-              data[var.ID][i] = var.missval;
-              numMissVals[var.ID]++;
-            }
-        }
+      if (amsr_data[i] <= 250) { data[var.ID][i] = amsr_data[i] * xscale + xminval; }
+      else
+      {
+        data[var.ID][i] = var.missval;
+        numMissVals[var.ID]++;
+      }
     }
+  }
 }
 
 static void
 write_data(CdoStreamID streamID, int nvars, Varray2D<double> &data, size_t *numMissVals)
 {
   for (int varID = 0; varID < nvars; ++varID)
-    {
-      cdo_def_field(streamID, varID, 0);
-      cdo_write_field(streamID, data[varID].data(), numMissVals[varID]);
-    }
+  {
+    cdo_def_field(streamID, varID, 0);
+    cdo_write_field(streamID, data[varID].data(), numMissVals[varID]);
+  }
 }
 
 static int
@@ -154,25 +154,25 @@ public:
   };
   inline static RegisterEntry<Importamsr> registration = RegisterEntry<Importamsr>(module);
 
-  int tsID;
-  int numVars;
+  int tsID{};
+  int numVars{};
   int vtime = 0;
   double xvals[NLON], yvals[NLAT];
   Varray2D<double> data;
   size_t numMissVals[MAX_VARS];
 
-  CdoStreamID streamID;
+  CdoStreamID streamID{};
 
-  int vlistID;
-  int gridID;
-  int zaxisID;
-  int taxisID;
+  int vlistID{};
+  int gridID{};
+  int zaxisID{};
+  int taxisID{};
 
-  size_t gridsize;
-  size_t fsize;
+  size_t gridsize{};
+  size_t fsize{};
 
-  FILE *fp;
-  int vdate;
+  FILE *fp{};
+  int vdate{};
 
   void
   A()
@@ -187,18 +187,18 @@ public:
 
     vtime = 13000;  // 1:30:00
     for (tsID = 0; tsID < 2; ++tsID)
-      {
-        CdiDateTime vDateTime{};
-        vDateTime.date = cdiDate_set(vdate);
-        vDateTime.time = cdiTime_set(vtime);
-        taxisDefVdatetime(taxisID, vDateTime);
-        vtime += 120000;  // 13:30:00
-        cdo_def_timestep(streamID, tsID);
+    {
+      CdiDateTime vDateTime{};
+      vDateTime.date = cdiDate_set(vdate);
+      vDateTime.time = cdiTime_set(vtime);
+      taxisDefVdatetime(taxisID, vDateTime);
+      vtime += 120000;  // 13:30:00
+      cdo_def_timestep(streamID, tsID);
 
-        read_amsr(fp, varList, data, numMissVals);
+      read_amsr(fp, varList, data, numMissVals);
 
-        write_data(streamID, numVars, data, numMissVals);
-      }
+      write_data(streamID, numVars, data, numMissVals);
+    }
   }
 
   void
@@ -233,10 +233,10 @@ public:
 
     fp = std::fopen(cdo_get_stream_name(0), "r");
     if (fp == nullptr)
-      {
-        perror(cdo_get_stream_name(0));
-        exit(EXIT_FAILURE);
-      }
+    {
+      perror(cdo_get_stream_name(0));
+      exit(EXIT_FAILURE);
+    }
 
     fseek(fp, 0L, SEEK_END);
     fsize = (size_t) ftell(fp);
