@@ -23,25 +23,24 @@ public:
   };
   inline static RegisterEntry<Importfv3grid> registration = RegisterEntry<Importfv3grid>(module);
 
-  size_t gridsize1;
-  size_t gridsize2;
+  size_t gridsize1{};
+  size_t gridsize2{};
 
-  CdoStreamID streamID1;
-  CdoStreamID streamID2;
+  CdoStreamID streamID1{};
+  CdoStreamID streamID2{};
 
-  size_t nx;
-  size_t ny;
+  size_t nx{};
+  size_t ny{};
 
-  int gridIDo;
+  int gridIDo{};
 
-  int vlistID2;
-  int surfaceID;
+  int vlistID2{ CDI_UNDEFID };
+  int surfaceID{};
 
 public:
   void
   init() override
   {
-
     operator_check_argc(0);
 
     streamID1 = cdo_open_read(0);
@@ -58,10 +57,10 @@ public:
     vars[4] = "area";
 
     for (int varID = 0; varID < nvars; ++varID)
-      {
-        auto varname = cdo::inq_var_name(vlistID1, varID);
-        if (varname == vars[varID]) cdo_abort("Found variable %s, expected variable %s!", varname, vars[varID]);
-      }
+    {
+      auto varname = cdo::inq_var_name(vlistID1, varID);
+      if (varname == vars[varID]) cdo_abort("Found variable %s, expected variable %s!", varname, vars[varID]);
+    }
 
     auto numGrids = vlistNumGrids(vlistID1);
     if (numGrids != 2) cdo_abort("Found %d grids, expected 2 grids!", nvars);
@@ -94,12 +93,12 @@ public:
 
       for (size_t j = 1; j < ny; ++j)
         for (size_t i = 1; i < nx; ++i)
-          {
-            grid_corner[((j - 1) * (nx - 1) + (i - 1)) * 4 + 0] = buffer[j * nx + i];
-            grid_corner[((j - 1) * (nx - 1) + (i - 1)) * 4 + 1] = buffer[j * nx + (i - 1)];
-            grid_corner[((j - 1) * (nx - 1) + (i - 1)) * 4 + 2] = buffer[(j - 1) * nx + (i - 1)];
-            grid_corner[((j - 1) * (nx - 1) + (i - 1)) * 4 + 3] = buffer[(j - 1) * nx + i];
-          }
+        {
+          grid_corner[((j - 1) * (nx - 1) + (i - 1)) * 4 + 0] = buffer[j * nx + i];
+          grid_corner[((j - 1) * (nx - 1) + (i - 1)) * 4 + 1] = buffer[j * nx + (i - 1)];
+          grid_corner[((j - 1) * (nx - 1) + (i - 1)) * 4 + 2] = buffer[(j - 1) * nx + (i - 1)];
+          grid_corner[((j - 1) * (nx - 1) + (i - 1)) * 4 + 3] = buffer[(j - 1) * nx + i];
+        }
 
       gridDefXbounds(gridIDo, grid_corner.data());
 
@@ -108,12 +107,12 @@ public:
 
       for (size_t j = 1; j < ny; ++j)
         for (size_t i = 1; i < nx; ++i)
-          {
-            grid_corner[((j - 1) * (nx - 1) + (i - 1)) * 4 + 0] = buffer[j * nx + i];
-            grid_corner[((j - 1) * (nx - 1) + (i - 1)) * 4 + 1] = buffer[j * nx + (i - 1)];
-            grid_corner[((j - 1) * (nx - 1) + (i - 1)) * 4 + 2] = buffer[(j - 1) * nx + (i - 1)];
-            grid_corner[((j - 1) * (nx - 1) + (i - 1)) * 4 + 3] = buffer[(j - 1) * nx + i];
-          }
+        {
+          grid_corner[((j - 1) * (nx - 1) + (i - 1)) * 4 + 0] = buffer[j * nx + i];
+          grid_corner[((j - 1) * (nx - 1) + (i - 1)) * 4 + 1] = buffer[j * nx + (i - 1)];
+          grid_corner[((j - 1) * (nx - 1) + (i - 1)) * 4 + 2] = buffer[(j - 1) * nx + (i - 1)];
+          grid_corner[((j - 1) * (nx - 1) + (i - 1)) * 4 + 3] = buffer[(j - 1) * nx + i];
+        }
 
       gridDefYbounds(gridIDo, grid_corner.data());
     }
