@@ -28,16 +28,16 @@ input_iarray(size_t numVals, int *array)
   size_t readVals = 0;
 
   for (size_t i = 0; i < numVals; ++i)
-    {
-      if (scanf("%d", &array[i]) != 1) break;
-      readVals++;
-    }
+  {
+    if (scanf("%d", &array[i]) != 1) break;
+    readVals++;
+  }
 
   return readVals;
 }
 
 static int
-read_record(int numFields, int numLevels, size_t &gridsize0, int &code, int &date, int &time, std::vector<double> &array)
+read_record(int numFields, int numLevels, size_t &gridsize0, int &code, int &date, int &time, Varray<double> &array)
 {
   code = -1;
   date = 10101;
@@ -59,7 +59,7 @@ read_record(int numFields, int numLevels, size_t &gridsize0, int &code, int &dat
 }
 
 static int
-read_record_ext(int numFields, size_t &gridsize0, int &code, int &date, int &time, std::vector<double> &array, int &gridID,
+read_record_ext(int numFields, size_t &gridsize0, int &code, int &date, int &time, Varray<double> &array, int &gridID,
                 double &dlevel)
 {
   cdo_print("Enter header (date,code,level,gridsize) of record %d (or EOF(=^D))!", numFields + 1);
@@ -78,16 +78,16 @@ read_record_ext(int numFields, size_t &gridsize0, int &code, int &date, int &tim
   time = 0;
 
   if (numFields == 0)
-    {
-      dlevel = level;
-      gridsize0 = gridsize;
-      array.resize(gridsize);
-      gridID = gridCreate(GRID_GENERIC, gridsize);
-    }
+  {
+    dlevel = level;
+    gridsize0 = gridsize;
+    array.resize(gridsize);
+    gridID = gridCreate(GRID_GENERIC, gridsize);
+  }
   else
-    {
-      if (gridsize != gridsize0) cdo_abort("Gridsize must not change!");
-    }
+  {
+    if (gridsize != gridsize0) cdo_abort("Gridsize must not change!");
+  }
 
   cdo_print("Enter all %zu elements of record %d!", gridsize, numFields + 1);
 
@@ -98,7 +98,7 @@ read_record_ext(int numFields, size_t &gridsize0, int &code, int &date, int &tim
 }
 
 static int
-read_record_srv(int numFields, size_t &gridsize0, int &code, int &date, int &time, std::vector<double> &array, int &gridID,
+read_record_srv(int numFields, size_t &gridsize0, int &code, int &date, int &time, Varray<double> &array, int &gridID,
                 double &dlevel)
 {
   cdo_print("Enter header (code,level,date,time,nlon,nlat,dispo1,dispo2) of record %d (or EOF(=^D))!", numFields + 1);
@@ -119,18 +119,18 @@ read_record_srv(int numFields, size_t &gridsize0, int &code, int &date, int &tim
   size_t gridsize = nlon * nlat;
 
   if (numFields == 0)
-    {
-      dlevel = level;
-      gridsize0 = gridsize;
-      array.resize(gridsize);
-      gridID = gridCreate(GRID_GENERIC, gridsize);
-      gridDefXsize(gridID, nlon);
-      gridDefYsize(gridID, nlat);
-    }
+  {
+    dlevel = level;
+    gridsize0 = gridsize;
+    array.resize(gridsize);
+    gridID = gridCreate(GRID_GENERIC, gridsize);
+    gridDefXsize(gridID, nlon);
+    gridDefYsize(gridID, nlat);
+  }
   else
-    {
-      if (gridsize != gridsize0) cdo_abort("Gridsize must not change!");
-    }
+  {
+    if (gridsize != gridsize0) cdo_abort("Gridsize must not change!");
+  }
 
   cdo_print("Enter all %zu elements of record %d!", gridsize, numFields + 1);
 
@@ -158,9 +158,9 @@ public:
   };
   inline static RegisterEntry<Input> registration = RegisterEntry<Input>(module);
 
-  int INPUT, INPUTSRV, INPUTEXT;
+  int INPUT{}, INPUTSRV{}, INPUTEXT{};
 
-  int operatorID;
+  int operatorID{};
 
   int outputFiletype = CDI_FILETYPE_GRB;
   CdoStreamID streamID = CDO_STREAM_UNDEF;
@@ -180,24 +180,24 @@ public:
     operatorID = cdo_operator_id();
 
     if (operatorID == INPUT)
-      {
-        operator_input_arg("grid description file or name");
-        operator_check_argc((cdo_operator_argc() == 1) ? 1 : 2);
+    {
+      operator_input_arg("grid description file or name");
+      operator_check_argc((cdo_operator_argc() == 1) ? 1 : 2);
 
-        gridID = cdo_define_grid(cdo_operator_argv(0));
-        if (cdo_operator_argc() == 2) zaxisID = cdo_define_zaxis(cdo_operator_argv(1));
-      }
+      gridID = cdo_define_grid(cdo_operator_argv(0));
+      if (cdo_operator_argc() == 2) zaxisID = cdo_define_zaxis(cdo_operator_argv(1));
+    }
     else { operator_check_argc(0); }
 
     if (operatorID == INPUT) { outputFiletype = cdo_filetype(); }
     else if (operatorID == INPUTEXT)
-      {
-        outputFiletype = (CdoDefault::FileType == CDI_UNDEFID) ? CDI_FILETYPE_EXT : CdoDefault::FileType;
-      }
+    {
+      outputFiletype = (CdoDefault::FileType == CDI_UNDEFID) ? CDI_FILETYPE_EXT : CdoDefault::FileType;
+    }
     else if (operatorID == INPUTSRV)
-      {
-        outputFiletype = (CdoDefault::FileType == CDI_UNDEFID) ? CDI_FILETYPE_SRV : CdoDefault::FileType;
-      }
+    {
+      outputFiletype = (CdoDefault::FileType == CDI_UNDEFID) ? CDI_FILETYPE_SRV : CdoDefault::FileType;
+    }
   }
 
   void
@@ -210,73 +210,73 @@ public:
     int code = 0, date = 0, time = 0;
     double missval = 0;
     double dlevel = 0;
-    std::vector<double> array;
+    Varray<double> array;
 
     int numFields = 0;
     int tsID = 0;
     while (true)
+    {
+      if (operatorID == INPUT)
       {
-        if (operatorID == INPUT)
-          {
-            if (-1 == read_record(numFields, numLevels, gridsize0, code, date, time, array)) break;
-          }
-        else if (operatorID == INPUTEXT)
-          {
-            if (-1 == read_record_ext(numFields, gridsize0, code, date, time, array, gridID, dlevel)) break;
-          }
-        else if (operatorID == INPUTSRV)
-          {
-            if (-1 == read_record_srv(numFields, gridsize0, code, date, time, array, gridID, dlevel)) break;
-          }
-
-        if (numFields == 0)
-          {
-            if (zaxisID == -1)
-              {
-                zaxisID = zaxisCreate(ZAXIS_SURFACE, 1);
-                zaxisDefLevels(zaxisID, &dlevel);
-              }
-
-            vlistID = vlistCreate();
-            int varID = vlistDefVar(vlistID, gridID, zaxisID, TIME_VARYING);
-            vlistDefVarParam(vlistID, varID, cdiEncodeParam(code, 255, 255));
-
-            missval = vlistInqVarMissval(vlistID, varID);
-
-            taxisID = cdo_taxis_create(TAXIS_RELATIVE);
-            vlistDefTaxis(vlistID, taxisID);
-
-            streamID = cdo_open_write(0, outputFiletype);
-            cdo_def_vlist(streamID, vlistID);
-          }
-
-        CdiDateTime vDateTime{};
-        vDateTime.date = cdiDate_set(date);
-        vDateTime.time = cdiTime_set(time);
-        taxisDefVdatetime(taxisID, vDateTime);
-        cdo_def_timestep(streamID, tsID);
-
-        constexpr int varID = 0;
-        for (int levelID = 0; levelID < numLevels; ++levelID)
-          {
-            auto offset = gridsize0 * levelID;
-            auto numMissVals = array_num_mv(gridsize0, &array[offset], missval);
-            cdo_def_field(streamID, varID, levelID);
-            cdo_write_field(streamID, &array[offset], numMissVals);
-          }
-
-        numFields++;
-        tsID++;
+        if (-1 == read_record(numFields, numLevels, gridsize0, code, date, time, array)) break;
       }
+      else if (operatorID == INPUTEXT)
+      {
+        if (-1 == read_record_ext(numFields, gridsize0, code, date, time, array, gridID, dlevel)) break;
+      }
+      else if (operatorID == INPUTSRV)
+      {
+        if (-1 == read_record_srv(numFields, gridsize0, code, date, time, array, gridID, dlevel)) break;
+      }
+
+      if (numFields == 0)
+      {
+        if (zaxisID == -1)
+        {
+          zaxisID = zaxisCreate(ZAXIS_SURFACE, 1);
+          zaxisDefLevels(zaxisID, &dlevel);
+        }
+
+        vlistID = vlistCreate();
+        int varID = vlistDefVar(vlistID, gridID, zaxisID, TIME_VARYING);
+        vlistDefVarParam(vlistID, varID, cdiEncodeParam(code, 255, 255));
+
+        missval = vlistInqVarMissval(vlistID, varID);
+
+        taxisID = cdo_taxis_create(TAXIS_RELATIVE);
+        vlistDefTaxis(vlistID, taxisID);
+
+        streamID = cdo_open_write(0, outputFiletype);
+        cdo_def_vlist(streamID, vlistID);
+      }
+
+      CdiDateTime vDateTime{};
+      vDateTime.date = cdiDate_set(date);
+      vDateTime.time = cdiTime_set(time);
+      taxisDefVdatetime(taxisID, vDateTime);
+      cdo_def_timestep(streamID, tsID);
+
+      constexpr int varID = 0;
+      for (int levelID = 0; levelID < numLevels; ++levelID)
+      {
+        auto offset = gridsize0 * levelID;
+        auto numMissVals = array_num_mv(gridsize0, &array[offset], missval);
+        cdo_def_field(streamID, varID, levelID);
+        cdo_write_field(streamID, &array[offset], numMissVals);
+      }
+
+      numFields++;
+      tsID++;
+    }
   }
 
   void
   close() override
   {
     if (streamID)
-      {
-        cdo_stream_close(streamID);
-        vlistDestroy(vlistID);
-      }
+    {
+      cdo_stream_close(streamID);
+      vlistDestroy(vlistID);
+    }
   }
 };
