@@ -21,8 +21,8 @@
 #include "cdi_lockedIO.h"
 
 void vert_interp_lev3d(size_t gridsize, int nlev1, double missval, const Field3D &field1, Field3D &field2, int nlev2,
-                       const Varray<int> &lev_idx, const Varray<float> &lev_wgt);
-void vert_gen_weights(int expol, int nlev1, const Varray<double> &lev1, int nlev2, const Varray<double> &lev2, Varray<int> &lev_idx,
+                       Varray<int> const &lev_idx, Varray<float> const &lev_wgt);
+void vert_gen_weights(int expol, int nlev1, Varray<double> const &lev1, int nlev2, Varray<double> const &lev2, Varray<int> &lev_idx,
                       Varray<float> &lev_wgt);
 bool levelDirUp(int nlev, const double *const lev);
 bool levelDirDown(int nlev, const double *const lev);
@@ -36,7 +36,7 @@ bool levelDirDown(int nlev, const double *const lev);
  * 3d version of vert_gen_weights() (src/Intlevel.cc)
  */
 static void
-vert_gen_weights3d(bool expol, size_t gridsize, int nlev1, const Varray<float> &xlev1, int nlev2, const Varray<float> &xlev2,
+vert_gen_weights3d(bool expol, size_t gridsize, int nlev1, Varray<float> const &xlev1, int nlev2, Varray<float> const &xlev2,
                    Varray<int> &xlev_idx, Varray<float> &xlev_wgt)
 {
   auto nthreads = Threading::ompNumMaxThreads;
@@ -57,19 +57,19 @@ vert_gen_weights3d(bool expol, size_t gridsize, int nlev1, const Varray<float> &
 #pragma omp parallel for default(shared) schedule(static)
 #endif
   for (size_t i = 0; i < gridsize; ++i)
-    {
-      auto ompthID = cdo_omp_get_thread_num();
+  {
+    auto ompthID = cdo_omp_get_thread_num();
 
-      lev1p2[ompthID][0] = level_0;
-      lev1p2[ompthID][nlev1 + 1] = level_N;
-      for (int k = 0; k < nlev1; ++k) lev1p2[ompthID][k + 1] = xlev1[k * gridsize + i];
-      for (int k = 0; k < nlev2; ++k) lev2[ompthID][k] = xlev2[k * gridsize + i];
+    lev1p2[ompthID][0] = level_0;
+    lev1p2[ompthID][nlev1 + 1] = level_N;
+    for (int k = 0; k < nlev1; ++k) lev1p2[ompthID][k + 1] = xlev1[k * gridsize + i];
+    for (int k = 0; k < nlev2; ++k) lev2[ompthID][k] = xlev2[k * gridsize + i];
 
-      vert_gen_weights(expol, nlev1 + 2, lev1p2[ompthID], nlev2, lev2[ompthID], lev_idx[ompthID], lev_wgt[ompthID]);
+    vert_gen_weights(expol, nlev1 + 2, lev1p2[ompthID], nlev2, lev2[ompthID], lev_idx[ompthID], lev_wgt[ompthID]);
 
-      for (int k = 0; k < nlev2; ++k) xlev_idx[k * gridsize + i] = lev_idx[ompthID][k];
-      for (int k = 0; k < nlev2; ++k) xlev_wgt[k * gridsize + i] = lev_wgt[ompthID][k];
-    }
+    for (int k = 0; k < nlev2; ++k) xlev_idx[k * gridsize + i] = lev_idx[ompthID][k];
+    for (int k = 0; k < nlev2; ++k) xlev_wgt[k * gridsize + i] = lev_wgt[ompthID][k];
+  }
 }
 
 static void
@@ -90,7 +90,7 @@ read_source_coordinate(int streamNumber, Varray<float> &zlevelsIn)
 
   if (varList.numVars() != 1) cdo_abort("infile2: Only one single variable is allowed!");
 
-  const auto &var0 = varList.vars[0];
+  auto const &var0 = varList.vars[0];
 
   zlevelsIn.resize(var0.gridsize * var0.nlevels);
 
@@ -98,13 +98,13 @@ read_source_coordinate(int streamNumber, Varray<float> &zlevelsIn)
   if (Options::cdoVerbose) cdo_print("%d fields input 3d vertical height", numFields);
 
   while (numFields-- > 0)
-    {
-      auto [varID, levelID] = cdo_inq_field(streamID2);
-      auto offset = var0.gridsize * levelID;
-      size_t numMissVals;
-      cdo_read_field_f(streamID2, &zlevelsIn[offset], &numMissVals);
-      if (0 != numMissVals) cdo_abort("Input vertical coordinate variables are not allowed to contain missing values.");
-    }
+  {
+    auto [varID, levelID] = cdo_inq_field(streamID2);
+    auto offset = var0.gridsize * levelID;
+    size_t numMissVals;
+    cdo_read_field_f(streamID2, &zlevelsIn[offset], &numMissVals);
+    if (0 != numMissVals) cdo_abort("Input vertical coordinate variables are not allowed to contain missing values.");
+  }
 
   cdo_stream_close(streamID2);
 
@@ -112,7 +112,7 @@ read_source_coordinate(int streamNumber, Varray<float> &zlevelsIn)
 }
 
 static CdoVar
-read_target_coordinate(const std::string &fileName, Varray<float> &zlevelsOut)
+read_target_coordinate(std::string const &fileName, Varray<float> &zlevelsOut)
 {
   auto streamID0 = stream_open_read_locked(fileName.c_str());  // 3d vertical target coordinate
   auto vlistID0 = streamInqVlist(streamID0);
@@ -121,7 +121,7 @@ read_target_coordinate(const std::string &fileName, Varray<float> &zlevelsOut)
 
   if (varList.numVars() != 1) cdo_abort("tgtcoordinate: Only one single variable is allowed!");
 
-  const auto &var0 = varList.vars[0];
+  auto const &var0 = varList.vars[0];
 
   zlevelsOut.resize(var0.gridsize * var0.nlevels);
 
@@ -129,14 +129,14 @@ read_target_coordinate(const std::string &fileName, Varray<float> &zlevelsOut)
   if (Options::cdoVerbose) cdo_print("%d fields target 3d vertical height and gridsize %zu", numFields, var0.gridsize);
 
   while (numFields-- > 0)
-    {
-      int varID, levelID;
-      streamInqField(streamID0, &varID, &levelID);
-      auto offset = var0.gridsize * levelID;
-      size_t numMissVals;
-      streamReadFieldF(streamID0, &zlevelsOut[offset], &numMissVals);
-      if (0 != numMissVals) cdo_abort("Output vertical coordinate variables are not allowd to contain missing values.");
-    }
+  {
+    int varID, levelID;
+    streamInqField(streamID0, &varID, &levelID);
+    auto offset = var0.gridsize * levelID;
+    size_t numMissVals;
+    streamReadFieldF(streamID0, &zlevelsOut[offset], &numMissVals);
+    if (0 != numMissVals) cdo_abort("Output vertical coordinate variables are not allowd to contain missing values.");
+  }
 
   streamClose(streamID0);
 
@@ -156,27 +156,27 @@ public:
     .constraints = { 2, 1, NoRestriction },
   };
   inline static RegisterEntry<Intlevel3d> registration = RegisterEntry<Intlevel3d>(module);
-  int INTLEVEL3D, INTLEVELX3D;
+  int INTLEVEL3D{}, INTLEVELX3D{};
 
-  CdoStreamID streamID1;
-  CdoStreamID streamID2;
-  CdoStreamID streamID3;
+  CdoStreamID streamID1{};
+  CdoStreamID streamID2{};
+  CdoStreamID streamID3{};
 
-  int taxisID1;
-  int taxisID3;
-  int vlistID3;
+  int taxisID1{ CDI_UNDEFID };
+  int taxisID3{};
+  int vlistID3{};
 
-  int numVars;
+  int numVars{};
 
-  int nlevi;
-  int nlevo;
+  int nlevi{};
+  int nlevo{};
 
-  int oz3dvarID;
+  int oz3dvarID{};
 
-  MemType memType;
+  MemType memType{};
 
-  VarList varList1;
-  VarList varList3;
+  VarList varList1{};
+  VarList varList3{};
 
   std::vector<bool> processVars;
   std::vector<bool> interpVars;
@@ -250,23 +250,23 @@ public:
     auto numZaxes = vlistNumZaxis(vlistID1);
     int i;
     for (i = 0; i < numZaxes; ++i)
+    {
+      auto zaxisID = vlistZaxis(vlistID1, i);
+      auto nlevel = zaxisInqSize(zaxisID);
+      if (nlevel == nlevi)
       {
-        auto zaxisID = vlistZaxis(vlistID1, i);
-        auto nlevel = zaxisInqSize(zaxisID);
-        if (nlevel == nlevi)
-          {
-            zaxisID1 = zaxisID;
-            break;
-          }
+        zaxisID1 = zaxisID;
+        break;
       }
+    }
     if (i == numZaxes) cdo_abort("No processable variable found (vertical coordinate differ)!");
 
     auto numGrids = vlistNumGrids(vlistID1);
     for (i = 0; i < numGrids; ++i)
-      {
-        auto gridsize = gridInqSize(vlistGrid(vlistID1, i));
-        if (gridsize == gridSize) break;
-      }
+    {
+      auto gridsize = gridInqSize(vlistGrid(vlistID1, i));
+      if (gridsize == gridSize) break;
+    }
     if (i == numZaxes) cdo_abort("No processable variable found (grid coordinate differ)!");
 
     // Create weights for later interpolation - assumption: input vertical correct is constant in time
@@ -299,31 +299,31 @@ public:
     vardata2 = Field3DVector(numVars);
 
     for (int varID = 0; varID < numVars; ++varID)
+    {
+      auto const &var1 = varList1.vars[varID];
+      auto zaxisID = var1.zaxisID;
+      auto gridsize = var1.gridsize;
+      auto nlevel = var1.nlevels;
+
+      vardata1[varID].init(var1);
+
+      /*  variabls for interpolation:
+       *  * have the required vertical axis, i.e. the correct number of levels (nlevi)
+       *  * have the same number of horizontal grid points (i.e. same gridSize) like the two vertical coordinates
+       *  * are NOT the output vertical coordinates itself
+       */
+      interpVars[varID] = (zaxisID == zaxisID1 && varID != oz3dvarID && gridsize == gridSize && gridsizeo == gridsize);
+      if (interpVars[varID])
       {
-        const auto &var1 = varList1.vars[varID];
-        auto zaxisID = var1.zaxisID;
-        auto gridsize = var1.gridsize;
-        auto nlevel = var1.nlevels;
-
-        vardata1[varID].init(var1);
-
-        /*  variabls for interpolation:
-         *  * have the required vertical axis, i.e. the correct number of levels (nlevi)
-         *  * have the same number of horizontal grid points (i.e. same gridSize) like the two vertical coordinates
-         *  * are NOT the output vertical coordinates itself
-         */
-        interpVars[varID] = (zaxisID == zaxisID1 && varID != oz3dvarID && gridsize == gridSize && gridsizeo == gridsize);
-        if (interpVars[varID])
-          {
-            varnumMissVals[varID].resize(maxlev, 0);
-            vardata2[varID].init(varList3.vars[varID]);
-          }
-        else
-          {
-            varnumMissVals[varID].resize(nlevel);
-            if (Options::cdoVerbose) cdo_print("Ignore variable %s (levels=%d gridsize=%zu)!", var1.name, nlevel, gridsize);
-          }
+        varnumMissVals[varID].resize(maxlev, 0);
+        vardata2[varID].init(varList3.vars[varID]);
       }
+      else
+      {
+        varnumMissVals[varID].resize(nlevel);
+        if (Options::cdoVerbose) cdo_print("Ignore variable %s (levels=%d gridsize=%zu)!", var1.name, nlevel, gridsize);
+      }
+    }
 
     {
       int varID;
@@ -338,72 +338,71 @@ public:
 
     int tsID = 0;
     while (true)
+    {
+      auto numFields = cdo_stream_inq_timestep(streamID1, tsID);
+      if (numFields == 0) break;
+
+      for (int varID = 0; varID < numVars; ++varID) processVars[varID] = false;
+
+      cdo_taxis_copy_timestep(taxisID3, taxisID1);
+      cdo_def_timestep(streamID3, tsID);
+
+      // Read the whole 3d data field
+      for (int fieldID = 0; fieldID < numFields; ++fieldID)
       {
-        auto numFields = cdo_stream_inq_timestep(streamID1, tsID);
-        if (numFields == 0) break;
-
-        for (int varID = 0; varID < numVars; ++varID) processVars[varID] = false;
-
-        cdo_taxis_copy_timestep(taxisID3, taxisID1);
-        cdo_def_timestep(streamID3, tsID);
-
-        // Read the whole 3d data field
-        for (int fieldID = 0; fieldID < numFields; ++fieldID)
-          {
-            auto [varID, levelID] = cdo_inq_field(streamID1);
-            cdo_read_field(streamID1, vardata1[varID], levelID, &varnumMissVals[varID][levelID]);
-            processVars[varID] = true;
-          }
-
-        // Perform the interpolation on all valid data variables
-        for (int varID = 0; varID < numVars; ++varID)
-          {
-            const auto &var1 = varList1.vars[varID];
-            if (processVars[varID] && interpVars[varID])
-              {
-                auto gridsize = var1.gridsize;
-                auto missval = var1.missval;
-
-                vert_interp_lev3d(gridsize, nlevi, missval, vardata1[varID], vardata2[varID], nlevo, lev_idx, lev_wgt);
-
-                for (int levelID = 0; levelID < nlevo; ++levelID)
-                  {
-                    auto offset = gridsize * levelID;
-                    auto func
-                        = [&](const auto &v) { varnumMissVals[varID][levelID] = array_num_mv(gridsize, &v[offset], missval); };
-                    field_operation(func, vardata2[varID]);
-                  }
-              }
-            else
-              {
-                if (Options::cdoVerbose && tsID <= 1) cdo_print("Perform no interpolation on variable %s", var1.name);
-              }
-          }
-
-        // write the output
-        for (int varID = 0; varID < numVars; ++varID)
-          {
-            if (processVars[varID])
-              {
-                for (int levelID = 0; levelID < varList3.vars[varID].nlevels; ++levelID)
-                  {
-                    cdo_def_field(streamID3, varID, levelID);
-                    cdo_write_field(streamID3, interpVars[varID] ? vardata2[varID] : vardata1[varID], levelID,
-                                    varnumMissVals[varID][levelID]);
-                  }
-              }
-          }
-
-        // copy output z coordinate to output stream
-        for (int levelID = 0; levelID < varList3.vars[oz3dvarID].nlevels; ++levelID)
-          {
-            auto offset = varList3.vars[oz3dvarID].gridsize * levelID;
-            cdo_def_field(streamID3, oz3dvarID, levelID);
-            cdo_write_field_f(streamID3, &zlevelsOut[offset], 0);
-          }
-
-        tsID++;
+        auto [varID, levelID] = cdo_inq_field(streamID1);
+        cdo_read_field(streamID1, vardata1[varID], levelID, &varnumMissVals[varID][levelID]);
+        processVars[varID] = true;
       }
+
+      // Perform the interpolation on all valid data variables
+      for (int varID = 0; varID < numVars; ++varID)
+      {
+        auto const &var1 = varList1.vars[varID];
+        if (processVars[varID] && interpVars[varID])
+        {
+          auto gridsize = var1.gridsize;
+          auto missval = var1.missval;
+
+          vert_interp_lev3d(gridsize, nlevi, missval, vardata1[varID], vardata2[varID], nlevo, lev_idx, lev_wgt);
+
+          for (int levelID = 0; levelID < nlevo; ++levelID)
+          {
+            auto offset = gridsize * levelID;
+            auto func = [&](auto const &v) { varnumMissVals[varID][levelID] = array_num_mv(gridsize, &v[offset], missval); };
+            field_operation(func, vardata2[varID]);
+          }
+        }
+        else
+        {
+          if (Options::cdoVerbose && tsID <= 1) cdo_print("Perform no interpolation on variable %s", var1.name);
+        }
+      }
+
+      // write the output
+      for (int varID = 0; varID < numVars; ++varID)
+      {
+        if (processVars[varID])
+        {
+          for (int levelID = 0; levelID < varList3.vars[varID].nlevels; ++levelID)
+          {
+            cdo_def_field(streamID3, varID, levelID);
+            cdo_write_field(streamID3, interpVars[varID] ? vardata2[varID] : vardata1[varID], levelID,
+                            varnumMissVals[varID][levelID]);
+          }
+        }
+      }
+
+      // copy output z coordinate to output stream
+      for (int levelID = 0; levelID < varList3.vars[oz3dvarID].nlevels; ++levelID)
+      {
+        auto offset = varList3.vars[oz3dvarID].gridsize * levelID;
+        cdo_def_field(streamID3, oz3dvarID, levelID);
+        cdo_write_field_f(streamID3, &zlevelsOut[offset], 0);
+      }
+
+      tsID++;
+    }
   }
   void
   close() override
