@@ -57,14 +57,14 @@ NormalizVectrs(int n_xres, int n_yres, float *pVectr)
 {
   for (int j = 0; j < n_yres; ++j)
     for (int i = 0; i < n_xres; ++i)
-      {
-        int index = (j * n_xres + i) << 1;
-        float vcMag = (float) (std::sqrt((double) (pVectr[index] * pVectr[index] + pVectr[index + 1] * pVectr[index + 1])));
+    {
+      int index = (j * n_xres + i) << 1;
+      float vcMag = (float) (std::sqrt((double) (pVectr[index] * pVectr[index] + pVectr[index + 1] * pVectr[index + 1])));
 
-        float scale = (vcMag == 0.0f) ? 0.0f : 1.0f / vcMag;
-        pVectr[index] *= scale;
-        pVectr[index + 1] *= scale;
-      }
+      float scale = (vcMag == 0.0f) ? 0.0f : 1.0f / vcMag;
+      pVectr[index] *= scale;
+      pVectr[index + 1] *= scale;
+    }
 }
 
 ///		make white noise as the LIC input texture     ///
@@ -73,11 +73,11 @@ MakeWhiteNoise(int n_xres, int n_yres, unsigned char *pNoise)
 {
   for (int j = 0; j < n_yres; ++j)
     for (int i = 0; i < n_xres; ++i)
-      {
-        int r = std::rand();
-        r = ((r & 0xff) + ((r & 0xff00) >> 8)) & 0xff;
-        pNoise[j * n_xres + i] = (unsigned char) r;
-      }
+    {
+      int r = std::rand();
+      r = ((r & 0xff) + ((r & 0xff00) >> 8)) & 0xff;
+      pNoise[j * n_xres + i] = (unsigned char) r;
+    }
 }
 
 ///		generate box filter LUTs     ///
@@ -126,17 +126,17 @@ setRGBmag(png_byte *ptr, float val, float mag)
     if (mag > cpt.lut[n].z_low && mag <= cpt.lut[n].z_high) break;
 
   if (n == cpt.ncolors)
-    {
-      r = cpt.bfn[0].rgb[0];
-      g = cpt.bfn[0].rgb[1];
-      b = cpt.bfn[0].rgb[2];
-    }
+  {
+    r = cpt.bfn[0].rgb[0];
+    g = cpt.bfn[0].rgb[1];
+    b = cpt.bfn[0].rgb[2];
+  }
   else
-    {
-      r = cpt.lut[n].rgb_high[0];
-      g = cpt.lut[n].rgb_high[1];
-      b = cpt.lut[n].rgb_high[2];
-    }
+  {
+    r = cpt.lut[n].rgb_high[0];
+    g = cpt.lut[n].rgb_high[1];
+    b = cpt.lut[n].rgb_high[2];
+  }
 
   float foregroundAlpha = .8;
   r = (val * foregroundAlpha) + (r * (1.0 - foregroundAlpha));
@@ -158,37 +158,37 @@ WriteImage2PNG(int width, int height, unsigned char *pImage, float *mag, const c
   // Open file for writing (binary mode)
   FILE *fp = std::fopen(filename, "wb");
   if (fp == nullptr)
-    {
-      fprintf(stderr, "Could not open file %s for writing\n", filename);
-      code = 1;
-      goto finalise;
-    }
+  {
+    fprintf(stderr, "Could not open file %s for writing\n", filename);
+    code = 1;
+    goto finalise;
+  }
 
   // Initialize write structure
   png_ptr = png_create_write_struct(PNG_LIBPNG_VER_STRING, nullptr, nullptr);
   if (png_ptr == nullptr)
-    {
-      fprintf(stderr, "Could not allocate write struct\n");
-      code = 1;
-      goto finalise;
-    }
+  {
+    fprintf(stderr, "Could not allocate write struct\n");
+    code = 1;
+    goto finalise;
+  }
 
   // Initialize info structure
   info_ptr = png_create_info_struct(png_ptr);
   if (info_ptr == nullptr)
-    {
-      fprintf(stderr, "Could not allocate info struct\n");
-      code = 1;
-      goto finalise;
-    }
+  {
+    fprintf(stderr, "Could not allocate info struct\n");
+    code = 1;
+    goto finalise;
+  }
 
   // Setup Exception handling
   if (setjmp(png_jmpbuf(png_ptr)))
-    {
-      fprintf(stderr, "Error during png creation\n");
-      code = 1;
-      goto finalise;
-    }
+  {
+    fprintf(stderr, "Error during png creation\n");
+    code = 1;
+    goto finalise;
+  }
 
   png_init_io(png_ptr, fp);
 
@@ -213,10 +213,10 @@ WriteImage2PNG(int width, int height, unsigned char *pImage, float *mag, const c
 
   // Write image data
   for (int y = 0; y < height; y++)
-    {
-      for (int x = 0; x < width; x++) { setRGBmag(&(row[x * 3]), pImage[y * width + x], mag[y * width + x]); }
-      png_write_row(png_ptr, row);
-    }
+  {
+    for (int x = 0; x < width; x++) { setRGBmag(&(row[x * 3]), pImage[y * width + x], mag[y * width + x]); }
+    png_write_row(png_ptr, row);
+  }
 
   // End write
   png_write_end(png_ptr, nullptr);
@@ -243,126 +243,125 @@ FlowImagingLIC(int n_xres, int n_yres, float *pVectr, unsigned char *pNoise, uns
 #pragma omp parallel for default(shared)
 #endif
   for (int j = 0; j < n_yres; ++j)
+  {
+    int vec_id;                       /// ID in the VECtor buffer (for the input flow field)
+    int advDir;                       /// ADVection DIRection (0: positive;  1: negative)
+    int advcts;                       /// number of ADVeCTion stepS per direction (a step counter)
+    int ADVCTS = (int) (krnlen * 3);  /// MAXIMUM number of advection steps per direction to break dead loops
+
+    float vctr_x;             /// x-component  of the VeCToR at the forefront point
+    float vctr_y;             /// y-component  of the VeCToR at the forefront point
+    float clp0_x;             /// x-coordinate of CLiP point 0 (current)
+    float clp0_y;             /// y-coordinate of CLiP point 0	(current)
+    float clp1_x;             /// x-coordinate of CLiP point 1 (next   )
+    float clp1_y;             /// y-coordinate of CLiP point 1 (next   )
+    float samp_x;             /// x-coordinate of the SAMPle in the current pixel
+    float samp_y;             /// y-coordinate of the SAMPle in the current pixel
+    float tmpLen;             /// TeMPorary LENgth of a trial clipped-segment
+    float segLen;             /// SEGment   LENgth
+    float curLen;             /// CURrent   LENgth of the streamline
+    float prvLen;             /// PReVious  LENgth of the streamline
+    float W_ACUM;             /// ACcuMulated Weight from the seed to the current streamline forefront
+    float texVal;             /// TEXture VALue
+    float smpWgt;             /// WeiGhT of the current SaMPle
+    float t_acum[2];          /// two ACcUMulated composite Textures for the two directions, perspectively
+    float w_acum[2];          /// two ACcUMulated Weighting values   for the two directions, perspectively
+    float *wgtLUT = nullptr;  /// WeiGhT Look Up Table pointing to the target filter LUT
+    float len2ID = (DISCRETE_FILTER_SIZE - 1) / krnlen;  /// map a curve LENgth TO an ID in the LUT
+    for (int i = 0; i < n_xres; ++i)
     {
-      int vec_id;                       /// ID in the VECtor buffer (for the input flow field)
-      int advDir;                       /// ADVection DIRection (0: positive;  1: negative)
-      int advcts;                       /// number of ADVeCTion stepS per direction (a step counter)
-      int ADVCTS = (int) (krnlen * 3);  /// MAXIMUM number of advection steps per direction to break dead loops
+      /// init the composite texture accumulators and the weight accumulators///
+      t_acum[0] = t_acum[1] = w_acum[0] = w_acum[1] = 0.0f;
 
-      float vctr_x;             /// x-component  of the VeCToR at the forefront point
-      float vctr_y;             /// y-component  of the VeCToR at the forefront point
-      float clp0_x;             /// x-coordinate of CLiP point 0 (current)
-      float clp0_y;             /// y-coordinate of CLiP point 0	(current)
-      float clp1_x;             /// x-coordinate of CLiP point 1 (next   )
-      float clp1_y;             /// y-coordinate of CLiP point 1 (next   )
-      float samp_x;             /// x-coordinate of the SAMPle in the current pixel
-      float samp_y;             /// y-coordinate of the SAMPle in the current pixel
-      float tmpLen;             /// TeMPorary LENgth of a trial clipped-segment
-      float segLen;             /// SEGment   LENgth
-      float curLen;             /// CURrent   LENgth of the streamline
-      float prvLen;             /// PReVious  LENgth of the streamline
-      float W_ACUM;             /// ACcuMulated Weight from the seed to the current streamline forefront
-      float texVal;             /// TEXture VALue
-      float smpWgt;             /// WeiGhT of the current SaMPle
-      float t_acum[2];          /// two ACcUMulated composite Textures for the two directions, perspectively
-      float w_acum[2];          /// two ACcUMulated Weighting values   for the two directions, perspectively
-      float *wgtLUT = nullptr;  /// WeiGhT Look Up Table pointing to the target filter LUT
-      float len2ID = (DISCRETE_FILTER_SIZE - 1) / krnlen;  /// map a curve LENgth TO an ID in the LUT
-      for (int i = 0; i < n_xres; ++i)
+      /// for either advection direction///
+      for (advDir = 0; advDir < 2; advDir++)
+      {
+        /// init the step counter, curve-length measurer, and streamline seed///
+        advcts = 0;
+        curLen = 0.0f;
+        clp0_x = i + 0.5f;
+        clp0_y = j + 0.5f;
+
+        /// access the target filter LUT///
+        wgtLUT = (advDir == 0) ? p_LUT0 : p_LUT1;
+
+        /// until the streamline is advected long enough or a tightly  spiralling center / focus is encountered///
+        while (curLen < krnlen && advcts < ADVCTS)
         {
-          /// init the composite texture accumulators and the weight accumulators///
-          t_acum[0] = t_acum[1] = w_acum[0] = w_acum[1] = 0.0f;
+          /// access the vector at the sample///
+          vec_id = ((int) (clp0_y) *n_xres + (int) (clp0_x)) << 1;
+          vctr_x = pVectr[vec_id];
+          vctr_y = pVectr[vec_id + 1];
 
-          /// for either advection direction///
-          for (advDir = 0; advDir < 2; advDir++)
-            {
-              /// init the step counter, curve-length measurer, and streamline seed///
-              advcts = 0;
-              curLen = 0.0f;
-              clp0_x = i + 0.5f;
-              clp0_y = j + 0.5f;
+          /// in case of a critical point///
+          if (vctr_x == 0.0f && vctr_y == 0.0f)
+          {
+            t_acum[advDir] = (advcts == 0) ? 0.0f : t_acum[advDir];  /// this line is indeed unnecessary
+            w_acum[advDir] = (advcts == 0) ? 1.0f : w_acum[advDir];
+            break;
+          }
 
-              /// access the target filter LUT///
-              wgtLUT = (advDir == 0) ? p_LUT0 : p_LUT1;
+          /// negate the vector for the backward-advection case///
+          vctr_x = (advDir == 0) ? vctr_x : -vctr_x;
+          vctr_y = (advDir == 0) ? vctr_y : -vctr_y;
 
-              /// until the streamline is advected long enough or a tightly  spiralling center / focus is encountered///
-              while (curLen < krnlen && advcts < ADVCTS)
-                {
-                  /// access the vector at the sample///
-                  vec_id = ((int) (clp0_y) *n_xres + (int) (clp0_x)) << 1;
-                  vctr_x = pVectr[vec_id];
-                  vctr_y = pVectr[vec_id + 1];
+          /// clip the segment against the pixel boundaries --- find the shorter from the two clipped segments///
+          /// replace  all  if-statements  whenever  possible  as  they  might  affect the computational speed///
+          segLen = LINE_SQUARE_CLIP_MAX;
+          segLen = (vctr_x < -VECTOR_COMPONENT_MIN) ? ((int) (clp0_x) -clp0_x) / vctr_x : segLen;
+          segLen = (vctr_x > VECTOR_COMPONENT_MIN) ? ((int) ((int) (clp0_x) + 1.5f) - clp0_x) / vctr_x : segLen;
+          segLen = (vctr_y < -VECTOR_COMPONENT_MIN) ? (((tmpLen = ((int) (clp0_y) -clp0_y) / vctr_y) < segLen) ? tmpLen : segLen)
+                                                    : segLen;
+          segLen = (vctr_y > VECTOR_COMPONENT_MIN)
+                       ? (((tmpLen = ((int) ((int) (clp0_y) + 1.5f) - clp0_y) / vctr_y) < segLen) ? tmpLen : segLen)
+                       : segLen;
 
-                  /// in case of a critical point///
-                  if (vctr_x == 0.0f && vctr_y == 0.0f)
-                    {
-                      t_acum[advDir] = (advcts == 0) ? 0.0f : t_acum[advDir];  /// this line is indeed unnecessary
-                      w_acum[advDir] = (advcts == 0) ? 1.0f : w_acum[advDir];
-                      break;
-                    }
+          /// update the curve-length measurers///
+          prvLen = curLen;
+          curLen += segLen;
+          segLen += 0.0004f;
 
-                  /// negate the vector for the backward-advection case///
-                  vctr_x = (advDir == 0) ? vctr_x : -vctr_x;
-                  vctr_y = (advDir == 0) ? vctr_y : -vctr_y;
+          /// check if the filter has reached either end///
+          segLen = (curLen > krnlen) ? ((curLen = krnlen) - prvLen) : segLen;
 
-                  /// clip the segment against the pixel boundaries --- find the shorter from the two clipped segments///
-                  /// replace  all  if-statements  whenever  possible  as  they  might  affect the computational speed///
-                  segLen = LINE_SQUARE_CLIP_MAX;
-                  segLen = (vctr_x < -VECTOR_COMPONENT_MIN) ? ((int) (clp0_x) -clp0_x) / vctr_x : segLen;
-                  segLen = (vctr_x > VECTOR_COMPONENT_MIN) ? ((int) ((int) (clp0_x) + 1.5f) - clp0_x) / vctr_x : segLen;
-                  segLen = (vctr_y < -VECTOR_COMPONENT_MIN)
-                               ? (((tmpLen = ((int) (clp0_y) -clp0_y) / vctr_y) < segLen) ? tmpLen : segLen)
-                               : segLen;
-                  segLen = (vctr_y > VECTOR_COMPONENT_MIN)
-                               ? (((tmpLen = ((int) ((int) (clp0_y) + 1.5f) - clp0_y) / vctr_y) < segLen) ? tmpLen : segLen)
-                               : segLen;
+          /// obtain the next clip point///
+          clp1_x = clp0_x + vctr_x * segLen;
+          clp1_y = clp0_y + vctr_y * segLen;
 
-                  /// update the curve-length measurers///
-                  prvLen = curLen;
-                  curLen += segLen;
-                  segLen += 0.0004f;
+          /// obtain the middle point of the segment as the texture-contributing sample///
+          samp_x = (clp0_x + clp1_x) * 0.5f;
+          samp_y = (clp0_y + clp1_y) * 0.5f;
 
-                  /// check if the filter has reached either end///
-                  segLen = (curLen > krnlen) ? ((curLen = krnlen) - prvLen) : segLen;
+          /// obtain the texture value of the sample///
+          if (samp_x >= n_xres) samp_x = n_xres - 1;  // bug fix
+          if (samp_y >= n_yres) samp_y = n_yres - 1;  // bug fix
+          texVal = pNoise[(int) (samp_y) *n_xres + (int) (samp_x)];
 
-                  /// obtain the next clip point///
-                  clp1_x = clp0_x + vctr_x * segLen;
-                  clp1_y = clp0_y + vctr_y * segLen;
+          /// update the accumulated weight and the accumulated composite texture (texture x weight)///
+          W_ACUM = wgtLUT[(int) (curLen * len2ID)];
+          smpWgt = W_ACUM - w_acum[advDir];
+          w_acum[advDir] = W_ACUM;
+          t_acum[advDir] += texVal * smpWgt;
 
-                  /// obtain the middle point of the segment as the texture-contributing sample///
-                  samp_x = (clp0_x + clp1_x) * 0.5f;
-                  samp_y = (clp0_y + clp1_y) * 0.5f;
+          /// update the step counter and the "current" clip point///
+          advcts++;
+          clp0_x = clp1_x;
+          clp0_y = clp1_y;
 
-                  /// obtain the texture value of the sample///
-                  if (samp_x >= n_xres) samp_x = n_xres - 1;  // bug fix
-                  if (samp_y >= n_yres) samp_y = n_yres - 1;  // bug fix
-                  texVal = pNoise[(int) (samp_y) *n_xres + (int) (samp_x)];
-
-                  /// update the accumulated weight and the accumulated composite texture (texture x weight)///
-                  W_ACUM = wgtLUT[(int) (curLen * len2ID)];
-                  smpWgt = W_ACUM - w_acum[advDir];
-                  w_acum[advDir] = W_ACUM;
-                  t_acum[advDir] += texVal * smpWgt;
-
-                  /// update the step counter and the "current" clip point///
-                  advcts++;
-                  clp0_x = clp1_x;
-                  clp0_y = clp1_y;
-
-                  /// check if the streamline has gone beyond the flow field///
-                  if (clp0_x < 0.0f || clp0_x >= n_xres || clp0_y < 0.0f || clp0_y >= n_yres) break;
-                }
-            }
-
-          /// normalize the accumulated composite texture///
-          texVal = (t_acum[0] + t_acum[1]) / (w_acum[0] + w_acum[1]);
-
-          /// clamp the texture value against the displayable intensity range [0, 255]
-          texVal = (texVal < 0.0f) ? 0.0f : texVal;
-          texVal = (texVal > 255.0f) ? 255.0f : texVal;
-          pImage[j * n_xres + i] = (unsigned char) texVal;
+          /// check if the streamline has gone beyond the flow field///
+          if (clp0_x < 0.0f || clp0_x >= n_xres || clp0_y < 0.0f || clp0_y >= n_yres) break;
         }
+      }
+
+      /// normalize the accumulated composite texture///
+      texVal = (t_acum[0] + t_acum[1]) / (w_acum[0] + w_acum[1]);
+
+      /// clamp the texture value against the displayable intensity range [0, 255]
+      texVal = (texVal < 0.0f) ? 0.0f : texVal;
+      texVal = (texVal > 255.0f) ? 255.0f : texVal;
+      pImage[j * n_xres + i] = (unsigned char) texVal;
     }
+  }
 }
 
 static void
@@ -383,16 +382,16 @@ lic1(const char *obasename, int num, int n_xres, int n_yres, float *pVectr)
     mag[i] = (float) std::sqrt((double) pVectr[i * 2] * pVectr[i * 2] + (double) pVectr[i * 2 + 1] * pVectr[i * 2 + 1]);
 
   if (Options::cdoVerbose)
+  {
+    float vmin = 1.e33;
+    float vmax = -1.e33;
+    for (int i = 0; i < n_xres * n_yres; ++i)
     {
-      float vmin = 1.e33;
-      float vmax = -1.e33;
-      for (int i = 0; i < n_xres * n_yres; ++i)
-        {
-          if (mag[i] < vmin) vmin = mag[i];
-          if (mag[i] > vmax) vmax = mag[i];
-        }
-      cdo_print("ts=%d minval=%g  maxval=%g", num + 1, vmin, vmax);
+      if (mag[i] < vmin) vmin = mag[i];
+      if (mag[i] > vmax) vmax = mag[i];
     }
+    cdo_print("ts=%d minval=%g  maxval=%g", num + 1, vmin, vmax);
+  }
 
   NormalizVectrs(n_xres, n_yres, pVectr);
   MakeWhiteNoise(n_xres, n_yres, pNoise);
@@ -498,13 +497,13 @@ public:
 
     Varray<double> ivar1, ivar2, ovar1;
     if (varID1 != -1 && varID2 != -1)
-      {
-        numLevels = varList1.vars[varID1].nlevels;
-        gridsize = varList1.vars[varID1].gridsize;
-        ivar1.resize(numLevels * gridsize);
-        ivar2.resize(numLevels * gridsize);
-        ovar1.resize(numLevels * gridsize);
-      }
+    {
+      numLevels = varList1.vars[varID1].nlevels;
+      gridsize = varList1.vars[varID1].gridsize;
+      ivar1.resize(numLevels * gridsize);
+      ivar2.resize(numLevels * gridsize);
+      ovar1.resize(numLevels * gridsize);
+    }
 
     auto gridtype = gridInqType(gridID);
     if (gridtype != GRID_LONLAT && gridtype != GRID_GAUSSIAN) cdo_abort("Unsupported grid!\n");
@@ -523,45 +522,45 @@ public:
   {
     int tsID = 0;
     while (true)
+    {
+      auto numFields = cdo_stream_inq_timestep(streamID1, tsID);
+      if (numFields == 0) break;
+      /*
+      cdo_taxis_copy_timestep(taxisID2, taxisID1);
+      cdo_def_timestep(streamID2, tsID);
+      */
+      for (int fieldID = 0; fieldID < numFields; ++fieldID)
       {
-        auto numFields = cdo_stream_inq_timestep(streamID1, tsID);
-        if (numFields == 0) break;
-        /*
-        cdo_taxis_copy_timestep(taxisID2, taxisID1);
-        cdo_def_timestep(streamID2, tsID);
-        */
-        for (int fieldID = 0; fieldID < numFields; ++fieldID)
+        auto [varID, levelID] = cdo_inq_field(streamID1);
+
+        if (varID == varID1 || varID == varID2)
+        {
+          cdo_read_field(streamID1, array1.data(), &numMissVals);
+          if (numMissVals) cdo_abort("Missing values unsupported!");
+
+          gridsize = gridInqSize(gridID);
+
+          if (invertlat)
           {
-            auto [varID, levelID] = cdo_inq_field(streamID1);
-
-            if (varID == varID1 || varID == varID2)
-              {
-                cdo_read_field(streamID1, array1.data(), &numMissVals);
-                if (numMissVals) cdo_abort("Missing values unsupported!");
-
-                gridsize = gridInqSize(gridID);
-
-                if (invertlat)
-                  {
-                    for (size_t j = 0; j < ny / 2; ++j)
-                      {
-                        for (size_t i = 0; i < nx; ++i) xvals[i] = array1[j * nx + i];
-                        for (size_t i = 0; i < nx; ++i) array1[j * nx + i] = array1[(ny - j - 1) * nx + i];
-                        for (size_t i = 0; i < nx; ++i) array1[(ny - j - 1) * nx + i] = xvals[i];
-                      }
-                  }
-
-                if (varID == varID1)
-                  for (size_t i = 0; i < gridsize; ++i) varray[i * 2] = (float) array1[i];
-                else if (varID == varID2)
-                  for (size_t i = 0; i < gridsize; ++i) varray[i * 2 + 1] = (float) array1[i];
-              }
+            for (size_t j = 0; j < ny / 2; ++j)
+            {
+              for (size_t i = 0; i < nx; ++i) xvals[i] = array1[j * nx + i];
+              for (size_t i = 0; i < nx; ++i) array1[j * nx + i] = array1[(ny - j - 1) * nx + i];
+              for (size_t i = 0; i < nx; ++i) array1[(ny - j - 1) * nx + i] = xvals[i];
+            }
           }
 
-        lic1(obasename, nstart + tsID, nx, ny, varray.data());
-
-        tsID++;
+          if (varID == varID1)
+            for (size_t i = 0; i < gridsize; ++i) varray[i * 2] = (float) array1[i];
+          else if (varID == varID2)
+            for (size_t i = 0; i < gridsize; ++i) varray[i * 2 + 1] = (float) array1[i];
+        }
       }
+
+      lic1(obasename, nstart + tsID, nx, ny, varray.data());
+
+      tsID++;
+    }
   }
 
   void
