@@ -61,7 +61,7 @@ quit_MAGICS()
 void
 magvector(const char *plotfile, long nlon, long nlat, Varray<double> &grid_center_lon, Varray<double> &grid_center_lat,
           Varray<double> &uarray, Varray<double> &varray, int nparam, std::vector<std::string> &params,
-          const std::string &datetimeStr)
+          std::string const &datetimeStr)
 
 {
   long i;
@@ -70,71 +70,71 @@ magvector(const char *plotfile, long nlon, long nlat, Varray<double> &grid_cente
   char *temp_str = nullptr;
 
   if (uarray.empty() && varray.empty())
-    {
-      fprintf(stderr, " No Velocity Components in input file, cannot creaate Vector PLOT!\n");
-      return;
-    }
+  {
+    fprintf(stderr, " No Velocity Components in input file, cannot creaate Vector PLOT!\n");
+    return;
+  }
 
   if (uarray.empty() || varray.empty())
-    {
-      fprintf(stderr, " Found only one Velocity Component in input file, cannot create Vector PLOT!\n");
-      return;
-    }
+  {
+    fprintf(stderr, " Found only one Velocity Component in input file, cannot create Vector PLOT!\n");
+    return;
+  }
 
   if (DBG)
-    {
-      fprintf(stderr, "Num params %zu\n", params.size());
+  {
+    fprintf(stderr, "Num params %zu\n", params.size());
 
-      for (i = 0; i < nparam; ++i) fprintf(stderr, "Param %s\n", params[i].c_str());
-      fflush(stderr);
-    }
+    for (i = 0; i < nparam; ++i) fprintf(stderr, "Param %s\n", params[i].c_str());
+    fflush(stderr);
+  }
 
   for (i = 0; i < nparam; ++i)
+  {
+    auto splitStrings = split_string(params[i], "=");
+    auto const &key = splitStrings[0];
+    auto const &value = splitStrings[1];
+
+    if (key == "thin_fac")
     {
-      auto splitStrings = split_string(params[i], "=");
-      const auto &key = splitStrings[0];
-      const auto &value = splitStrings[1];
-
-      if (key == "thin_fac")
-        {
-          THIN_FAC = std::stof(value);
-          if (DBG) fprintf(stderr, "THIN FACTOR %g\n", THIN_FAC);
-        }
-
-      if (key == "unit_vec")
-        {
-          UNIT_VEC = std::stof(value);
-          if (DBG) fprintf(stderr, "UNIT VECTOR %g\n", UNIT_VEC);
-        }
-
-      if (key == "device")
-        {
-          temp_str = strdup(value.c_str());
-          cstr_to_upper(temp_str);
-          DEVICE = temp_str;
-          if (DBG) fprintf(stderr, "DEVICE %s\n", DEVICE);
-
-          mag_setc("output_format", DEVICE);
-        }
-
-      if (key == "step_freq")
-        {
-          STEP_FREQ = std::stoi(value);
-          if (DBG) fprintf(stderr, "STEP FREQ %d\n", STEP_FREQ);
-        }
+      THIN_FAC = std::stof(value);
+      if (DBG) fprintf(stderr, "THIN FACTOR %g\n", THIN_FAC);
     }
 
+    if (key == "unit_vec")
+    {
+      UNIT_VEC = std::stof(value);
+      if (DBG) fprintf(stderr, "UNIT VECTOR %g\n", UNIT_VEC);
+    }
+
+    if (key == "device")
+    {
+      temp_str = strdup(value.c_str());
+      cstr_to_upper(temp_str);
+      DEVICE = temp_str;
+      if (DBG) fprintf(stderr, "DEVICE %s\n", DEVICE);
+
+      mag_setc("output_format", DEVICE);
+    }
+
+    if (key == "step_freq")
+    {
+      STEP_FREQ = std::stoi(value);
+      if (DBG) fprintf(stderr, "STEP FREQ %d\n", STEP_FREQ);
+    }
+  }
+
   if (nlon > 1)
-    {
-      for (i = 1; i < nlon; ++i) dlon += (grid_center_lon[i] - grid_center_lon[i - 1]);
-      dlon /= (nlon - 1);
-    }
+  {
+    for (i = 1; i < nlon; ++i) dlon += (grid_center_lon[i] - grid_center_lon[i - 1]);
+    dlon /= (nlon - 1);
+  }
 
   if (nlat > 1)
-    {
-      for (i = 1; i < nlat; ++i) dlat += (grid_center_lat[nlon * i] - grid_center_lat[nlon * (i - 1)]);
-      dlat /= (nlat - 1);
-    }
+  {
+    for (i = 1; i < nlat; ++i) dlat += (grid_center_lat[nlon * i] - grid_center_lat[nlon * (i - 1)]);
+    dlat /= (nlat - 1);
+  }
 
   /* magics_template_parser( magics_node ); */
 
@@ -203,68 +203,68 @@ verify_vector_parameters(int num_param, std::vector<std::string> &param_names, b
   // char  *vector_params[] = {"min","max","count","interval","list","colour","thickness","style","RGB"};
 
   for (i = 0; i < num_param; ++i)
+  {
+    auto found = false;
+    auto syntax = true;
+    auto splitStrings = split_string(param_names[i], "=");
+
+    if (DBG) fprintf(stderr, "Verifying params!\n");
+
+    if (splitStrings.size() > 1)
     {
-      auto found = false;
-      auto syntax = true;
-      auto splitStrings = split_string(param_names[i], "=");
+      auto const &key = splitStrings[0];
+      auto const &value = splitStrings[1];
+      if (vectorMode)
+      {
+        param_count = vector_param_count;
+        params = vector_params;
+      }
 
-      if (DBG) fprintf(stderr, "Verifying params!\n");
-
-      if (splitStrings.size() > 1)
+      for (j = 0; j < param_count; ++j)
+      {
+        if (key == params[j])
         {
-          const auto &key = splitStrings[0];
-          const auto &value = splitStrings[1];
-          if (vectorMode)
+          found = true;
+
+          if (key == "thin_fac" || key == "unit_vec" || key == "step_freq")
+          {
+            if (!string_is_float(value)) syntax = false;
+          }
+
+          if (key == "device")
+          {
+            if (string_is_float(value))
+              syntax = false;
+            else
             {
-              param_count = vector_param_count;
-              params = vector_params;
-            }
-
-          for (j = 0; j < param_count; ++j)
-            {
-              if (key == params[j])
-                {
-                  found = true;
-
-                  if (key == "thin_fac" || key == "unit_vec" || key == "step_freq")
-                    {
-                      if (!string_is_float(value)) syntax = false;
-                    }
-
-                  if (key == "device")
-                    {
-                      if (string_is_float(value))
-                        syntax = false;
-                      else
-                        {
-                          if (DBG) fprintf(stderr, "Parameter value '%s'\n", value.c_str());
-                          char *deviceCstr = strdup(value.c_str());
-                          if (checkdevice(deviceCstr)) syntax = false;
-
-                          // Vector not supported in google earth format
-                          if (value == "KML" || value == "kml")
-                            {
-                              syntax = false;
-                              if (DBG) fprintf(stderr, "Parameter value '%s'\n", value.c_str());
-                            }
-                        }
-                    }
-                }
+              if (DBG) fprintf(stderr, "Parameter value '%s'\n", value.c_str());
+              char *deviceCstr = strdup(value.c_str());
+              if (checkdevice(deviceCstr)) syntax = false;
+
+              // Vector not supported in google earth format
+              if (value == "KML" || value == "kml")
+              {
+                syntax = false;
+                if (DBG) fprintf(stderr, "Parameter value '%s'\n", value.c_str());
+              }
             }
+          }
         }
-      else { syntax = false; }
-
-      if (!found)
-        {
-          halt_flag = true;
-          fprintf(stderr, "Invalid parameter  '%s'\n", param_names[i].c_str());
-        }
-      if (found && !syntax)
-        {
-          halt_flag = true;
-          fprintf(stderr, "Invalid parameter specification  '%s'\n", param_names[i].c_str());
-        }
+      }
     }
+    else { syntax = false; }
+
+    if (!found)
+    {
+      halt_flag = true;
+      fprintf(stderr, "Invalid parameter  '%s'\n", param_names[i].c_str());
+    }
+    if (found && !syntax)
+    {
+      halt_flag = true;
+      fprintf(stderr, "Invalid parameter specification  '%s'\n", param_names[i].c_str());
+    }
+  }
 
   if (halt_flag) exit(0);
 }
@@ -320,12 +320,12 @@ public:
     operatorID = cdo_operator_id();
 
     if (nparam)
-      {
-        if (DBG)
-          for (int i = 0; i < nparam; ++i) fprintf(stderr, "Param %d is %s!\n", i + 1, pnames[i].c_str());
+    {
+      if (DBG)
+        for (int i = 0; i < nparam; ++i) fprintf(stderr, "Param %d is %s!\n", i + 1, pnames[i].c_str());
 
-        verify_vector_parameters(nparam, pnames, (operatorID == VECTOR));
-      }
+      verify_vector_parameters(nparam, pnames, (operatorID == VECTOR));
+    }
 
     streamID = cdo_open_read(0);
 
@@ -375,94 +375,93 @@ public:
     int tsID = 0;
 
     while (true)
+    {
+      auto numFields = cdo_stream_inq_timestep(streamID, tsID);
+      if (numFields == 0) break;
+
+      if (ANIM_FLAG)
       {
-        auto numFields = cdo_stream_inq_timestep(streamID, tsID);
-        if (numFields == 0) break;
+        if (tsID % STEP_FREQ)
+        {
+          tsID++;
+          continue;
+        }
+      }
+      else
+      {
+        if (!STEP_FREQ && tsID)
+        {
+          cdo_warning("File has values at more than one time step! Image created for first time step!!!");
+          break;
+        }
+      }
 
-        if (ANIM_FLAG)
-          {
-            if (tsID % STEP_FREQ)
-              {
-                tsID++;
-                continue;
-              }
-          }
-        else
-          {
-            if (!STEP_FREQ && tsID)
-              {
-                cdo_warning("File has values at more than one time step! Image created for first time step!!!");
-                break;
-              }
-          }
+      auto datetimeStr = datetime_to_string(taxisInqVdatetime(taxisID));
 
-        auto datetimeStr = datetime_to_string(taxisInqVdatetime(taxisID));
+      for (int fieldID = 0; fieldID < numFields; ++fieldID)
+      {
+        auto [varID, levelID] = cdo_inq_field(streamID);
 
-        for (int fieldID = 0; fieldID < numFields; ++fieldID)
-          {
-            int varID, levelID;
-            cdo_inq_field(streamID, &varID, &levelID);
-
-            auto varname = cdo::inq_var_name(vlistID, varID);
-
-            if (operatorID == VECTOR)
-              {
-                if (varname == "var131" || varname == "u")  // U Velocity as per GRIB is var131, as per NC 'u'
-                  {
-                    if (DBG) fprintf(stderr, "Found U VEL in Varname %s\n", varname.c_str());
-                    size_t numMissVals;
-                    cdo_read_field(streamID, uarray.data(), &numMissVals);
-                    if (numMissVals) cdo_set_nan(vlistInqVarMissval(vlistID, varID), gridsize, uarray.data());
-                    found++;
-                  }
-                if (varname == "var132" || varname == "v")  // V Velocity as per GRIB  is var132, as per NC 'v'
-                  {
-                    if (DBG) fprintf(stderr, "Found V VEL in Varname %s\n", varname.c_str());
-                    size_t numMissVals;
-                    cdo_read_field(streamID, varray.data(), &numMissVals);
-                    if (numMissVals) cdo_set_nan(vlistInqVarMissval(vlistID, varID), gridsize, varray.data());
-                    found++;
-                  }
-                if (found == 2) break;
-              }
-            else if (operatorID == STREAM)
-              fprintf(stderr, " Stream Operator Un-Supported!\n");
-            else
-              fprintf(stderr, " Operator Un-Supported!\n");
-          }
+        auto varname = cdo::inq_var_name(vlistID, varID);
 
         if (operatorID == VECTOR)
+        {
+          if (varname == "var131" || varname == "u")  // U Velocity as per GRIB is var131, as per NC 'u'
           {
-            if (found == 2)
-              {
-                if (DBG) fprintf(stderr, "Found Both U & V VEL, Creating vector fields! \n");
-                magvector(cdo_get_stream_name(1), nlon, nlat, grid_center_lon, grid_center_lat, uarray, varray, nparam, pnames,
-                          datetimeStr);
-              }
-            else if (found == 1)
-              {
-                fprintf(stderr, "Found only one Velocity Component in input file, cannot create Vector PLOT!\n");
-                break;
-              }
-            else if (found == 0)
-              {
-                fprintf(stderr, "No Velocity Components in input file, cannot create Vector PLOT!\n");
-                break;
-              }
+            if (DBG) fprintf(stderr, "Found U VEL in Varname %s\n", varname.c_str());
+            size_t numMissVals;
+            cdo_read_field(streamID, uarray.data(), &numMissVals);
+            if (numMissVals) cdo_set_nan(vlistInqVarMissval(vlistID, varID), gridsize, uarray.data());
+            found++;
           }
-
-        tsID++;
-
-        /*
-        if( ANIM_FLAG )
-          tsID++;
+          if (varname == "var132" || varname == "v")  // V Velocity as per GRIB  is var132, as per NC 'v'
+          {
+            if (DBG) fprintf(stderr, "Found V VEL in Varname %s\n", varname.c_str());
+            size_t numMissVals;
+            cdo_read_field(streamID, varray.data(), &numMissVals);
+            if (numMissVals) cdo_set_nan(vlistInqVarMissval(vlistID, varID), gridsize, varray.data());
+            found++;
+          }
+          if (found == 2) break;
+        }
+        else if (operatorID == STREAM)
+          fprintf(stderr, " Stream Operator Un-Supported!\n");
         else
-          {
-             cdo_warning("File has values at more than one time step! Image created for first time step!!!");
-             if( STEP_FREQ > 1 ) cdo_warning("Step frequency parameter ignored!!!"); break;
-          }
-        */
+          fprintf(stderr, " Operator Un-Supported!\n");
       }
+
+      if (operatorID == VECTOR)
+      {
+        if (found == 2)
+        {
+          if (DBG) fprintf(stderr, "Found Both U & V VEL, Creating vector fields! \n");
+          magvector(cdo_get_stream_name(1), nlon, nlat, grid_center_lon, grid_center_lat, uarray, varray, nparam, pnames,
+                    datetimeStr);
+        }
+        else if (found == 1)
+        {
+          fprintf(stderr, "Found only one Velocity Component in input file, cannot create Vector PLOT!\n");
+          break;
+        }
+        else if (found == 0)
+        {
+          fprintf(stderr, "No Velocity Components in input file, cannot create Vector PLOT!\n");
+          break;
+        }
+      }
+
+      tsID++;
+
+      /*
+      if( ANIM_FLAG )
+        tsID++;
+      else
+        {
+           cdo_warning("File has values at more than one time step! Image created for first time step!!!");
+           if( STEP_FREQ > 1 ) cdo_warning("Step frequency parameter ignored!!!"); break;
+        }
+      */
+    }
 #else
     cdo_abort("MAGICS support not compiled in!");
 #endif
