@@ -41,23 +41,23 @@ check_out_of_range(Varray<T> &v, size_t &numMissVals, double missval_, double rm
   T rmax = static_cast<T>(rmax_);
 
   if (numMissVals)
-    {
-      for (size_t i = 0, n = v.size(); i < n; ++i)
-        if (fp_is_not_equal(v[i], missval) && (v[i] < rmin || v[i] > rmax))
-          {
-            v[i] = missval;
-            numMissVals++;
-          }
-    }
+  {
+    for (size_t i = 0, n = v.size(); i < n; ++i)
+      if (fp_is_not_equal(v[i], missval) && (v[i] < rmin || v[i] > rmax))
+      {
+        v[i] = missval;
+        numMissVals++;
+      }
+  }
   else
-    {
-      for (size_t i = 0, n = v.size(); i < n; ++i)
-        if (v[i] < rmin || v[i] > rmax)
-          {
-            v[i] = missval;
-            numMissVals++;
-          }
-    }
+  {
+    for (size_t i = 0, n = v.size(); i < n; ++i)
+      if (v[i] < rmin || v[i] > rmax)
+      {
+        v[i] = missval;
+        numMissVals++;
+      }
+  }
 }
 
 static void
@@ -76,23 +76,23 @@ check_lower_range(Varray<T> &v, size_t &numMissVals, double missval_, double rmi
   T rmin = static_cast<T>(rmin_);
 
   if (numMissVals)
-    {
-      for (size_t i = 0, n = v.size(); i < n; ++i)
-        if (fp_is_not_equal(v[i], missval) && v[i] < rmin)
-          {
-            v[i] = missval;
-            numMissVals++;
-          }
-    }
+  {
+    for (size_t i = 0, n = v.size(); i < n; ++i)
+      if (fp_is_not_equal(v[i], missval) && v[i] < rmin)
+      {
+        v[i] = missval;
+        numMissVals++;
+      }
+  }
   else
-    {
-      for (size_t i = 0, n = v.size(); i < n; ++i)
-        if (v[i] < rmin)
-          {
-            v[i] = missval;
-            numMissVals++;
-          }
-    }
+  {
+    for (size_t i = 0, n = v.size(); i < n; ++i)
+      if (v[i] < rmin)
+      {
+        v[i] = missval;
+        numMissVals++;
+      }
+  }
 }
 
 static void
@@ -160,9 +160,9 @@ math_field_rand(Varray<T> &v, double missval_)
 {
   T missval = static_cast<T>(missval_);
   for (size_t i = 0, n = v.size(); i < n; ++i)
-    {
-      v[i] = fp_is_equal(v[i], missval) ? missval : ((double) std::rand()) / ((double) RAND_MAX);
-    }
+  {
+    v[i] = fp_is_equal(v[i], missval) ? missval : ((double) std::rand()) / ((double) RAND_MAX);
+  }
 }
 
 static void
@@ -177,10 +177,10 @@ static void
 math_field_sqr_cplx(Varray<T> &vc, size_t n)
 {
   for (size_t i = 0; i < n; ++i)
-    {
-      vc[i * 2] = vc[i * 2] * vc[i * 2] + vc[i * 2 + 1] * vc[i * 2 + 1];
-      vc[i * 2 + 1] = 0.0;
-    }
+  {
+    vc[i * 2] = vc[i * 2] * vc[i * 2] + vc[i * 2 + 1] * vc[i * 2 + 1];
+    vc[i * 2 + 1] = 0.0;
+  }
 }
 
 static void
@@ -199,11 +199,11 @@ math_field_sqrt_cplx(Varray<T> &vc, size_t n, double missval)
   T missval2 = static_cast<T>(missval);
   auto rsqrt2 = 1.0 / std::sqrt(2.0);
   for (size_t i = 0; i < n; ++i)
-    {
-      double abs = SQRTM(ADDM(MULM(vc[2 * i], vc[2 * i]), MULM(vc[2 * i + 1], vc[2 * i + 1])));
-      vc[i * 2] = MULM(rsqrt2, SQRTM(ADDM(vc[i * 2], abs)));
-      vc[i * 2 + 1] = MULM(rsqrt2, DIVM(vc[2 * i + 1], SQRTM(ADDM(vc[2 * i], abs))));
-    }
+  {
+    double abs = SQRTM(ADDM(MULM(vc[2 * i], vc[2 * i]), MULM(vc[2 * i + 1], vc[2 * i + 1])));
+    vc[i * 2] = MULM(rsqrt2, SQRTM(ADDM(vc[i * 2], abs)));
+    vc[i * 2 + 1] = MULM(rsqrt2, DIVM(vc[2 * i + 1], SQRTM(ADDM(vc[2 * i], abs))));
+  }
 }
 
 static void
@@ -218,10 +218,10 @@ static void
 math_field_conj_cplx(Varray<T> &vc, size_t n)
 {
   for (size_t i = 0; i < n; ++i)
-    {
-      // vc[i * 2] = vc[i * 2];
-      vc[i * 2 + 1] = -vc[i * 2 + 1];
-    }
+  {
+    // vc[i * 2] = vc[i * 2];
+    vc[i * 2 + 1] = -vc[i * 2 + 1];
+  }
 }
 
 static void
@@ -254,10 +254,10 @@ math_field_arg_cplx(Varray<T> &vc, size_t n, double missval_)
 {
   T missval = static_cast<T>(missval_);
   for (size_t i = 0; i < n; ++i)
-    {
-      vc[i] = (fp_is_equal(vc[2 * i], missval) || fp_is_equal(vc[2 * i + 1], missval)) ? missval
-                                                                                       : std::atan2(vc[2 * i + 1], vc[2 * i]);
-    }
+  {
+    vc[i]
+        = (fp_is_equal(vc[2 * i], missval) || fp_is_equal(vc[2 * i + 1], missval)) ? missval : std::atan2(vc[2 * i + 1], vc[2 * i]);
+  }
 }
 
 static void
@@ -346,16 +346,16 @@ public:
   inline static RegisterEntry<Math> registration = RegisterEntry<Math>(module);
 
 private:
-  Oper operfunc;
+  Oper operfunc{};
 
-  CdoStreamID streamID1;
-  CdoStreamID streamID2;
+  CdoStreamID streamID1{};
+  CdoStreamID streamID2{};
 
-  int taxisID1;
-  int taxisID2;
-  int vlistID2;
+  int taxisID1{ CDI_UNDEFID };
+  int taxisID2{ CDI_UNDEFID };
+  int vlistID2{ CDI_UNDEFID };
 
-  VarList varList1;
+  VarList varList1{};
 
   double rc = 0.0;
 
@@ -367,10 +367,10 @@ public:
     operfunc = (Oper) cdo_operator_f1(operatorID);
 
     if (operfunc == Oper::Pow)
-      {
-        operator_input_arg("value");
-        rc = parameter_to_double(cdo_operator_argv(0));
-      }
+    {
+      operator_input_arg("value");
+      rc = parameter_to_double(cdo_operator_argv(0));
+    }
     else { operator_check_argc(0); }
 
     if (operfunc == Oper::Rand) std::srand(Options::Random_Seed);
@@ -383,15 +383,15 @@ public:
     varList1 = VarList(vlistID1);
 
     if (operfunc == Oper::Re || operfunc == Oper::Im || operfunc == Oper::Abs || operfunc == Oper::Arg)
+    {
+      auto numVars = varList1.numVars();
+      for (int varID = 0; varID < numVars; ++varID)
       {
-        auto numVars = varList1.numVars();
-        for (int varID = 0; varID < numVars; ++varID)
-          {
-            const auto &var1 = varList1.vars[varID];
-            if (var1.dataType == CDI_DATATYPE_CPX32) vlistDefVarDatatype(vlistID2, varID, CDI_DATATYPE_FLT32);
-            if (var1.dataType == CDI_DATATYPE_CPX64) vlistDefVarDatatype(vlistID2, varID, CDI_DATATYPE_FLT64);
-          }
+        auto const &var1 = varList1.vars[varID];
+        if (var1.dataType == CDI_DATATYPE_CPX32) vlistDefVarDatatype(vlistID2, varID, CDI_DATATYPE_FLT32);
+        if (var1.dataType == CDI_DATATYPE_CPX64) vlistDefVarDatatype(vlistID2, varID, CDI_DATATYPE_FLT64);
       }
+    }
 
     taxisID1 = vlistInqTaxis(vlistID1);
     taxisID2 = taxisDuplicate(taxisID1);
@@ -408,81 +408,81 @@ public:
 
     int tsID = 0;
     while (true)
+    {
+      auto numFields = cdo_stream_inq_timestep(streamID1, tsID);
+      if (numFields == 0) break;
+
+      cdo_taxis_copy_timestep(taxisID2, taxisID1);
+      cdo_def_timestep(streamID2, tsID);
+
+      for (int fieldID = 0; fieldID < numFields; ++fieldID)
       {
-        auto numFields = cdo_stream_inq_timestep(streamID1, tsID);
-        if (numFields == 0) break;
+        auto [varID, levelID] = cdo_inq_field(streamID1);
+        auto const &var = varList1.vars[varID];
+        field.init(var);
+        cdo_read_field(streamID1, field);
 
-        cdo_taxis_copy_timestep(taxisID2, taxisID1);
-        cdo_def_timestep(streamID2, tsID);
-
-        for (int fieldID = 0; fieldID < numFields; ++fieldID)
+        auto number = var.nwpv;
+        if (number == CDI_REAL)
+        {
+          // clang-format off
+          switch (operfunc)
           {
-            auto [varID, levelID] = cdo_inq_field(streamID1);
-            auto const &var = varList1.vars[varID];
-            field.init(var);
-            cdo_read_field(streamID1, field);
-
-            auto number = var.nwpv;
-            if (number == CDI_REAL)
-              {
-                // clang-format off
-              switch (operfunc)
-                {
-                case Oper::Abs:   math_field_transform(field, unary_op_abs); break;
-                case Oper::Int:   math_field_transform(field, unary_op_int); break;
-                case Oper::Nint:  math_field_transform(field, unary_op_nint); break;
-                case Oper::Sqr:   math_field_transform(field, unary_op_sqr); break;
-                case Oper::Sqrt:  math_field_sqrt(field); break;
-                case Oper::Exp:   math_field_transform(field, unary_op_exp); break;
-                case Oper::Ln:    check_lower_range(field, -1);
-                                  math_field_transform(field, unary_op_log); break;
-                case Oper::Log10: check_lower_range(field, -1);
-                                  math_field_transform(field, unary_op_log10); break;
-                case Oper::Sin:   math_field_transform(field, unary_op_sin); break;
-                case Oper::Cos:   math_field_transform(field, unary_op_cos); break;
-                case Oper::Tan:   math_field_transform(field, unary_op_tan); break;
-                case Oper::Asin:  check_out_of_range(field, -1, 1);
-                                  math_field_transform(field, unary_op_asin); break;
-                case Oper::Acos:  check_out_of_range(field, -1, 1);
-                                  math_field_transform(field, unary_op_acos); break;
-                case Oper::Atan:  math_field_transform(field, unary_op_atan); break;
-                case Oper::Pow:   math_field_pow(field, rc); break;
-                case Oper::Rand:  math_field_rand(field); break;
-                case Oper::Reci:  math_field_transform(field, unary_op_reci); break;
-                case Oper::Not:   math_field_transform(field, unary_op_not); break;
-                case Oper::Re:
-                case Oper::Arg:   math_field_transform(field, unary_op_nop); break;
-                default: cdo_abort("Operator not implemented for real data!"); break;
-                }
-                // clang-format on
-
-                field_num_mv(field);
-              }
-            else
-              {
-                // clang-format off
-              switch (operfunc)
-                {
-                case Oper::Sqr:   math_field_sqr_cplx(field); break;
-                case Oper::Sqrt:  math_field_sqrt_cplx(field); break;
-                case Oper::Conj:  math_field_conj_cplx(field); break;
-                case Oper::Re:    math_field_re_cplx(field); break;
-                case Oper::Im:    math_field_im_cplx(field); break;
-                case Oper::Abs:   math_field_abs_cplx(field); break;
-                case Oper::Arg:   math_field_arg_cplx(field); break;
-                default: cdo_abort("Fields with complex numbers are not supported by this operator!"); break;
-                }
-                // clang-format on
-
-                field.numMissVals = 0;
-              }
-
-            cdo_def_field(streamID2, varID, levelID);
-            cdo_write_field(streamID2, field);
+            case Oper::Abs:   math_field_transform(field, unary_op_abs); break;
+            case Oper::Int:   math_field_transform(field, unary_op_int); break;
+            case Oper::Nint:  math_field_transform(field, unary_op_nint); break;
+            case Oper::Sqr:   math_field_transform(field, unary_op_sqr); break;
+            case Oper::Sqrt:  math_field_sqrt(field); break;
+            case Oper::Exp:   math_field_transform(field, unary_op_exp); break;
+            case Oper::Ln:    check_lower_range(field, -1);
+                              math_field_transform(field, unary_op_log); break;
+            case Oper::Log10: check_lower_range(field, -1);
+                              math_field_transform(field, unary_op_log10); break;
+            case Oper::Sin:   math_field_transform(field, unary_op_sin); break;
+            case Oper::Cos:   math_field_transform(field, unary_op_cos); break;
+            case Oper::Tan:   math_field_transform(field, unary_op_tan); break;
+            case Oper::Asin:  check_out_of_range(field, -1, 1);
+                              math_field_transform(field, unary_op_asin); break;
+            case Oper::Acos:  check_out_of_range(field, -1, 1);
+                              math_field_transform(field, unary_op_acos); break;
+            case Oper::Atan:  math_field_transform(field, unary_op_atan); break;
+            case Oper::Pow:   math_field_pow(field, rc); break;
+            case Oper::Rand:  math_field_rand(field); break;
+            case Oper::Reci:  math_field_transform(field, unary_op_reci); break;
+            case Oper::Not:   math_field_transform(field, unary_op_not); break;
+            case Oper::Re:
+            case Oper::Arg:   math_field_transform(field, unary_op_nop); break;
+            default: cdo_abort("Operator not implemented for real data!"); break;
           }
+          // clang-format on
 
-        tsID++;
+          field_num_mv(field);
+        }
+        else
+        {
+          // clang-format off
+          switch (operfunc)
+          {
+            case Oper::Sqr:   math_field_sqr_cplx(field); break;
+            case Oper::Sqrt:  math_field_sqrt_cplx(field); break;
+            case Oper::Conj:  math_field_conj_cplx(field); break;
+            case Oper::Re:    math_field_re_cplx(field); break;
+            case Oper::Im:    math_field_im_cplx(field); break;
+            case Oper::Abs:   math_field_abs_cplx(field); break;
+            case Oper::Arg:   math_field_arg_cplx(field); break;
+            default: cdo_abort("Fields with complex numbers are not supported by this operator!"); break;
+          }
+          // clang-format on
+
+          field.numMissVals = 0;
+        }
+
+        cdo_def_field(streamID2, varID, levelID);
+        cdo_write_field(streamID2, field);
       }
+
+      tsID++;
+    }
   }
 
   void
