@@ -31,19 +31,19 @@ uv2dv_cfd_W(double missval, double *u, double *v, double *lon, double *lat, size
   size_t gridsize_uv = nlat * nlon;
 
   for (size_t k = 0; k < nlev; ++k)
-    {
-      double *tmp_u = u + k * gridsize_uv;
-      double *tmp_v = v + k * gridsize_uv;
-      double *tmp_div = div + k * gridsize_uv;
-      // Init output array.
-      ranges::fill_n(tmp_div, gridsize_uv, 0.0);
-      // Call the Fortran routine.
+  {
+    double *tmp_u = u + k * gridsize_uv;
+    double *tmp_v = v + k * gridsize_uv;
+    double *tmp_div = div + k * gridsize_uv;
+    // Init output array.
+    std::ranges::fill_n(tmp_div, gridsize_uv, 0.0);
+    // Call the Fortran routine.
 #ifdef HAVE_CF_INTERFACE
-      DDVFIDF(tmp_u, tmp_v, lat, lon, inlon, inlat, missval, boundOpt, tmp_div, ierror);
+    DDVFIDF(tmp_u, tmp_v, lat, lon, inlon, inlat, missval, boundOpt, tmp_div, ierror);
 #else
-      cdo_abort("Fortran support not compiled in!");
+    cdo_abort("Fortran support not compiled in!");
 #endif
-    }
+  }
 }
 
 static void
@@ -61,29 +61,29 @@ uv2vr_cfd_W(double missval, double *u, double *v, double *lon, double *lat, size
   size_t gridsize_uv = nlat * nlon;
 
   for (size_t k = 0; k < nlev; ++k)
-    {
-      double *tmp_u = u + k * gridsize_uv;
-      double *tmp_v = v + k * gridsize_uv;
-      double *tmp_vort = vort + k * gridsize_uv;
-      // Init output array.
-      ranges::fill_n(tmp_vort, gridsize_uv, 0.0);
-      // Call the Fortran routine.
+  {
+    double *tmp_u = u + k * gridsize_uv;
+    double *tmp_v = v + k * gridsize_uv;
+    double *tmp_vort = vort + k * gridsize_uv;
+    // Init output array.
+    std::ranges::fill_n(tmp_vort, gridsize_uv, 0.0);
+    // Call the Fortran routine.
 #ifdef HAVE_CF_INTERFACE
-      DVRFIDF(tmp_u, tmp_v, lat, lon, inlon, inlat, missval, boundOpt, tmp_vort, ierror);
+    DVRFIDF(tmp_u, tmp_v, lat, lon, inlon, inlat, missval, boundOpt, tmp_vort, ierror);
 #else
-      cdo_abort("Fortran support not compiled in!");
+    cdo_abort("Fortran support not compiled in!");
 #endif
-    }
+  }
 }
 
 static int
-find_name(const VarList &varList, const std::string &name)
+find_name(VarList const &varList, std::string const &name)
 {
   auto numVars = varList.numVars();
   for (int varID = 0; varID < numVars; ++varID)
-    {
-      if (name == varList.vars[varID].name) return varID;
-    }
+  {
+    if (name == varList.vars[varID].name) return varID;
+  }
 
   return CDI_UNDEFID;
 }
@@ -116,38 +116,38 @@ set_parameter(void)
   uName = "u";
   vName = "v";
 
-  auto pargc = cdo_operator_argc();
-  if (pargc)
+  auto numArgs = cdo_operator_argc();
+  if (numArgs)
+  {
+    auto const &argList = cdo_get_oper_argv();
+
+    KVList kvlist;
+    kvlist.name = "PARAMETER";
+    if (kvlist.parse_arguments(argList) != 0) cdo_abort("Parse error!");
+    if (Options::cdoVerbose) kvlist.print();
+
+    for (auto const &kv : kvlist)
     {
-      const auto &pargv = cdo_get_oper_argv();
+      auto const &key = kv.key;
+      if (kv.nvalues > 1) cdo_abort("Too many values for parameter key >%s<!", key);
+      if (kv.nvalues < 1) cdo_abort("Missing value for parameter key >%s<!", key);
+      auto const &value = kv.values[0];
 
-      KVList kvlist;
-      kvlist.name = "PARAMETER";
-      if (kvlist.parse_arguments(pargv) != 0) cdo_abort("Parse error!");
-      if (Options::cdoVerbose) kvlist.print();
-
-      for (const auto &kv : kvlist)
-        {
-          const auto &key = kv.key;
-          if (kv.nvalues > 1) cdo_abort("Too many values for parameter key >%s<!", key);
-          if (kv.nvalues < 1) cdo_abort("Missing value for parameter key >%s<!", key);
-          const auto &value = kv.values[0];
-
-          // clang-format off
-          if      (key == "u") uName = value;
-          else if (key == "v") vName = value;
-          else if (key == "boundOpt") boundOpt = parameter_to_int(value);
-          else if (key == "outMode")
-            {
-              if      (value == "new")     outMode = OutMode::NEW;
-              else if (value == "append")  outMode = OutMode::APPEND;
-              else if (value == "replace") outMode = OutMode::REPLACE;
-              else cdo_abort("Invalid parameter key value: outMode=%s (valid are: new/append/replace)", value);
-            }
-          else cdo_abort("Invalid parameter key >%s<!", key);
-          // clang-format on
-        }
+      // clang-format off
+      if      (key == "u") uName = value;
+      else if (key == "v") vName = value;
+      else if (key == "boundOpt") boundOpt = parameter_to_int(value);
+      else if (key == "outMode")
+      {
+        if      (value == "new")     outMode = OutMode::NEW;
+        else if (value == "append")  outMode = OutMode::APPEND;
+        else if (value == "replace") outMode = OutMode::REPLACE;
+        else cdo_abort("Invalid parameter key value: outMode=%s (valid are: new/append/replace)", value);
+      }
+      else cdo_abort("Invalid parameter key >%s<!", key);
+      // clang-format on
     }
+  }
 
   if (Options::cdoVerbose) print_parameter();
 }
@@ -169,26 +169,26 @@ public:
   };
   inline static RegisterEntry<NCL_wind> registration = RegisterEntry<NCL_wind>(module);
 
-  int UV2DV_CFD, UV2VR_CFD;
+  int UV2DV_CFD{}, UV2VR_CFD{};
 
   CdoStreamID streamID1;
   CdoStreamID streamID2;
 
-  int operatorID;
+  int operatorID{};
 
-  int taxisID1;
-  int taxisID2;
+  int taxisID1{ CDI_UNDEFID };
+  int taxisID2{ CDI_UNDEFID };
 
-  int vlistID2;
+  int vlistID2{ CDI_UNDEFID };
 
-  int varIDu;
-  int varIDv;
-  int varIDo;
-  int nlev;
+  int varIDu{};
+  int varIDv{};
+  int varIDo{};
+  int nlev{};
 
-  size_t gridsizeuv;
-  size_t nlon;
-  size_t nlat;
+  size_t gridsizeuv{};
+  size_t nlon{};
+  size_t nlat{};
 
   Varray<double> lon;
   Varray<double> lat;
@@ -225,8 +225,8 @@ public:
     if (varIDu == CDI_UNDEFID) cdo_abort("%s not found!", uName);
     if (varIDv == CDI_UNDEFID) cdo_abort("%s not found!", vName);
 
-    const auto &varU = varList1.vars[varIDu];
-    const auto &varV = varList1.vars[varIDv];
+    auto const &varU = varList1.vars[varIDu];
+    auto const &varV = varList1.vars[varIDv];
 
     auto gridIDu = varU.gridID;
     auto gridIDv = varV.gridID;
@@ -252,17 +252,17 @@ public:
 
     varIDo = vlistDefVar(vlistID2, gridIDu, zaxisIDu, varU.timeType);
     if (operatorID == UV2DV_CFD)
-      {
-        cdiDefKeyString(vlistID2, varIDo, CDI_KEY_NAME, "d");
-        cdiDefKeyString(vlistID2, varIDo, CDI_KEY_LONGNAME, "divergence");
-        cdiDefKeyString(vlistID2, varIDo, CDI_KEY_UNITS, "1/s");
-      }
+    {
+      cdiDefKeyString(vlistID2, varIDo, CDI_KEY_NAME, "d");
+      cdiDefKeyString(vlistID2, varIDo, CDI_KEY_LONGNAME, "divergence");
+      cdiDefKeyString(vlistID2, varIDo, CDI_KEY_UNITS, "1/s");
+    }
     else if (operatorID == UV2VR_CFD)
-      {
-        cdiDefKeyString(vlistID2, varIDo, CDI_KEY_NAME, "vo");
-        cdiDefKeyString(vlistID2, varIDo, CDI_KEY_LONGNAME, "vorticity");
-        cdiDefKeyString(vlistID2, varIDo, CDI_KEY_UNITS, "1/s");
-      }
+    {
+      cdiDefKeyString(vlistID2, varIDo, CDI_KEY_NAME, "vo");
+      cdiDefKeyString(vlistID2, varIDo, CDI_KEY_LONGNAME, "vorticity");
+      cdiDefKeyString(vlistID2, varIDo, CDI_KEY_UNITS, "1/s");
+    }
 
     vlistDefVarMissval(vlistID2, varIDo, varU.missval);
 
@@ -288,75 +288,75 @@ public:
     Varray<double> arrayv(nlev * gridsizeuv);
     Varray<double> arrayo(nlev * gridsizeuv);
 
-    const auto &varU = varList1.vars[varIDu];
-    const auto &varV = varList1.vars[varIDv];
+    auto const &varU = varList1.vars[varIDu];
+    auto const &varV = varList1.vars[varIDv];
     int tsID = 0;
     while (true)
+    {
+      auto numFields = cdo_stream_inq_timestep(streamID1, tsID);
+      if (numFields == 0) break;
+
+      size_t numMissValsu = 0, numMissValsv = 0;
+
+      cdo_taxis_copy_timestep(taxisID2, taxisID1);
+      cdo_def_timestep(streamID2, tsID);
+
+      for (int fieldID = 0; fieldID < numFields; ++fieldID)
       {
-        auto numFields = cdo_stream_inq_timestep(streamID1, tsID);
-        if (numFields == 0) break;
+        auto [varID, levelID] = cdo_inq_field(streamID1);
+        size_t numMissVals;
+        cdo_read_field(streamID1, &array[0], &numMissVals);
 
-        size_t numMissValsu = 0, numMissValsv = 0;
-
-        cdo_taxis_copy_timestep(taxisID2, taxisID1);
-        cdo_def_timestep(streamID2, tsID);
-
-        for (int fieldID = 0; fieldID < numFields; ++fieldID)
+        if (varID == varIDu || varID == varIDv)
+        {
+          if (varID == varIDu)
           {
-            auto [varID, levelID] = cdo_inq_field(streamID1);
-            size_t numMissVals;
-            cdo_read_field(streamID1, &array[0], &numMissVals);
-
-            if (varID == varIDu || varID == varIDv)
-              {
-                if (varID == varIDu)
-                  {
-                    std::copy_n(&array[0], gridsizeuv, &arrayu[levelID * gridsizeuv]);
-                    numMissValsu += numMissVals;
-                  }
-                if (varID == varIDv)
-                  {
-                    std::copy_n(&array[0], gridsizeuv, &arrayv[levelID * gridsizeuv]);
-                    numMissValsv += numMissVals;
-                  }
-              }
-
-            if (outMode == OutMode::APPEND)
-              {
-                cdo_def_field(streamID2, varID, levelID);
-                cdo_write_field(streamID2, &array[0], numMissVals);
-              }
+            std::copy_n(&array[0], gridsizeuv, &arrayu[levelID * gridsizeuv]);
+            numMissValsu += numMissVals;
           }
-
-        if (numMissValsu != numMissValsv)
+          if (varID == varIDv)
           {
-            cdo_abort("u and v have different number of missing values!");
-            if (numMissValsu && fp_is_not_equal(varU.missval, varV.missval))
-              {
-                for (int levelID = 0; levelID < nlev; ++levelID)
-                  {
-                    auto parray = &arrayv[levelID * gridsizeuv];
-                    for (size_t i = 0; i < gridsizeuv; ++i)
-                      if (fp_is_equal(parray[i], varV.missval)) parray[i] = varU.missval;
-                  }
-              }
+            std::copy_n(&array[0], gridsizeuv, &arrayv[levelID * gridsizeuv]);
+            numMissValsv += numMissVals;
           }
+        }
 
-        if (operatorID == UV2DV_CFD)
-          uv2dv_cfd_W(varU.missval, &arrayu[0], &arrayv[0], &lon[0], &lat[0], nlon, nlat, nlev, boundOpt, &arrayo[0]);
-        else if (operatorID == UV2VR_CFD)
-          uv2vr_cfd_W(varU.missval, &arrayu[0], &arrayv[0], &lon[0], &lat[0], nlon, nlat, nlev, boundOpt, &arrayo[0]);
-
-        for (int levelID = 0; levelID < nlev; ++levelID)
-          {
-            auto parray = &arrayo[levelID * gridsizeuv];
-            auto numMissVals = array_num_mv(gridsizeuv, parray, varU.missval);
-            cdo_def_field(streamID2, varIDo, levelID);
-            cdo_write_field(streamID2, parray, numMissVals);
-          }
-
-        tsID++;
+        if (outMode == OutMode::APPEND)
+        {
+          cdo_def_field(streamID2, varID, levelID);
+          cdo_write_field(streamID2, &array[0], numMissVals);
+        }
       }
+
+      if (numMissValsu != numMissValsv)
+      {
+        cdo_abort("u and v have different number of missing values!");
+        if (numMissValsu && fp_is_not_equal(varU.missval, varV.missval))
+        {
+          for (int levelID = 0; levelID < nlev; ++levelID)
+          {
+            auto parray = &arrayv[levelID * gridsizeuv];
+            for (size_t i = 0; i < gridsizeuv; ++i)
+              if (fp_is_equal(parray[i], varV.missval)) parray[i] = varU.missval;
+          }
+        }
+      }
+
+      if (operatorID == UV2DV_CFD)
+        uv2dv_cfd_W(varU.missval, &arrayu[0], &arrayv[0], &lon[0], &lat[0], nlon, nlat, nlev, boundOpt, &arrayo[0]);
+      else if (operatorID == UV2VR_CFD)
+        uv2vr_cfd_W(varU.missval, &arrayu[0], &arrayv[0], &lon[0], &lat[0], nlon, nlat, nlev, boundOpt, &arrayo[0]);
+
+      for (int levelID = 0; levelID < nlev; ++levelID)
+      {
+        auto parray = &arrayo[levelID * gridsizeuv];
+        auto numMissVals = array_num_mv(gridsizeuv, parray, varU.missval);
+        cdo_def_field(streamID2, varIDo, levelID);
+        cdo_write_field(streamID2, parray, numMissVals);
+      }
+
+      tsID++;
+    }
   }
 
   void
