@@ -19,50 +19,50 @@
 #include "util_string.h"
 
 static void
-print_values(int numValues, const std::vector<std::string> &values)
+print_values(int numValues, std::vector<std::string> const &values)
 {
   char fltstr[128];
   if (numValues)
+  {
+    auto dataType = literals_find_datatype(numValues, values);
+    for (int i = 0; i < numValues; ++i)
     {
-      auto dataType = literals_find_datatype(numValues, values);
-      for (int i = 0; i < numValues; ++i)
-        {
-          const auto &value = values[i];
-          if (i) printf(", ");
-          switch (dataType)
-            {
-            case CDI_DATATYPE_INT8: printf("%db", literal_to_int(value)); break;
-            case CDI_DATATYPE_INT16: printf("%ds", literal_to_int(value)); break;
-            case CDI_DATATYPE_INT32: printf("%d", literal_to_int(value)); break;
-            case CDI_DATATYPE_FLT32:
-              printf("%sf", double_to_att_str(Options::CDO_flt_digits, fltstr, sizeof(fltstr), literal_to_double(value)));
-              break;
-            case CDI_DATATYPE_FLT64:
-              printf("%s", double_to_att_str(Options::CDO_dbl_digits, fltstr, sizeof(fltstr), literal_to_double(value)));
-              break;
-            default: printf("\"%s\"", value.c_str());
-            }
-        }
+      auto const &value = values[i];
+      if (i) printf(", ");
+      switch (dataType)
+      {
+        case CDI_DATATYPE_INT8: printf("%db", literal_to_int(value)); break;
+        case CDI_DATATYPE_INT16: printf("%ds", literal_to_int(value)); break;
+        case CDI_DATATYPE_INT32: printf("%d", literal_to_int(value)); break;
+        case CDI_DATATYPE_FLT32:
+          printf("%sf", double_to_att_str(Options::CDO_flt_digits, fltstr, sizeof(fltstr), literal_to_double(value)));
+          break;
+        case CDI_DATATYPE_FLT64:
+          printf("%s", double_to_att_str(Options::CDO_dbl_digits, fltstr, sizeof(fltstr), literal_to_double(value)));
+          break;
+        default: printf("\"%s\"", value.c_str());
+      }
     }
+  }
 }
 
 void
 kvldump(const PMList &pmlist)
 {
-  for (const auto &kvlist : pmlist)
+  for (auto const &kvlist : pmlist)
+  {
+    auto const &listname = kvlist.name;
+    if (!listname.empty()) printf("&%s\n", listname.c_str());
+    for (auto const &kv : kvlist)
     {
-      const auto &listname = kvlist.name;
-      if (!listname.empty()) printf("&%s\n", listname.c_str());
-      for (const auto &kv : kvlist)
-        {
-          const auto &key = kv.key;
-          if (!listname.empty()) printf("  ");
-          printf("%s = ", key.c_str());
-          print_values(kv.nvalues, kv.values);
-          printf("\n");
-        }
-      if (!listname.empty()) printf("/\n");
+      auto const &key = kv.key;
+      if (!listname.empty()) printf("  ");
+      printf("%s = ", key.c_str());
+      print_values(kv.nvalues, kv.values);
+      printf("\n");
     }
+    if (!listname.empty()) printf("/\n");
+  }
 }
 
 class Nmldump : public Process
