@@ -28,13 +28,13 @@ public:
   };
   inline static RegisterEntry<Query> registration = RegisterEntry<Query>(module);
 
-  int streamID1;  // QueryStream
-  CdoStreamID streamID2;
+  int streamID1{};  // QueryStream
+  CdoStreamID streamID2{};
 
-  int taxisID1;
-  int taxisID2;
+  int taxisID1{ CDI_UNDEFID };
+  int taxisID2{ CDI_UNDEFID };
 
-  VarList varList1;
+  VarList varList1{};
 
 public:
   void
@@ -59,20 +59,20 @@ public:
 
     auto pkvlist = &kvlist;
     if (natts == 1)
+    {
+      KeyValues &kv = kvlist.front();
+      if (kv.key == "FILE")
       {
-        KeyValues &kv = kvlist.front();
-        if (kv.key == "FILE")
-          {
-            if (Options::cdoVerbose) cdo_print("Reading query from: %s", kv.values[0]);
-            auto filename = parameter_to_word(kv.values[0].c_str());
-            auto fp = std::fopen(filename, "r");
-            if (fp == nullptr) cdo_abort("Open failed on: %s\n", filename);
-            pmlist.read_namelist(fp, filename);
-            pkvlist = &pmlist.front();
-            std::fclose(fp);
-            if (Options::cdoVerbose) pkvlist->print();
-          }
+        if (Options::cdoVerbose) cdo_print("Reading query from: %s", kv.values[0]);
+        auto filename = parameter_to_word(kv.values[0].c_str());
+        auto fp = std::fopen(filename, "r");
+        if (fp == nullptr) cdo_abort("Open failed on: %s\n", filename);
+        pmlist.read_namelist(fp, filename);
+        pkvlist = &pmlist.front();
+        std::fclose(fp);
+        if (Options::cdoVerbose) pkvlist->print();
       }
+    }
 
     auto query = cdiQueryCreate();
     set_query_parameter(*pkvlist, query);
@@ -107,37 +107,37 @@ public:
 
     int tsID = 0;
     while (true)
+    {
+      auto numFields = streamInqTimestep(streamID1, tsID);
+      if (numFields == 0) break;
+
+      cdo_taxis_copy_timestep(taxisID2, taxisID1);
+      cdo_def_timestep(streamID2, tsID);
+
+      for (int fieldID = 0; fieldID < numFields; ++fieldID)
       {
-        auto numFields = streamInqTimestep(streamID1, tsID);
-        if (numFields == 0) break;
-
-        cdo_taxis_copy_timestep(taxisID2, taxisID1);
-        cdo_def_timestep(streamID2, tsID);
-
-        for (int fieldID = 0; fieldID < numFields; ++fieldID)
+        int varID, levelID;
+        streamInqField(streamID1, &varID, &levelID);
+        cdo_def_field(streamID2, varID, levelID);
+        /*
+        if (dataIsUnchanged)
           {
-            int varID, levelID;
-            streamInqField(streamID1, &varID, &levelID);
-            cdo_def_field(streamID2, varID, levelID);
-            /*
-            if (dataIsUnchanged)
-              {
-                streamCopyField(streamID2, streamID1);
-              }
-            else
-            */
-            {
-              field.init(varList1.vars[varID]);
-              if (field.memType == MemType::Float)
-                streamReadFieldF(streamID1, field.vec_f.data(), &field.numMissVals);
-              else
-                streamReadField(streamID1, field.vec_d.data(), &field.numMissVals);
-              cdo_write_field(streamID2, field);
-            }
+            streamCopyField(streamID2, streamID1);
           }
-
-        tsID++;
+        else
+        */
+        {
+          field.init(varList1.vars[varID]);
+          if (field.memType == MemType::Float)
+            streamReadFieldF(streamID1, field.vec_f.data(), &field.numMissVals);
+          else
+            streamReadField(streamID1, field.vec_d.data(), &field.numMissVals);
+          cdo_write_field(streamID2, field);
+        }
       }
+
+      tsID++;
+    }
   }
 
   void
