@@ -23,16 +23,16 @@ public:
   };
   inline static RegisterEntry<Recttocomplex> registration = RegisterEntry<Recttocomplex>(module);
 
-  CdoStreamID streamID1;
-  CdoStreamID streamID2;
-  CdoStreamID streamID3;
+  CdoStreamID streamID1{};
+  CdoStreamID streamID2{};
+  CdoStreamID streamID3{};
 
   int taxisID1{ CDI_UNDEFID };
-  int taxisID3;
+  int taxisID3{};
 
-  int vlistID3;
+  int vlistID3{};
 
-  VarList varList1;
+  VarList varList1{};
 
 public:
   void
@@ -54,11 +54,11 @@ public:
 
     auto nvars = vlistNvars(vlistID3);
     for (int varID = 0; varID < nvars; ++varID)
-      {
-        auto datatype = vlistInqVarDatatype(vlistID2, varID);
-        datatype = (datatype == CDI_DATATYPE_FLT64) ? CDI_DATATYPE_CPX64 : CDI_DATATYPE_CPX32;
-        vlistDefVarDatatype(vlistID3, varID, datatype);
-      }
+    {
+      auto datatype = vlistInqVarDatatype(vlistID2, varID);
+      datatype = (datatype == CDI_DATATYPE_FLT64) ? CDI_DATATYPE_CPX64 : CDI_DATATYPE_CPX32;
+      vlistDefVarDatatype(vlistID3, varID, datatype);
+    }
 
     streamID3 = cdo_open_write(2);
     cdo_def_vlist(streamID3, vlistID3);
@@ -76,38 +76,38 @@ public:
 
     int tsID = 0;
     while (true)
+    {
+      auto numFields = cdo_stream_inq_timestep(streamID1, tsID);
+      if (numFields == 0) break;
+      auto numFields2 = cdo_stream_inq_timestep(streamID2, tsID);
+      if (numFields2 == 0) break;
+
+      cdo_taxis_copy_timestep(taxisID3, taxisID1);
+      cdo_def_timestep(streamID3, tsID);
+
+      for (int fieldID = 0; fieldID < numFields; ++fieldID)
       {
-        auto numFields = cdo_stream_inq_timestep(streamID1, tsID);
-        if (numFields == 0) break;
-        auto numFields2 = cdo_stream_inq_timestep(streamID2, tsID);
-        if (numFields2 == 0) break;
+        auto [varID, levelID] = cdo_inq_field(streamID1);
+        cdo_def_field(streamID3, varID, levelID);
 
-        cdo_taxis_copy_timestep(taxisID3, taxisID1);
-        cdo_def_timestep(streamID3, tsID);
+        (void) cdo_inq_field(streamID2);
 
-        for (int fieldID = 0; fieldID < numFields; ++fieldID)
-          {
-            auto [varID, levelID] = cdo_inq_field(streamID1);
-            cdo_def_field(streamID3, varID, levelID);
+        size_t numMissVals;
+        cdo_read_field(streamID1, array1.data(), &numMissVals);
+        cdo_read_field(streamID2, array2.data(), &numMissVals);
 
-            (void) cdo_inq_field(streamID2);
+        auto gridsize = varList1.vars[varID].gridsize;
+        for (size_t i = 0; i < gridsize; ++i)
+        {
+          array3[2 * i] = array1[i];
+          array3[2 * i + 1] = array2[i];
+        }
 
-            size_t numMissVals;
-            cdo_read_field(streamID1, array1.data(), &numMissVals);
-            cdo_read_field(streamID2, array2.data(), &numMissVals);
-
-            auto gridsize = varList1.vars[varID].gridsize;
-            for (size_t i = 0; i < gridsize; ++i)
-              {
-                array3[2 * i] = array1[i];
-                array3[2 * i + 1] = array2[i];
-              }
-
-            cdo_write_field(streamID3, array3.data(), numMissVals);
-          }
-
-        tsID++;
+        cdo_write_field(streamID3, array3.data(), numMissVals);
       }
+
+      tsID++;
+    }
   }
 
   void
