@@ -13,7 +13,6 @@
 
 #include <cdi.h>
 
-#include "arithmetic.h"
 #include "process_int.h"
 #include "cdo_options.h"
 #include "field_trend.h"
@@ -29,29 +28,29 @@ get_parameter()
 {
   bool tstepIsEqual = true;
 
-  auto pargc = cdo_operator_argc();
-  if (pargc)
+  auto numArgs = cdo_operator_argc();
+  if (numArgs)
+  {
+    auto const &argList = cdo_get_oper_argv();
+
+    KVList kvlist;
+    kvlist.name = cdo_module_name();
+    if (kvlist.parse_arguments(argList) != 0) cdo_abort("Parse error!");
+    if (Options::cdoVerbose) kvlist.print();
+
+    for (auto const &kv : kvlist)
     {
-      const auto &pargv = cdo_get_oper_argv();
+      auto const &key = kv.key;
+      if (kv.nvalues > 1) cdo_abort("Too many values for parameter key >%s<!", key);
+      if (kv.nvalues < 1) cdo_abort("Missing value for parameter key >%s<!", key);
+      auto const &value = kv.values[0];
 
-      KVList kvlist;
-      kvlist.name = cdo_module_name();
-      if (kvlist.parse_arguments(pargv) != 0) cdo_abort("Parse error!");
-      if (Options::cdoVerbose) kvlist.print();
-
-      for (const auto &kv : kvlist)
-        {
-          const auto &key = kv.key;
-          if (kv.nvalues > 1) cdo_abort("Too many values for parameter key >%s<!", key);
-          if (kv.nvalues < 1) cdo_abort("Missing value for parameter key >%s<!", key);
-          const auto &value = kv.values[0];
-
-          // clang-format off
-          if      (key == "equal") tstepIsEqual = parameter_to_bool(value);
-          else cdo_abort("Invalid parameter key >%s<!", key);
-          // clang-format on
-        }
+      // clang-format off
+      if      (key == "equal") tstepIsEqual = parameter_to_bool(value);
+      else cdo_abort("Invalid parameter key >%s<!", key);
+      // clang-format on
     }
+  }
 
   return tstepIsEqual;
 }
@@ -70,16 +69,16 @@ public:
   };
   inline static RegisterEntry<Regres> registration = RegisterEntry<Regres>(module);
 
-  CdoStreamID streamID1;
-  CdoStreamID streamID3;
+  CdoStreamID streamID1{};
+  CdoStreamID streamID3{};
 
-  int taxisID1;
-  int taxisID2;
+  int taxisID1{ CDI_UNDEFID };
+  int taxisID2{ CDI_UNDEFID };
 
   bool tstepIsEqual{ true };
 
-  VarList varList1;
-  VarList varList2;
+  VarList varList1{};
+  VarList varList2{};
 
 public:
   void
@@ -127,48 +126,48 @@ public:
     CdiDateTime vDateTime{};
     int tsID = 0;
     while (true)
+    {
+      auto numFields = cdo_stream_inq_timestep(streamID1, tsID);
+      if (numFields == 0) break;
+
+      vDateTime = taxisInqVdatetime(taxisID1);
+
+      if (tstepIsEqual) check_time_increment(tsID, calendar, vDateTime, checkTimeIncr);
+      auto zj = tstepIsEqual ? (double) tsID : delta_time_step_0(tsID, calendar, vDateTime, julianDate0, deltat1);
+
+      for (int fieldID = 0; fieldID < numFields; ++fieldID)
       {
-        auto numFields = cdo_stream_inq_timestep(streamID1, tsID);
-        if (numFields == 0) break;
+        auto [varID, levelID] = cdo_inq_field(streamID1);
 
-        vDateTime = taxisInqVdatetime(taxisID1);
+        fieldInfoList[fieldID].set(varID, levelID);
 
-        if (tstepIsEqual) check_time_increment(tsID, calendar, vDateTime, checkTimeIncr);
-        auto zj = tstepIsEqual ? (double) tsID : delta_time_step_0(tsID, calendar, vDateTime, julianDate0, deltat1);
+        field1.init(varList1.vars[varID]);
+        cdo_read_field(streamID1, field1);
 
-        for (int fieldID = 0; fieldID < numFields; ++fieldID)
-          {
-            auto [varID, levelID] = cdo_inq_field(streamID1);
-
-            fieldInfoList[fieldID].set(varID, levelID);
-
-            field1.init(varList1.vars[varID]);
-            cdo_read_field(streamID1, field1);
-
-            calc_trend_sum(work, field1, zj, varID, levelID);
-          }
-
-        tsID++;
+        calc_trend_sum(work, field1, zj, varID, levelID);
       }
 
+      tsID++;
+    }
+
     taxisDefVdatetime(taxisID2, vDateTime);
     cdo_def_timestep(streamID3, 0);
 
     for (int fieldID = 0; fieldID < maxFields; ++fieldID)
-      {
-        auto [varID, levelID] = fieldInfoList[fieldID].get();
+    {
+      auto [varID, levelID] = fieldInfoList[fieldID].get();
 
-        const auto &var = varList2.vars[varID];
-        field2.init(var);
-        field3.init(var);
+      auto const &var = varList2.vars[varID];
+      field2.init(var);
+      field3.init(var);
 
-        calc_trend_param(work, field2, field3, varID, levelID);
+      calc_trend_param(work, field2, field3, varID, levelID);
 
-        field_num_mv(field3);
+      field_num_mv(field3);
 
-        cdo_def_field(streamID3, varID, levelID);
-        cdo_write_field(streamID3, field3);
-      }
+      cdo_def_field(streamID3, varID, levelID);
+      cdo_write_field(streamID3, field3);
+    }
   }
 
   void
