@@ -34,27 +34,27 @@
 #include "remapknn.h"
 
 int
-get_remapIndex(int numRemaps, std::vector<RemapType> &remaps, int gridID, size_t numMissVals, bool useMask, const Vmask &imask)
+get_remapIndex(int numRemaps, std::vector<RemapType> &remaps, int gridID, size_t numMissVals, bool useMask, Vmask const &imask)
 {
   int remapIndex = -1;
   for (remapIndex = numRemaps - 1; remapIndex >= 0; remapIndex--)
+  {
+    auto &remap = remaps[remapIndex];
+    if (gridID == remap.gridID)
     {
-      auto &remap = remaps[remapIndex];
-      if (gridID == remap.gridID)
-        {
-          if ((useMask && numMissVals == remap.numMissVals && imask == remap.srcGrid.mask) || !useMask)
-            {
-              remap.nused++;
-              break;
-            }
-        }
+      if ((useMask && numMissVals == remap.numMissVals && imask == remap.srcGrid.mask) || !useMask)
+      {
+        remap.nused++;
+        break;
+      }
     }
+  }
 
   return remapIndex;
 }
 
 void
-pack_gme_vgpm(const Varray<int> &vgpm, Vmask &imask)
+pack_gme_vgpm(Varray<int> const &vgpm, Vmask &imask)
 {
   auto n = imask.size();
   assert(n <= vgpm.size());
@@ -74,12 +74,12 @@ maptype_to_operfunc(const RemapSwitches &remapSwitches)
   else if (remapSwitches.mapType == RemapMethod::BICUBIC)
     operfunc = REMAPBIC;
   else if (remapSwitches.mapType == RemapMethod::KNN)
-    {
-      if (remapSwitches.numNeighbors == -1)
-        operfunc = REMAPKNN;
-      else
-        operfunc = (remapSwitches.numNeighbors == 1) ? REMAPNN : REMAPDIS;
-    }
+  {
+    if (remapSwitches.numNeighbors == -1)
+      operfunc = REMAPKNN;
+    else
+      operfunc = (remapSwitches.numNeighbors == 1) ? REMAPNN : REMAPDIS;
+  }
   else
     cdo_abort("Unsupported mapping method (mapType = %d)", remapSwitches.mapType);
 
@@ -87,12 +87,13 @@ maptype_to_operfunc(const RemapSwitches &remapSwitches)
 }
 
 static void
-scale_gridbox_area(const Field &field1, Field &field2, const Varray<double> &grid2_area)
+scale_gridbox_area(Field const &field1, Field &field2, Varray<double> const &grid2_area)
 {
   auto gridsize1 = field1.size;
   auto gridsize2 = field2.size;
   double v1sum;
-  auto func = [&](const auto &v1, auto &v2) {
+  auto func = [&](auto const &v1, auto &v2)
+  {
     v1sum = varray_sum(gridsize1, v1);
     auto v2sum = varray_sum(gridsize2, grid2_area);
     for (size_t i = 0; i < gridsize2; ++i) v2[i] = grid2_area[i] / v2sum * v1sum;
@@ -100,10 +101,10 @@ scale_gridbox_area(const Field &field1, Field &field2, const Varray<double> &gri
   field_operation2(func, field1, field2);
   static auto hasGridboxInfo = true;
   if (hasGridboxInfo)
-    {
-      cdo_print("gridbox_area replaced and scaled to %g", v1sum);
-      hasGridboxInfo = false;
-    }
+  {
+    cdo_print("gridbox_area replaced and scaled to %g", v1sum);
+    hasGridboxInfo = false;
+  }
 }
 
 template <typename T>
@@ -111,7 +112,7 @@ void gme_grid_restore(T *p, int ni, int nd);
 
 template <typename T>
 static void
-restore_gme_grid(int gridID, size_t srvGridSize, Varray<T> &v, size_t tgtGridSize, const Varray<int> &vgpm)
+restore_gme_grid(int gridID, size_t srvGridSize, Varray<T> &v, size_t tgtGridSize, Varray<int> const &vgpm)
 {
   int nd, ni, ni2, ni3;
   gridInqParamGME(gridID, &nd, &ni, &ni2, &ni3);
@@ -132,14 +133,14 @@ restore_gme_grid(Field &field, const RemapGrid &tgtGrid)
 
 template <typename T>
 static void
-store_gme_grid(size_t gridsize, Varray<T> &v, const Varray<int> &vgpm)
+store_gme_grid(size_t gridsize, Varray<T> &v, Varray<int> const &vgpm)
 {
   for (size_t i = 0, j = 0; i < gridsize; ++i)
     if (vgpm[i]) v[j++] = v[i];
 }
 
 static void
-store_gme_grid(Field &field, const Varray<int> &vgpm)
+store_gme_grid(Field &field, Varray<int> const &vgpm)
 {
   auto func = [&](auto &v) { store_gme_grid(field.gridsize, v, vgpm); };
   field_operation(func, field);
@@ -153,26 +154,26 @@ remap_normalize_field(NormOpt normOpt, size_t gridsize, Varray<T> &array, double
   // used to check the result of remapcon
 
   if (normOpt == NormOpt::NONE)
+  {
+    for (size_t i = 0; i < gridsize; ++i)
     {
-      for (size_t i = 0; i < gridsize; ++i)
-        {
-          if (fp_is_not_equal(array[i], missval))
-            {
-              auto gridError = tgtGrid.cellFrac[i] * tgtGrid.cellArea[i];
-              array[i] = (std::fabs(gridError) > 0.0) ? (array[i] / gridError) : missval;
-            }
-        }
+      if (fp_is_not_equal(array[i], missval))
+      {
+        auto gridError = tgtGrid.cellFrac[i] * tgtGrid.cellArea[i];
+        array[i] = (std::fabs(gridError) > 0.0) ? (array[i] / gridError) : missval;
+      }
     }
+  }
   else if (normOpt == NormOpt::DESTAREA)
+  {
+    for (size_t i = 0; i < gridsize; ++i)
     {
-      for (size_t i = 0; i < gridsize; ++i)
-        {
-          if (fp_is_not_equal(array[i], missval))
-            {
-              array[i] = (std::fabs(tgtGrid.cellFrac[i]) > 0.0) ? (array[i] / tgtGrid.cellFrac[i]) : missval;
-            }
-        }
+      if (fp_is_not_equal(array[i], missval))
+      {
+        array[i] = (std::fabs(tgtGrid.cellFrac[i]) > 0.0) ? (array[i] / tgtGrid.cellFrac[i]) : missval;
+      }
     }
+  }
 }
 
 static void
@@ -187,11 +188,11 @@ static void
 remap_set_fracmin(double fracMin, size_t gridsize, Varray<T> &array, double mv, const RemapGrid *tgtGrid)
 {
   if (fracMin > 0.0)
-    {
-      T missval = mv;
-      for (size_t i = 0; i < gridsize; ++i)
-        if (tgtGrid->cellFrac[i] < fracMin) array[i] = missval;
-    }
+  {
+    T missval = mv;
+    for (size_t i = 0; i < gridsize; ++i)
+      if (tgtGrid->cellFrac[i] < fracMin) array[i] = missval;
+  }
 }
 
 static void
@@ -202,7 +203,7 @@ remap_set_fracmin(double fracMin, Field &field, const RemapGrid *tgtGrid)
 }
 
 static void
-remap_field(RemapMethod mapType, const KnnParams &knnParams, RemapType &remap, const Field &field1, Field &field2)
+remap_field(RemapMethod mapType, KnnParams const &knnParams, RemapType &remap, Field const &field1, Field &field2)
 {
   // clang-format off
   if      (mapType == RemapMethod::BILINEAR) remap_bilinear(remap.search, field1, field2);
@@ -213,7 +214,7 @@ remap_field(RemapMethod mapType, const KnnParams &knnParams, RemapType &remap, c
 }
 
 static RemapSwitches
-remap_read_weights(const std::string &remapWeightsFile, int gridID1, int gridID2, RemapType &remap0, bool extrapolateIsSet,
+remap_read_weights(std::string const &remapWeightsFile, int gridID1, int gridID2, RemapType &remap0, bool extrapolateIsSet,
                    bool &remapExtrapolate, KnnParams &knnParams)
 {
   auto remapSwitches
@@ -227,19 +228,19 @@ remap_read_weights(const std::string &remapWeightsFile, int gridID1, int gridID2
   if (gridIsCircular(gridID1) && !extrapolateIsSet) remapExtrapolate = true;
 
   if (remapSwitches.mapType == RemapMethod::KNN)
+  {
+    if (remapSwitches.numNeighbors == -1)
     {
-      if (remapSwitches.numNeighbors == -1)
-        {
-          if (knnParams.kMin == 0) knnParams.kMin = knnParams.k;
-        }
-      else
-        {
-          knnParams.k = remapSwitches.numNeighbors;
-          knnParams.kMin = 1;
-          knnParams.extrapolate = remapExtrapolate;
-          knnParams.weighted = WeightingMethod::distanceWeighted;
-        }
+      if (knnParams.kMin == 0) knnParams.kMin = knnParams.k;
     }
+    else
+    {
+      knnParams.k = remapSwitches.numNeighbors;
+      knnParams.kMin = 1;
+      knnParams.extrapolate = remapExtrapolate;
+      knnParams.weighted = WeightingMethod::distanceWeighted;
+    }
+  }
 
   if (gridInqType(gridID1) == GRID_GME) gridsize = remap0.srcGrid.nvgp;
 
@@ -252,17 +253,17 @@ remap_read_weights(const std::string &remapWeightsFile, int gridID1, int gridID2
 
   auto gridsize2 = gridInqSize(gridID2);
   if (gridInqType(gridID2) == GRID_GME)
-    {
-      remap0.tgtGrid.nvgp = gridInqSize(gridID2);
-      remap0.tgtGrid.vgpm.resize(gridInqSize(gridID2));
-      auto gridID2_gme = gridToUnstructured(gridID2, NeedCorners::Yes);
-      gridInqMaskGME(gridID2_gme, &remap0.tgtGrid.vgpm[0]);
-      gridDestroy(gridID2_gme);
-      size_t isize = 0;
-      for (size_t i = 0; i < gridsize2; ++i)
-        if (remap0.tgtGrid.vgpm[i]) isize++;
-      gridsize2 = isize;
-    }
+  {
+    remap0.tgtGrid.nvgp = gridInqSize(gridID2);
+    remap0.tgtGrid.vgpm.resize(gridInqSize(gridID2));
+    auto gridID2_gme = gridToUnstructured(gridID2, NeedCorners::Yes);
+    gridInqMaskGME(gridID2_gme, &remap0.tgtGrid.vgpm[0]);
+    gridDestroy(gridID2_gme);
+    size_t isize = 0;
+    for (size_t i = 0; i < gridsize2; ++i)
+      if (remap0.tgtGrid.vgpm[i]) isize++;
+    gridsize2 = isize;
+  }
   // printf("grid2 %zu %d %zu\n", gridsize2, remap0.tgtGrid.nvgp, remap0.tgtGrid.size);
   if (remap0.tgtGrid.size != gridsize2) cdo_abort("Size of target grid and weights from %s differ!", remapWeightsFile);
 
@@ -272,7 +273,7 @@ remap_read_weights(const std::string &remapWeightsFile, int gridID1, int gridID2
 double get_planet_radius_in_meter(int gridID);
 
 static void
-print_node_info(int gridID2, const RemapVars &rv, const RemapGrid &srcGrid)
+print_node_info(int gridID2, RemapVars const &rv, const RemapGrid &srcGrid)
 {
   static auto printNodeInfo = true;
   if (printNodeInfo == false) return;
@@ -280,23 +281,23 @@ print_node_info(int gridID2, const RemapVars &rv, const RemapGrid &srcGrid)
 
   double lon2{}, lat2{};
   if (gridInqSize(gridID2) == 1)
-    {
-      gridInqXvals(gridID2, &lon2);
-      gridInqYvals(gridID2, &lat2);
-    }
+  {
+    gridInqXvals(gridID2, &lon2);
+    gridInqYvals(gridID2, &lat2);
+  }
 
   if (rv.numLinks == 1)
-    {
-      auto srcCellIndex = rv.srcCellIndices[0];
-      auto pointLL = remapgrid_get_lonlat(&srcGrid, srcCellIndex);
-      auto lon1 = pointLL.get_lon();
-      auto lat1 = pointLL.get_lat();
-      if (lon1 > PI) lon1 -= PI2;
-      auto distance = orthodrome(lon1, lat1, DEG2RAD * lon2, DEG2RAD * lat2) * get_planet_radius_in_meter(srcGrid.gridID) / 1000;
+  {
+    auto srcCellIndex = rv.srcCellIndices[0];
+    auto pointLL = remapgrid_get_lonlat(&srcGrid, srcCellIndex);
+    auto lon1 = pointLL.lon();
+    auto lat1 = pointLL.lat();
+    if (lon1 > PI) lon1 -= PI2;
+    auto distance = orthodrome(lon1, lat1, DEG2RAD * lon2, DEG2RAD * lat2) * get_planet_radius_in_meter(srcGrid.gridID) / 1000;
 
-      cdo_print("Target Point: lon=%g/lat=%g  Source Point: index=%zu lon=%g/lat=%g distance=%.3fkm", lon2, lat2, srcCellIndex + 1,
-                RAD2DEG * lon1, RAD2DEG * lat1, distance);
-    }
+    cdo_print("Target Point: lon=%g/lat=%g  Source Point: index=%zu lon=%g/lat=%g distance=%.3fkm", lon2, lat2, srcCellIndex + 1,
+              RAD2DEG * lon1, RAD2DEG * lat1, distance);
+  }
   else if (rv.numLinks == 0) { cdo_print("Target Point: lon=%g/lat=%g  Source Point: not found", lon2, lat2); }
 }
 
@@ -306,35 +307,35 @@ remapknn_get_parameter()
   RemapknnParams params;
   auto &knnParams = params.knnParams;
 
-  auto pargc = cdo_operator_argc();
-  if (pargc)
+  auto numArgs = cdo_operator_argc();
+  if (numArgs)
+  {
+    auto const &argList = cdo_get_oper_argv();
+
+    KVList kvlist;
+    kvlist.name = cdo_module_name();
+    if (kvlist.parse_arguments(argList) != 0) cdo_abort("Parse error!");
+    if (Options::cdoVerbose) kvlist.print();
+
+    for (auto const &kv : kvlist)
     {
-      const auto &pargv = cdo_get_oper_argv();
+      auto const &key = kv.key;
+      if (kv.nvalues > 1) cdo_abort("Too many values for parameter key >%s<!", key);
+      if (kv.nvalues < 1) cdo_abort("Missing value for parameter key >%s<!", key);
+      auto const &value = kv.values[0];
 
-      KVList kvlist;
-      kvlist.name = cdo_module_name();
-      if (kvlist.parse_arguments(pargv) != 0) cdo_abort("Parse error!");
-      if (Options::cdoVerbose) kvlist.print();
-
-      for (const auto &kv : kvlist)
-        {
-          const auto &key = kv.key;
-          if (kv.nvalues > 1) cdo_abort("Too many values for parameter key >%s<!", key);
-          if (kv.nvalues < 1) cdo_abort("Missing value for parameter key >%s<!", key);
-          const auto &value = kv.values[0];
-
-          // clang-format off
-          if      (key == "k")           knnParams.k = parameter_to_int(value);
-          else if (key == "kmin")        knnParams.kMin = parameter_to_int(value);
-          else if (key == "weighted")    knnParams.weighted = string_to_weightingMethod(parameter_to_word(value));
-          else if (key == "gauss_scale") knnParams.gaussScale = parameter_to_double(value);
-          else if (key == "rbf_scale")   knnParams.rbfScale = parameter_to_double(value);
-          else if (key == "extrapolate") knnParams.extrapolate = parameter_to_bool(value);
-          else if (key == "grid")        params.gridString = parameter_to_word(value);
-          else cdo_abort("Invalid parameter key >%s<!", key);
-          // clang-format on
-        }
+      // clang-format off
+      if      (key == "k")           knnParams.k = parameter_to_int(value);
+      else if (key == "kmin")        knnParams.kMin = parameter_to_int(value);
+      else if (key == "weighted")    knnParams.weighted = string_to_weightingMethod(parameter_to_word(value));
+      else if (key == "gauss_scale") knnParams.gaussScale = parameter_to_double(value);
+      else if (key == "rbf_scale")   knnParams.rbfScale = parameter_to_double(value);
+      else if (key == "extrapolate") knnParams.extrapolate = parameter_to_bool(value);
+      else if (key == "grid")        params.gridString = parameter_to_word(value);
+      else cdo_abort("Invalid parameter key >%s<!", key);
+      // clang-format on
     }
+  }
 
   return params;
 }
@@ -343,10 +344,10 @@ void
 remapknn_verify_parameter(KnnParams const &knnParams)
 {
   if (knnParams.weighted == WeightingMethod::gaussWeighted)
-    {
-      if (knnParams.k <= 1) cdo_abort("Parameter k must be greater than 1!");
-      if (knnParams.kMin <= 1) cdo_abort("Parameter kmin must be greater than 1!");
-    }
+  {
+    if (knnParams.k <= 1) cdo_abort("Parameter k must be greater than 1!");
+    if (knnParams.kMin <= 1) cdo_abort("Parameter kmin must be greater than 1!");
+  }
 }
 
 void
@@ -395,42 +396,42 @@ public:
   };
   inline static RegisterEntry<Remapgrid> registration = RegisterEntry<Remapgrid>(module);
 
-  KnnParams knnParams;
-  RemapSwitches remapSwitches;
+  KnnParams knnParams{};
+  RemapSwitches remapSwitches{};
   bool remap_genweights = Options::REMAP_genweights;
   int numRemaps = 0;
   int numNeighbors = 0;
-  std::vector<std::string> remapWeightsFiles;
+  std::vector<std::string> remapWeightsFiles{};
 
-  CdoStreamID streamID1;
-  int taxisID1;
-  int vlistID1;
+  CdoStreamID streamID1{};
+  int taxisID1{ CDI_UNDEFID };
+  int vlistID1{ CDI_UNDEFID };
 
-  CdoStreamID streamID2;
-  int taxisID2;
-  int gridID2;
+  CdoStreamID streamID2{};
+  int taxisID2{ CDI_UNDEFID };
+  int gridID2{};
 
-  bool useMask;
-  bool extrapolateIsSet;
-  bool remapExtrapolate;
-  bool needGradients;
-  bool doRemap;
+  bool useMask{};
+  bool extrapolateIsSet{};
+  bool remapExtrapolate{};
+  bool needGradients{};
+  bool doRemap{};
 
-  int operfunc;
-  int maxRemaps;
+  int operfunc{};
+  int maxRemaps{};
 
-  std::vector<bool> remapGrids;
-  std::vector<RemapType> remapList;
+  std::vector<bool> remapGrids{};
+  std::vector<RemapType> remapList{};
 
-  RemapGradients gradients;
-  RemapDefaults remapDefaults;
-  RemapMethod mapType;
-  int remapOrder;
+  RemapGradients gradients{};
+  RemapDefaults remapDefaults{};
+  RemapMethod mapType{};
+  int remapOrder{};
 
-  NormOpt normOpt;
+  NormOpt normOpt{};
 
-  VarList varList1;
-  VarList varList2;
+  VarList varList1{};
+  VarList varList2{};
 
 public:
   std::string
@@ -439,41 +440,41 @@ public:
     std::string targetGridName;
 
     if (doRemap)
+    {
+      operator_input_arg("grid description file or name, remap weights file (SCRIP NetCDF)");
+      operator_check_argc(2);
+      remapWeightsFiles.push_back(cdo_operator_argv(1));
+      targetGridName = cdo_operator_argv(0);
+    }
+    else
+    {
+      if (operfunc == REMAPKNN)
       {
-        operator_input_arg("grid description file or name, remap weights file (SCRIP NetCDF)");
-        operator_check_argc(2);
-        remapWeightsFiles.push_back(cdo_operator_argv(1));
+        auto remapParams = remapknn_get_parameter();
+        if (Options::cdoVerbose) remapknn_print_parameter(remapParams);
+        if (remapParams.gridString.empty()) cdo_abort("target grid parameter missing!");
+        targetGridName = remapParams.gridString;
+        knnParams = remapParams.knnParams;
+        if (knnParams.kMin == 0) knnParams.kMin = knnParams.k;
+        remapknn_verify_parameter(knnParams);
+        if (Options::cdoVerbose) print_knn_parameter(knnParams, "KNN parameter: ");
+        extrapolateIsSet = true;
+        remapExtrapolate = knnParams.extrapolate;
+      }
+
+      else
+      {
+        operator_input_arg("grid description file or name");
+        if (operfunc == REMAPDIS && cdo_operator_argc() == 2)
+        {
+          auto inum = parameter_to_int(cdo_operator_argv(1));
+          if (inum < 1) cdo_abort("Number of nearest neighbors out of range (>0)!");
+          numNeighbors = inum;
+        }
+        else { operator_check_argc(1); }
         targetGridName = cdo_operator_argv(0);
       }
-    else
-      {
-        if (operfunc == REMAPKNN)
-          {
-            auto remapParams = remapknn_get_parameter();
-            if (Options::cdoVerbose) remapknn_print_parameter(remapParams);
-            if (remapParams.gridString.empty()) cdo_abort("target grid parameter missing!");
-            targetGridName = remapParams.gridString;
-            knnParams = remapParams.knnParams;
-            if (knnParams.kMin == 0) knnParams.kMin = knnParams.k;
-            remapknn_verify_parameter(knnParams);
-            if (Options::cdoVerbose) print_knn_parameter(knnParams, "KNN parameter: ");
-            extrapolateIsSet = true;
-            remapExtrapolate = knnParams.extrapolate;
-          }
-
-        else
-          {
-            operator_input_arg("grid description file or name");
-            if (operfunc == REMAPDIS && cdo_operator_argc() == 2)
-              {
-                auto inum = parameter_to_int(cdo_operator_argv(1));
-                if (inum < 1) cdo_abort("Number of nearest neighbors out of range (>0)!");
-                numNeighbors = inum;
-              }
-            else { operator_check_argc(1); }
-            targetGridName = cdo_operator_argv(0);
-          }
-      }
+    }
 
     return targetGridName;
   }
@@ -526,8 +527,7 @@ public:
     varList1 = VarList(vlistID1);
 
     remapGrids = remap_set_grids(vlistID1, varList1);
-
-    auto numRemapGrids = ranges::count_if(remapGrids, [](auto flag) { return (flag == true); });
+    auto numRemapGrids = std::ranges::count_if(remapGrids, [](auto flag) { return (flag == true); });
     if (numRemapGrids == 0) cdo_abort("No remappable grid found!");
 
     auto numGrids = vlistNumGrids(vlistID1);
@@ -543,36 +543,33 @@ public:
     if (doRemap) remap_genweights = true;
 
     if (doRemap)
-      {
-        int gridIndex1;
-        for (gridIndex1 = 0; gridIndex1 < numGrids; ++gridIndex1)
-          if (remapGrids[gridIndex1]) break;
-        auto gridID1 = vlistGrid(vlistID1, gridIndex1);
+    {
+      int gridIndex1;
+      for (gridIndex1 = 0; gridIndex1 < numGrids; ++gridIndex1)
+        if (remapGrids[gridIndex1]) break;
+      auto gridID1 = vlistGrid(vlistID1, gridIndex1);
 
-        remapWeightsFiles = expand_path_names(remapWeightsFiles);
-        for (auto &remapWeightsFile : remapWeightsFiles)
-          {
-            // printf("read remapWeightsFile %d: %s\n", numRemaps+1, remapWeightsFile.c_str());
-            auto &remap = remapList[numRemaps];
-            remapSwitches
-                = remap_read_weights(remapWeightsFile, gridID1, gridID2, remap, extrapolateIsSet, remapExtrapolate, knnParams);
-            if (numRemaps == 0) { operfunc = maptype_to_operfunc(remapSwitches); }
-            else if (operfunc != maptype_to_operfunc(remapSwitches))
-              {
-                cdo_abort("Remapping method changed in input weights files!");
-              }
-            numRemaps++;
-          }
-      }
-    else
+      remapWeightsFiles = expand_path_names(remapWeightsFiles);
+      for (auto &remapWeightsFile : remapWeightsFiles)
       {
-        remapSwitches = remap_operfunc_to_maptype(operfunc);
-        if (remapSwitches.mapType == RemapMethod::KNN)
-          {
-            if (numNeighbors) remapSwitches.numNeighbors = numNeighbors;
-            if (remapSwitches.numNeighbors != -1) set_knn_parameter();
-          }
+        // printf("read remapWeightsFile %d: %s\n", numRemaps+1, remapWeightsFile.c_str());
+        auto &remap = remapList[numRemaps];
+        remapSwitches
+            = remap_read_weights(remapWeightsFile, gridID1, gridID2, remap, extrapolateIsSet, remapExtrapolate, knnParams);
+        if (numRemaps == 0) { operfunc = maptype_to_operfunc(remapSwitches); }
+        else if (operfunc != maptype_to_operfunc(remapSwitches)) { cdo_abort("Remapping method changed in input weights files!"); }
+        numRemaps++;
       }
+    }
+    else
+    {
+      remapSwitches = remap_operfunc_to_maptype(operfunc);
+      if (remapSwitches.mapType == RemapMethod::KNN)
+      {
+        if (numNeighbors) remapSwitches.numNeighbors = numNeighbors;
+        if (remapSwitches.numNeighbors != -1) set_knn_parameter();
+      }
+    }
 
     mapType = remapSwitches.mapType;
     remapOrder = remapSwitches.remapOrder;
@@ -591,18 +588,18 @@ public:
 
     needGradients = (mapType == RemapMethod::BICUBIC);
     if (mapType == RemapMethod::CONSERV && remapOrder == 2)
-      {
-        if (Options::cdoVerbose) cdo_print("Second order remapping");
-        needGradients = true;
-      }
+    {
+      if (Options::cdoVerbose) cdo_print("Second order remapping");
+      needGradients = true;
+    }
 
     if (needGradients) gradients.init(varList1.gridsizeMax());
 
     if (remap_genweights)
-      {
-        // remap() gives rounding errors on target arrays with single precision floats
-        for (auto &var : varList2.vars) var.memType = MemType::Double;
-      }
+    {
+      // remap() gives rounding errors on target arrays with single precision floats
+      for (auto &var : varList2.vars) var.memType = MemType::Double;
+    }
 
     streamID2 = cdo_open_write(1);
     cdo_def_vlist(streamID2, vlistID2);
@@ -612,11 +609,11 @@ public:
   new_remapIndex()
   {
     if (numRemaps < maxRemaps)
-      {
-        auto remapIndex = numRemaps;
-        numRemaps++;
-        return remapIndex;
-      }
+    {
+      auto remapIndex = numRemaps;
+      numRemaps++;
+      return remapIndex;
+    }
 
     auto remapIndex = maxRemaps - 1;
     auto &remapLast = remapList[remapIndex];
@@ -660,12 +657,12 @@ public:
     varray_copy(remap.srcGrid.size, imask, remap.srcGrid.mask);
 
     if (mapType == RemapMethod::CONSERV)
-      {
-        ranges::fill(remap.srcGrid.cellArea, 0.0);
-        ranges::fill(remap.srcGrid.cellFrac, 0.0);
-        ranges::fill(remap.tgtGrid.cellArea, 0.0);
-      }
-    // ranges::fill(remap.tgtGrid.cellFrac, 0.0); failed with pgc++ 23.9.0
+    {
+      std::ranges::fill(remap.srcGrid.cellArea, 0.0);
+      std::ranges::fill(remap.srcGrid.cellFrac, 0.0);
+      std::ranges::fill(remap.tgtGrid.cellArea, 0.0);
+    }
+    // std::ranges::fill(remap.tgtGrid.cellFrac, 0.0); failed with pgc++ 23.9.0
     for (auto &cf : remap.tgtGrid.cellFrac) cf = 0.0;
 
     // initialize some remapping variables
@@ -674,15 +671,15 @@ public:
     remap_print_info(operfunc, remap_genweights, remap.srcGrid, remap.tgtGrid, numMissVals1, knnParams);
 
     if (remap_genweights)
+    {
+      if (needGradients)
       {
-        if (needGradients)
-          {
-            if (remap.srcGrid.rank != 2 && remapOrder == 2)
-              cdo_abort("Second order remapping is not available for unstructured grids!");
-          }
-
-        remap_gen_weights(remapSwitches.mapType, knnParams, remap);
+        if (remap.srcGrid.rank != 2 && remapOrder == 2)
+          cdo_abort("Second order remapping is not available for unstructured grids!");
       }
+
+      remap_gen_weights(remapSwitches.mapType, knnParams, remap);
+    }
   }
 
   void
@@ -693,108 +690,108 @@ public:
 
     int tsID = 0;
     while (true)
+    {
+      auto numFields = cdo_stream_inq_timestep(streamID1, tsID);
+      if (numFields == 0) break;
+
+      cdo_taxis_copy_timestep(taxisID2, taxisID1);
+
+      cdo_def_timestep(streamID2, tsID);
+
+      for (int fieldID = 0; fieldID < numFields; ++fieldID)
       {
-        auto numFields = cdo_stream_inq_timestep(streamID1, tsID);
-        if (numFields == 0) break;
+        auto [varID, levelID] = cdo_inq_field(streamID1);
+        auto &var = varList1.vars[varID];
+        field1.init(var);
+        cdo_read_field(streamID1, field1);
+        auto numMissVals1 = useMask ? field1.numMissVals : 0;
 
-        cdo_taxis_copy_timestep(taxisID2, taxisID1);
+        field2.init(varList2.vars[varID]);
 
-        cdo_def_timestep(streamID2, tsID);
+        auto gridIndex = vlistGridIndex(vlistID1, var.gridID);
 
-        for (int fieldID = 0; fieldID < numFields; ++fieldID)
+        if (!remapGrids[gridIndex]) { field_copy(field1, field2); }
+        else
+        {
+          if (mapType != RemapMethod::CONSERV && var.gridType == GRID_GME)
+            cdo_abort("Only conservative remapping is available to remap between GME grids!");
+
+          if (gridIsCircular(var.gridID) && !extrapolateIsSet) remapExtrapolate = true;
+
+          remap_set_mask(field1, var.gridsize, numMissVals1, var.missval, imask);
+
+          int remapIndex = get_remapIndex(numRemaps, remapList, var.gridID, numMissVals1, useMask, imask);
+          if (Options::cdoVerbose && remapIndex >= 0) cdo_print("Using remap %d", remapIndex);
+          if (remapIndex < 0)
           {
-            auto [varID, levelID] = cdo_inq_field(streamID1);
-            auto &var = varList1.vars[varID];
-            field1.init(var);
-            cdo_read_field(streamID1, field1);
-            auto numMissVals1 = useMask ? field1.numMissVals : 0;
-
-            field2.init(varList2.vars[varID]);
-
-            auto gridIndex = vlistGridIndex(vlistID1, var.gridID);
-
-            if (!remapGrids[gridIndex]) { field_copy(field1, field2); }
-            else
-              {
-                if (mapType != RemapMethod::CONSERV && var.gridType == GRID_GME)
-                  cdo_abort("Only conservative remapping is available to remap between GME grids!");
-
-                if (gridIsCircular(var.gridID) && !extrapolateIsSet) remapExtrapolate = true;
-
-                remap_set_mask(field1, var.gridsize, numMissVals1, var.missval, imask);
-
-                int remapIndex = get_remapIndex(numRemaps, remapList, var.gridID, numMissVals1, useMask, imask);
-                if (Options::cdoVerbose && remapIndex >= 0) cdo_print("Using remap %d", remapIndex);
-                if (remapIndex < 0)
-                  {
-                    remapIndex = new_remapIndex();
-                    remap_init(remapList[remapIndex], var, numMissVals1, imask);
-                  }
-
-                auto &remap = remapList[remapIndex];
-                if (var.gridType == GRID_GME) store_gme_grid(field1, remapList[remapIndex].srcGrid.vgpm);
-
-                auto gridsize2 = gridInqSize(gridID2);
-
-                if (remap_genweights)
-                  {
-                    remap.nused++;
-
-                    if (needGradients)
-                      {
-                        if (remap.srcGrid.rank != 2 && remapOrder == 2)
-                          cdo_abort("Second order remapping is not available for unstructured grids!");
-
-                        remap::gradients(field1, remap.srcGrid, gradients);
-                      }
-
-                    if (Options::cdoVerbose && operfunc == REMAPNN && gridsize2 == 1)
-                      {
-                        print_node_info(gridID2, remap.vars, remap.srcGrid);
-                      }
-
-                    if (operfunc == REMAPLAF)
-                      remap_laf(field2, var.missval, gridsize2, remap.vars, field1);
-                    else if (operfunc == REMAPAVG)
-                      remap_avg(field2, var.missval, gridsize2, remap.vars, field1);
-                    else
-                      remap_field(field2, var.missval, gridsize2, remap.vars, field1, gradients);
-                  }
-                else { remap_field(remapSwitches.mapType, knnParams, remap, field1, field2); }
-
-                if (operfunc == REMAPCON || operfunc == REMAPYCON2)
-                  {
-                    // used only to check the result of remapcon
-                    if (0) remap_normalize_field(remap.vars.normOpt, field2, remap.tgtGrid);
-                    remap_set_fracmin(remapDefaults.fracMin, field2, &remap.tgtGrid);
-                    if (var.name == "gridbox_area") scale_gridbox_area(field1, field2, remap.tgtGrid.cellArea);
-                  }
-
-                // calculate some statistics
-                if (Options::cdoVerbose) remap::stat(remapOrder, remap.srcGrid, remap.tgtGrid, remap.vars, field1, field2);
-
-                if (gridInqType(gridID2) == GRID_GME) restore_gme_grid(field2, remap.tgtGrid);
-
-                field2.numMissVals = field_num_mv(field2);
-              }
-
-            cdo_def_field(streamID2, varID, levelID);
-            cdo_write_field(streamID2, field2);
+            remapIndex = new_remapIndex();
+            remap_init(remapList[remapIndex], var, numMissVals1, imask);
           }
 
-        tsID++;
+          auto &remap = remapList[remapIndex];
+          if (var.gridType == GRID_GME) store_gme_grid(field1, remapList[remapIndex].srcGrid.vgpm);
+
+          auto gridsize2 = gridInqSize(gridID2);
+
+          if (remap_genweights)
+          {
+            remap.nused++;
+
+            if (needGradients)
+            {
+              if (remap.srcGrid.rank != 2 && remapOrder == 2)
+                cdo_abort("Second order remapping is not available for unstructured grids!");
+
+              remap::gradients(field1, remap.srcGrid, gradients);
+            }
+
+            if (Options::cdoVerbose && operfunc == REMAPNN && gridsize2 == 1)
+            {
+              print_node_info(gridID2, remap.vars, remap.srcGrid);
+            }
+
+            if (operfunc == REMAPLAF)
+              remap_laf(field2, var.missval, gridsize2, remap.vars, field1);
+            else if (operfunc == REMAPAVG)
+              remap_avg(field2, var.missval, gridsize2, remap.vars, field1);
+            else
+              remap_field(field2, var.missval, gridsize2, remap.vars, field1, gradients);
+          }
+          else { remap_field(remapSwitches.mapType, knnParams, remap, field1, field2); }
+
+          if (operfunc == REMAPCON || operfunc == REMAPYCON2)
+          {
+            // used only to check the result of remapcon
+            if (0) remap_normalize_field(remap.vars.normOpt, field2, remap.tgtGrid);
+            remap_set_fracmin(remapDefaults.fracMin, field2, &remap.tgtGrid);
+            if (var.name == "gridbox_area") scale_gridbox_area(field1, field2, remap.tgtGrid.cellArea);
+          }
+
+          // calculate some statistics
+          if (Options::cdoVerbose) remap::stat(remapOrder, remap.srcGrid, remap.tgtGrid, remap.vars, field1, field2);
+
+          if (gridInqType(gridID2) == GRID_GME) restore_gme_grid(field2, remap.tgtGrid);
+
+          field2.numMissVals = field_num_mv(field2);
+        }
+
+        cdo_def_field(streamID2, varID, levelID);
+        cdo_write_field(streamID2, field2);
       }
 
+      tsID++;
+    }
+
     if (doRemap && remap_genweights && remapList[0].nused == 0)
       remap_print_warning(remapWeightsFiles[0], operfunc, remapList[0].srcGrid, remapList[0].numMissVals);
 
     for (int remapIndex = 0; remapIndex < numRemaps; remapIndex++)
-      {
-        auto &remap = remapList[remapIndex];
-        remap_vars_free(remap.vars);
-        remap_grid_free(remap.srcGrid);
-        remap_grid_free(remap.tgtGrid);
-      }
+    {
+      auto &remap = remapList[remapIndex];
+      remap_vars_free(remap.vars);
+      remap_grid_free(remap.srcGrid);
+      remap_grid_free(remap.tgtGrid);
+    }
   }
 
   void
