@@ -37,6 +37,8 @@ constexpr double PI2 = M_PI * 2.0;
 
 double radiusDegToKm(double radiusInDeg);
 
+namespace
+{
 struct StatInfo
 {
   size_t n = 0;
@@ -70,6 +72,7 @@ struct StatInfo
     cdo_print("Max:   svals=%3zu  nvals=%2zu  radius=%.3gdeg(%.3gkm)", max_svals, max_nvals, max_radius, radiusDegToKm(max_radius));
   };
 };
+}  // namespace
 
 static size_t
 read_target_cell_bounds(int gridID, Varray<double> &xbounds, Varray<double> &ybounds)
@@ -108,65 +111,65 @@ read_coordinates(int gridID, Varray<double> &xvals, Varray<double> &yvals)
   cdo_grid_to_radian(gridID, CDI_YAXIS, yvals, "grid center lat");
 
   for (size_t i = 0; i < gridsize; ++i)
-    {
-      if (xvals[i] > PI2) xvals[i] -= PI2;
-      if (xvals[i] < 0.0) xvals[i] += PI2;
-    }
+  {
+    if (xvals[i] > PI2) xvals[i] -= PI2;
+    if (xvals[i] < 0.0) xvals[i] += PI2;
+  }
 
   if (gridID0 != gridID) gridDestroy(gridID);
 }
 
 static void
-read_xbounds_reg2d(int gridID, std::vector<double> &xbounds2d)
+read_xbounds_reg2d(int gridID, Varray<double> &xbounds2d)
 {
   auto nlon = gridInqXsize(gridID);
   xbounds2d.resize(nlon * 2);
 
   if (gridInqXbounds(gridID, nullptr)) { gridInqXbounds(gridID, xbounds2d.data()); }
   else
-    {
-      std::vector<double> xvals(nlon);
-      gridInqXvals(gridID, xvals.data());
-      grid_gen_bounds(nlon, xvals, xbounds2d);
-    }
+  {
+    Varray<double> xvals(nlon);
+    gridInqXvals(gridID, xvals.data());
+    grid_gen_bounds(nlon, xvals, xbounds2d);
+  }
 
   for (size_t i = 0; i < 2 * nlon; ++i) xbounds2d[i] *= DEG2RAD;
 
   for (size_t i = 0; i < nlon; ++i)
+  {
+    if (xbounds2d[2 * i + 1] > PI2)
     {
-      if (xbounds2d[2 * i + 1] > PI2)
-        {
-          xbounds2d[2 * i] -= PI2;
-          xbounds2d[2 * i + 1] -= PI2;
-        }
-      if (xbounds2d[2 * i + 1] < 0.0)
-        {
-          xbounds2d[2 * i] += PI2;
-          xbounds2d[2 * i + 1] += PI2;
-        }
+      xbounds2d[2 * i] -= PI2;
+      xbounds2d[2 * i + 1] -= PI2;
     }
+    if (xbounds2d[2 * i + 1] < 0.0)
+    {
+      xbounds2d[2 * i] += PI2;
+      xbounds2d[2 * i + 1] += PI2;
+    }
+  }
 }
 
 static void
-read_ybounds_reg2d(int gridID, std::vector<double> &ybounds2d)
+read_ybounds_reg2d(int gridID, Varray<double> &ybounds2d)
 {
   auto nlat = gridInqYsize(gridID);
   ybounds2d.resize(nlat * 2);
 
   if (gridInqYbounds(gridID, nullptr)) { gridInqYbounds(gridID, ybounds2d.data()); }
   else
-    {
-      std::vector<double> yvals(nlat);
-      gridInqYvals(gridID, yvals.data());
-      grid_gen_bounds(nlat, yvals, ybounds2d);
-      grid_check_lat_borders(2 * nlat, ybounds2d);
-    }
+  {
+    Varray<double> yvals(nlat);
+    gridInqYvals(gridID, yvals.data());
+    grid_gen_bounds(nlat, yvals, ybounds2d);
+    grid_check_lat_borders(2 * nlat, ybounds2d);
+  }
 
   for (size_t i = 0; i < 2 * nlat; ++i) ybounds2d[i] *= DEG2RAD;
 }
 
 static bool
-is_zonal_grid(int gridID, const std::vector<double> &xbounds2d, const std::vector<double> &ybounds2d)
+is_zonal_grid(int gridID, Varray<double> const &xbounds2d, Varray<double> const &ybounds2d)
 {
   bool isZonalGrid{ false };
 
@@ -174,46 +177,45 @@ is_zonal_grid(int gridID, const std::vector<double> &xbounds2d, const std::vecto
   auto nlat = gridInqYsize(gridID);
 
   if (nlon == 1 && xbounds2d[1] > xbounds2d[0])
+  {
+    isZonalGrid = true;
+    for (size_t i = 1; i < nlat; ++i)
     {
-      isZonalGrid = true;
-      for (size_t i = 1; i < nlat; ++i)
-        {
-          if (is_not_equal(ybounds2d[2 * i - 1], ybounds2d[2 * i]))
-            {
-              isZonalGrid = false;
-              break;
-            }
-        }
+      if (is_not_equal(ybounds2d[2 * i - 1], ybounds2d[2 * i]))
+      {
+        isZonalGrid = false;
+        break;
+      }
     }
+  }
 
   return isZonalGrid;
 }
 
 static double
-calc_maxdist(size_t i, size_t nv, const PointLonLat &pointLL, const Varray<double> &xbounds, const Varray<double> &ybounds)
+calc_maxdist(size_t i, size_t nv, PointLonLat const &pointLL, Varray<double> const &xbounds, Varray<double> const &ybounds)
 {
   double p1[3], p2[3];
-  gcLLtoXYZ(pointLL.get_lon(), pointLL.get_lat(), p1);
+  gcLLtoXYZ(pointLL.lon(), pointLL.lat(), p1);
 
   double maxdist = 0.0;
   for (size_t k = 0; k < nv; ++k)
-    {
-      auto lons = &xbounds[nv * i];
-      auto lats = &ybounds[nv * i];
-      gcLLtoXYZ(lons[k], lats[k], p2);
-      auto sdist = cdo::sqr_distance(p1, p2);
-      maxdist = std::max(maxdist, sdist);
-    }
+  {
+    auto lons = &xbounds[nv * i];
+    auto lats = &ybounds[nv * i];
+    gcLLtoXYZ(lons[k], lats[k], p2);
+    auto sdist = cdo::sqr_distance(p1, p2);
+    maxdist = std::max(maxdist, sdist);
+  }
 
   return maxdist;
 }
 
 static double
-calc_maxdist_rec2d(size_t i, size_t nlon, const PointLonLat &pointLL, const std::vector<double> &xbounds,
-                   const std::vector<double> &ybounds)
+calc_maxdist_rec2d(size_t i, size_t nlon, PointLonLat const &pointLL, Varray<double> const &xbounds, Varray<double> const &ybounds)
 {
   double p1[3], p2[3];
-  gcLLtoXYZ(pointLL.get_lon(), pointLL.get_lat(), p1);
+  gcLLtoXYZ(pointLL.lon(), pointLL.lat(), p1);
 
   constexpr int nv = 4;
   double lons[nv], lats[nv];
@@ -230,11 +232,11 @@ calc_maxdist_rec2d(size_t i, size_t nlon, const PointLonLat &pointLL, const std:
 
   double maxdist = 0.0;
   for (size_t k = 0; k < nv; ++k)
-    {
-      gcLLtoXYZ(lons[k], lats[k], p2);
-      auto sdist = cdo::sqr_distance(p1, p2);
-      maxdist = std::max(maxdist, sdist);
-    }
+  {
+    gcLLtoXYZ(lons[k], lats[k], p2);
+    auto sdist = cdo::sqr_distance(p1, p2);
+    maxdist = std::max(maxdist, sdist);
+  }
 
   return maxdist;
 }
@@ -242,8 +244,8 @@ calc_maxdist_rec2d(size_t i, size_t nlon, const PointLonLat &pointLL, const std:
 #ifdef USE_YAC
 static size_t
 find_points_yac(Vmask &vmask, size_t cell_no, size_t ncorner, size_t numIndices, Varray<size_t> &indices,
-                const Varray<double> &xvals1, const Varray<double> &yvals1, const Varray<double> &xbounds,
-                const Varray<double> &ybounds)
+                Varray<double> const &xvals1, Varray<double> const &yvals1, Varray<double> const &xbounds,
+                Varray<double> const &ybounds)
 {
 #ifndef TESTIMPL
   cdo_abort("Internal error: find_points() not implemented!");
@@ -260,34 +262,34 @@ find_points_yac(Vmask &vmask, size_t cell_no, size_t ncorner, size_t numIndices,
   // };
 
   for (size_t k = 0; k < ncorner; ++k)
-    {
-      auto lon = xbounds[cell_no * ncorner + k];
-      auto lat = ybounds[cell_no * ncorner + k];
-      cell.edge_type[k] = YAC_GREAT_CIRCLE_EDGE;
-      // cell.edge_type[k] = lonlat_circle_type[k + 1];
-      gcLLtoXYZ(lon, lat, cell.coordinates_xyz[k]);
-    }
+  {
+    auto lon = xbounds[cell_no * ncorner + k];
+    auto lat = ybounds[cell_no * ncorner + k];
+    cell.edge_type[k] = YAC_GREAT_CIRCLE_EDGE;
+    // cell.edge_type[k] = lonlat_circle_type[k + 1];
+    gcLLtoXYZ(lon, lat, cell.coordinates_xyz[k]);
+  }
 
   double centerCoordinates[3];
   size_t nvalues = 0;
   for (size_t k = 0; k < numIndices; ++k)
+  {
+    auto index1 = indices[k];
+    auto lon = xvals1[index1];
+    auto lat = yvals1[index1];
+
+    gcLLtoXYZ(lon, lat, centerCoordinates);
+
+    if (yac_point_in_cell(centerCoordinates, cell))
     {
-      auto index1 = indices[k];
-      auto lon = xvals1[index1];
-      auto lat = yvals1[index1];
-
-      gcLLtoXYZ(lon, lat, centerCoordinates);
-
-      if (yac_point_in_cell(centerCoordinates, cell))
-        {
-          if (vmask[index1] == 0)
-            {
-              indices[nvalues] = indices[k];
-              nvalues++;
-            }
-          if (vmask[index1] < 127) vmask[index1]++;
-        }
+      if (vmask[index1] == 0)
+      {
+        indices[nvalues] = indices[k];
+        nvalues++;
+      }
+      if (vmask[index1] < 127) vmask[index1]++;
     }
+  }
 
   delete[] cell.edge_type;
   delete[] cell.coordinates_xyz;
@@ -297,8 +299,8 @@ find_points_yac(Vmask &vmask, size_t cell_no, size_t ncorner, size_t numIndices,
 #endif
 
 static size_t
-find_points(Vmask &vmask, size_t cell_no, size_t ncorner, size_t numIndices, Varray<size_t> &indices, const Varray<double> &xvals1,
-            const Varray<double> &yvals1, const Varray<double> &xbounds, const Varray<double> &ybounds)
+find_points(Vmask &vmask, size_t cell_no, size_t ncorner, size_t numIndices, Varray<size_t> &indices, Varray<double> const &xvals1,
+            Varray<double> const &yvals1, Varray<double> const &xbounds, Varray<double> const &ybounds)
 {
 #ifndef TESTIMPL
   cdo_abort("Internal error: find_points() not implemented!");
@@ -340,92 +342,92 @@ find_points(Vmask &vmask, size_t cell_no, size_t ncorner, size_t numIndices, Var
   double centerCoordinates[3];
   size_t nvalues = 0;
   for (size_t k = 0; k < numIndices; ++k)
+  {
+    auto index1 = indices[k];
+    auto lon = xvals1[index1];
+    auto lat = yvals1[index1];
+
+    gcLLtoXYZ(lon, lat, centerCoordinates);
+    centerPoint3D.X = centerCoordinates[0];
+    centerPoint3D.Y = centerCoordinates[1];
+    centerPoint3D.Z = centerCoordinates[2];
+
+    auto centerPoint2D = set_center_point_plane_projection(coordinateToIgnore, centerPoint3D);
+
+    auto windingNumber = winding_numbers_algorithm(cellCornersPlaneProjection, actualNumberOfCorners + 1, centerPoint2D);
+
+    if (windingNumber != 0)
     {
-      auto index1 = indices[k];
-      auto lon = xvals1[index1];
-      auto lat = yvals1[index1];
-
-      gcLLtoXYZ(lon, lat, centerCoordinates);
-      centerPoint3D.X = centerCoordinates[0];
-      centerPoint3D.Y = centerCoordinates[1];
-      centerPoint3D.Z = centerCoordinates[2];
-
-      auto centerPoint2D = set_center_point_plane_projection(coordinateToIgnore, centerPoint3D);
-
-      auto windingNumber = winding_numbers_algorithm(cellCornersPlaneProjection, actualNumberOfCorners + 1, centerPoint2D);
-
-      if (windingNumber != 0)
-        {
-          if (vmask[index1] == 0)
-            {
-              indices[nvalues] = indices[k];
-              nvalues++;
-            }
-          if (vmask[index1] < 127) vmask[index1]++;
-        }
+      if (vmask[index1] == 0)
+      {
+        indices[nvalues] = indices[k];
+        nvalues++;
+      }
+      if (vmask[index1] < 127) vmask[index1]++;
     }
+  }
 
   return nvalues;
 }
 
 static size_t
-find_points_rec2d(Vmask &vmask, size_t i, size_t nlon2, size_t numIndices, Varray<size_t> &indices, const Varray<double> &xvals1,
-                  const Varray<double> &yvals1, const std::vector<double> &xbounds2d, const std::vector<double> &ybounds2d)
+find_points_rec2d(Vmask &vmask, size_t i, size_t nlon2, size_t numIndices, Varray<size_t> &indices, Varray<double> const &xvals1,
+                  Varray<double> const &yvals1, Varray<double> const &xbounds2d, Varray<double> const &ybounds2d)
 {
   auto iy = i / nlon2;
   auto ix = i - iy * nlon2;
 
   size_t nvalues = 0;
   for (size_t k = 0; k < numIndices; ++k)
+  {
+    auto index1 = indices[k];
+    auto y = yvals1[index1];
+    if (y >= ybounds2d[2 * iy] && y < ybounds2d[2 * iy + 1])
     {
-      auto index1 = indices[k];
-      auto y = yvals1[index1];
-      if (y >= ybounds2d[2 * iy] && y < ybounds2d[2 * iy + 1])
+      auto x = xvals1[index1];
+      if ((x >= xbounds2d[2 * ix] && x < xbounds2d[2 * ix + 1])
+          || ((x - PI2) >= xbounds2d[2 * ix] && (x - PI2) < xbounds2d[2 * ix + 1]))
+      {
+        if (vmask[index1] == 0)
         {
-          auto x = xvals1[index1];
-          if ((x >= xbounds2d[2 * ix] && x < xbounds2d[2 * ix + 1])
-              || ((x - PI2) >= xbounds2d[2 * ix] && (x - PI2) < xbounds2d[2 * ix + 1]))
-            {
-              if (vmask[index1] == 0)
-                {
-                  indices[nvalues] = index1;
-                  nvalues++;
-                }
-              if (vmask[index1] < 127) vmask[index1]++;
-            }
+          indices[nvalues] = index1;
+          nvalues++;
         }
+        if (vmask[index1] < 127) vmask[index1]++;
+      }
     }
+  }
 
   return nvalues;
 }
 
 static long
-get_bin_num(double lon1, double lat1, size_t numBins, const std::vector<double> &xbounds2d, const std::vector<double> &ybounds2)
+get_bin_num(double lon1, double lat1, size_t numBins, Varray<double> const &xbounds2d, Varray<double> const &ybounds2)
 {
   if ((lon1 >= xbounds2d[0] && lon1 <= xbounds2d[1]) || ((lon1 - PI2) >= xbounds2d[0] && (lon1 - PI2) <= xbounds2d[1]))
+  {
+    auto latIsUp = (ybounds2[1] > ybounds2[0]);
+    if (latIsUp)
     {
-      auto latIsUp = (ybounds2[1] > ybounds2[0]);
-      if (latIsUp)
-        {
-          for (size_t i = 0; i < numBins; ++i)
-            {
-              if (lat1 > ybounds2[i * 2] && lat1 <= ybounds2[i * 2 + 1]) return (long) i;
-            }
-        }
-      else
-        {
-          for (size_t i = 0; i < numBins; ++i)
-            {
-              if (lat1 <= ybounds2[i * 2] && lat1 > ybounds2[i * 2 + 1]) return (long) i;
-            }
-        }
+      for (size_t i = 0; i < numBins; ++i)
+      {
+        if (lat1 > ybounds2[i * 2] && lat1 <= ybounds2[i * 2 + 1]) return (long) i;
+      }
     }
+    else
+    {
+      for (size_t i = 0; i < numBins; ++i)
+      {
+        if (lat1 <= ybounds2[i * 2] && lat1 > ybounds2[i * 2 + 1]) return (long) i;
+      }
+    }
+  }
 
   return -1;
 }
 
 static void
-check_vmask(const Vmask &vmask)
+check_vmask(Vmask const &vmask)
 {
   constexpr int maxVals = 128;
   size_t vm[maxVals] = { 0 };
@@ -461,152 +463,151 @@ gen_mapdata(int gridID1, int gridID2)
   int gridIDdestroy = -1;
 
   Varray<double> xbounds, ybounds;
-  std::vector<double> xbounds2d, ybounds2d;
+  Varray<double> xbounds2d, ybounds2d;
   size_t nv = 4;
   if (grid2IsReg2d)
-    {
-      read_xbounds_reg2d(gridID2, xbounds2d);
-      read_ybounds_reg2d(gridID2, ybounds2d);
-    }
+  {
+    read_xbounds_reg2d(gridID2, xbounds2d);
+    read_ybounds_reg2d(gridID2, ybounds2d);
+  }
   else
-    {
-      auto gridID = generate_full_cell_grid(gridID2);
-      if (gridID != gridID2) gridIDdestroy = gridID2 = gridID;
-      nv = read_target_cell_bounds(gridID2, xbounds, ybounds);
-    }
+  {
+    auto gridID = generate_full_cell_grid(gridID2);
+    if (gridID != gridID2) gridIDdestroy = gridID2 = gridID;
+    nv = read_target_cell_bounds(gridID2, xbounds, ybounds);
+  }
 
   auto isZonalGrid = (grid2IsReg2d ? is_zonal_grid(gridID2, xbounds2d, ybounds2d) : false);
 
   if (isZonalGrid)
-    {
-      Varray<size_t> zonalBinsNum(gridsize2, 0);
-      Varray<long> indexMap(gridsize1, -1);
+  {
+    Varray<size_t> zonalBinsNum(gridsize2, 0);
+    Varray<long> indexMap(gridsize1, -1);
 
 #ifdef _OPENMP
 #pragma omp parallel for default(shared) schedule(dynamic)
 #endif
-      for (size_t i = 0; i < gridsize1; ++i)
-        {
-          auto binNum = get_bin_num(xvals1[i], yvals1[i], gridsize2, xbounds2d, ybounds2d);
-          if (binNum >= 0)
-            {
-              indexMap[i] = binNum;
+    for (size_t i = 0; i < gridsize1; ++i)
+    {
+      auto binNum = get_bin_num(xvals1[i], yvals1[i], gridsize2, xbounds2d, ybounds2d);
+      if (binNum >= 0)
+      {
+        indexMap[i] = binNum;
 #ifdef _OPENMP
 #pragma omp atomic
 #endif
-              zonalBinsNum[binNum]++;
-            }
-        }
-
-      for (size_t i = 0; i < gridsize2; ++i) mapdata[i].reserve(zonalBinsNum[i]);
-
-      for (size_t i = 0; i < gridsize1; ++i)
-        {
-          if (indexMap[i] >= 0) mapdata[indexMap[i]].push_back(i);
-        }
+        zonalBinsNum[binNum]++;
+      }
     }
-  else
+
+    for (size_t i = 0; i < gridsize2; ++i) mapdata[i].reserve(zonalBinsNum[i]);
+
+    for (size_t i = 0; i < gridsize1; ++i)
     {
-      cdo::timer timer;
+      if (indexMap[i] >= 0) mapdata[indexMap[i]].push_back(i);
+    }
+  }
+  else
+  {
+    cdo::timer timer;
 
-      GridPointsearch gps;
-      grid_pointsearch_create_unstruct(gps, xvals1, yvals1, true);
+    GridPointsearch gps;
+    grid_pointsearch_create_unstruct(gps, xvals1, yvals1, true);
 
-      if (Options::cdoVerbose) cdo_print("Point search created: %.2f seconds", timer.elapsed());
+    if (Options::cdoVerbose) cdo_print("Point search created: %.2f seconds", timer.elapsed());
 
-      timer.reset();
+    timer.reset();
 
-      auto maxIndex = gridsize1;
-      if (gridsize1 > 1000000) maxIndex /= 4;
-      Vmask vmask(gridsize1, 0);
-      Varray2D<size_t> indices_2D(Threading::ompNumMaxThreads, Varray<size_t>(maxIndex));
-      Varray2D<double> dist_2D(Threading::ompNumMaxThreads, Varray<double>(maxIndex));
+    auto maxIndex = gridsize1;
+    if (gridsize1 > 1000000) maxIndex /= 4;
+    Vmask vmask(gridsize1, 0);
+    Varray2D<size_t> indices_2D(Threading::ompNumMaxThreads, Varray<size_t>(maxIndex));
+    Varray2D<double> dist_2D(Threading::ompNumMaxThreads, Varray<double>(maxIndex));
 
-      StatInfo statInfo;
+    StatInfo statInfo;
 
 #ifdef _OPENMP
 #pragma omp parallel for default(shared) schedule(dynamic)
 #endif
-      for (size_t i = 0; i < gridsize2; ++i)
-        {
-          auto ompthID = cdo_omp_get_thread_num();
-          auto &indices = indices_2D[ompthID];
-          auto &dist = dist_2D[ompthID];
+    for (size_t i = 0; i < gridsize2; ++i)
+    {
+      auto ompthID = cdo_omp_get_thread_num();
+      auto &indices = indices_2D[ompthID];
+      auto &dist = dist_2D[ompthID];
 
-          PointLonLat pointLL2{ xvals2[i], yvals2[i] };
+      PointLonLat pointLL2{ xvals2[i], yvals2[i] };
 
-          auto searchRadius = grid2IsReg2d ? calc_maxdist_rec2d(i, nlon2, pointLL2, xbounds2d, ybounds2d)
-                                           : calc_maxdist(i, nv, pointLL2, xbounds, ybounds);
+      auto searchRadius = grid2IsReg2d ? calc_maxdist_rec2d(i, nlon2, pointLL2, xbounds2d, ybounds2d)
+                                       : calc_maxdist(i, nv, pointLL2, xbounds, ybounds);
 
-          if (searchRadius < 2.0) { searchRadius = 1.01 * std::sqrt(searchRadius); }
-          else { cdo_abort("Search radius of target grid cell[%zu] > 90 degrees!", i + 1); }
+      if (searchRadius < 2.0) { searchRadius = 1.01 * std::sqrt(searchRadius); }
+      else { cdo_abort("Search radius of target grid cell[%zu] > 90 degrees!", i + 1); }
 
-          gps.set_radius(searchRadius);
-          auto numIndices = grid_pointsearch_qnearest(gps, pointLL2, maxIndex, indices.data(), dist.data());
-          // printf("%zu numIndices %zu\n", i+1, numIndices);
+      gps.set_radius(searchRadius);
+      auto numIndices = grid_pointsearch_qnearest(gps, pointLL2, maxIndex, indices.data(), dist.data());
+      // printf("%zu numIndices %zu\n", i+1, numIndices);
 
-          auto nvalues = grid2IsReg2d
-                             ? find_points_rec2d(vmask, i, nlon2, numIndices, indices, xvals1, yvals1, xbounds2d, ybounds2d)
+      auto nvalues = grid2IsReg2d ? find_points_rec2d(vmask, i, nlon2, numIndices, indices, xvals1, yvals1, xbounds2d, ybounds2d)
 #ifdef USE_YAC
-                             : find_points_yac(vmask, i, nv, numIndices, indices, xvals1, yvals1, xbounds, ybounds);
+                                  : find_points_yac(vmask, i, nv, numIndices, indices, xvals1, yvals1, xbounds, ybounds);
 #else
-                             : find_points(vmask, i, nv, numIndices, indices, xvals1, yvals1, xbounds, ybounds);
+                                  : find_points(vmask, i, nv, numIndices, indices, xvals1, yvals1, xbounds, ybounds);
 #endif
 
-          if (nvalues)
-            {
-              mapdata[i].resize(nvalues);
-              for (size_t k = 0; k < nvalues; ++k) mapdata[i][k] = indices[k];
-            }
+      if (nvalues)
+      {
+        mapdata[i].resize(nvalues);
+        for (size_t k = 0; k < nvalues; ++k) mapdata[i][k] = indices[k];
+      }
 
-          // if (Options::cdoVerbose) printf("%zu numIndices %zu nvalues %zu  maxdist %g\n", i+1, numIndices, nvalues, maxdist);
-          if (Options::cdoVerbose && Threading::ompNumMaxThreads == 1) statInfo.add(numIndices, nvalues, searchRadius);
-        }
-
-      if (Options::cdoVerbose && Threading::ompNumMaxThreads == 1) statInfo.print();
-      if (Options::cdoVerbose) check_vmask(vmask);
-      if (Options::cdoVerbose) cdo_print("Point search qnearest: %.2f seconds", timer.elapsed());
-
-      if (gridIDdestroy != -1) gridDestroy(gridIDdestroy);
+      // if (Options::cdoVerbose) printf("%zu numIndices %zu nvalues %zu  maxdist %g\n", i+1, numIndices, nvalues, maxdist);
+      if (Options::cdoVerbose && Threading::ompNumMaxThreads == 1) statInfo.add(numIndices, nvalues, searchRadius);
     }
 
+    if (Options::cdoVerbose && Threading::ompNumMaxThreads == 1) statInfo.print();
+    if (Options::cdoVerbose) check_vmask(vmask);
+    if (Options::cdoVerbose) cdo_print("Point search qnearest: %.2f seconds", timer.elapsed());
+
+    if (gridIDdestroy != -1) gridDestroy(gridIDdestroy);
+  }
+
   return mapdata;
 }
 
 template <typename T>
 static T
-remap_kernel(int operfunc, const Varray<size_t> &indices, size_t &numMissVals2, Field &field, Varray<T> &fieldvec,
-             const Varray<T> &vec1, double mv)
+remap_kernel(int operfunc, Varray<size_t> const &indices, size_t &numMissVals2, Field &field, Varray<T> &fieldvec,
+             Varray<T> const &vec1, double mv)
 {
   T missval = mv;
   T value;
   auto nvalues = indices.size();
   if (nvalues)
+  {
+    for (size_t k = 0; k < nvalues; ++k) { fieldvec[k] = vec1[indices[k]]; }
+
+    field.numMissVals = 0;
+    for (size_t k = 0; k < nvalues; ++k)
     {
-      for (size_t k = 0; k < nvalues; ++k) { fieldvec[k] = vec1[indices[k]]; }
-
-      field.numMissVals = 0;
-      for (size_t k = 0; k < nvalues; ++k)
-        {
-          if (fp_is_equal(fieldvec[k], missval)) field.numMissVals++;
-        }
-
-      field.size = nvalues;
-      field.missval = missval;
-      value = field_function(field, operfunc);
-      if (fp_is_equal(value, missval)) numMissVals2++;
+      if (fp_is_equal(fieldvec[k], missval)) field.numMissVals++;
     }
+
+    field.size = nvalues;
+    field.missval = missval;
+    value = field_function(field, operfunc);
+    if (fp_is_equal(value, missval)) numMissVals2++;
+  }
   else
-    {
-      value = missval;
-      numMissVals2++;
-    }
+  {
+    value = missval;
+    numMissVals2++;
+  }
 
   return value;
 }
 
 static void
-remap_field(const Varray2D<size_t> &mapdata, const Field &field1, Field &field2, int operfunc)
+remap_field(const Varray2D<size_t> &mapdata, Field const &field1, Field &field2, int operfunc)
 {
   std::vector<Field> fields(Threading::ompNumMaxThreads);
 
@@ -618,28 +619,28 @@ remap_field(const Varray2D<size_t> &mapdata, const Field &field1, Field &field2,
 #pragma omp parallel for default(shared) schedule(static) reduction(+ : numMissVals2)
 #endif
   for (size_t i = 0; i < gridsize2; ++i)
-    {
-      const auto &indices = mapdata[i];
-      auto nvalues = indices.size();
-      auto missval = field1.missval;
+  {
+    auto const &indices = mapdata[i];
+    auto nvalues = indices.size();
+    auto missval = field1.missval;
 
-      auto ompthID = cdo_omp_get_thread_num();
-      auto &field = fields[ompthID];
-      field.memType = field1.memType;
-      if (field1.memType == MemType::Float)
-        field.vec_f.resize(nvalues);
-      else
-        field.vec_d.resize(nvalues);
+    auto ompthID = cdo_omp_get_thread_num();
+    auto &field = fields[ompthID];
+    field.memType = field1.memType;
+    if (field1.memType == MemType::Float)
+      field.vec_f.resize(nvalues);
+    else
+      field.vec_d.resize(nvalues);
 
-      double rvalue = 0.0;
-      if (field1.memType == MemType::Float)
-        rvalue = remap_kernel(operfunc, indices, numMissVals2, field, field.vec_f, field1.vec_f, missval);
-      else
-        rvalue = remap_kernel(operfunc, indices, numMissVals2, field, field.vec_d, field1.vec_d, missval);
+    double rvalue = 0.0;
+    if (field1.memType == MemType::Float)
+      rvalue = remap_kernel(operfunc, indices, numMissVals2, field, field.vec_f, field1.vec_f, missval);
+    else
+      rvalue = remap_kernel(operfunc, indices, numMissVals2, field, field.vec_d, field1.vec_d, missval);
 
-      auto func = [&](auto &v) { v[i] = rvalue; };
-      field_operation(func, field2);
-    }
+    auto func = [&](auto &v) { v[i] = rvalue; };
+    field_operation(func, field2);
+  }
 
   field2.numMissVals = numMissVals2;
 
@@ -672,17 +673,17 @@ public:
   };
   inline static RegisterEntry<Remapstat> registration = RegisterEntry<Remapstat>(module);
 
-  CdoStreamID streamID1;
-  CdoStreamID streamID2;
+  CdoStreamID streamID1{};
+  CdoStreamID streamID2{};
 
-  int taxisID1;
-  int taxisID2;
+  int taxisID1{ CDI_UNDEFID };
+  int taxisID2{ CDI_UNDEFID };
 
-  VarList varList1;
-  VarList varList2;
+  VarList varList1{};
+  VarList varList2{};
 
-  Varray2D<size_t> mapdata;
-  int operfunc;
+  Varray2D<size_t> mapdata{};
+  int operfunc{};
 
 public:
   void
@@ -701,7 +702,7 @@ public:
 #ifdef TESTIMPL
       auto hasProjParams = ((gridtype2 == GRID_PROJECTION) && grid_has_proj_params(gridID2));
       if (!gridProjIsSupported(gridID2) && !hasProjParams && gridtype2 != GRID_LONLAT && gridtype2 != GRID_GAUSSIAN
-          && gridtype2 != GRID_CURVILINEAR && gridtype2 != GRID_UNSTRUCTURED)
+          && gridtype2 != GRID_CURVILINEAR && gridtype2 != GRID_UNSTRUCTURED && gridtype2 != GRID_HEALPIX)
 #else
       if (gridtype2 != GRID_LONLAT && gridtype2 != GRID_GAUSSIAN)
 #endif
@@ -722,18 +723,18 @@ public:
     auto numGrids = vlistNumGrids(vlistID1);
     auto gridID1 = vlistGrid(vlistID1, 0);
     for (int index = 0; index < numGrids; ++index)
-      {
-        if (index > 0) cdo_abort("Too many different grids!");
+    {
+      if (index > 0) cdo_abort("Too many different grids!");
 
-        // auto gridID1 = vlistGrid(vlistID1, index);
-        auto gridtype = gridInqType(gridID1);
-        auto hasProjParams = ((gridtype == GRID_PROJECTION) && grid_has_proj_params(gridID1));
-        if (!gridProjIsSupported(gridID1) && !hasProjParams && gridtype != GRID_LONLAT && gridtype != GRID_GAUSSIAN
-            && gridtype != GRID_GME && gridtype != GRID_CURVILINEAR && gridtype != GRID_UNSTRUCTURED)
-          cdo_abort("Interpolation of %s data unsupported!", gridNamePtr(gridtype));
+      // auto gridID1 = vlistGrid(vlistID1, index);
+      auto gridtype = gridInqType(gridID1);
+      auto hasProjParams = ((gridtype == GRID_PROJECTION) && grid_has_proj_params(gridID1));
+      if (!gridProjIsSupported(gridID1) && !hasProjParams && gridtype != GRID_LONLAT && gridtype != GRID_GAUSSIAN
+          && gridtype != GRID_GME && gridtype != GRID_CURVILINEAR && gridtype != GRID_UNSTRUCTURED && gridtype != GRID_HEALPIX)
+        cdo_abort("Interpolation of %s data unsupported!", gridNamePtr(gridtype));
 
-        vlistChangeGridIndex(vlistID2, index, gridID2);
-      }
+      vlistChangeGridIndex(vlistID2, index, gridID2);
+    }
 
     streamID2 = cdo_open_write(1);
     cdo_def_vlist(streamID2, vlistID2);
@@ -751,28 +752,28 @@ public:
 
     int tsID = 0;
     while (true)
+    {
+      auto numFields = cdo_stream_inq_timestep(streamID1, tsID);
+      if (numFields == 0) break;
+
+      cdo_taxis_copy_timestep(taxisID2, taxisID1);
+      cdo_def_timestep(streamID2, tsID);
+
+      for (int fieldID = 0; fieldID < numFields; ++fieldID)
       {
-        auto numFields = cdo_stream_inq_timestep(streamID1, tsID);
-        if (numFields == 0) break;
+        auto [varID, levelID] = cdo_inq_field(streamID1);
+        field1.init(varList1.vars[varID]);
+        cdo_read_field(streamID1, field1);
 
-        cdo_taxis_copy_timestep(taxisID2, taxisID1);
-        cdo_def_timestep(streamID2, tsID);
+        field2.init(varList2.vars[varID]);
 
-        for (int fieldID = 0; fieldID < numFields; ++fieldID)
-          {
-            auto [varID, levelID] = cdo_inq_field(streamID1);
-            field1.init(varList1.vars[varID]);
-            cdo_read_field(streamID1, field1);
+        remap_field(mapdata, field1, field2, operfunc);
 
-            field2.init(varList2.vars[varID]);
-
-            remap_field(mapdata, field1, field2, operfunc);
-
-            cdo_def_field(streamID2, varID, levelID);
-            cdo_write_field(streamID2, field2);
-          }
-        tsID++;
+        cdo_def_field(streamID2, varID, levelID);
+        cdo_write_field(streamID2, field2);
       }
+      tsID++;
+    }
   }
 
   void
