@@ -26,18 +26,19 @@ public:
   };
   inline static RegisterEntry<Seloperator> registration = RegisterEntry<Seloperator>(module);
 
-  CdoStreamID streamID1;
-  CdoStreamID streamID2;
+private:
+  CdoStreamID streamID1{};
+  CdoStreamID streamID2{};
 
-  int vlistID1;
-  int vlistID2;
+  int vlistID1{ CDI_UNDEFID };
+  int vlistID2{ CDI_UNDEFID };
 
-  int taxisID1;
-  int taxisID2;
+  int taxisID1{ CDI_UNDEFID };
+  int taxisID2{ CDI_UNDEFID };
 
-  VarList varList1;
+  VarList varList1{};
 
-  bool dataIsUnchanged;
+  bool dataIsUnchanged{};
 
 public:
   void
@@ -57,34 +58,36 @@ public:
     streamID1 = cdo_open_read(0);
     vlistID1 = cdo_stream_inq_vlist(streamID1);
 
-    auto nvars = vlistNvars(vlistID1);
-    for (int varID = 0; varID < nvars; ++varID)
+    varList1 = VarList(vlistID1);
+
+    auto numVars = varList1.numVars();
+    for (int varID = 0; varID < numVars; ++varID)
+    {
+      auto code = vlistInqVarCode(vlistID1, varID);
+      auto zaxisID = vlistInqVarZaxis(vlistID1, varID);
+      auto nlevels = zaxisInqSize(zaxisID);
+      auto ltype = zaxis_to_ltype(zaxisID);
+
+      for (int levID = 0; levID < nlevels; levID++)
       {
-        auto code = vlistInqVarCode(vlistID1, varID);
-        auto zaxisID = vlistInqVarZaxis(vlistID1, varID);
-        auto nlevels = zaxisInqSize(zaxisID);
-        auto ltype = zaxis_to_ltype(zaxisID);
+        auto level = cdo_zaxis_inq_level(zaxisID, levID);
+        auto sellevel = (cdo_operator_argc() == 3) ? is_equal(level, slevel) : true;
+        auto selcode = (scode == -1 || scode == code);
+        auto selltype = (sltype == -1 || sltype == ltype);
 
-        for (int levID = 0; levID < nlevels; levID++)
-          {
-            auto level = cdo_zaxis_inq_level(zaxisID, levID);
-            auto sellevel = (cdo_operator_argc() == 3) ? is_equal(level, slevel) : true;
-            auto selcode = (scode == -1 || scode == code);
-            auto selltype = (sltype == -1 || sltype == ltype);
-
-            if (selcode && selltype && sellevel)
-              {
-                vlistDefFlag(vlistID1, varID, levID, true);
-                selfound = true;
-              }
-          }
+        if (selcode && selltype && sellevel)
+        {
+          vlistDefFlag(vlistID1, varID, levID, true);
+          selfound = true;
+        }
       }
+    }
 
     if (!selfound) cdo_warning("Code %d, ltype %d, level %g not found!", scode, sltype, slevel);
 
     vlistID2 = vlistCreate();
     cdo_vlist_copy_flag(vlistID2, vlistID1);
-    vlistDefNtsteps(vlistID2, vlistNtsteps(vlistID1));
+    vlistDefNtsteps(vlistID2, varList1.numSteps());
 
     taxisID1 = vlistInqTaxis(vlistID1);
     taxisID2 = taxisDuplicate(taxisID1);
@@ -92,8 +95,6 @@ public:
 
     streamID2 = cdo_open_write(1);
     cdo_def_vlist(streamID2, vlistID2);
-
-    varList1 = VarList(vlistID1);
   }
 
   void
@@ -103,34 +104,34 @@ public:
 
     int tsID = 0;
     while (true)
+    {
+      auto numFields = cdo_stream_inq_timestep(streamID1, tsID);
+      if (numFields == 0) break;
+
+      cdo_taxis_copy_timestep(taxisID2, taxisID1);
+      cdo_def_timestep(streamID2, tsID);
+
+      for (int fieldID = 0; fieldID < numFields; ++fieldID)
       {
-        auto numFields = cdo_stream_inq_timestep(streamID1, tsID);
-        if (numFields == 0) break;
+        auto [varID, levelID] = cdo_inq_field(streamID1);
+        if (vlistInqFlag(vlistID1, varID, levelID) == true)
+        {
+          auto varID2 = vlistFindVar(vlistID2, varID);
+          auto levelID2 = vlistFindLevel(vlistID2, varID, levelID);
+          cdo_def_field(streamID2, varID2, levelID2);
 
-        cdo_taxis_copy_timestep(taxisID2, taxisID1);
-        cdo_def_timestep(streamID2, tsID);
-
-        for (int fieldID = 0; fieldID < numFields; ++fieldID)
+          if (dataIsUnchanged) { cdo_copy_field(streamID1, streamID2); }
+          else
           {
-            auto [varID, levelID] = cdo_inq_field(streamID1);
-            if (vlistInqFlag(vlistID1, varID, levelID) == true)
-              {
-                auto varID2 = vlistFindVar(vlistID2, varID);
-                auto levelID2 = vlistFindLevel(vlistID2, varID, levelID);
-                cdo_def_field(streamID2, varID2, levelID2);
-
-                if (dataIsUnchanged) { cdo_copy_field(streamID2, streamID1); }
-                else
-                  {
-                    field.init(varList1.vars[varID]);
-                    cdo_read_field(streamID1, field);
-                    cdo_write_field(streamID2, field);
-                  }
-              }
+            field.init(varList1.vars[varID]);
+            cdo_read_field(streamID1, field);
+            cdo_write_field(streamID2, field);
           }
-
-        tsID++;
+        }
       }
+
+      tsID++;
+    }
   }
 
   void
