@@ -45,8 +45,8 @@ show_year(CdoStreamID streamID)
 {
   auto vlistID = cdo_stream_inq_vlist(streamID);
   auto taxisID = vlistInqTaxis(vlistID);
-  auto ntsteps = vlistNtsteps(vlistID);
-  if (ntsteps == 0) return;
+  auto numSteps = vlistNtsteps(vlistID);
+  if (numSteps == 0) return;
 
   constexpr int maxOut = 20;
   int nout = 0;
@@ -54,23 +54,23 @@ show_year(CdoStreamID streamID)
 
   int tsID = 0;
   while (true)
+  {
+    auto numFields = cdo_stream_inq_timestep(streamID, tsID);
+    if (numFields == 0) break;
+
+    auto vDateTime = taxisInqVdatetime(taxisID);
+    int year = vDateTime.date.year;
+
+    if (tsID == 0 || year0 != year)
     {
-      auto numFields = cdo_stream_inq_timestep(streamID, tsID);
-      if (numFields == 0) break;
-
-      auto vDateTime = taxisInqVdatetime(taxisID);
-      int year = vDateTime.date.year;
-
-      if (tsID == 0 || year0 != year)
-        {
-          nout++;
-          year0 = year;
-          fprintf(stdout, " %4d", year0);
-          print_newline(nout, maxOut);
-        }
-
-      tsID++;
+      nout++;
+      year0 = year;
+      fprintf(stdout, " %4d", year0);
+      print_newline(nout, maxOut);
     }
+
+    tsID++;
+  }
   print_newline_if_missing(nout, maxOut);
 }
 
@@ -79,8 +79,8 @@ show_mon(CdoStreamID streamID)
 {
   auto vlistID = cdo_stream_inq_vlist(streamID);
   auto taxisID = vlistInqTaxis(vlistID);
-  auto ntsteps = vlistNtsteps(vlistID);
-  if (ntsteps == 0) return;
+  auto numSteps = vlistNtsteps(vlistID);
+  if (numSteps == 0) return;
 
   constexpr int maxOut = 36;
   int nout = 0;
@@ -88,23 +88,23 @@ show_mon(CdoStreamID streamID)
 
   int tsID = 0;
   while (true)
+  {
+    auto numFields = cdo_stream_inq_timestep(streamID, tsID);
+    if (numFields == 0) break;
+
+    auto vDateTime = taxisInqVdatetime(taxisID);
+    int month = vDateTime.date.month;
+
+    if (tsID == 0 || month0 != month)
     {
-      auto numFields = cdo_stream_inq_timestep(streamID, tsID);
-      if (numFields == 0) break;
-
-      auto vDateTime = taxisInqVdatetime(taxisID);
-      int month = vDateTime.date.month;
-
-      if (tsID == 0 || month0 != month)
-        {
-          nout++;
-          month0 = month;
-          fprintf(stdout, " %2d", month0);
-          print_newline(nout, maxOut);
-        }
-
-      tsID++;
+      nout++;
+      month0 = month;
+      fprintf(stdout, " %2d", month0);
+      print_newline(nout, maxOut);
     }
+
+    tsID++;
+  }
   print_newline_if_missing(nout, maxOut);
 }
 
@@ -113,8 +113,8 @@ show_date(CdoStreamID streamID)
 {
   auto vlistID = cdo_stream_inq_vlist(streamID);
   auto taxisID = vlistInqTaxis(vlistID);
-  auto ntsteps = vlistNtsteps(vlistID);
-  if (ntsteps == 0) return;
+  auto numSteps = vlistNtsteps(vlistID);
+  if (numSteps == 0) return;
 
   constexpr int maxOut = 12;
   int nout = 0;
@@ -122,23 +122,23 @@ show_date(CdoStreamID streamID)
 
   int tsID = 0;
   while (true)
+  {
+    auto numFields = cdo_stream_inq_timestep(streamID, tsID);
+    if (numFields == 0) break;
+
+    auto vDateTime = taxisInqVdatetime(taxisID);
+    auto vdate = cdiDate_get(vDateTime.date);
+
+    if (tsID == 0 || date0 != vdate)
     {
-      auto numFields = cdo_stream_inq_timestep(streamID, tsID);
-      if (numFields == 0) break;
-
-      auto vDateTime = taxisInqVdatetime(taxisID);
-      auto vdate = cdiDate_get(vDateTime.date);
-
-      if (tsID == 0 || date0 != vdate)
-        {
-          nout++;
-          date0 = vdate;
-          fprintf(stdout, " %s", date_to_string(vDateTime.date).c_str());
-          print_newline(nout, maxOut);
-        }
-
-      tsID++;
+      nout++;
+      date0 = vdate;
+      fprintf(stdout, " %s", date_to_string(vDateTime.date).c_str());
+      print_newline(nout, maxOut);
     }
+
+    tsID++;
+  }
   print_newline_if_missing(nout, maxOut);
 }
 
@@ -147,25 +147,25 @@ show_time(CdoStreamID streamID)
 {
   auto vlistID = cdo_stream_inq_vlist(streamID);
   auto taxisID = vlistInqTaxis(vlistID);
-  auto ntsteps = vlistNtsteps(vlistID);
-  if (ntsteps == 0) return;
+  auto numSteps = vlistNtsteps(vlistID);
+  if (numSteps == 0) return;
 
   constexpr int maxOut = 12;
   int nout = 0;
 
   int tsID = 0;
   while (true)
-    {
-      auto numFields = cdo_stream_inq_timestep(streamID, tsID);
-      if (numFields == 0) break;
+  {
+    auto numFields = cdo_stream_inq_timestep(streamID, tsID);
+    if (numFields == 0) break;
 
-      auto vDateTime = taxisInqVdatetime(taxisID);
-      nout++;
-      fprintf(stdout, " %s", time_to_string(vDateTime.time).c_str());
-      print_newline(nout, maxOut);
+    auto vDateTime = taxisInqVdatetime(taxisID);
+    nout++;
+    fprintf(stdout, " %s", time_to_string(vDateTime.time).c_str());
+    print_newline(nout, maxOut);
 
-      tsID++;
-    }
+    tsID++;
+  }
   print_newline_if_missing(nout, maxOut);
 }
 
@@ -174,127 +174,125 @@ show_timestamp(CdoStreamID streamID)
 {
   auto vlistID = cdo_stream_inq_vlist(streamID);
   auto taxisID = vlistInqTaxis(vlistID);
-  auto ntsteps = vlistNtsteps(vlistID);
-  if (ntsteps == 0) return;
+  auto numSteps = vlistNtsteps(vlistID);
+  if (numSteps == 0) return;
 
   constexpr int maxOut = 4;
   int nout = 0;
 
   int tsID = 0;
   while (true)
-    {
-      auto numFields = cdo_stream_inq_timestep(streamID, tsID);
-      if (numFields == 0) break;
+  {
+    auto numFields = cdo_stream_inq_timestep(streamID, tsID);
+    if (numFields == 0) break;
 
-      nout++;
-      fprintf(stdout, " %s", datetime_to_string(taxisInqVdatetime(taxisID)).c_str());
-      print_newline(nout, maxOut);
+    nout++;
+    fprintf(stdout, " %s", datetime_to_string(taxisInqVdatetime(taxisID)).c_str());
+    print_newline(nout, maxOut);
 
-      tsID++;
-    }
+    tsID++;
+  }
   print_newline_if_missing(nout, maxOut);
 }
 
 static void
-show_code(const VarList &varList)
+show_code(VarList const &varList)
 {
   constexpr int maxOut = 25;
   int nout = 0;
 
   auto numVars = varList.numVars();
   for (int varID = 0; varID < numVars; ++varID)
-    {
-      nout++;
-      const auto &var = varList.vars[varID];
-      fprintf(stdout, " %d", var.code);
-      print_newline(nout, maxOut);
-    }
+  {
+    nout++;
+    auto const &var = varList.vars[varID];
+    fprintf(stdout, " %d", var.code);
+    print_newline(nout, maxOut);
+  }
   if (Options::silentMode || (nout % maxOut)) fprintf(stdout, "\n");
 }
 
 static void
-show_grid(const VarList &varList)
+show_grid(VarList const &varList)
 {
   fprintf(stdout, "# param nr | grid nr | z-axis nr:   /* Use in combination with operatores: griddes and zaxisdes */\n");
   auto vlistID = varList.vlistID;
-  for (const auto &var : varList.vars)
-    {
-      fprintf(stdout, "      %3d     %3d      %3d\n", var.code, vlistGridIndex(vlistID, var.gridID) + 1,
-              vlistZaxisIndex(vlistID, var.zaxisID) + 1);
-    }
+  for (auto const &var : varList.vars)
+  {
+    fprintf(stdout, "      %3d     %3d      %3d\n", var.code, vlistGridIndex(vlistID, var.gridID) + 1,
+            vlistZaxisIndex(vlistID, var.zaxisID) + 1);
+  }
 }
 
 static void
-show_unit(const VarList &varList)
+show_unit(VarList const &varList)
 {
   constexpr int maxOut = 10;
   int nout = 0;
 
-  for (const auto &var : varList.vars)
-    {
-      nout++;
-      if (var.units.size()) fprintf(stdout, " %s", var.units.c_str());
-      print_newline(nout, maxOut);
-    }
+  for (auto const &var : varList.vars)
+  {
+    nout++;
+    if (var.units.size()) fprintf(stdout, " %s", var.units.c_str());
+    print_newline(nout, maxOut);
+  }
   print_newline_if_missing(nout, maxOut);
 }
 
 static void
-show_param(const VarList &varList)
+show_param(VarList const &varList)
 {
   constexpr int maxOut = 10;
   int nout = 0;
 
   char paramstr[32];
-  for (const auto &var : varList.vars)
-    {
-      nout++;
-      cdiParamToString(var.param, paramstr, sizeof(paramstr));
+  for (auto const &var : varList.vars)
+  {
+    nout++;
+    cdiParamToString(var.param, paramstr, sizeof(paramstr));
 
-      fprintf(stdout, " %s", paramstr);
-      print_newline(nout, maxOut);
-    }
+    fprintf(stdout, " %s", paramstr);
+    print_newline(nout, maxOut);
+  }
   print_newline_if_missing(nout, maxOut);
 }
 
 static void
-show_name(const VarList &varList)
+show_name(VarList const &varList)
 {
-  constexpr int maxOut = 10;
   int nout = 0;
-
-  for (const auto &var : varList.vars)
-    {
-      nout++;
-      fprintf(stdout, " %s", var.name.c_str());
-      print_newline(nout, maxOut);
-    }
-  print_newline_if_missing(nout, maxOut);
+  for (auto const &var : varList.vars)
+  {
+    nout++;
+    if (nout > 1) fprintf(stdout, " ");
+    fprintf(stdout, "%s", var.name.c_str());
+  }
+  fprintf(stdout, "\n");
 }
 
 static void
-show_stdname(const VarList &varList)
+show_stdname(VarList const &varList)
 {
   constexpr int maxOut = 1;
   int nout = 0;
 
-  for (const auto &var : varList.vars)
-    {
-      nout++;
-      fprintf(stdout, " %s", var.stdname.size() ? var.stdname.c_str() : "unknown");
-      print_newline(nout, maxOut);
-    }
+  for (auto const &var : varList.vars)
+  {
+    nout++;
+    fprintf(stdout, " %s", var.stdname.size() ? var.stdname.c_str() : "unknown");
+    print_newline(nout, maxOut);
+  }
   print_newline_if_missing(nout, maxOut);
 }
 
 static void
-show_level(const VarList &varList)
+show_level(VarList const &varList)
 {
-  for (const auto &var : varList.vars)
-    {
-      for (int levelID = 0; levelID < var.nlevels; ++levelID) fprintf(stdout, " %.9g", cdo_zaxis_inq_level(var.zaxisID, levelID));
-      fprintf(stdout, "\n");
-    }
+  for (auto const &var : varList.vars)
+  {
+    for (int levelID = 0; levelID < var.nlevels; ++levelID) fprintf(stdout, " %.9g", cdo_zaxis_inq_level(var.zaxisID, levelID));
+    fprintf(stdout, "\n");
+  }
 }
 
 static void
@@ -302,43 +300,43 @@ show_ltype(int vlistID)
 {
   auto numZaxes = vlistNumZaxis(vlistID);
   for (int index = 0; index < numZaxes; ++index)
-    {
-      auto zaxisID = vlistZaxis(vlistID, index);
-      auto ltype = zaxis_to_ltype(zaxisID);
+  {
+    auto zaxisID = vlistZaxis(vlistID, index);
+    auto ltype = zaxis_to_ltype(zaxisID);
 
-      if (ltype != -1) fprintf(stdout, " %d", ltype);
-    }
+    if (ltype != -1) fprintf(stdout, " %d", ltype);
+  }
   fprintf(stdout, "\n");
 }
 
 static void
-show_filter(int vlistID, const VarList &varList)
+show_filter(int vlistID, VarList const &varList)
 {
   char filterSpec[CDI_MAX_NAME];
   auto numVars = varList.numVars();
   for (int varID = 0; varID < numVars; ++varID)
+  {
+    auto comptype = vlistInqVarCompType(vlistID, varID);
+    if (comptype == CDI_COMPRESS_FILTER || comptype == CDI_COMPRESS_ZIP || comptype == CDI_COMPRESS_SZIP)
     {
-      auto comptype = vlistInqVarCompType(vlistID, varID);
-      if (comptype == CDI_COMPRESS_FILTER || comptype == CDI_COMPRESS_ZIP || comptype == CDI_COMPRESS_SZIP)
-        {
-          const auto &var = varList.vars[varID];
-          int length = CDI_MAX_NAME;
-          cdiInqKeyString(vlistID, varID, CDI_KEY_FILTERSPEC_IN, filterSpec, &length);
-          if (length > 0) fprintf(stdout, "%s=\"%s\"\n", var.name.c_str(), filterSpec);
-        }
+      auto const &var = varList.vars[varID];
+      int length = CDI_MAX_NAME;
+      cdiInqKeyString(vlistID, varID, CDI_KEY_FILTERSPEC_IN, filterSpec, &length);
+      if (length > 0) fprintf(stdout, "%s=\"%s\"\n", var.name.c_str(), filterSpec);
     }
+  }
 }
 
 static void
-show_chunks(int vlistID, const VarList &varList)
+show_chunkspec(int vlistID, VarList const &varList)
 {
   auto numVars = varList.numVars();
   for (int varID = 0; varID < numVars; ++varID)
-    {
-      const auto &var = varList.vars[varID];
-      auto chunkSpecString = cdo::get_chunkspec_string(vlistID, varID);
-      if (chunkSpecString.size() > 0) fprintf(stdout, "%s=\"%s\"\n", var.name.c_str(), chunkSpecString.c_str());
-    }
+  {
+    auto const &var = varList.vars[varID];
+    auto chunkSpecString = cdo::get_chunkspec_string(vlistID, varID);
+    if (chunkSpecString.size() > 0) fprintf(stdout, "%s=\"%s\"\n", var.name.c_str(), chunkSpecString.c_str());
+  }
 }
 
 static void
@@ -368,7 +366,7 @@ public:
                    { "showltype", ShowinfoHelp },
                    { "showformat", ShowinfoHelp },
                    { "showgrid", ShowinfoHelp },
-                   { "showchunks", ShowinfoHelp },
+                   { "showchunkspec", ShowinfoHelp },
                    { "showhistory" },
                    { "showfilter", ShowinfoHelp } },
     .aliases = { { "showvar", "showname" } },
@@ -382,6 +380,8 @@ public:
   void
   init() override
   {
+    cdiDefGlobal("COPY_CHUNKSPEC", true);
+
     if (Options::lazyGridLoad && this_is_the_only_process()) { cdiDefGlobal("NETCDF_LAZY_GRID_LOAD", true); }
     if (this_is_the_only_process()) { cdiDefGlobal("READ_CELL_CORNERS", false); }
     if (this_is_the_only_process()) { cdiDefGlobal("READ_CELL_CENTER", false); }
@@ -400,7 +400,7 @@ public:
     auto SHOWLTYPE = module.get_id("showltype");
     auto SHOWFORMAT = module.get_id("showformat");
     auto SHOWGRID = module.get_id("showgrid");
-    auto SHOWCHUNKS = module.get_id("showchunks");
+    auto SHOWCHUNKSPEC = module.get_id("showchunkspec");
     auto SHOWFILTER = module.get_id("showfilter");
     auto SHOWHISTORY = module.get_id("showhistory");
 
@@ -427,7 +427,7 @@ public:
     else if (operatorID == SHOWLEVEL)     show_level(varList);
     else if (operatorID == SHOWLTYPE)     show_ltype(vlistID);
     else if (operatorID == SHOWFORMAT)    print_filetype(streamID, vlistID);
-    else if (operatorID == SHOWCHUNKS)    show_chunks(vlistID, varList);
+    else if (operatorID == SHOWCHUNKSPEC) show_chunkspec(vlistID, varList);
     else if (operatorID == SHOWFILTER)    show_filter(vlistID, varList);
     else if (operatorID == SHOWHISTORY)   show_history(vlistID);
     // clang-format on
