@@ -25,9 +25,9 @@ class Testdata : public Process
 
   CdoStreamID streamID1;
   CdoStreamID streamID2;
-  int taxisID1;
-  int vlistID1;
-  int taxisID2;
+  int taxisID1{ CDI_UNDEFID };
+  int vlistID1{ CDI_UNDEFID };
+  int taxisID2{ CDI_UNDEFID };
 
 public:
   void
@@ -66,48 +66,48 @@ public:
     int tsID2 = 0;
     int tsID1 = 0;
     while (true)
+    {
+      auto numFields = cdo_stream_inq_timestep(streamID1, tsID1);
+      if (numFields == 0) break;
+
+      cdo_taxis_copy_timestep(taxisID2, taxisID1);
+      cdo_def_timestep(streamID2, tsID2);
+
+      for (int fieldID = 0; fieldID < numFields; ++fieldID)
       {
-        auto numFields = cdo_stream_inq_timestep(streamID1, tsID1);
-        if (numFields == 0) break;
+        auto [varID, levelID] = cdo_inq_field(streamID1);
+        cdo_def_field(streamID2, varID, levelID);
 
-        cdo_taxis_copy_timestep(taxisID2, taxisID1);
-        cdo_def_timestep(streamID2, tsID2);
+        size_t numMissVals;
+        cdo_read_field(streamID1, array.data(), &numMissVals);
 
-        for (int fieldID = 0; fieldID < numFields; ++fieldID)
-          {
-            auto [varID, levelID] = cdo_inq_field(streamID1);
-            cdo_def_field(streamID2, varID, levelID);
+        gridsizeMax = varList1.vars[varID].gridsize;
+        for (size_t i = 0; i < gridsizeMax; ++i)
+        {
+          fval[i] = (float) array[i];
 
-            size_t numMissVals;
-            cdo_read_field(streamID1, array.data(), &numMissVals);
+          std::memcpy(&ival[i], &fval[i], 4);
+          std::memcpy(&cval[i * 4], &fval[i], 4);
 
-            gridsizeMax = varList1.vars[varID].gridsize;
-            for (size_t i = 0; i < gridsizeMax; ++i)
-              {
-                fval[i] = (float) array[i];
+          cval2[i + gridsizeMax * 0] = cval[i * 4 + 0];
+          cval2[i + gridsizeMax * 1] = cval[i * 4 + 1];
+          cval2[i + gridsizeMax * 2] = cval[i * 4 + 2];
+          cval2[i + gridsizeMax * 3] = cval[i * 4 + 3];
 
-                std::memcpy(&ival[i], &fval[i], 4);
-                std::memcpy(&cval[i * 4], &fval[i], 4);
+          if (tsID1 == 0 && fieldID == 0)
+            printf("%4zu %3u %3u %3u %3u %d %g\n", i, (unsigned int) cval[4 * i + 0], (unsigned int) cval[4 * i + 1],
+                   (unsigned int) cval[4 * i + 2], (unsigned int) cval[4 * i + 3], ival[i], fval[i]);
+        }
 
-                cval2[i + gridsizeMax * 0] = cval[i * 4 + 0];
-                cval2[i + gridsizeMax * 1] = cval[i * 4 + 1];
-                cval2[i + gridsizeMax * 2] = cval[i * 4 + 2];
-                cval2[i + gridsizeMax * 3] = cval[i * 4 + 3];
+        cdo_write_field(streamID2, array.data(), numMissVals);
 
-                if (tsID1 == 0 && fieldID == 0)
-                  printf("%4zu %3u %3u %3u %3u %d %g\n", i, (unsigned int) cval[4 * i + 0], (unsigned int) cval[4 * i + 1],
-                         (unsigned int) cval[4 * i + 2], (unsigned int) cval[4 * i + 3], ival[i], fval[i]);
-              }
-
-            cdo_write_field(streamID2, array.data(), numMissVals);
-
-            fwrite(cval.data(), 4, gridsizeMax, fp);
-          }
-
-        tsID1++;
-        tsID2++;
+        fwrite(cval.data(), 4, gridsizeMax, fp);
       }
 
+      tsID1++;
+      tsID2++;
+    }
+
     std::fclose(fp);
   }
 
