@@ -41,13 +41,14 @@ public:
     .constraints = { 1, 1, NoRestriction },
   };
   inline static RegisterEntry<Timcount> registration = RegisterEntry<Timcount>(module);
-  CdoStreamID streamID1;
-  int taxisID1;
 
-  CdoStreamID streamID2;
-  int taxisID2;
+private:
+  CdoStreamID streamID1{};
+  CdoStreamID streamID2{};
+  int taxisID1{ CDI_UNDEFID };
+  int taxisID2{ CDI_UNDEFID };
 
-  int compareDate;
+  int compareDate{};
 
   CdiDateTime vDateTime0{};
   CdiDateTime vDateTimeN{};
@@ -68,8 +69,10 @@ public:
     auto vlistID1 = cdo_stream_inq_vlist(streamID1);
     auto vlistID2 = vlistDuplicate(vlistID1);
 
-    auto nvars = vlistNvars(vlistID1);
-    for (int varID = 0; varID < nvars; ++varID) cdiDefKeyString(vlistID2, varID, CDI_KEY_UNITS, "No.");
+    varList1 = VarList(vlistID1);
+
+    auto numVars = varList1.numVars();
+    for (int varID = 0; varID < numVars; ++varID) cdiDefKeyString(vlistID2, varID, CDI_KEY_UNITS, "No.");
 
     vlistDefNtsteps(vlistID2, (compareDate == CMP_DATE) ? 1 : -1);
 
@@ -79,8 +82,6 @@ public:
 
     streamID2 = cdo_open_write(1);
     cdo_def_vlist(streamID2, vlistID2);
-
-    varList1 = VarList(vlistID1);
   }
 
   void
@@ -96,66 +97,66 @@ public:
     int tsID = 0;
     int otsID = 0;
     while (true)
+    {
+      int numFields = 0;
+      int numSets = 0;
+      while (true)
       {
-        int numFields = 0;
-        int numSets = 0;
-        while (true)
-          {
-            numFields = cdo_stream_inq_timestep(streamID1, tsID);
-            if (numFields == 0) break;
-
-            auto vDateTime = taxisInqVdatetime(taxisID1);
-
-            if (numSets == 0) vDateTime0 = vDateTime;
-
-            if (date_is_neq(vDateTime, vDateTime0, compareDate))
-              {
-                cdo_add_steps(-1);
-                break;
-              }
-
-            for (int fieldID = 0; fieldID < numFields; ++fieldID)
-              {
-                auto [varID, levelID] = cdo_inq_field(streamID1);
-
-                if (tsID == 0) fieldInfoList[fieldID].set(varID, levelID);
-
-                auto fieldsize = varsData1[varID][levelID].size;
-
-                if (numSets == 0)
-                  {
-                    for (size_t i = 0; i < fieldsize; ++i) varsData1[varID][levelID].vec_d[i] = varsData1[varID][levelID].missval;
-                    varsData1[varID][levelID].numMissVals = fieldsize;
-                  }
-
-                field.init(varList1.vars[varID]);
-                cdo_read_field(streamID1, field);
-
-                field2_count(varsData1[varID][levelID], field);
-              }
-
-            vDateTimeN = vDateTime;
-            numSets++;
-            tsID++;
-          }
-
-        if (numFields == 0 && numSets == 0) break;
-
-        taxisDefVdatetime(taxisID2, vDateTimeN);
-        cdo_def_timestep(streamID2, otsID);
-
-        for (int fieldID = 0; fieldID < maxFields; ++fieldID)
-          {
-            auto [varID, levelID] = fieldInfoList[fieldID].get();
-            if (otsID && varList1.vars[varID].isConstant) continue;
-
-            cdo_def_field(streamID2, varID, levelID);
-            cdo_write_field(streamID2, varsData1[varID][levelID]);
-          }
-
+        numFields = cdo_stream_inq_timestep(streamID1, tsID);
         if (numFields == 0) break;
-        otsID++;
+
+        auto vDateTime = taxisInqVdatetime(taxisID1);
+
+        if (numSets == 0) vDateTime0 = vDateTime;
+
+        if (date_is_neq(vDateTime, vDateTime0, compareDate))
+        {
+          cdo_add_steps(-1);
+          break;
+        }
+
+        for (int fieldID = 0; fieldID < numFields; ++fieldID)
+        {
+          auto [varID, levelID] = cdo_inq_field(streamID1);
+
+          if (tsID == 0) fieldInfoList[fieldID].set(varID, levelID);
+
+          auto fieldsize = varsData1[varID][levelID].size;
+
+          if (numSets == 0)
+          {
+            for (size_t i = 0; i < fieldsize; ++i) varsData1[varID][levelID].vec_d[i] = varsData1[varID][levelID].missval;
+            varsData1[varID][levelID].numMissVals = fieldsize;
+          }
+
+          field.init(varList1.vars[varID]);
+          cdo_read_field(streamID1, field);
+
+          field2_count(varsData1[varID][levelID], field);
+        }
+
+        vDateTimeN = vDateTime;
+        numSets++;
+        tsID++;
       }
+
+      if (numFields == 0 && numSets == 0) break;
+
+      taxisDefVdatetime(taxisID2, vDateTimeN);
+      cdo_def_timestep(streamID2, otsID);
+
+      for (int fieldID = 0; fieldID < maxFields; ++fieldID)
+      {
+        auto [varID, levelID] = fieldInfoList[fieldID].get();
+        if (otsID && varList1.vars[varID].isConstant) continue;
+
+        cdo_def_field(streamID2, varID, levelID);
+        cdo_write_field(streamID2, varsData1[varID][levelID]);
+      }
+
+      if (numFields == 0) break;
+      otsID++;
+    }
   }
 
   void
