@@ -39,10 +39,10 @@ public:
   inline static RegisterEntry<Timselpctl> registration = RegisterEntry<Timselpctl>(module);
 
   CdoStreamID streamID1;
-  int taxisID1;
+  int taxisID1{ CDI_UNDEFID };
 
   CdoStreamID streamID2;
-  int taxisID2;
+  int taxisID2{ CDI_UNDEFID };
 
   CdoStreamID streamID3;
   int taxisID3;
@@ -114,7 +114,7 @@ public:
 
     hset = HistogramSet(numVars, numSteps);
 
-    for (const auto &var : varList1.vars) hset.createVarLevels(var.ID, var.nlevels, var.gridsize);
+    for (auto const &var : varList1.vars) hset.createVarLevels(var.ID, var.nlevels, var.gridsize);
   }
 
   void
@@ -127,118 +127,118 @@ public:
 
     int tsID;
     for (tsID = 0; tsID < noffset; ++tsID)
-      {
-        auto numFields = cdo_stream_inq_timestep(streamID1, tsID);
-        if (numFields == 0) break;
+    {
+      auto numFields = cdo_stream_inq_timestep(streamID1, tsID);
+      if (numFields == 0) break;
 
-        for (int fieldID = 0; fieldID < numFields; ++fieldID)
-          {
-            auto [varID, levelID] = cdo_inq_field(streamID1);
-            if (tsID == 0) fieldInfoList[fieldID].set(varID, levelID);
-          }
+      for (int fieldID = 0; fieldID < numFields; ++fieldID)
+      {
+        auto [varID, levelID] = cdo_inq_field(streamID1);
+        if (tsID == 0) fieldInfoList[fieldID].set(varID, levelID);
       }
+    }
     int otsID = 0;
     if (tsID < noffset)
-      {
-        cdo_warning("noffset is larger than number of timesteps!");
-        return;
-      }
+    {
+      cdo_warning("noffset is larger than number of timesteps!");
+      return;
+    }
 
     while (true)
+    {
+      auto numFields = cdo_stream_inq_timestep(streamID2, otsID);
+      if (numFields != cdo_stream_inq_timestep(streamID3, otsID))
+        cdo_abort("Number of fields at time step %d of %s and %s differ!", otsID + 1, cdo_get_stream_name(1),
+                  cdo_get_stream_name(2));
+
+      auto vDateTime2 = taxisInqVdatetime(taxisID2);
+      auto vDateTime3 = taxisInqVdatetime(taxisID3);
+      if (cdiDateTime_isNE(vDateTime2, vDateTime3))
+        cdo_abort("Verification dates at time step %d of %s and %s differ!", otsID + 1, cdo_get_stream_name(1),
+                  cdo_get_stream_name(2));
+
+      for (int fieldID = 0; fieldID < numFields; ++fieldID)
       {
-        auto numFields = cdo_stream_inq_timestep(streamID2, otsID);
-        if (numFields != cdo_stream_inq_timestep(streamID3, otsID))
-          cdo_abort("Number of fields at time step %d of %s and %s differ!", otsID + 1, cdo_get_stream_name(1),
-                    cdo_get_stream_name(2));
+        {
+          auto [varID, levelID] = cdo_inq_field(streamID2);
+          field1.init(varList1.vars[varID]);
+          cdo_read_field(streamID2, field1);
+        }
 
-        auto vDateTime2 = taxisInqVdatetime(taxisID2);
-        auto vDateTime3 = taxisInqVdatetime(taxisID3);
-        if (cdiDateTime_isNE(vDateTime2, vDateTime3))
-          cdo_abort("Verification dates at time step %d of %s and %s differ!", otsID + 1, cdo_get_stream_name(1),
-                    cdo_get_stream_name(2));
+        auto [varID, levelID] = cdo_inq_field(streamID3);
+        field2.init(varList1.vars[varID]);
+        cdo_read_field(streamID3, field2);
 
-        for (int fieldID = 0; fieldID < numFields; ++fieldID)
-          {
-            {
-              auto [varID, levelID] = cdo_inq_field(streamID2);
-              field1.init(varList1.vars[varID]);
-              cdo_read_field(streamID2, field1);
-            }
-
-            auto [varID, levelID] = cdo_inq_field(streamID3);
-            field2.init(varList1.vars[varID]);
-            cdo_read_field(streamID3, field2);
-
-            hset.defVarLevelBounds(varID, levelID, field1, field2);
-          }
-
-        int numSets = 0;
-        if (numFields)
-          for (numSets = 0; numSets < ndates; numSets++)
-            {
-              numFields = cdo_stream_inq_timestep(streamID1, tsID);
-              if (numFields == 0) break;
-
-              dtlist.taxis_inq_timestep(taxisID1, numSets);
-
-              for (int fieldID = 0; fieldID < numFields; ++fieldID)
-                {
-                  auto [varID, levelID] = cdo_inq_field(streamID1);
-
-                  if (tsID == 0) fieldInfoList[fieldID].set(varID, levelID);
-
-                  const auto &var1 = varList1.vars[varID];
-                  if (tsID == 0 && var1.isConstant)
-                    {
-                      constFields[fieldID].init(var1);
-                      cdo_read_field(streamID1, constFields[fieldID]);
-                    }
-                  else
-                    {
-                      field1.init(var1);
-                      cdo_read_field(streamID1, field1);
-
-                      hset.addVarLevelValues(varID, levelID, field1);
-                    }
-                }
-
-              tsID++;
-            }
-
-        if (numFields == 0 && numSets == 0) break;
-
-        dtlist.stat_taxis_def_timestep(taxisID4, numSets);
-        cdo_def_timestep(streamID4, otsID);
-
-        for (int fieldID = 0; fieldID < maxFields; ++fieldID)
-          {
-            auto [varID, levelID] = fieldInfoList[fieldID].get();
-            const auto &var1 = varList1.vars[varID];
-            if (otsID && var1.isConstant) continue;
-
-            cdo_def_field(streamID4, varID, levelID);
-
-            if (var1.isConstant) { cdo_write_field(streamID4, constFields[fieldID]); }
-            else
-              {
-                field1.init(var1);
-                hset.getVarLevelPercentiles(field1, varID, levelID, pn);
-                cdo_write_field(streamID4, field1);
-              }
-          }
-
-        if (numFields == 0) break;
-        otsID++;
-
-        for (int i = 0; i < nskip; ++i)
-          {
-            numFields = cdo_stream_inq_timestep(streamID1, tsID);
-            if (numFields == 0) break;
-            tsID++;
-          }
-
-        if (numFields == 0) break;
+        hset.defVarLevelBounds(varID, levelID, field1, field2);
       }
+
+      int numSets = 0;
+      if (numFields)
+        for (numSets = 0; numSets < ndates; numSets++)
+        {
+          numFields = cdo_stream_inq_timestep(streamID1, tsID);
+          if (numFields == 0) break;
+
+          dtlist.taxis_inq_timestep(taxisID1, numSets);
+
+          for (int fieldID = 0; fieldID < numFields; ++fieldID)
+          {
+            auto [varID, levelID] = cdo_inq_field(streamID1);
+
+            if (tsID == 0) fieldInfoList[fieldID].set(varID, levelID);
+
+            auto const &var1 = varList1.vars[varID];
+            if (tsID == 0 && var1.isConstant)
+            {
+              constFields[fieldID].init(var1);
+              cdo_read_field(streamID1, constFields[fieldID]);
+            }
+            else
+            {
+              field1.init(var1);
+              cdo_read_field(streamID1, field1);
+
+              hset.addVarLevelValues(varID, levelID, field1);
+            }
+          }
+
+          tsID++;
+        }
+
+      if (numFields == 0 && numSets == 0) break;
+
+      dtlist.stat_taxis_def_timestep(taxisID4, numSets);
+      cdo_def_timestep(streamID4, otsID);
+
+      for (int fieldID = 0; fieldID < maxFields; ++fieldID)
+      {
+        auto [varID, levelID] = fieldInfoList[fieldID].get();
+        auto const &var1 = varList1.vars[varID];
+        if (otsID && var1.isConstant) continue;
+
+        cdo_def_field(streamID4, varID, levelID);
+
+        if (var1.isConstant) { cdo_write_field(streamID4, constFields[fieldID]); }
+        else
+        {
+          field1.init(var1);
+          hset.getVarLevelPercentiles(field1, varID, levelID, pn);
+          cdo_write_field(streamID4, field1);
+        }
+      }
+
+      if (numFields == 0) break;
+      otsID++;
+
+      for (int i = 0; i < nskip; ++i)
+      {
+        numFields = cdo_stream_inq_timestep(streamID1, tsID);
+        if (numFields == 0) break;
+        tsID++;
+      }
+
+      if (numFields == 0) break;
+    }
   }
 
   void
