@@ -55,22 +55,22 @@ public:
   inline static RegisterEntry<Timselstat> registration = RegisterEntry<Timselstat>(module);
 
 private:
-  CdoStreamID streamID1;
-  CdoStreamID streamID2;
-  int taxisID1;
-  int taxisID2;
+  CdoStreamID streamID1{};
+  CdoStreamID streamID2{};
+  int taxisID1{ CDI_UNDEFID };
+  int taxisID2{ CDI_UNDEFID };
 
-  int noffset;
-  int ndates;
-  int nskip;
+  int noffset{};
+  int ndates{};
+  int nskip{};
 
-  int maxFields;
+  int maxFields{};
 
-  cdo::StepStat2D stepStat;
+  cdo::StepStat2D stepStat{};
 
-  std::vector<FieldInfo> fieldInfoList;
-  DateTimeList dtlist;
-  VarList varList1;
+  std::vector<FieldInfo> fieldInfoList{};
+  DateTimeList dtlist{};
+  VarList varList1{};
 
 public:
   void
@@ -124,17 +124,17 @@ public:
   skip_noffset_steps(int &tsID)
   {
     for (tsID = 0; tsID < noffset; ++tsID)
+    {
+      auto numFields = cdo_stream_inq_timestep(streamID1, tsID);
+      if (numFields == 0) break;
+
+      for (int fieldID = 0; fieldID < numFields; ++fieldID)
       {
-        auto numFields = cdo_stream_inq_timestep(streamID1, tsID);
-        if (numFields == 0) break;
+        auto [varID, levelID] = cdo_inq_field(streamID1);
 
-        for (int fieldID = 0; fieldID < numFields; ++fieldID)
-          {
-            auto [varID, levelID] = cdo_inq_field(streamID1);
-
-            if (tsID == 0) fieldInfoList[fieldID].set(varID, levelID);
-          }
+        if (tsID == 0) fieldInfoList[fieldID].set(varID, levelID);
       }
+    }
 
     if (tsID < noffset) { cdo_abort("noffset is larger than number of timesteps!"); }
   }
@@ -143,11 +143,11 @@ public:
   skip_nskip_steps(int &tsID, int &numFields)
   {
     for (int i = 0; i < nskip; ++i)
-      {
-        numFields = cdo_stream_inq_timestep(streamID1, tsID);
-        if (numFields == 0) break;
-        tsID++;
-      }
+    {
+      numFields = cdo_stream_inq_timestep(streamID1, tsID);
+      if (numFields == 0) break;
+      tsID++;
+    }
   }
 
   void
@@ -159,10 +159,10 @@ public:
     cdo::Progress progress(get_id());
 
     if (nskip == -1)
-      {
-        int VARS_MEMTYPE = stepStat.lminmax ? FIELD_NAT : 0;
-        field2D_init(lastData, varList1, FIELD_VEC | VARS_MEMTYPE);
-      }
+    {
+      int VARS_MEMTYPE = stepStat.lminmax ? FIELD_NAT : 0;
+      field2D_init(lastData, varList1, FIELD_VEC | VARS_MEMTYPE);
+    }
 
     int tsID;
     skip_noffset_steps(tsID);
@@ -170,67 +170,67 @@ public:
     int otsID = 0;
 
     while (true)
+    {
+      int numSetsStart{ 0 };
+      if (nskip == -1 && otsID > 0)
       {
-        int numSetsStart{ 0 };
-        if (nskip == -1 && otsID > 0)
+        numSetsStart = 1;
+        for (int varID = 0; varID < varList1.numVars(); ++varID)
+        {
+          for (int levelID = 0; levelID < varList1.vars[varID].nlevels; ++levelID)
           {
-            numSetsStart = 1;
-            for (int varID = 0; varID < varList1.numVars(); ++varID)
-              {
-                for (int levelID = 0; levelID < varList1.vars[varID].nlevels; ++levelID)
-                  {
-                    stepStat.add_field(lastData[varID][levelID], varID, levelID, 0);
-                  }
-              }
+            stepStat.add_field(lastData[varID][levelID], varID, levelID, 0);
           }
-
-        int numFields{ 0 };
-        int numSets{ 0 };
-        for (numSets = numSetsStart; numSets < ndates; numSets++)
-          {
-            numFields = cdo_stream_inq_timestep(streamID1, tsID);
-            if (numFields == 0) break;
-
-            if (numSteps > 1) progress.update((tsID + 1.0) / numSteps);
-
-            dtlist.taxis_inq_timestep(taxisID1, numSets);
-
-            for (int fieldID = 0; fieldID < numFields; ++fieldID)
-              {
-                auto [varID, levelID] = cdo_inq_field(streamID1);
-                if (tsID == 0) fieldInfoList[fieldID].set(varID, levelID);
-                field.init(varList1.vars[varID]);
-                cdo_read_field(streamID1, field);
-                stepStat.add_field(field, varID, levelID, numSets);
-                if (nskip == -1 && numSets == (ndates - 1)) { field_copy(field, lastData[varID][levelID]); }
-              }
-
-            tsID++;
-          }
-
-        if (numFields == 0 && numSets == 0) break;
-        if (numFields == 0 && numSets == 1 && nskip == -1) break;
-
-        cdo::fields_process(fieldInfoList, varList1, stepStat, numSets);
-
-        dtlist.stat_taxis_def_timestep(taxisID2, numSets);
-        cdo::write_out_stream(streamID2, fieldInfoList, varList1, stepStat, otsID);
-
-        if (numSets < ndates)
-          {
-            cdo_warning("Last output step %d contains only %d of %d input time step%s!", otsID + 1, numSets, ndates,
-                        (numSets == 1) ? "" : "s");
-            break;
-          }
-
-        if (numFields == 0) break;
-        otsID++;
-
-        skip_nskip_steps(tsID, numFields);
-
-        if (numFields == 0) break;
+        }
       }
 
+      int numFields{ 0 };
+      int numSets{ 0 };
+      for (numSets = numSetsStart; numSets < ndates; numSets++)
+      {
+        numFields = cdo_stream_inq_timestep(streamID1, tsID);
+        if (numFields == 0) break;
+
+        if (numSteps > 1) progress.update((tsID + 1.0) / numSteps);
+
+        dtlist.taxis_inq_timestep(taxisID1, numSets);
+
+        for (int fieldID = 0; fieldID < numFields; ++fieldID)
+        {
+          auto [varID, levelID] = cdo_inq_field(streamID1);
+          if (tsID == 0) fieldInfoList[fieldID].set(varID, levelID);
+          field.init(varList1.vars[varID]);
+          cdo_read_field(streamID1, field);
+          stepStat.add_field(field, varID, levelID, numSets);
+          if (nskip == -1 && numSets == (ndates - 1)) { field_copy(field, lastData[varID][levelID]); }
+        }
+
+        tsID++;
+      }
+
+      if (numFields == 0 && numSets == 0) break;
+      if (numFields == 0 && numSets == 1 && nskip == -1) break;
+
+      cdo::fields_process(fieldInfoList, varList1, stepStat, numSets);
+
+      dtlist.stat_taxis_def_timestep(taxisID2, numSets);
+      cdo::write_out_stream(streamID2, fieldInfoList, varList1, stepStat, otsID);
+
+      if (numSets < ndates)
+      {
+        cdo_warning("Last output step %d contains only %d of %d input time step%s!", otsID + 1, numSets, ndates,
+                    (numSets == 1) ? "" : "s");
+        break;
+      }
+
+      if (numFields == 0) break;
+      otsID++;
+
+      skip_nskip_steps(tsID, numFields);
+
+      if (numFields == 0) break;
+    }
+
     if (otsID == 0) cdo_abort("No output step found!");
   }
 
