@@ -28,9 +28,10 @@ varquot2test(double rconst, double risk, size_t gridsize, double missval, Varray
   auto missval1 = missval;
   auto missval2 = missval;
 
-  auto varquot2test_kernel = [&](auto i, auto is_EQ) {
-    auto temp0 = DIVM(MULM(work[0][i], work[0][i]), work[2][i]);
-    auto temp1 = DIVM(MULM(work[3][i], work[3][i]), work[5][i]);
+  auto varquot2test_kernel = [&](auto i, auto is_EQ)
+  {
+    auto temp0 = DIVMX(MULM(work[0][i], work[0][i]), work[2][i]);
+    auto temp1 = DIVMX(MULM(work[3][i], work[3][i]), work[5][i]);
     auto temp2 = SUBM(work[1][i], temp0);
     auto temp3 = SUBM(work[4][i], temp1);
     auto statistic = DIVM(temp2, ADDM(temp2, MULM(rconst, temp3)));
@@ -61,26 +62,27 @@ meandiff2test(double rconst, double risk, size_t gridsize, double missval, Varra
   auto missval1 = missval;
   auto missval2 = missval;
 
-  auto meandiff2test_kernel = [&](auto i, auto is_EQ) {
+  auto meandiff2test_kernel = [&](auto i, auto is_EQ)
+  {
     double temp0 = 0.0;
     double degOfFreedom = -NIN;
-    auto tmp = DIVM(MULM(work[0][i], work[0][i]), work[2][i]);
-    temp0 = ADDM(temp0, DIVM(SUBM(work[1][i], tmp), varFactor[0]));
+    auto tmp = DIVMX(MULM(work[0][i], work[0][i]), work[2][i]);
+    temp0 = ADDM(temp0, DIVMX(SUBM(work[1][i], tmp), varFactor[0]));
     degOfFreedom = ADDM(degOfFreedom, work[2][i]);
-    tmp = DIVM(MULM(work[3][i], work[3][i]), work[5][i]);
-    temp0 = ADDM(temp0, DIVM(SUBM(work[4][i], tmp), varFactor[1]));
+    tmp = DIVMX(MULM(work[3][i], work[3][i]), work[5][i]);
+    temp0 = ADDM(temp0, DIVMX(SUBM(work[4][i], tmp), varFactor[1]));
     degOfFreedom = ADDM(degOfFreedom, work[5][i]);
 
     if (fp_is_not_equal(temp0, missval1) && temp0 < 0) temp0 = 0;  // This is possible because of rounding errors
 
-    auto stddevEstimator = SQRTM(DIVM(temp0, degOfFreedom));
+    auto stddevEstimator = SQRTM(DIVMX(temp0, degOfFreedom));
     auto meanEstimator = -rconst;
-    meanEstimator = ADDM(meanEstimator, MULM(meanFactor[0], DIVM(work[0][i], work[2][i])));
-    meanEstimator = ADDM(meanEstimator, MULM(meanFactor[1], DIVM(work[3][i], work[5][i])));
+    meanEstimator = ADDM(meanEstimator, MULM(meanFactor[0], DIVMX(work[0][i], work[2][i])));
+    meanEstimator = ADDM(meanEstimator, MULM(meanFactor[1], DIVMX(work[3][i], work[5][i])));
 
     double temp1 = 0.0;
-    temp1 = ADDM(temp1, DIVM(factor1, work[2][i]));
-    temp1 = ADDM(temp1, DIVM(factor2, work[5][i]));
+    temp1 = ADDM(temp1, DIVMX(factor1, work[2][i]));
+    temp1 = ADDM(temp1, DIVMX(factor2, work[5][i]));
     auto norm = SQRTM(temp1);
 
     auto temp2 = DIVM(DIVM(meanEstimator, norm), stddevEstimator);
@@ -115,7 +117,7 @@ public:
 
   CdoStreamID streamID[NIN];
   CdoStreamID streamID3;
-  int taxisID1;
+  int taxisID1{ CDI_UNDEFID };
   int taxisID3;
 
   double rconst;
@@ -175,87 +177,87 @@ public:
     Varray4D<double> work(numVars);
 
     for (int varID = 0; varID < numVars; ++varID)
+    {
+      auto const &var = varList1.vars[varID];
+      auto gridsize = var.gridsize;
+      auto numLevels = var.nlevels;
+
+      work[varID].resize(numLevels);
+
+      for (int levelID = 0; levelID < numLevels; ++levelID)
       {
-        auto const &var = varList1.vars[varID];
-        auto gridsize = var.gridsize;
-        auto numLevels = var.nlevels;
-
-        work[varID].resize(numLevels);
-
-        for (int levelID = 0; levelID < numLevels; ++levelID)
-          {
-            work[varID][levelID].resize(NWORK);
-            for (int iw = 0; iw < NWORK; ++iw) work[varID][levelID][iw].resize(gridsize, 0);
-          }
+        work[varID][levelID].resize(NWORK);
+        for (int iw = 0; iw < NWORK; ++iw) work[varID][levelID][iw].resize(gridsize, 0);
       }
+    }
 
     int tsID = 0;
     while (true)
+    {
+      int is;
+      for (is = 0; is < NIN; ++is)
       {
-        int is;
-        for (is = 0; is < NIN; ++is)
+        if (reachedEOF[is]) continue;
+
+        auto numFields = cdo_stream_inq_timestep(streamID[is], tsID);
+        if (numFields == 0)
+        {
+          reachedEOF[is] = 1;
+          continue;
+        }
+
+        vDateTime = taxisInqVdatetime(taxisID1);
+
+        for (int fieldID = 0; fieldID < numFields; ++fieldID)
+        {
+          auto [varID, levelID] = cdo_inq_field(streamID[is]);
+
+          if (tsID == 0 && is == 0) fieldInfoList[fieldID].set(varID, levelID);
+
+          auto const &var = varList1.vars[varID];
+          inField.init(var);
+          cdo_read_field(streamID[is], inField);
+
+          auto const &inArray = inField.vec_d;
+          auto &rwork1 = work[varID][levelID][3 * is + 0];
+          auto &rwork2 = work[varID][levelID][3 * is + 1];
+          auto &rwork3 = work[varID][levelID][3 * is + 2];
+          auto gridsize = var.gridsize;
+          for (size_t i = 0; i < gridsize; ++i)
           {
-            if (reachedEOF[is]) continue;
-
-            auto numFields = cdo_stream_inq_timestep(streamID[is], tsID);
-            if (numFields == 0)
-              {
-                reachedEOF[is] = 1;
-                continue;
-              }
-
-            vDateTime = taxisInqVdatetime(taxisID1);
-
-            for (int fieldID = 0; fieldID < numFields; ++fieldID)
-              {
-                auto [varID, levelID] = cdo_inq_field(streamID[is]);
-
-                if (tsID == 0 && is == 0) fieldInfoList[fieldID].set(varID, levelID);
-
-                auto const &var = varList1.vars[varID];
-                inField.init(var);
-                cdo_read_field(streamID[is], inField);
-
-                auto const &inArray = inField.vec_d;
-                auto &rwork1 = work[varID][levelID][3 * is + 0];
-                auto &rwork2 = work[varID][levelID][3 * is + 1];
-                auto &rwork3 = work[varID][levelID][3 * is + 2];
-                auto gridsize = var.gridsize;
-                for (size_t i = 0; i < gridsize; ++i)
-                  {
-                    rwork1[i] += inArray[i];
-                    rwork2[i] += inArray[i] * inArray[i];
-                    rwork3[i]++;
-                  }
-              }
+            rwork1[i] += inArray[i];
+            rwork2[i] += inArray[i] * inArray[i];
+            rwork3[i]++;
           }
-
-        for (is = 0; is < NIN; ++is)
-          if (not reachedEOF[is]) break;
-
-        if (is == NIN) break;
-
-        tsID++;
+        }
       }
 
+      for (is = 0; is < NIN; ++is)
+        if (not reachedEOF[is]) break;
+
+      if (is == NIN) break;
+
+      tsID++;
+    }
+
     taxisDefVdatetime(taxisID3, vDateTime);
     cdo_def_timestep(streamID3, 0);
 
     for (int fieldID = 0; fieldID < maxFields; ++fieldID)
-      {
-        auto [varID, levelID] = fieldInfoList[fieldID].get();
+    {
+      auto [varID, levelID] = fieldInfoList[fieldID].get();
 
-        auto const &var = varList1.vars[varID];
-        outField.init(var);
-        auto const &rwork = work[varID][levelID];
+      auto const &var = varList1.vars[varID];
+      outField.init(var);
+      auto const &rwork = work[varID][levelID];
 
-        if (operatorID == VARQUOT2TEST) { varquot2test(rconst, risk, var.gridsize, var.missval, rwork, outField.vec_d); }
-        else if (operatorID == MEANDIFF2TEST) { meandiff2test(rconst, risk, var.gridsize, var.missval, rwork, outField.vec_d); }
+      if (operatorID == VARQUOT2TEST) { varquot2test(rconst, risk, var.gridsize, var.missval, rwork, outField.vec_d); }
+      else if (operatorID == MEANDIFF2TEST) { meandiff2test(rconst, risk, var.gridsize, var.missval, rwork, outField.vec_d); }
 
-        field_num_mv(outField);
-        cdo_def_field(streamID3, varID, levelID);
-        cdo_write_field(streamID3, outField);
-      }
+      field_num_mv(outField);
+      cdo_def_field(streamID3, varID, levelID);
+      cdo_write_field(streamID3, outField);
+    }
   }
 
   void
