@@ -25,34 +25,33 @@
 #include "param_conversion.h"
 #include "progress.h"
 #include "field_functions.h"
-#include "arithmetic.h"
 
 static void
 get_parameter(bool &tstepIsEqual)
 {
-  auto pargc = cdo_operator_argc();
-  if (pargc)
+  auto numArgs = cdo_operator_argc();
+  if (numArgs)
+  {
+    auto const &argList = cdo_get_oper_argv();
+
+    KVList kvlist;
+    kvlist.name = cdo_module_name();
+    if (kvlist.parse_arguments(argList) != 0) cdo_abort("Parse error!");
+    if (Options::cdoVerbose) kvlist.print();
+
+    for (auto const &kv : kvlist)
     {
-      const auto &pargv = cdo_get_oper_argv();
+      auto const &key = kv.key;
+      if (kv.nvalues > 1) cdo_abort("Too many values for parameter key >%s<!", key);
+      if (kv.nvalues < 1) cdo_abort("Missing value for parameter key >%s<!", key);
+      auto const &value = kv.values[0];
 
-      KVList kvlist;
-      kvlist.name = cdo_module_name();
-      if (kvlist.parse_arguments(pargv) != 0) cdo_abort("Parse error!");
-      if (Options::cdoVerbose) kvlist.print();
-
-      for (const auto &kv : kvlist)
-        {
-          const auto &key = kv.key;
-          if (kv.nvalues > 1) cdo_abort("Too many values for parameter key >%s<!", key);
-          if (kv.nvalues < 1) cdo_abort("Missing value for parameter key >%s<!", key);
-          const auto &value = kv.values[0];
-
-          // clang-format off
-          if (key == "equal") tstepIsEqual = parameter_to_bool(value);
-          else cdo_abort("Invalid parameter key >%s<!", key);
-          // clang-format on
-        }
+      // clang-format off
+      if (key == "equal") tstepIsEqual = parameter_to_bool(value);
+      else cdo_abort("Invalid parameter key >%s<!", key);
+      // clang-format on
     }
+  }
 }
 
 class Trend : public Process
@@ -71,19 +70,19 @@ public:
 
   static const int numWork = 5;
 
-  CdoStreamID streamID1;
-  CdoStreamID streamID2;
-  CdoStreamID streamID3;
+  CdoStreamID streamID1{};
+  CdoStreamID streamID2{};
+  CdoStreamID streamID3{};
 
-  int taxisID1;
-  int taxisID2;
+  int taxisID1{ CDI_UNDEFID };
+  int taxisID2{ CDI_UNDEFID };
 
-  int maxFields;
+  int maxFields{};
 
   bool tstepIsEqual = true;
 
-  VarList varList1;
-  VarList varList2;
+  VarList varList1{};
+  VarList varList2{};
   std::vector<FieldInfo> fieldInfoList;
 
 public:
@@ -123,7 +122,7 @@ public:
   }
 
   void
-  write_output(const FieldVector3D &work)
+  write_output(FieldVector3D const &work)
   {
     Field field2, field3;
 
@@ -131,24 +130,24 @@ public:
     cdo_def_timestep(streamID3, 0);
 
     for (int fieldID = 0; fieldID < maxFields; ++fieldID)
-      {
-        auto [varID, levelID] = fieldInfoList[fieldID].get();
+    {
+      auto [varID, levelID] = fieldInfoList[fieldID].get();
 
-        const auto &var = varList2.vars[varID];
-        field2.init(var);
-        field3.init(var);
+      auto const &var = varList2.vars[varID];
+      field2.init(var);
+      field3.init(var);
 
-        calc_trend_param(work, field2, field3, varID, levelID);
+      calc_trend_param(work, field2, field3, varID, levelID);
 
-        field_num_mv(field2);
-        field_num_mv(field3);
+      field_num_mv(field2);
+      field_num_mv(field3);
 
-        cdo_def_field(streamID2, varID, levelID);
-        cdo_write_field(streamID2, field2);
+      cdo_def_field(streamID2, varID, levelID);
+      cdo_write_field(streamID2, field2);
 
-        cdo_def_field(streamID3, varID, levelID);
-        cdo_write_field(streamID3, field3);
-      }
+      cdo_def_field(streamID3, varID, levelID);
+      cdo_write_field(streamID3, field3);
+    }
   }
 
   void
@@ -168,44 +167,44 @@ public:
 
     int tsID = 0;
     while (true)
+    {
+      auto numFields = cdo_stream_inq_timestep(streamID1, tsID);
+      if (numFields == 0) break;
+
+      vDateTime = taxisInqVdatetime(taxisID1);
+
+      if (tstepIsEqual) check_time_increment(tsID, calendar, vDateTime, checkTimeIncr);
+      auto zj = tstepIsEqual ? (double) tsID : delta_time_step_0(tsID, calendar, vDateTime, julianDate0, deltat1);
+
+      for (int fieldID = 0; fieldID < numFields; ++fieldID)
       {
-        auto numFields = cdo_stream_inq_timestep(streamID1, tsID);
-        if (numFields == 0) break;
+        auto fstatus = (tsID + (fieldID + 1.0) / numFields) / numSteps;
+        if (numSteps > 0) progress.update(fstatus);
 
-        vDateTime = taxisInqVdatetime(taxisID1);
+        auto [varID, levelID] = cdo_inq_field(streamID1);
+        fieldInfoList[fieldID].set(varID, levelID);
+        field1.init(varList1.vars[varID]);
+        cdo_read_field(streamID1, field1);
 
-        if (tstepIsEqual) check_time_increment(tsID, calendar, vDateTime, checkTimeIncr);
-        auto zj = tstepIsEqual ? (double) tsID : delta_time_step_0(tsID, calendar, vDateTime, julianDate0, deltat1);
-
-        for (int fieldID = 0; fieldID < numFields; ++fieldID)
-          {
-            auto fstatus = (tsID + (fieldID + 1.0) / numFields) / numSteps;
-            if (numSteps > 0) progress.update(fstatus);
-
-            auto [varID, levelID] = cdo_inq_field(streamID1);
-            fieldInfoList[fieldID].set(varID, levelID);
-            field1.init(varList1.vars[varID]);
-            cdo_read_field(streamID1, field1);
-
-            calc_trend_sum(work, field1, zj, varID, levelID);
-          }
-
-        tsID++;
+        calc_trend_sum(work, field1, zj, varID, levelID);
       }
 
+      tsID++;
+    }
+
     taxisDefVdatetime(taxisID2, vDateTime);
     write_output(work);
   }
 
   static void
-  fields_calc_trend_sum(FieldVector3D &work, const FieldVector2D &fields2D, const std::vector<FieldInfo> &fieldInfoList,
+  fields_calc_trend_sum(FieldVector3D &work, FieldVector2D const &fields2D, std::vector<FieldInfo> const &fieldInfoList,
                         double zj) noexcept
   {
-    for (const auto &fieldInfo : fieldInfoList)
-      {
-        auto [varID, levelID] = fieldInfo.get();
-        calc_trend_sum(work, fields2D[varID][levelID], zj, varID, levelID);
-      }
+    for (auto const &fieldInfo : fieldInfoList)
+    {
+      auto [varID, levelID] = fieldInfo.get();
+      calc_trend_sum(work, fields2D[varID][levelID], zj, varID, levelID);
+    }
   }
 
   void
@@ -227,41 +226,41 @@ public:
     field2D_init(fields3D[1], varList1, FIELD_VEC | FIELD_NAT);
 
     bool useTask = true;
-    auto task = useTask ? std::make_unique<WorkerThread>() : nullptr;
+    auto workerThread = useTask ? std::make_unique<WorkerThread>() : nullptr;
 
     int tsID = 0;
     while (true)
+    {
+      auto numFields = cdo_stream_inq_timestep(streamID1, tsID);
+      if (numFields == 0) break;
+
+      vDateTime = taxisInqVdatetime(taxisID1);
+
+      if (tstepIsEqual) check_time_increment(tsID, calendar, vDateTime, checkTimeIncr);
+      auto zj = tstepIsEqual ? (double) tsID : delta_time_step_0(tsID, calendar, vDateTime, julianDate0, deltat1);
+
+      for (int fieldID = 0; fieldID < numFields; ++fieldID)
       {
-        auto numFields = cdo_stream_inq_timestep(streamID1, tsID);
-        if (numFields == 0) break;
+        auto fstatus = (tsID + (fieldID + 1.0) / numFields) / numSteps;
+        if (numSteps > 0) progress.update(fstatus);
 
-        vDateTime = taxisInqVdatetime(taxisID1);
-
-        if (tstepIsEqual) check_time_increment(tsID, calendar, vDateTime, checkTimeIncr);
-        auto zj = tstepIsEqual ? (double) tsID : delta_time_step_0(tsID, calendar, vDateTime, julianDate0, deltat1);
-
-        for (int fieldID = 0; fieldID < numFields; ++fieldID)
-          {
-            auto fstatus = (tsID + (fieldID + 1.0) / numFields) / numSteps;
-            if (numSteps > 0) progress.update(fstatus);
-
-            auto [varID, levelID] = cdo_inq_field(streamID1);
-            fieldInfoList[fieldID].set(varID, levelID);
-            cdo_read_field(streamID1, fields3D[tsID % 2][varID][levelID]);
-          }
-
-        if (useTask && tsID > 0) task->wait();
-
-        std::function<void()> fields_calc_trend_sum_func
-            = std::bind(fields_calc_trend_sum, std::ref(work), std::ref(fields3D[tsID % 2]), std::cref(fieldInfoList), zj);
-
-        if (useTask) { task->doAsync(fields_calc_trend_sum_func); }
-        else { fields_calc_trend_sum_func(); }
-
-        tsID++;
+        auto [varID, levelID] = cdo_inq_field(streamID1);
+        fieldInfoList[fieldID].set(varID, levelID);
+        cdo_read_field(streamID1, fields3D[tsID % 2][varID][levelID]);
       }
 
-    if (useTask) task->wait();
+      if (useTask && tsID > 0) workerThread->wait();
+
+      std::function<void()> fields_calc_trend_sum_task
+          = std::bind(fields_calc_trend_sum, std::ref(work), std::ref(fields3D[tsID % 2]), std::cref(fieldInfoList), zj);
+
+      if (useTask) { workerThread->doAsync(fields_calc_trend_sum_task); }
+      else { fields_calc_trend_sum_task(); }
+
+      tsID++;
+    }
+
+    if (useTask) workerThread->wait();
 
     taxisDefVdatetime(taxisID2, vDateTime);
     write_output(work);
