@@ -38,10 +38,10 @@ random_init(int operatorID)
   if (cdo_operator_argc() > 2) cdo_abort("Too many arguments!");
   auto gridID = cdo_define_grid(cdo_operator_argv(0));
   if (cdo_operator_argc() == 2)
-    {
-      auto idum = parameter_to_int(cdo_operator_argv(1));
-      if (idum >= 0 && idum < 0x7FFFFFFF) seed = idum;
-    }
+  {
+    auto idum = parameter_to_int(cdo_operator_argv(1));
+    if (idum >= 0 && idum < 0x7FFFFFFF) seed = idum;
+  }
   std::srand(seed);
   return gridID;
 }
@@ -63,10 +63,10 @@ conv_generic_grid(int gridID, size_t gridsize, Varray<double> &xvals2D, Varray<d
 
   for (size_t j = 0; j < ysize; ++j)
     for (size_t i = 0; i < xsize; ++i)
-      {
-        xvals2D[j * xsize + i] = xcoord[i] * M_PI / xrange;
-        yvals2D[j * xsize + i] = ycoord[j] * M_PI / yrange;
-      }
+    {
+      xvals2D[j * xsize + i] = xcoord[i] * M_PI / xrange;
+      yvals2D[j * xsize + i] = ycoord[j] * M_PI / yrange;
+    }
 }
 
 static int
@@ -104,7 +104,7 @@ calc_index_jj(size_t ny, double yval)
 }
 
 static void
-remap_nn_reg2d_to_reg2d(size_t nx, size_t ny, const Varray<float> &data, int gridID, Varray<float> &array)
+remap_nn_reg2d_to_reg2d(size_t nx, size_t ny, Varray<float> const &data, int gridID, Varray<float> &array)
 {
   auto gridtype = gridInqType(gridID);
   if (gridtype != GRID_LONLAT && gridtype != GRID_GAUSSIAN) cdo_abort("Internal error, wrong grid type!");
@@ -124,18 +124,18 @@ remap_nn_reg2d_to_reg2d(size_t nx, size_t ny, const Varray<float> &data, int gri
 #pragma omp parallel for default(shared) schedule(static)
 #endif
   for (size_t j = 0; j < nyvals; ++j)
+  {
+    auto jj = calc_index_jj(ny, yvals[j]);
+    for (size_t i = 0; i < nxvals; ++i)
     {
-      auto jj = calc_index_jj(ny, yvals[j]);
-      for (size_t i = 0; i < nxvals; ++i)
-        {
-          auto ii = calc_index_ii(nx, xvals[i]);
-          array[j * nxvals + i] = data[jj * nx + ii];
-        }
+      auto ii = calc_index_ii(nx, xvals[i]);
+      array[j * nxvals + i] = data[jj * nx + ii];
     }
+  }
 }
 
 static void
-remap_nn_reg2d_to_nonreg2d(size_t nx, size_t ny, const Varray<float> &data, int gridID, Varray<float> &array)
+remap_nn_reg2d_to_nonreg2d(size_t nx, size_t ny, Varray<float> const &data, int gridID, Varray<float> &array)
 {
   auto gridsize = gridInqSize(gridID);
   Varray<double> xvals(gridsize), yvals(gridsize);
@@ -154,17 +154,17 @@ remap_nn_reg2d_to_nonreg2d(size_t nx, size_t ny, const Varray<float> &data, int
 #pragma omp parallel for default(shared) schedule(static)
 #endif
   for (size_t i = 0; i < gridsize; ++i)
-    {
-      auto jj = calc_index_jj(ny, yvals[i]);
-      auto ii = calc_index_ii(nx, xvals[i]);
-      array[i] = data[jj * nx + ii];
-    }
+  {
+    auto jj = calc_index_jj(ny, yvals[i]);
+    auto ii = calc_index_ii(nx, xvals[i]);
+    array[i] = data[jj * nx + ii];
+  }
 
   if (gridID != gridID2) gridDestroy(gridID2);
 }
 
 static void
-remap_nn_reg2d_to_healpix(size_t nx, size_t ny, const Varray<float> &data, int gridID, Varray<float> &array)
+remap_nn_reg2d_to_healpix(size_t nx, size_t ny, Varray<float> const &data, int gridID, Varray<float> &array)
 {
   auto gridID2 = gridID;
   auto gridsize = gridInqSize(gridID2);
@@ -174,17 +174,17 @@ remap_nn_reg2d_to_healpix(size_t nx, size_t ny, const Varray<float> &data, int g
 #pragma omp parallel for default(shared) schedule(static)
 #endif
   for (size_t i = 0; i < gridsize; ++i)
-    {
-      double xval, yval;
-      hp_index_to_lonlat(hpParams, i, &xval, &yval);
-      auto jj = calc_index_jj(ny, yval * RAD2DEG);
-      auto ii = calc_index_ii(nx, xval * RAD2DEG);
-      array[i] = data[jj * nx + ii];
-    }
+  {
+    double xval, yval;
+    hp_index_to_lonlat(hpParams, i, &xval, &yval);
+    auto jj = calc_index_jj(ny, yval * RAD2DEG);
+    auto ii = calc_index_ii(nx, xval * RAD2DEG);
+    array[i] = data[jj * nx + ii];
+  }
 }
 
 static void
-remap_nn_reg2d(size_t nx, size_t ny, const Varray<float> &data, int gridID, Varray<float> &array)
+remap_nn_reg2d(size_t nx, size_t ny, Varray<float> const &data, int gridID, Varray<float> &array)
 {
   auto gridtype = gridInqType(gridID);
   if (gridtype == GRID_LONLAT || gridtype == GRID_GAUSSIAN)
@@ -214,13 +214,13 @@ define_zaxis(bool lstdatm, int nlevels, double *levels)
   int zaxisID = -1;
 
   if (lstdatm)
-    {
-      zaxisID = zaxisCreate(ZAXIS_HEIGHT, nlevels);
-      zaxisDefLevels(zaxisID, levels);
-      cdiDefKeyString(zaxisID, CDI_GLOBAL, CDI_KEY_NAME, "level");
-      cdiDefKeyString(zaxisID, CDI_GLOBAL, CDI_KEY_LONGNAME, "Level");
-      cdiDefKeyString(zaxisID, CDI_GLOBAL, CDI_KEY_UNITS, "m");
-    }
+  {
+    zaxisID = zaxisCreate(ZAXIS_HEIGHT, nlevels);
+    zaxisDefLevels(zaxisID, levels);
+    cdiDefKeyString(zaxisID, CDI_GLOBAL, CDI_KEY_NAME, "level");
+    cdiDefKeyString(zaxisID, CDI_GLOBAL, CDI_KEY_LONGNAME, "Level");
+    cdiDefKeyString(zaxisID, CDI_GLOBAL, CDI_KEY_UNITS, "m");
+  }
   else { zaxisID = zaxis_from_name("surface"); }
 
   return zaxisID;
@@ -275,18 +275,18 @@ public:
 
 private:
   static constexpr size_t nlat = 360, nlon = 720;
-  double lon[nlon], lat[nlat];
+  double lon[nlon]{}, lat[nlat]{};
   int gridID = -1, gridIDdata = -1;
   double rstart = 0.0, rstop = 0.0, rinc = 0.0;
   double rconst = 0.0;
-  std::vector<double> levels;
-  int numSteps;
+  std::vector<double> levels{};
+  int numSteps{};
 
-  int taxisID;
-  CdoStreamID streamID;
-  int varID2;
-  int vlistID;
-  int operatorID;
+  int taxisID{};
+  CdoStreamID streamID{};
+  int varID2{};
+  int vlistID{};
+  int operatorID{};
 
 public:
   void
@@ -310,59 +310,59 @@ public:
 
     if (operatorID == RANDOM) { gridID = random_init(operatorID); }
     else if (operatorID == SINCOS || operatorID == COSHILL || operatorID == TESTFIELD)
-      {
-        operator_input_arg(cdo_operator_enter(operatorID));
-        operator_check_argc(1);
-        gridID = cdo_define_grid(cdo_operator_argv(0));
-      }
+    {
+      operator_input_arg(cdo_operator_enter(operatorID));
+      operator_check_argc(1);
+      gridID = cdo_define_grid(cdo_operator_argv(0));
+    }
     else if (operatorID == CONST)
-      {
-        operator_input_arg(cdo_operator_enter(operatorID));
-        operator_check_argc(2);
-        rconst = parameter_to_double(cdo_operator_argv(0));
-        gridID = cdo_define_grid(cdo_operator_argv(1));
-      }
+    {
+      operator_input_arg(cdo_operator_enter(operatorID));
+      operator_check_argc(2);
+      rconst = parameter_to_double(cdo_operator_argv(0));
+      gridID = cdo_define_grid(cdo_operator_argv(1));
+    }
     else if (operatorID == TOPO || operatorID == TEMP || operatorID == MASK)
-      {
-        gridIDdata = gridCreate(GRID_LONLAT, nlon * nlat);
-        gridDefXsize(gridIDdata, nlon);
-        gridDefYsize(gridIDdata, nlat);
+    {
+      gridIDdata = gridCreate(GRID_LONLAT, nlon * nlat);
+      gridDefXsize(gridIDdata, nlon);
+      gridDefYsize(gridIDdata, nlat);
 
-        for (size_t i = 0; i < nlon; ++i) lon[i] = -179.75 + i * 0.5;
-        for (size_t i = 0; i < nlat; ++i) lat[i] = -89.75 + i * 0.5;
+      for (size_t i = 0; i < nlon; ++i) lon[i] = -179.75 + i * 0.5;
+      for (size_t i = 0; i < nlat; ++i) lat[i] = -89.75 + i * 0.5;
 
-        gridDefXvals(gridIDdata, lon);
-        gridDefYvals(gridIDdata, lat);
+      gridDefXvals(gridIDdata, lon);
+      gridDefYvals(gridIDdata, lat);
 
-        gridID = gridIDdata;
+      gridID = gridIDdata;
 
-        if (cdo_operator_argc() == 1) gridID = cdo_define_grid(cdo_operator_argv(0));
-        if (cdo_operator_argc() > 1) cdo_abort("Too many arguments!");
-      }
+      if (cdo_operator_argc() == 1) gridID = cdo_define_grid(cdo_operator_argv(0));
+      if (cdo_operator_argc() > 1) cdo_abort("Too many arguments!");
+    }
     else if (operatorID == SEQ)
-      {
-        operator_input_arg(cdo_operator_enter(operatorID));
-        if (cdo_operator_argc() < 2) cdo_abort("Too few arguments!");
-        if (cdo_operator_argc() > 3) cdo_abort("Too many arguments!");
+    {
+      operator_input_arg(cdo_operator_enter(operatorID));
+      if (cdo_operator_argc() < 2) cdo_abort("Too few arguments!");
+      if (cdo_operator_argc() > 3) cdo_abort("Too many arguments!");
 
-        rstart = parameter_to_double(cdo_operator_argv(0));
-        rstop = parameter_to_double(cdo_operator_argv(1));
-        rinc = (cdo_operator_argc() == 3) ? parameter_to_double(cdo_operator_argv(2)) : 1;
-        if (fp_is_equal(rinc, 0.0)) cdo_abort("Increment is zero!");
+      rstart = parameter_to_double(cdo_operator_argv(0));
+      rstop = parameter_to_double(cdo_operator_argv(1));
+      rinc = (cdo_operator_argc() == 3) ? parameter_to_double(cdo_operator_argv(2)) : 1;
+      if (fp_is_equal(rinc, 0.0)) cdo_abort("Increment is zero!");
 
-        gridID = define_point_grid();
-      }
+      gridID = define_point_grid();
+    }
     else if (operatorID == STDATM)
-      {
-        operator_input_arg(cdo_operator_enter(operatorID));
-        levels = cdo_argv_to_fltarr(cdo_get_oper_argv());
-        nlevels = levels.size();
+    {
+      operator_input_arg(cdo_operator_enter(operatorID));
+      levels = cdo_argv_to_fltarr(cdo_get_oper_argv());
+      nlevels = levels.size();
 
-        if (Options::cdoVerbose)
-          for (int i = 0; i < nlevels; ++i) printf("levels %d: %g\n", i, levels[i]);
+      if (Options::cdoVerbose)
+        for (int i = 0; i < nlevels; ++i) printf("levels %d: %g\n", i, levels[i]);
 
-        gridID = define_point_grid();
-      }
+      gridID = define_point_grid();
+    }
 
     auto zaxisID = define_zaxis(operatorID == STDATM, nlevels, levels.data());
 
@@ -380,16 +380,16 @@ public:
     if (operatorID == MASK) vlistDefVarDatatype(vlistID, varID, CDI_DATATYPE_INT8);
 
     if (operatorID == STDATM)
-      {
-        define_pressure_attributes(vlistID, varID);
-        define_temperature_attributes(vlistID, varID2);
-      }
+    {
+      define_pressure_attributes(vlistID, varID);
+      define_temperature_attributes(vlistID, varID2);
+    }
     else
-      {
-        cdiDefKeyString(vlistID, varID, CDI_KEY_NAME, cdo_operator_name(operatorID));
-        if (operatorID == TOPO) cdiDefKeyString(vlistID, varID, CDI_KEY_UNITS, "m");
-        if (operatorID == TEMP) cdiDefKeyString(vlistID, varID, CDI_KEY_UNITS, "K");
-      }
+    {
+      cdiDefKeyString(vlistID, varID, CDI_KEY_NAME, cdo_operator_name(operatorID));
+      if (operatorID == TOPO) cdiDefKeyString(vlistID, varID, CDI_KEY_UNITS, "m");
+      if (operatorID == TEMP) cdiDefKeyString(vlistID, varID, CDI_KEY_UNITS, "K");
+    }
 
     taxisID = cdo_taxis_create(TAXIS_RELATIVE);
     vlistDefTaxis(vlistID, taxisID);
@@ -415,59 +415,58 @@ public:
     Varray<float> array(gridsize);
 
     for (int tsID = 0; tsID < numSteps; ++tsID)
+    {
+      auto rval = rstart + rinc * tsID;
+      CdiDateTime vDateTime{};
+      vDateTime.date = cdiDate_set(julday_to_date(CALENDAR_PROLEPTIC, julday + tsID));
+      taxisDefVdatetime(taxisID, vDateTime);
+      cdo_def_timestep(streamID, tsID);
+
+      // this should either be 1 or 2, two for atmosphere
+      for (int varID = 0; varID < varList.numVars(); ++varID)
       {
-        auto rval = rstart + rinc * tsID;
-        CdiDateTime vDateTime{};
-        vDateTime.date = cdiDate_set(julday_to_date(CALENDAR_PROLEPTIC, julday + tsID));
-        taxisDefVdatetime(taxisID, vDateTime);
-        cdo_def_timestep(streamID, tsID);
+        for (int levelID = 0; levelID < varList.vars[varID].nlevels; ++levelID)
+        {
+          cdo_def_field(streamID, varID, levelID);
 
-        // this should either be 1 or 2, two for atmosphere
-        for (int varID = 0; varID < varList.numVars(); ++varID)
+          if (operatorID == RANDOM) { cdo::fill_random(array); }
+          else if (operatorID == SINCOS || operatorID == COSHILL || operatorID == TESTFIELD)
           {
-            for (int levelID = 0; levelID < varList.vars[varID].nlevels; ++levelID)
-              {
-                cdo_def_field(streamID, varID, levelID);
+            Varray<double> xvals(gridsize), yvals(gridsize);
 
-                if (operatorID == RANDOM) { cdo::fill_random(array); }
-                else if (operatorID == SINCOS || operatorID == COSHILL || operatorID == TESTFIELD)
-                  {
-                    Varray<double> xvals(gridsize), yvals(gridsize);
+            if (grid_is_distance_generic(gridID)) { conv_generic_grid(gridID, gridsize, xvals, yvals); }
+            else { gridID = generate_full_point_grid_radian(gridID, xvals, yvals); }
 
-                    if (grid_is_distance_generic(gridID)) { conv_generic_grid(gridID, gridsize, xvals, yvals); }
-                    else { gridID = generate_full_point_grid_radian(gridID, xvals, yvals); }
-
-                    // clang-format off
-                    if      (operatorID == SINCOS)    cdo::fill_sincos(array, xvals, yvals);
-                    else if (operatorID == COSHILL)   cdo::fill_coshill(array, xvals, yvals);
-                    else if (operatorID == TESTFIELD) cdo::fill_testfield(array, xvals, yvals);
-                    // clang-format on
-                  }
-                else if (operatorID == CONST) { ranges::fill(array, rconst); }
-                else if (operatorID == TOPO || operatorID == TEMP || operatorID == MASK)
-                  {
-                    Varray<float> data;
-
-                    // clang-format off
-                    if      (operatorID == TOPO) data = cdo::unpack_data(cdo::topoData);
-                    else if (operatorID == TEMP) data = cdo::unpack_data(cdo::tempData);
-                    else if (operatorID == MASK) data = cdo::unpack_data(cdo::maskData);
-                    // clang-format on
-
-                    if (gridID != gridIDdata && gridIDdata != -1) { remap_nn_reg2d(nlon, nlat, data, gridID, array); }
-                    else { array = data; }
-                  }
-                else if (operatorID == SEQ) { array[0] = rval; }
-                else if (operatorID == STDATM)
-                  {
-                    array[0]
-                        = (varID == varID2) ? cdo::std_atm_temperatur(levels[levelID]) : cdo::std_atm_pressure(levels[levelID]);
-                  }
-
-                cdo_write_field_f(streamID, array.data(), 0);
-              }
+            // clang-format off
+            if      (operatorID == SINCOS)    cdo::fill_sincos(array, xvals, yvals);
+            else if (operatorID == COSHILL)   cdo::fill_coshill(array, xvals, yvals);
+            else if (operatorID == TESTFIELD) cdo::fill_testfield(array, xvals, yvals);
+            // clang-format on
           }
+          else if (operatorID == CONST) { std::ranges::fill(array, rconst); }
+          else if (operatorID == TOPO || operatorID == TEMP || operatorID == MASK)
+          {
+            Varray<float> data;
+
+            // clang-format off
+            if      (operatorID == TOPO) data = cdo::unpack_data(cdo::topoData);
+            else if (operatorID == TEMP) data = cdo::unpack_data(cdo::tempData);
+            else if (operatorID == MASK) data = cdo::unpack_data(cdo::maskData);
+            // clang-format on
+
+            if (gridID != gridIDdata && gridIDdata != -1) { remap_nn_reg2d(nlon, nlat, data, gridID, array); }
+            else { array = data; }
+          }
+          else if (operatorID == SEQ) { array[0] = rval; }
+          else if (operatorID == STDATM)
+          {
+            array[0] = (varID == varID2) ? cdo::std_atm_temperatur(levels[levelID]) : cdo::std_atm_pressure(levels[levelID]);
+          }
+
+          cdo_write_field_f(streamID, array.data(), 0);
+        }
       }
+    }
   }
 
   void
