@@ -47,15 +47,15 @@ cdf_read_att_text(int ncfileid, int ncvarid, const char *name, std::string &text
   nce(nc_inq_attlen(ncfileid, ncvarid, name, &attlen));
 
   if (atttype == NC_CHAR)
-    {
-      char *attbuf = new char[attlen + 1];
+  {
+    char *attbuf = new char[attlen + 1];
 
-      nce(nc_get_att_text(ncfileid, ncvarid, name, attbuf));
-      attbuf[attlen] = 0;
-      text = attbuf;
+    nce(nc_get_att_text(ncfileid, ncvarid, name, attbuf));
+    attbuf[attlen] = 0;
+    text = attbuf;
 
-      delete[] attbuf;
-    }
+    delete[] attbuf;
+  }
 }
 
 static void
@@ -70,19 +70,17 @@ static void
 cdf_read_var_size(int ncfileid, const char *name, size_t len, size_t *array)
 {
   if (len < 0x7FFFFC00)  // 2GB
-    {
-      std::vector<int> iarray(len);
-      cdf_read_var_int(ncfileid, name, iarray.data());
-      for (size_t i = 0; i < len; ++i) array[i] = (size_t) iarray[i];
-    }
-#ifdef HAVE_NETCDF4
+  {
+    std::vector<int> iarray(len);
+    cdf_read_var_int(ncfileid, name, iarray.data());
+    for (size_t i = 0; i < len; ++i) array[i] = (size_t) iarray[i];
+  }
   else
-    {
-      int ncvarid;
-      nce(nc_inq_varid(ncfileid, name, &ncvarid));
-      nce(nc_get_var_ulonglong(ncfileid, ncvarid, (unsigned long long *) array));
-    }
-#endif
+  {
+    int ncvarid;
+    nce(nc_inq_varid(ncfileid, name, &ncvarid));
+    nce(nc_get_var_ulonglong(ncfileid, ncvarid, (unsigned long long *) array));
+  }
 }
 
 static void
@@ -105,12 +103,15 @@ cdf_read_coordinate_radian(int ncfileid, const char *name, Varray<double> &varra
   if (string_to_LonLatUnits(grid_units, name) == LonLatUnits::Deg) grid_to_radian(varray);
 }
 
+namespace
+{
 struct RemapAttributes
 {
   std::string map_name;
   std::string history;
   std::string cdo_version;
 };
+}  // namespace
 
 struct RemapGridW
 {
@@ -180,7 +181,7 @@ remapVarsWInit(RemapMethod mapType, int remapOrder, RemapVarsW &rv)
 }
 
 static NormOpt
-remapGetNormOpt(const std::string &normOptStr)
+remapGetNormOpt(std::string const &normOptStr)
 {
   NormOpt normOpt(NormOpt::NONE);
   // clang-format off
@@ -203,7 +204,7 @@ RemapSwitches get_maptype(int ncfileid);
 KnnParams read_knn_params(int ncfileid);
 
 static void
-read_remapgrid_scrip(int ncfileid, const std::string &prefix, bool lgridarea, RemapGridW &grid)
+read_remapgrid_scrip(int ncfileid, std::string const &prefix, bool lgridarea, RemapGridW &grid)
 {
   // Read all variables of the grid
   cdf_read_var_size(ncfileid, (prefix + "_dims").c_str(), 2, grid.dims);
@@ -213,10 +214,10 @@ read_remapgrid_scrip(int ncfileid, const std::string &prefix, bool lgridarea, Re
   cdf_read_coordinate_radian(ncfileid, (prefix + "_center_lon").c_str(), grid.cell_center_lon);
 
   if (grid.ncorners)
-    {
-      cdf_read_coordinate_radian(ncfileid, (prefix + "_corner_lat").c_str(), grid.cell_corner_lat);
-      cdf_read_coordinate_radian(ncfileid, (prefix + "_corner_lon").c_str(), grid.cell_corner_lon);
-    }
+  {
+    cdf_read_coordinate_radian(ncfileid, (prefix + "_corner_lat").c_str(), grid.cell_corner_lat);
+    cdf_read_coordinate_radian(ncfileid, (prefix + "_corner_lon").c_str(), grid.cell_corner_lon);
+  }
 
   if (lgridarea) cdf_read_var_double(ncfileid, (prefix + "_area").c_str(), grid.cell_area.data());
   cdf_read_var_double(ncfileid, (prefix + "_frac").c_str(), grid.cell_frac.data());
@@ -235,7 +236,7 @@ read_remapweights_scrip(int ncfileid, RemapVarsW &rv)
 }
 
 static RemapSwitches
-readRemapFileScrip(const std::string &remapFile, RemapAttributes &remapAtts, RemapGridW &srcGrid, RemapGridW &tgtGrid,
+readRemapFileScrip(std::string const &remapFile, RemapAttributes &remapAtts, RemapGridW &srcGrid, RemapGridW &tgtGrid,
                    RemapVarsW &rv)
 {
   // The routine reads a NetCDF file to extract remapping info in SCRIP format
@@ -249,10 +250,10 @@ readRemapFileScrip(const std::string &remapFile, RemapAttributes &remapAtts, Rem
   cdf_read_att_text(ncfileid, NC_GLOBAL, "title", remapAtts.map_name);
 
   if (Options::cdoVerbose)
-    {
-      cdo_print("Reading remapping: %s", remapAtts.map_name);
-      cdo_print("From file: %s", remapFile);
-    }
+  {
+    cdo_print("Reading remapping: %s", remapAtts.map_name);
+    cdo_print("From file: %s", remapFile);
+  }
 
   // Map Type
   auto remapSwitches = get_maptype(ncfileid);
@@ -272,13 +273,13 @@ readRemapFileScrip(const std::string &remapFile, RemapAttributes &remapAtts, Rem
   std::string convention;  // character string for output convention
   cdf_read_att_text(ncfileid, NC_GLOBAL, "conventions", convention);
   if (convention != "SCRIP")
-    {
-      cdo_print("convention = %s", convention);
-      if (convention == "NCAR-CSM")
-        cdo_abort("Unsupported file convention: %s!", convention);
-      else
-        cdo_abort("Unknown file convention!");
-    }
+  {
+    cdo_print("convention = %s", convention);
+    if (convention == "NCAR-CSM")
+      cdo_abort("Unsupported file convention: %s!", convention);
+    else
+      cdo_abort("Unknown file convention!");
+  }
 
   // Read some additional global attributes
 
@@ -307,11 +308,11 @@ readRemapFileScrip(const std::string &remapFile, RemapAttributes &remapAtts, Rem
 
   // Allocate address and weight arrays
   if (rv.numLinks > 0)
-    {
-      rv.srcCellIndices.resize(rv.numLinks);
-      rv.tgtCellIndices.resize(rv.numLinks);
-      rv.weights.resize(rv.numWeights * rv.numLinks);
-    }
+  {
+    rv.srcCellIndices.resize(rv.numLinks);
+    rv.tgtCellIndices.resize(rv.numLinks);
+    rv.weights.resize(rv.numWeights * rv.numLinks);
+  }
 
   read_remapgrid_scrip(ncfileid, "src_grid", lgridarea, srcGrid);
   read_remapgrid_scrip(ncfileid, "dst_grid", lgridarea, tgtGrid);
@@ -341,7 +342,7 @@ cdf_def_var(int ncfileid, const char *name, nc_type xtype, int ndims, const int
 }
 
 static void
-cdfWriteAttText(int ncfileid, int ncvarid, const char *name, const std::string &text)
+cdfWriteAttText(int ncfileid, int ncvarid, const char *name, std::string const &text)
 {
   if (text.size()) nce(nc_put_att_text(ncfileid, ncvarid, name, text.size(), text.c_str()));
 }
@@ -364,14 +365,12 @@ cdfWriteVarSize(int ncfileid, int ncvarid, nc_type sizetype, size_t len, size_t
   if (len == 0) return;
 
   if (sizetype == NC_INT)
-    {
-      std::vector<int> iarray(len);
-      for (size_t i = 0; i < len; ++i) iarray[i] = (int) array[i];
-      nce(nc_put_var_int(ncfileid, ncvarid, iarray.data()));
-    }
-#ifdef HAVE_NETCDF4
+  {
+    std::vector<int> iarray(len);
+    for (size_t i = 0; i < len; ++i) iarray[i] = (int) array[i];
+    nce(nc_put_var_int(ncfileid, ncvarid, iarray.data()));
+  }
   else { nce(nc_put_var_ulonglong(ncfileid, ncvarid, (unsigned long long *) array)); }
-#endif
 }
 
 static void
@@ -383,38 +382,34 @@ checkRemapFilesize(const RemapGridW &srcGrid, const RemapGridW &tgtGrid, const R
   size_t filesize = srcGrid.ncells * nele1 + tgtGrid.ncells * nele2 + nlinks * (4 + 4 + rv.numWeights * 8);
 
   if (Options::cdoVerbose)
-    {
-      cdo_print("Number of remap links:       %zu", nlinks);
-      cdo_print("Filesize for remap weights: ~%zu", filesize);
-    }
+  {
+    cdo_print("Number of remap links:       %zu", nlinks);
+    cdo_print("Filesize for remap weights: ~%zu", filesize);
+  }
 
   if (filesize > 0x7FFFFC00)  // 2**31 - 1024 (<2GB)
+  {
+    size_t maxlinks = 0x3FFFFFFF;  // 1GB
+    auto gridsizemax = (srcGrid.ncells > tgtGrid.ncells) ? srcGrid.ncells : tgtGrid.ncells;
+    if (nlinks > maxlinks || filesize > 8 * maxlinks || gridsizemax > 0x7FFFFC00)
     {
-      size_t maxlinks = 0x3FFFFFFF;  // 1GB
-      auto gridsizemax = (srcGrid.ncells > tgtGrid.ncells) ? srcGrid.ncells : tgtGrid.ncells;
-      if (nlinks > maxlinks || filesize > 8 * maxlinks || gridsizemax > 0x7FFFFC00)
-        {
-#ifdef HAVE_NETCDF4
-          if (Options::cdoVerbose) cdo_print("Store weights and links to NetCDF4!");
-          writemode |= NC_NETCDF4;
-          if (gridsizemax > 0x7FFFFC00)
-            sizetype = NC_UINT64;
-          else
-            writemode |= NC_CLASSIC_MODEL;
-#else
-          cdo_print("Number of remap links %zu exceeds maximum of %zu and NetCDF 4 is not available!", nlinks, maxlinks);
-#endif
-        }
+      if (Options::cdoVerbose) cdo_print("Store weights and links to NetCDF4!");
+      writemode |= NC_NETCDF4;
+      if (gridsizemax > 0x7FFFFC00)
+        sizetype = NC_UINT64;
       else
-        {
-#ifdef NC_64BIT_OFFSET
-          writemode |= NC_64BIT_OFFSET;
-          if (Options::cdoVerbose) cdo_print("Store weights and links to NetCDF2!");
-#else
-          cdo_print("Filesize for remap weights maybe too large!");
-#endif
-        }
+        writemode |= NC_CLASSIC_MODEL;
     }
+    else
+    {
+#ifdef NC_64BIT_OFFSET
+      writemode |= NC_64BIT_OFFSET;
+      if (Options::cdoVerbose) cdo_print("Store weights and links to NetCDF2!");
+#else
+      cdo_print("Filesize for remap weights maybe too large!");
+#endif
+    }
+  }
 }
 
 struct CDFgrid
@@ -430,7 +425,7 @@ struct CDFgrid
 };
 
 static CDFgrid
-define_remapgrid_scrip(int ncfileid, const std::string &prefix, nc_type sizetype, bool lgridarea, const RemapGridW &grid)
+define_remapgrid_scrip(int ncfileid, std::string const &prefix, nc_type sizetype, bool lgridarea, const RemapGridW &grid)
 {
   CDFgrid cdfGrid;
 
@@ -458,10 +453,10 @@ define_remapgrid_scrip(int ncfileid, const std::string &prefix, nc_type sizetype
   cdfWriteAttText(ncfileid, cdfGrid.cntrlat_id, "units", gridunits);
   cdfWriteAttText(ncfileid, cdfGrid.cntrlon_id, "units", gridunits);
   if (grid.ncorners)
-    {
-      cdfWriteAttText(ncfileid, cdfGrid.crnrlat_id, "units", gridunits);
-      cdfWriteAttText(ncfileid, cdfGrid.crnrlon_id, "units", gridunits);
-    }
+  {
+    cdfWriteAttText(ncfileid, cdfGrid.crnrlat_id, "units", gridunits);
+    cdfWriteAttText(ncfileid, cdfGrid.crnrlon_id, "units", gridunits);
+  }
 
   // Define grid mask
   cdfGrid.imask_id = cdf_def_var(ncfileid, (prefix + "_imask").c_str(), NC_INT, 1, &nc_size_id);
@@ -470,10 +465,10 @@ define_remapgrid_scrip(int ncfileid, const std::string &prefix, nc_type sizetype
   // Define grid area array
   cdfGrid.area_id = -1;  // id for area of source grid cells
   if (lgridarea)
-    {
-      cdfGrid.area_id = cdf_def_var(ncfileid, (prefix + "_area").c_str(), NC_DOUBLE, 1, &nc_size_id);
-      cdfWriteAttText(ncfileid, cdfGrid.area_id, "units", "square radians");
-    }
+  {
+    cdfGrid.area_id = cdf_def_var(ncfileid, (prefix + "_area").c_str(), NC_DOUBLE, 1, &nc_size_id);
+    cdfWriteAttText(ncfileid, cdfGrid.area_id, "units", "square radians");
+  }
 
   // Define grid fraction array
   cdfGrid.frac_id = cdf_def_var(ncfileid, (prefix + "_frac").c_str(), NC_DOUBLE, 1, &nc_size_id);
@@ -494,10 +489,10 @@ write_remapgrid_scrip(int ncfileid, const CDFgrid &cdfGrid, bool lgridarea, Rema
   if (grid.cell_center_lon.size()) cdfWriteVarDouble(ncfileid, cdfGrid.cntrlon_id, grid.cell_center_lon.data());
 
   if (grid.ncorners)
-    {
-      cdfWriteVarDouble(ncfileid, cdfGrid.crnrlat_id, grid.cell_corner_lat.data());
-      cdfWriteVarDouble(ncfileid, cdfGrid.crnrlon_id, grid.cell_corner_lon.data());
-    }
+  {
+    cdfWriteVarDouble(ncfileid, cdfGrid.crnrlat_id, grid.cell_corner_lat.data());
+    cdfWriteVarDouble(ncfileid, cdfGrid.crnrlon_id, grid.cell_corner_lon.data());
+  }
 
   if (lgridarea) cdfWriteVarDouble(ncfileid, cdfGrid.area_id, grid.cell_area.data());
 
@@ -530,7 +525,7 @@ remap_set_mapmethod(const RemapSwitches &remapSwitches)
 }
 
 static void
-write_remapfile_scrip(const std::string &remapFile, const RemapAttributes &remapAtts, const RemapSwitches &remapSwitches,
+write_remapfile_scrip(std::string const &remapFile, const RemapAttributes &remapAtts, const RemapSwitches &remapSwitches,
                       RemapGridW &srcGrid, RemapGridW &tgtGrid, RemapVarsW &rv)
 {
   // Writes remap data to a NetCDF file using SCRIP conventions
@@ -627,8 +622,8 @@ write_remapfile_scrip(const std::string &remapFile, const RemapAttributes &remap
 }
 
 static void
-check_areas(size_t n_a, const Varray<double> &area_a, const Varray<double> &area_b, size_t n_s, const Varray<size_t> &col,
-            const Varray<size_t> &row, const Varray<double> &S)
+check_areas(size_t n_a, Varray<double> const &area_a, Varray<double> const &area_b, size_t n_s, Varray<size_t> const &col,
+            Varray<size_t> const &row, Varray<double> const &S)
 {
   if (area_a.size() == 0 || area_b.size() == 0) return;
 
@@ -641,17 +636,17 @@ check_areas(size_t n_a, const Varray<double> &area_a, const Varray<double> &area
 
   // check that sums are equal to 1 (within tolerance of 1.e-6)
   for (size_t i = 0; i < n_a; ++i)  // loop over all source cells
+  {
+    if (std::fabs(sum[i] - 1.0) > 1.e-6)
     {
-      if (std::fabs(sum[i] - 1.0) > 1.e-6)
-        {
-          cdo_print("srcCellIndex=%zu areaSum=%g", i + 1, sum[i]);
-          break;
-        }
+      cdo_print("srcCellIndex=%zu areaSum=%g", i + 1, sum[i]);
+      break;
     }
+  }
 }
 
 static void
-verify_weights(const std::string &remapFile)
+verify_weights(std::string const &remapFile)
 {
   RemapGridW srcGrid, tgtGrid;
   RemapVarsW remapVars;
@@ -664,7 +659,7 @@ verify_weights(const std::string &remapFile)
 }
 
 static void
-write_remap_scrip(const std::string &remapFileIn, const std::string &remapFileOut)
+write_remap_scrip(std::string const &remapFileIn, std::string const &remapFileOut)
 {
   RemapGridW srcGrid, tgtGrid;
   RemapVarsW remapVars;
@@ -714,8 +709,8 @@ public:
     auto operatorID = cdo_operator_id();
 
     operator_input_arg(cdo_operator_enter(operatorID));
-    auto nfiles = cdo_operator_f2(operatorID);
-    operator_check_argc(nfiles);
+    auto numFiles = cdo_operator_f2(operatorID);
+    operator_check_argc(numFiles);
 
     auto remapFileIn = cdo_operator_argv(0);
 
