@@ -34,39 +34,39 @@
 
 struct YstatParam
 {
-  int year = 0;
-  bool yearMode{ false };
+  int year{};
+  bool yearMode{};
 };
 
 static YstatParam
 setParameter(void)
 {
   YstatParam params;
-  auto pargc = cdo_operator_argc();
-  if (pargc)
+  auto numArgs = cdo_operator_argc();
+  if (numArgs)
+  {
+    auto const &argList = cdo_get_oper_argv();
+
+    KVList kvlist;
+    kvlist.name = cdo_module_name();
+    if (kvlist.parse_arguments(argList) != 0) cdo_abort("Parse error!");
+    if (Options::cdoVerbose) kvlist.print();
+
+    for (auto const &kv : kvlist)
     {
-      const auto &pargv = cdo_get_oper_argv();
+      auto const &key = kv.key;
+      if (kv.nvalues > 1) cdo_abort("Too many values for parameter key >%s<!", key);
+      if (kv.nvalues < 1) cdo_abort("Missing value for parameter key >%s<!", key);
+      auto const &value = kv.values[0];
 
-      KVList kvlist;
-      kvlist.name = cdo_module_name();
-      if (kvlist.parse_arguments(pargv) != 0) cdo_abort("Parse error!");
-      if (Options::cdoVerbose) kvlist.print();
-
-      for (const auto &kv : kvlist)
-        {
-          const auto &key = kv.key;
-          if (kv.nvalues > 1) cdo_abort("Too many values for parameter key >%s<!", key);
-          if (kv.nvalues < 1) cdo_abort("Missing value for parameter key >%s<!", key);
-          const auto &value = kv.values[0];
-
-          if (key == "yearMode")
-            params.yearMode = parameter_to_bool(value);
-          else if (key == "year")
-            params.year = parameter_to_int(value);
-          else
-            cdo_abort("Invalid parameter key >%s<!", key);
-        }
+      if (key == "yearMode")
+        params.yearMode = parameter_to_bool(value);
+      else if (key == "year")
+        params.year = parameter_to_int(value);
+      else
+        cdo_abort("Invalid parameter key >%s<!", key);
     }
+  }
 
   return params;
 }
@@ -95,19 +95,19 @@ public:
   inline static RegisterEntry<Ydaystat> registration = RegisterEntry<Ydaystat>(module);
 
 private:
-  CdoStreamID streamID1;
-  CdoStreamID streamID2;
-  int taxisID1;
-  int taxisID2;
+  CdoStreamID streamID1{};
+  CdoStreamID streamID2{};
+  int taxisID1{ CDI_UNDEFID };
+  int taxisID2{ CDI_UNDEFID };
 
-  int vlistID1;
-  VarList varList1;
+  int vlistID1{ CDI_UNDEFID };
+  VarList varList1{};
 
-  int maxFields;
-  std::vector<FieldInfo> fieldInfoList;
+  int maxFields{};
+  std::vector<FieldInfo> fieldInfoList{};
 
-  cdo::StepStat3D stepStat;
-  YstatParam params;
+  cdo::StepStat3D stepStat{};
+  YstatParam params{};
 
 public:
   void
@@ -157,10 +157,10 @@ public:
 
     auto calendar = taxisInqCalendar(taxisID1);
     for (int stepIndex = 0; stepIndex < MaxSteps; ++stepIndex)
-      {
-        dtLists[stepIndex].set_stat(timestatDate);
-        dtLists[stepIndex].set_calendar(calendar);
-      }
+    {
+      dtLists[stepIndex].set_stat(timestatDate);
+      dtLists[stepIndex].set_calendar(calendar);
+    }
 
     auto numSteps = varList1.numSteps();
     cdo::Progress progress(get_id());
@@ -168,76 +168,76 @@ public:
     int tsID = 0;
     int otsID = 0;
     while (true)
+    {
+      auto numFields = cdo_stream_inq_timestep(streamID1, tsID);
+      if (numFields == 0) break;
+
+      if (numSteps > 1) progress.update((tsID + 1.0) / numSteps);
+
+      auto vDateTime = taxisInqVdatetime(taxisID1);
+      if (Options::cdoVerbose) cdo_print("process timestep: %d %s", tsID + 1, datetime_to_string(vDateTime));
+
+      auto stepIndex = decode_day_of_year(vDateTime.date);
+      if (stepIndex < 0 || stepIndex >= MaxSteps)
+        cdo_abort("Day of year %d out of range (%s)!", stepIndex, datetime_to_string(vDateTime));
+
+      dtLists[stepIndex].taxis_set_next_timestep(taxisID1);
+
+      if (!stepStat.var1(stepIndex).size()) { stepStat.alloc(stepIndex, varList1, VARS_MEMTYPE); }
+
+      auto numSets = rangeNumSets[stepIndex];
+      for (int fieldID = 0; fieldID < numFields; ++fieldID)
       {
-        auto numFields = cdo_stream_inq_timestep(streamID1, tsID);
-        if (numFields == 0) break;
-
-        if (numSteps > 1) progress.update((tsID + 1.0) / numSteps);
-
-        auto vDateTime = taxisInqVdatetime(taxisID1);
-        if (Options::cdoVerbose) cdo_print("process timestep: %d %s", tsID + 1, datetime_to_string(vDateTime));
-
-        auto stepIndex = decode_day_of_year(vDateTime.date);
-        if (stepIndex < 0 || stepIndex >= MaxSteps)
-          cdo_abort("Day of year %d out of range (%s)!", stepIndex, datetime_to_string(vDateTime));
-
-        dtLists[stepIndex].taxis_set_next_timestep(taxisID1);
-
-        if (!stepStat.var1(stepIndex).size()) { stepStat.alloc(stepIndex, varList1, VARS_MEMTYPE); }
-
-        auto numSets = rangeNumSets[stepIndex];
-        for (int fieldID = 0; fieldID < numFields; ++fieldID)
-          {
-            auto [varID, levelID] = cdo_inq_field(streamID1);
-            if (tsID == 0) fieldInfoList[fieldID].set(varID, levelID);
-            field.init(varList1.vars[varID]);
-            cdo_read_field(streamID1, field);
-            stepStat.add_field(field, stepIndex, varID, levelID, numSets);
-          }
-
-        rangeNumSets[stepIndex]++;
-        tsID++;
+        auto [varID, levelID] = cdo_inq_field(streamID1);
+        if (tsID == 0) fieldInfoList[fieldID].set(varID, levelID);
+        field.init(varList1.vars[varID]);
+        cdo_read_field(streamID1, field);
+        stepStat.add_field(field, stepIndex, varID, levelID, numSets);
       }
 
+      rangeNumSets[stepIndex]++;
+      tsID++;
+    }
+
     // set the year to the minimum of years found on output timestep
     if (params.yearMode)
+    {
+      int outyear = 1e9;
+      for (int stepIndex = 0; stepIndex < MaxSteps; stepIndex++)
       {
-        int outyear = 1e9;
-        for (int stepIndex = 0; stepIndex < MaxSteps; stepIndex++)
-          {
-            if (rangeNumSets[stepIndex])
-              {
-                auto numEntries = dtLists[stepIndex].get_size();
-                const auto &dtInfo = dtLists[stepIndex].get_info();
-                outyear = std::min(outyear, dtInfo[numEntries - 1].v.date.year);
-              }
-          }
-        params.year = outyear;
+        if (rangeNumSets[stepIndex])
+        {
+          auto numEntries = dtLists[stepIndex].size();
+          auto const &dtInfo = dtLists[stepIndex].info();
+          outyear = std::min(outyear, dtInfo[numEntries - 1].v.date.year);
+        }
       }
+      params.year = outyear;
+    }
 
     for (int stepIndex = 0; stepIndex < MaxSteps; stepIndex++)
+    {
+      auto numSets = rangeNumSets[stepIndex];
+      if (numSets)
       {
-        auto numSets = rangeNumSets[stepIndex];
-        if (numSets)
-          {
-            cdo::fields_process_3D(stepIndex, fieldInfoList, varList1, stepStat, numSets);
+        cdo::fields_process_3D(stepIndex, fieldInfoList, varList1, stepStat, numSets);
 
-            if (params.year) dtLists[stepIndex].set_year(params.year);
-            dtLists[stepIndex].stat_taxis_def_timestep(taxisID2);
-            cdo_def_timestep(streamID2, otsID);
+        if (params.year) dtLists[stepIndex].set_year(params.year);
+        dtLists[stepIndex].stat_taxis_def_timestep(taxisID2);
+        cdo_def_timestep(streamID2, otsID);
 
-            for (int fieldID = 0; fieldID < maxFields; ++fieldID)
-              {
-                auto [varID, levelID] = fieldInfoList[fieldID].get();
-                if (otsID && varList1.vars[varID].isConstant) continue;
+        for (int fieldID = 0; fieldID < maxFields; ++fieldID)
+        {
+          auto [varID, levelID] = fieldInfoList[fieldID].get();
+          if (otsID && varList1.vars[varID].isConstant) continue;
 
-                cdo_def_field(streamID2, varID, levelID);
-                cdo_write_field(streamID2, stepStat.var1(stepIndex, varID, levelID));
-              }
+          cdo_def_field(streamID2, varID, levelID);
+          cdo_write_field(streamID2, stepStat.var1(stepIndex, varID, levelID));
+        }
 
-            otsID++;
-          }
+        otsID++;
       }
+    }
   }
 
   void
