@@ -43,8 +43,8 @@ public:
   CdoStreamID streamID2;
   CdoStreamID streamID3;
 
-  int taxisID1;
-  int taxisID2;
+  int taxisID1{ CDI_UNDEFID };
+  int taxisID2{ CDI_UNDEFID };
   int taxisID3;
 
   FieldVector2D varsData2;
@@ -96,57 +96,57 @@ public:
     int tsID2 = 0;
     int tsID = 0;
     while (true)
+    {
+      auto numFields = cdo_stream_inq_timestep(streamID1, tsID);
+      if (numFields == 0) break;
+
+      auto year = taxisInqVdatetime(taxisID1).date.year;
+      if (year > year0)
       {
-        auto numFields = cdo_stream_inq_timestep(streamID1, tsID);
-        if (numFields == 0) break;
+        auto lfound = false;
+        while (true)
+        {
+          auto numFields2 = cdo_stream_inq_timestep(streamID2, tsID2);
+          if (numFields2 == 0) break;
 
-        auto year = taxisInqVdatetime(taxisID1).date.year;
-        if (year > year0)
+          tsID2++;
+          auto year2 = taxisInqVdatetime(taxisID2).date.year;
+          if (year == year2)
           {
-            auto lfound = false;
-            while (true)
-              {
-                auto numFields2 = cdo_stream_inq_timestep(streamID2, tsID2);
-                if (numFields2 == 0) break;
-
-                tsID2++;
-                auto year2 = taxisInqVdatetime(taxisID2).date.year;
-                if (year == year2)
-                  {
-                    lfound = true;
-                    year0 = year;
-                    while (numFields2--)
-                      {
-                        auto [varID, levelID] = cdo_inq_field(streamID2);
-                        cdo_read_field(streamID2, varsData2[varID][levelID]);
-                      }
-                    break;
-                  }
-
-                if (tsID2 > 1 && year2 <= year2last) cdo_abort("stream2 doesn't contain yearly data!");
-                year2last = year2;
-              }
-
-            if (!lfound) cdo_abort("Data of year %d not found in stream2!", year);
+            lfound = true;
+            year0 = year;
+            while (numFields2--)
+            {
+              auto [varID, levelID] = cdo_inq_field(streamID2);
+              cdo_read_field(streamID2, varsData2[varID][levelID]);
+            }
+            break;
           }
 
-        cdo_taxis_copy_timestep(taxisID3, taxisID1);
-        cdo_def_timestep(streamID3, tsID);
+          if (tsID2 > 1 && year2 <= year2last) cdo_abort("stream2 doesn't contain yearly data!");
+          year2last = year2;
+        }
 
-        while (numFields--)
-          {
-            auto [varID, levelID] = cdo_inq_field(streamID1);
-            field.init(varList1.vars[varID]);
-            cdo_read_field(streamID1, field);
-
-            field2_function(field, varsData2[varID][levelID], operfunc);
-
-            cdo_def_field(streamID3, varID, levelID);
-            cdo_write_field(streamID3, field);
-          }
-
-        tsID++;
+        if (!lfound) cdo_abort("Data of year %d not found in stream2!", year);
       }
+
+      cdo_taxis_copy_timestep(taxisID3, taxisID1);
+      cdo_def_timestep(streamID3, tsID);
+
+      while (numFields--)
+      {
+        auto [varID, levelID] = cdo_inq_field(streamID1);
+        field.init(varList1.vars[varID]);
+        cdo_read_field(streamID1, field);
+
+        field2_function(field, varsData2[varID][levelID], operfunc);
+
+        cdo_def_field(streamID3, varID, levelID);
+        cdo_write_field(streamID3, field);
+      }
+
+      tsID++;
+    }
   }
 
   void
