@@ -45,11 +45,11 @@ public:
   CdoStreamID streamID2;
   CdoStreamID streamID3;
 
-  int taxisID1;
-  int taxisID2;
+  int taxisID1{ CDI_UNDEFID };
+  int taxisID2{ CDI_UNDEFID };
   int taxisID3;
 
-  int vlistID2;
+  int vlistID2{ CDI_UNDEFID };
 
   VarList varList1;
   VarList varList2;
@@ -93,52 +93,52 @@ public:
 
     int tsID = 0;
     while (true)
+    {
+      auto numFields = cdo_stream_inq_timestep(streamID2, tsID);
+      if (numFields == 0) break;
+
+      auto hourOfYear = decode_hour_of_year(taxisInqVdatetime(taxisID2), MaxHours);
+      if (varsData2[hourOfYear].size() > 0) cdo_abort("Hour of year index %d already allocated!", hourOfYear);
+
+      field2D_init(varsData2[hourOfYear], varList2, FIELD_VEC | FIELD_NAT);
+
+      while (numFields--)
       {
-        auto numFields = cdo_stream_inq_timestep(streamID2, tsID);
-        if (numFields == 0) break;
-
-        auto hourOfYear = decode_hour_of_year(taxisInqVdatetime(taxisID2), MaxHours);
-        if (varsData2[hourOfYear].size() > 0) cdo_abort("Hour of year index %d already allocated!", hourOfYear);
-
-        field2D_init(varsData2[hourOfYear], varList2, FIELD_VEC | FIELD_NAT);
-
-        while (numFields--)
-          {
-            auto [varID, levelID] = cdo_inq_field(streamID2);
-            cdo_read_field(streamID2, varsData2[hourOfYear][varID][levelID]);
-          }
-
-        tsID++;
+        auto [varID, levelID] = cdo_inq_field(streamID2);
+        cdo_read_field(streamID2, varsData2[hourOfYear][varID][levelID]);
       }
 
+      tsID++;
+    }
+
     cdo_stream_close(streamID2);
 
     tsID = 0;
     while (true)
+    {
+      auto numFields = cdo_stream_inq_timestep(streamID1, tsID);
+      if (numFields == 0) break;
+
+      auto hourOfYear = decode_hour_of_year(taxisInqVdatetime(taxisID1), MaxHours);
+      if (varsData2[hourOfYear].size() == 0) cdo_abort("Hour of year index %d not found!", hourOfYear);
+
+      cdo_taxis_copy_timestep(taxisID3, taxisID1);
+      cdo_def_timestep(streamID3, tsID);
+
+      while (numFields--)
       {
-        auto numFields = cdo_stream_inq_timestep(streamID1, tsID);
-        if (numFields == 0) break;
+        auto [varID, levelID] = cdo_inq_field(streamID1);
+        field.init(varList1.vars[varID]);
+        cdo_read_field(streamID1, field);
 
-        auto hourOfYear = decode_hour_of_year(taxisInqVdatetime(taxisID1), MaxHours);
-        if (varsData2[hourOfYear].size() == 0) cdo_abort("Hour of year index %d not found!", hourOfYear);
+        field2_function(field, varsData2[hourOfYear][varID][levelID], operfunc);
 
-        cdo_taxis_copy_timestep(taxisID3, taxisID1);
-        cdo_def_timestep(streamID3, tsID);
-
-        while (numFields--)
-          {
-            auto [varID, levelID] = cdo_inq_field(streamID1);
-            field.init(varList1.vars[varID]);
-            cdo_read_field(streamID1, field);
-
-            field2_function(field, varsData2[hourOfYear][varID][levelID], operfunc);
-
-            cdo_def_field(streamID3, varID, levelID);
-            cdo_write_field(streamID3, field);
-          }
-
-        tsID++;
+        cdo_def_field(streamID3, varID, levelID);
+        cdo_write_field(streamID3, field);
       }
+
+      tsID++;
+    }
   }
 
   void
