@@ -33,10 +33,9 @@ static const char *monthNames[]
 static int
 get_month_index(const CdiDate vDate)
 {
-  int year, mon, day;
-  cdiDate_decode(vDate, &year, &mon, &day);
-  if (mon < 1 || mon > MaxMonths) cdo_abort("Month %d out of range!", mon);
-  return --mon;
+  int month = vDate.month;
+  if (month < 1 || month > MaxMonths) cdo_abort("Month %d out of range!", month);
+  return --month;
 }
 
 enum
@@ -73,11 +72,11 @@ public:
   CdoStreamID streamID2;
   CdoStreamID streamID3;
 
-  int taxisID1;
-  int taxisID2;
+  int taxisID1{ CDI_UNDEFID };
+  int taxisID2{ CDI_UNDEFID };
   int taxisID3;
 
-  int vlistID2;
+  int vlistID2{ CDI_UNDEFID };
 
   VarList varList1;
   VarList varList2;
@@ -91,16 +90,16 @@ public:
     cdo_def_timestep(streamID3, tsID);
 
     while (numFields--)
-      {
-        auto [varID, levelID] = cdo_inq_field(streamID1);
-        field.init(varList1.vars[varID]);
-        cdo_read_field(streamID1, field);
+    {
+      auto [varID, levelID] = cdo_inq_field(streamID1);
+      field.init(varList1.vars[varID]);
+      cdo_read_field(streamID1, field);
 
-        field2_function(field, varsData2[mon][varID][levelID], operfunc);
+      field2_function(field, varsData2[mon][varID][levelID], operfunc);
 
-        cdo_def_field(streamID3, varID, levelID);
-        cdo_write_field(streamID3, field);
-      }
+      cdo_def_field(streamID3, varID, levelID);
+      cdo_write_field(streamID3, field);
+    }
   }
 
   void
@@ -109,34 +108,34 @@ public:
     field2D_init(varsData2[mon], varList2, FIELD_VEC | FIELD_NAT);
 
     while (numFields--)
-      {
-        auto [varID, levelID] = cdo_inq_field(streamID2);
-        cdo_read_field(streamID2, varsData2[mon][varID][levelID]);
-      }
+    {
+      auto [varID, levelID] = cdo_inq_field(streamID2);
+      cdo_read_field(streamID2, varsData2[mon][varID][levelID]);
+    }
   }
 
   void
   run_monthly()
   {
     for (int numFields, tsID = 0; (numFields = cdo_stream_inq_timestep(streamID2, tsID)) != 0; tsID++)
-      {
-        auto mon = get_month_index(taxisInqVdatetime(taxisID2).date);
-        if (varsData2[mon].size())
-          cdo_abort("%s already allocated! The second input file must contain monthly mean values for a maximum of one year.",
-                    monthNames[mon]);
+    {
+      auto mon = get_month_index(taxisInqVdatetime(taxisID2).date);
+      if (varsData2[mon].size())
+        cdo_abort("%s already allocated! The second input file must contain monthly mean values for a maximum of one year.",
+                  monthNames[mon]);
 
-        load_data_from_stream(mon, numFields);
-      }
+      load_data_from_stream(mon, numFields);
+    }
 
     for (int numFields, tsID = 0; (numFields = cdo_stream_inq_timestep(streamID1, tsID)) != 0; tsID++)
-      {
-        auto mon = get_month_index(taxisInqVdatetime(taxisID1).date);
-        if (varsData2[mon].size() == 0)
-          cdo_abort("%s not found! The second input file must contain monthly mean values for a maximum of one year.",
-                    monthNames[mon]);
+    {
+      auto mon = get_month_index(taxisInqVdatetime(taxisID1).date);
+      if (varsData2[mon].size() == 0)
+        cdo_abort("%s not found! The second input file must contain monthly mean values for a maximum of one year.",
+                  monthNames[mon]);
 
-        process_data(tsID, numFields, mon);
-      }
+      process_data(tsID, numFields, mon);
+    }
   }
 
   void
@@ -144,22 +143,22 @@ public:
   {
     auto seasonNames = get_season_name();
     for (int numFields, tsID = 0; (numFields = cdo_stream_inq_timestep(streamID2, tsID)) != 0; tsID++)
-      {
-        auto mon = get_month_index(taxisInqVdatetime(taxisID2).date);
-        auto season = month_to_season(mon + 1);
-        if (varsData2[season].size()) cdo_abort("Season %s already allocated!", seasonNames[season]);
+    {
+      auto mon = get_month_index(taxisInqVdatetime(taxisID2).date);
+      auto season = month_to_season(mon + 1);
+      if (varsData2[season].size()) cdo_abort("Season %s already allocated!", seasonNames[season]);
 
-        load_data_from_stream(season, numFields);
-      }
+      load_data_from_stream(season, numFields);
+    }
 
     for (int numFields, tsID = 0; (numFields = cdo_stream_inq_timestep(streamID1, tsID)) != 0; tsID++)
-      {
-        auto mon = get_month_index(taxisInqVdatetime(taxisID1).date);
-        auto season = month_to_season(mon + 1);
-        if (varsData2[season].size() == 0) cdo_abort("Season %s not found!", seasonNames[season]);
+    {
+      auto mon = get_month_index(taxisInqVdatetime(taxisID1).date);
+      auto season = month_to_season(mon + 1);
+      if (varsData2[season].size() == 0) cdo_abort("Season %s not found!", seasonNames[season]);
 
-        process_data(tsID, numFields, season);
-      }
+      process_data(tsID, numFields, season);
+    }
   }
 
 public:
