@@ -29,8 +29,16 @@
 #include "process_int.h"
 #include "field_functions.h"
 
-static auto func_comp = [](auto hasMissvals, auto n, auto mv1, auto mv2, auto &v1, const auto &v2, auto binary_operator) {
-  if (hasMissvals)
+template <typename T1, typename T2>
+static void
+comp_function(Varray<T1> &v1, Varray<T2> const &v2, double missval1, double missval2, size_t n, int operFunc, bool hasMissvals)
+{
+  T1 mv1 = missval1;
+  T2 mv2 = missval2;
+
+  auto func_comp = [&](auto binary_operator)
+  {
+    if (hasMissvals)
     {
       if (std::isnan(mv1) || std::isnan(mv2))
         for (size_t i = 0; i < n; ++i)
@@ -38,38 +46,29 @@ static auto func_comp = [](auto hasMissvals, auto n, auto mv1, auto mv2, auto &v
       else
         for (size_t i = 0; i < n; ++i) v1[i] = (is_equal(v1[i], mv1) || is_equal(v2[i], mv2)) ? mv1 : binary_operator(v1[i], v2[i]);
     }
-  else
+    else
     {
       for (size_t i = 0; i < n; ++i) v1[i] = binary_operator(v1[i], v2[i]);
     }
-};
+  };
 
-template <typename T1, typename T2>
-static void
-comp_function(Varray<T1> &v1, const Varray<T2> &v2, double missval1, double missval2, size_t ngp, int operFunc, bool hasMissvals)
-{
-  T1 mv1 = missval1;
-  T2 mv2 = missval2;
   // clang-format off
-  if      (operFunc == FieldFunc_EQ) func_comp(hasMissvals, ngp, mv1, mv2, v1, v2, binary_op_EQ);
-  else if (operFunc == FieldFunc_NE) func_comp(hasMissvals, ngp, mv1, mv2, v1, v2, binary_op_NE);
-  else if (operFunc == FieldFunc_LE) func_comp(hasMissvals, ngp, mv1, mv2, v1, v2, binary_op_LE);
-  else if (operFunc == FieldFunc_LT) func_comp(hasMissvals, ngp, mv1, mv2, v1, v2, binary_op_LT);
-  else if (operFunc == FieldFunc_GE) func_comp(hasMissvals, ngp, mv1, mv2, v1, v2, binary_op_GE);
-  else if (operFunc == FieldFunc_GT) func_comp(hasMissvals, ngp, mv1, mv2, v1, v2, binary_op_GT);
+  if      (operFunc == FieldFunc_EQ) func_comp(binary_op_EQ);
+  else if (operFunc == FieldFunc_NE) func_comp(binary_op_NE);
+  else if (operFunc == FieldFunc_LE) func_comp(binary_op_LE);
+  else if (operFunc == FieldFunc_LT) func_comp(binary_op_LT);
+  else if (operFunc == FieldFunc_GE) func_comp(binary_op_GE);
+  else if (operFunc == FieldFunc_GT) func_comp(binary_op_GT);
   else cdo_abort("Operator not implemented!");
   // clang-format on
 }
 
 static void
-comp_function(Field &f1, const Field &f2, int operFunc)
+comp_function(Field &f1, Field const &f2, int operFunc)
 {
   auto hasMissvals = (f1.numMissVals > 0 || f2.numMissVals > 0);
-
-  auto func = [&](auto &v1, const auto &v2, double mv1, double mv2, size_t size) {
-    comp_function(v1, v2, mv1, mv2, size, operFunc, hasMissvals);
-  };
-  field_operation2(func, f1, f2, f1.missval, f2.missval, f1.size);
+  auto func = [&](auto &v1, auto const &v2) { comp_function(v1, v2, f1.missval, f2.missval, f1.size, operFunc, hasMissvals); };
+  field_operation2(func, f1, f2);
 }
 
 constexpr int MaxMonths = 12;
@@ -80,11 +79,10 @@ static const char *monthNames[]
 static int
 get_month_index(CdiDate vDate)
 {
-  int year, mon, day;
-  cdiDate_decode(vDate, &year, &mon, &day);
-  if (mon < 1 || mon > MaxMonths) cdo_abort("Month %d out of range!", mon);
-  mon--;
-  return mon;
+  int month = vDate.month;
+  if (month < 1 || month > MaxMonths) cdo_abort("Month %d out of range!", month);
+  month--;
+  return month;
 }
 
 enum
@@ -105,12 +103,12 @@ public:
                    { "ymonlt", FieldFunc_LT, MONTHLY, YmoncompHelp },
                    { "ymonge", FieldFunc_GE, MONTHLY, YmoncompHelp },
                    { "ymongt", FieldFunc_GT, MONTHLY, YmoncompHelp },
-                   { "yseaseq", FieldFunc_EQ, SEASONAL, nullptr },
-                   { "yseasne", FieldFunc_NE, SEASONAL, nullptr },
-                   { "yseasle", FieldFunc_LE, SEASONAL, nullptr },
-                   { "yseaslt", FieldFunc_LT, SEASONAL, nullptr },
-                   { "yseasge", FieldFunc_GE, SEASONAL, nullptr },
-                   { "yseasgt", FieldFunc_GT, SEASONAL, nullptr } },
+                   { "yseaseq", FieldFunc_EQ, SEASONAL, YseascompHelp },
+                   { "yseasne", FieldFunc_NE, SEASONAL, YseascompHelp },
+                   { "yseasle", FieldFunc_LE, SEASONAL, YseascompHelp },
+                   { "yseaslt", FieldFunc_LT, SEASONAL, YseascompHelp },
+                   { "yseasge", FieldFunc_GE, SEASONAL, YseascompHelp },
+                   { "yseasgt", FieldFunc_GT, SEASONAL, YseascompHelp } },
     .aliases = {},
     .mode = EXPOSED,     // Module mode: 0:intern 1:extern
     .number = CDI_REAL,  // Allowed number type
@@ -125,11 +123,11 @@ public:
   CdoStreamID streamID2;
   CdoStreamID streamID3;
 
-  int taxisID1;
-  int taxisID2;
+  int taxisID1{ CDI_UNDEFID };
+  int taxisID2{ CDI_UNDEFID };
   int taxisID3;
 
-  int vlistID2;
+  int vlistID2{ CDI_UNDEFID };
 
   VarList varList1;
   VarList varList2;
@@ -143,16 +141,16 @@ public:
     cdo_def_timestep(streamID3, tsID);
 
     while (numFields--)
-      {
-        auto [varID, levelID] = cdo_inq_field(streamID1);
-        field.init(varList1.vars[varID]);
-        cdo_read_field(streamID1, field);
+    {
+      auto [varID, levelID] = cdo_inq_field(streamID1);
+      field.init(varList1.vars[varID]);
+      cdo_read_field(streamID1, field);
 
-        comp_function(field, varsData2[mon][varID][levelID], operfunc);
+      comp_function(field, varsData2[mon][varID][levelID], operfunc);
 
-        cdo_def_field(streamID3, varID, levelID);
-        cdo_write_field(streamID3, field);
-      }
+      cdo_def_field(streamID3, varID, levelID);
+      cdo_write_field(streamID3, field);
+    }
   }
 
   void
@@ -161,34 +159,34 @@ public:
     field2D_init(varsData2[mon], varList2, FIELD_VEC | FIELD_NAT);
 
     while (numFields--)
-      {
-        auto [varID, levelID] = cdo_inq_field(streamID2);
-        cdo_read_field(streamID2, varsData2[mon][varID][levelID]);
-      }
+    {
+      auto [varID, levelID] = cdo_inq_field(streamID2);
+      cdo_read_field(streamID2, varsData2[mon][varID][levelID]);
+    }
   }
 
   void
   run_monthly()
   {
     for (int numFields, tsID = 0; (numFields = cdo_stream_inq_timestep(streamID2, tsID)) != 0; tsID++)
-      {
-        auto mon = get_month_index(taxisInqVdatetime(taxisID2).date);
-        if (varsData2[mon].size())
-          cdo_abort("%s already allocated! The second input file must contain monthly mean values for a maximum of one year.",
-                    monthNames[mon]);
+    {
+      auto mon = get_month_index(taxisInqVdatetime(taxisID2).date);
+      if (varsData2[mon].size())
+        cdo_abort("%s already allocated! The second input file must contain monthly mean values for a maximum of one year.",
+                  monthNames[mon]);
 
-        load_data_from_stream(mon, numFields);
-      }
+      load_data_from_stream(mon, numFields);
+    }
 
     for (int numFields, tsID = 0; (numFields = cdo_stream_inq_timestep(streamID1, tsID)) != 0; tsID++)
-      {
-        auto mon = get_month_index(taxisInqVdatetime(taxisID1).date);
-        if (varsData2[mon].size() == 0)
-          cdo_abort("%s not found! The second input file must contain monthly mean values for a maximum of one year.",
-                    monthNames[mon]);
+    {
+      auto mon = get_month_index(taxisInqVdatetime(taxisID1).date);
+      if (varsData2[mon].size() == 0)
+        cdo_abort("%s not found! The second input file must contain monthly mean values for a maximum of one year.",
+                  monthNames[mon]);
 
-        process_data(tsID, numFields, mon);
-      }
+      process_data(tsID, numFields, mon);
+    }
   }
 
   void
@@ -196,22 +194,22 @@ public:
   {
     auto seasonNames = get_season_name();
     for (int numFields, tsID = 0; (numFields = cdo_stream_inq_timestep(streamID2, tsID)) != 0; tsID++)
-      {
-        auto mon = get_month_index(taxisInqVdatetime(taxisID2).date);
-        auto season = month_to_season(mon + 1);
-        if (varsData2[season].size()) cdo_abort("Season %s already allocated!", seasonNames[season]);
+    {
+      auto mon = get_month_index(taxisInqVdatetime(taxisID2).date);
+      auto season = month_to_season(mon + 1);
+      if (varsData2[season].size()) cdo_abort("Season %s already allocated!", seasonNames[season]);
 
-        load_data_from_stream(mon, numFields);
-      }
+      load_data_from_stream(mon, numFields);
+    }
 
     for (int numFields, tsID = 0; (numFields = cdo_stream_inq_timestep(streamID1, tsID)) != 0; tsID++)
-      {
-        auto mon = get_month_index(taxisInqVdatetime(taxisID1).date);
-        auto season = month_to_season(mon + 1);
-        if (varsData2[season].size() == 0) cdo_abort("Season %s not found!", seasonNames[season]);
+    {
+      auto mon = get_month_index(taxisInqVdatetime(taxisID1).date);
+      auto season = month_to_season(mon + 1);
+      if (varsData2[season].size() == 0) cdo_abort("Season %s not found!", seasonNames[season]);
 
-        process_data(tsID, numFields, season);
-      }
+      process_data(tsID, numFields, season);
+    }
   }
 
 public:
@@ -249,10 +247,7 @@ public:
   void
   run() override
   {
-    if (opertype == SEASONAL)
-      run_seasonal();
-    else
-      run_monthly();
+    (opertype == SEASONAL) ? run_seasonal() : run_monthly();
   }
 
   void
