@@ -54,18 +54,18 @@ public:
   inline static RegisterEntry<Ymonstat> registration = RegisterEntry<Ymonstat>(module);
 
 private:
-  CdoStreamID streamID1;
-  CdoStreamID streamID2;
-  int taxisID1;
-  int taxisID2;
+  CdoStreamID streamID1{};
+  CdoStreamID streamID2{};
+  int taxisID1{ CDI_UNDEFID };
+  int taxisID2{ CDI_UNDEFID };
 
-  int vlistID1;
-  VarList varList1;
+  int vlistID1{ CDI_UNDEFID };
+  VarList varList1{};
 
-  int maxFields;
-  std::vector<FieldInfo> fieldInfoList;
+  int maxFields{};
+  std::vector<FieldInfo> fieldInfoList{};
 
-  cdo::StepStat3D stepStat;
+  cdo::StepStat3D stepStat{};
 
 public:
   void
@@ -115,10 +115,10 @@ public:
 
     auto calendar = taxisInqCalendar(taxisID1);
     for (int stepIndex = 0; stepIndex < MaxSteps; ++stepIndex)
-      {
-        dtLists[stepIndex].set_stat(timestatDate);
-        dtLists[stepIndex].set_calendar(calendar);
-      }
+    {
+      dtLists[stepIndex].set_stat(timestatDate);
+      dtLists[stepIndex].set_calendar(calendar);
+    }
 
     auto numSteps = varList1.numSteps();
     cdo::Progress progress(get_id());
@@ -126,58 +126,58 @@ public:
     int tsID = 0;
     int otsID = 0;
     while (true)
+    {
+      auto numFields = cdo_stream_inq_timestep(streamID1, tsID);
+      if (numFields == 0) break;
+
+      if (numSteps > 1) progress.update((tsID + 1.0) / numSteps);
+
+      auto vDateTime = taxisInqVdatetime(taxisID1);
+      if (Options::cdoVerbose) cdo_print("process timestep: %d %s", tsID + 1, datetime_to_string(vDateTime));
+
+      int stepIndex = vDateTime.date.month;
+      if (stepIndex < 0 || stepIndex >= MaxSteps) cdo_abort("Month %d out of range!", stepIndex);
+
+      dtLists[stepIndex].taxis_set_next_timestep(taxisID1);
+
+      if (!stepStat.var1(stepIndex).size()) { stepStat.alloc(stepIndex, varList1, VARS_MEMTYPE); }
+
+      auto numSets = rangeNumSets[stepIndex];
+      for (int fieldID = 0; fieldID < numFields; ++fieldID)
       {
-        auto numFields = cdo_stream_inq_timestep(streamID1, tsID);
-        if (numFields == 0) break;
-
-        if (numSteps > 1) progress.update((tsID + 1.0) / numSteps);
-
-        auto vDateTime = taxisInqVdatetime(taxisID1);
-        if (Options::cdoVerbose) cdo_print("process timestep: %d %s", tsID + 1, datetime_to_string(vDateTime));
-
-        int stepIndex = vDateTime.date.month;
-        if (stepIndex < 0 || stepIndex >= MaxSteps) cdo_abort("Month %d out of range!", stepIndex);
-
-        dtLists[stepIndex].taxis_set_next_timestep(taxisID1);
-
-        if (!stepStat.var1(stepIndex).size()) { stepStat.alloc(stepIndex, varList1, VARS_MEMTYPE); }
-
-        auto numSets = rangeNumSets[stepIndex];
-        for (int fieldID = 0; fieldID < numFields; ++fieldID)
-          {
-            auto [varID, levelID] = cdo_inq_field(streamID1);
-            if (tsID == 0) fieldInfoList[fieldID].set(varID, levelID);
-            field.init(varList1.vars[varID]);
-            cdo_read_field(streamID1, field);
-            stepStat.add_field(field, stepIndex, varID, levelID, numSets);
-          }
-
-        rangeNumSets[stepIndex]++;
-        tsID++;
+        auto [varID, levelID] = cdo_inq_field(streamID1);
+        if (tsID == 0) fieldInfoList[fieldID].set(varID, levelID);
+        field.init(varList1.vars[varID]);
+        cdo_read_field(streamID1, field);
+        stepStat.add_field(field, stepIndex, varID, levelID, numSets);
       }
 
+      rangeNumSets[stepIndex]++;
+      tsID++;
+    }
+
     for (int stepIndex = 0; stepIndex < MaxSteps; stepIndex++)
+    {
+      auto numSets = rangeNumSets[stepIndex];
+      if (numSets)
       {
-        auto numSets = rangeNumSets[stepIndex];
-        if (numSets)
-          {
-            cdo::fields_process_3D(stepIndex, fieldInfoList, varList1, stepStat, numSets);
+        cdo::fields_process_3D(stepIndex, fieldInfoList, varList1, stepStat, numSets);
 
-            dtLists[stepIndex].stat_taxis_def_timestep(taxisID2);
-            cdo_def_timestep(streamID2, otsID);
+        dtLists[stepIndex].stat_taxis_def_timestep(taxisID2);
+        cdo_def_timestep(streamID2, otsID);
 
-            for (int fieldID = 0; fieldID < maxFields; ++fieldID)
-              {
-                auto [varID, levelID] = fieldInfoList[fieldID].get();
-                if (otsID && varList1.vars[varID].isConstant) continue;
+        for (int fieldID = 0; fieldID < maxFields; ++fieldID)
+        {
+          auto [varID, levelID] = fieldInfoList[fieldID].get();
+          if (otsID && varList1.vars[varID].isConstant) continue;
 
-                cdo_def_field(streamID2, varID, levelID);
-                cdo_write_field(streamID2, stepStat.var1(stepIndex, varID, levelID));
-              }
+          cdo_def_field(streamID2, varID, levelID);
+          cdo_write_field(streamID2, stepStat.var1(stepIndex, varID, levelID));
+        }
 
-            otsID++;
-          }
+        otsID++;
       }
+    }
   }
 
   void
