@@ -21,7 +21,9 @@
 
 #include <map>
 
-#ifdef HAVE_NETCDF_META_H
+#include "cdf_config.h"
+
+#ifdef HAVE_LIBNETCDF
 #include <netcdf_meta.h>
 #endif
 
@@ -45,13 +47,6 @@
 #include <proj.h>
 #endif
 
-#ifdef HAVE_LIBCMOR
-extern "C"
-{
-#include "cmor.h"
-}
-#endif
-
 #include <cstdio>
 #include <cstring>
 #include <iostream>
@@ -82,12 +77,6 @@ constexpr bool have_hdf5 = true;
 constexpr bool have_hdf5 = false;
 #endif
 
-#ifdef HAVE_LIBCGRIBEX
-constexpr bool have_cgribex = true;
-#else
-constexpr bool have_cgribex = false;
-#endif
-
 #ifdef HAVE_LIBCMOR
 constexpr bool have_cmor = true;
 #else
@@ -144,7 +133,9 @@ static std::map<std::string, std::pair<std::string, bool>> configMap
         { "has-nc5", { "NetCDF 5", cdiHaveFiletype(CDI_FILETYPE_NC5) } },
         { "has-nczarr", { "NetCDF 4 zarr", cdiHaveFiletype(CDI_FILETYPE_NCZARR) } },
         { "has-hdf5", { "HDF5", have_hdf5 } },
-        { "has-cgribex", { "CGRIBEX", have_cgribex } },
+        { "has-ncfilter", { "NetCDF 4 filter", cdi_has_ncfilter() } },
+        { "has-ncdap", { "NetCDF OpenDap", cdi_has_ncdap() } },
+        { "has-cgribex", { "CGRIBEX", cdi_has_cgribex() } },
         { "has-cmor", { "CMOR", have_cmor } },
         { "has-magics", { "MAGICS", have_magics } },
         { "has-openmp", { "OPENMP", have_openmp } },
@@ -202,18 +193,19 @@ print_features()
 #ifdef HAVE_LIBHDF5
   fprintf(fp, " HDF5");
 #endif
-#ifdef HAVE_NETCDF4
+#ifdef HAVE_LIBNETCDF
   fprintf(fp, " NC4");
+#endif
+#ifdef HAVE_NC4S3
+  fprintf(fp, "/S3");
+#endif
 #ifdef HAVE_NC4HDF5
   fprintf(fp, "/HDF5");
+#endif
 #ifdef HAVE_NC4HDF5_THREADSAFE
   fprintf(fp, "/threadsafe");
 #endif
-#endif
-#endif
-#ifdef HAVE_LIBNC_DAP
-  fprintf(fp, " OPeNDAP");
-#endif
+  if (cdi_has_ncdap()) fprintf(fp, " dap");
 #ifdef HAVE_LIBSZ
   fprintf(fp, " sz");
 #endif
@@ -370,48 +362,48 @@ print_argument_options()
 {
   fprintf(stdout, "Available config option:\n");
   fprintf(stdout, "\n");
-  for (const auto &entry : configMap)
+  for (auto const &entry : configMap)
     fprintf(stdout, "  %-12s  whether %s is enabled\n", entry.first.c_str(), entry.second.first.c_str());
 }
 
 int
-print_config(const std::string &option)
+print_config(std::string const &option)
 {
   int status = EXIT_SUCCESS;
 
   if ("all-json" == option || "all" == option)
+  {
+    std::cout << "{\n";
+    int i = 0;
+    for (auto const &entry : configMap)
     {
-      std::cout << "{";
-      int i = 0;
-      for (const auto &entry : configMap)
-        {
-          if (i++) fprintf(stdout, ",");
-          std::cout << "\"" << entry.first << "\":\"" << (entry.second.second ? "yes" : "no") << "\"";
-        }
-      std::cout << "}\n";
+      if (i++) fprintf(stdout, ",\n");
+      std::cout << "\"" << entry.first << "\":\"" << (entry.second.second ? "yes" : "no") << "\"";
     }
+    std::cout << "\n}\n";
+  }
   else
+  {
+    auto foundOption = false;
+    for (auto const &entry : configMap)
     {
-      auto foundOption = false;
-      for (const auto &entry : configMap)
-        {
-          if (entry.first == option)
-            {
-              foundOption = true;
-              std::cout << (entry.second.second ? "yes" : "no") << "\n";
-            }
-        }
-
-      if (!foundOption)
-        {
-          fprintf(stdout, "unknown config option: %s\n", option.c_str());
-          fprintf(stdout, "\n");
-          print_argument_options();
-
-          status = EXIT_FAILURE;
-        }
+      if (entry.first == option)
+      {
+        foundOption = true;
+        std::cout << (entry.second.second ? "yes" : "no") << "\n";
+      }
     }
 
+    if (!foundOption)
+    {
+      fprintf(stdout, "unknown config option: %s\n", option.c_str());
+      fprintf(stdout, "\n");
+      print_argument_options();
+
+      status = EXIT_FAILURE;
+    }
+  }
+
   return status;
 }
 
@@ -423,7 +415,7 @@ alignof_address(void *ptr) -> int
 }
 
 static auto
-alignof_malloc_data(const std::vector<int> &tsize) -> int
+alignof_malloc_data(std::vector<int> const &tsize) -> int
 {
   int align = (1 << 30);
   auto n = tsize.size();
@@ -431,17 +423,17 @@ alignof_malloc_data(const std::vector<int> &tsize) -> int
   std::vector<double *> ptr(n);
 
   for (size_t i = 0; i < n; ++i)
-    {
-      ptr[i] = (double *) std::malloc(tsize[i] * sizeof(double));
-      align = std::min(align, alignof_address(ptr[i]));
-    }
+  {
+    ptr[i] = (double *) std::malloc(tsize[i] * sizeof(double));
+    align = std::min(align, alignof_address(ptr[i]));
+  }
   for (auto &p : ptr) std::free(p);
 
   return align;
 }
 
 static auto
-alignof_vector_data(const std::vector<int> &tsize) -> int
+alignof_vector_data(std::vector<int> const &tsize) -> int
 {
   int align = 1 << 30;
   auto n = tsize.size();
@@ -449,10 +441,10 @@ alignof_vector_data(const std::vector<int> &tsize) -> int
   std::vector<std::vector<double>> ptr(n);
 
   for (size_t i = 0; i < n; ++i)
-    {
-      ptr[i].resize(tsize[i]);
-      align = std::min(align, alignof_address(ptr[i].data()));
-    }
+  {
+    ptr[i].resize(tsize[i]);
+    align = std::min(align, alignof_address(ptr[i].data()));
+  }
 
   return align;
 }
@@ -607,7 +599,7 @@ print_filetypes(FILE *fp)
 
   fprintf(fp, "CDI file types: ");
   set_text_color(fp, BRIGHT, GREEN);
-  for (const auto &[type, name] : fileTypes)
+  for (auto const &[type, name] : fileTypes)
     if (cdiHaveFiletype(type)) fprintf(fp, "%s ", name.c_str());
   reset_text_color(fp);
   fprintf(fp, "\n");
@@ -675,38 +667,38 @@ print_rusage()
   struct rusage ru;
   auto status = getrusage(RUSAGE_SELF, &ru);
   if (status == 0)
-    {
-      double ut = ru.ru_utime.tv_sec + 0.000001 * ru.ru_utime.tv_usec;
-      double st = ru.ru_stime.tv_sec + 0.000001 * ru.ru_stime.tv_usec;
+  {
+    double ut = ru.ru_utime.tv_sec + 0.000001 * ru.ru_utime.tv_usec;
+    double st = ru.ru_stime.tv_sec + 0.000001 * ru.ru_stime.tv_usec;
 
-      fprintf(stderr, "  User time:     %.3f seconds\n", ut);
-      fprintf(stderr, "  System time:   %.3f seconds\n", st);
-      fprintf(stderr, "  Total time:    %.3f seconds\n", ut + st);
+    fprintf(stderr, "  User time:     %.3f seconds\n", ut);
+    fprintf(stderr, "  System time:   %.3f seconds\n", st);
+    fprintf(stderr, "  Total time:    %.3f seconds\n", ut + st);
 #if defined(__APPLE__) && defined(__MACH__)
-      fprintf(stderr, "  Memory usage:  %.2f MBytes\n", ru.ru_maxrss / (1024.0 * 1024.0));
+    fprintf(stderr, "  Memory usage:  %.2f MBytes\n", ru.ru_maxrss / (1024.0 * 1024.0));
 #else
-      fprintf(stderr, "  Memory usage:  %.2f MBytes\n", ru.ru_maxrss / (1024.0));
+    fprintf(stderr, "  Memory usage:  %.2f MBytes\n", ru.ru_maxrss / (1024.0));
 #endif
-      fprintf(stderr, "  Page reclaims: %5ld page%s\n", ru.ru_minflt, ADD_PLURAL(ru.ru_minflt));
-      fprintf(stderr, "  Page faults:   %5ld page%s\n", ru.ru_majflt, ADD_PLURAL(ru.ru_majflt));
-      fprintf(stderr, "  Swaps:         %5ld\n", ru.ru_nswap);
-      fprintf(stderr, "  Disk read:     %5ld block%s\n", ru.ru_inblock, ADD_PLURAL(ru.ru_inblock));
-      fprintf(stderr, "  Disk Write:    %5ld block%s\n", ru.ru_oublock, ADD_PLURAL(ru.ru_oublock));
-      /*
-  #if defined(__APPLE__) && defined(__MACH__)
-  #ifdef RUSAGE_INFO_CURRENT
-      pid_t pid = fork();
-      rusage_info_current ruinfo;
-      int rusage_ret = proc_pid_rusage(pid, RUSAGE_INFO_CURRENT, (void **)&ruinfo);
-      if (rusage_ret >= 0 && ruinfo.ri_lifetime_max_phys_footprint > 0)
-        {
-          fprintf(stderr, "  Peak memory:   %.2f MBytes\n", ruinfo.ri_lifetime_max_phys_footprint / 1.0);
-          fprintf(stderr, "  Peak memory:   %.2f MBytes\n", ruinfo.ri_lifetime_max_phys_footprint / (1024.0 * 1024.0));
-        }
-  #endif
-  #endif
-      */
-    }
+    fprintf(stderr, "  Page reclaims: %5ld page%s\n", ru.ru_minflt, ADD_PLURAL(ru.ru_minflt));
+    fprintf(stderr, "  Page faults:   %5ld page%s\n", ru.ru_majflt, ADD_PLURAL(ru.ru_majflt));
+    fprintf(stderr, "  Swaps:         %5ld\n", ru.ru_nswap);
+    fprintf(stderr, "  Disk read:     %5ld block%s\n", ru.ru_inblock, ADD_PLURAL(ru.ru_inblock));
+    fprintf(stderr, "  Disk Write:    %5ld block%s\n", ru.ru_oublock, ADD_PLURAL(ru.ru_oublock));
+    /*
+#if defined(__APPLE__) && defined(__MACH__)
+#ifdef RUSAGE_INFO_CURRENT
+    pid_t pid = fork();
+    rusage_info_current ruinfo;
+    int rusage_ret = proc_pid_rusage(pid, RUSAGE_INFO_CURRENT, (void **)&ruinfo);
+    if (rusage_ret >= 0 && ruinfo.ri_lifetime_max_phys_footprint > 0)
+      {
+        fprintf(stderr, "  Peak memory:   %.2f MBytes\n", ruinfo.ri_lifetime_max_phys_footprint / 1.0);
+        fprintf(stderr, "  Peak memory:   %.2f MBytes\n", ruinfo.ri_lifetime_max_phys_footprint / (1024.0 * 1024.0));
+      }
+#endif
+#endif
+    */
+  }
 #endif
 }
 
