@@ -11,7 +11,7 @@ static std::mutex fftwMutex;
 
 #ifdef HAVE_LIBFFTW3
 void
-fourier2grid(int gridID1, const Varray<double> &array1, Varray<double> &array2)
+fourier2grid(int gridID1, Varray<double> const &array1, Varray<double> &array2)
 {
   auto nlon = gridInqXsize(gridID1);
   auto nlat = gridInqYsize(gridID1);
@@ -65,7 +65,7 @@ fourier2grid(int gridID1, const Varray<double> &array1, Varray<double> &array2)
 }
 
 void
-grid2fourier(int gridID1, const Varray<double> &array1, int gridID2, Varray<double> &array2)
+grid2fourier(int gridID1, Varray<double> const &array1, int gridID2, Varray<double> &array2)
 {
   (void) gridID2;
   auto nlon = gridInqXsize(gridID1);
@@ -121,7 +121,7 @@ grid2fourier(int gridID1, const Varray<double> &array1, int gridID2, Varray<doub
 }
 
 void
-filter_fftw(int nts, const std::vector<int> &fmasc, fftw_complex *fft_out, fftw_plan *p_T2S, fftw_plan *p_S2T)
+filter_fftw(int nts, std::vector<int> const &fmasc, fftw_complex *fft_out, fftw_plan *p_T2S, fftw_plan *p_S2T)
 {
   fftw_execute(*p_T2S);
 
@@ -141,7 +141,7 @@ filter_fftw(int nts, const std::vector<int> &fmasc, fftw_complex *fft_out, fftw_
 
 #include "cdo_output.h"
 void
-fourier2grid(int gridID1, const Varray<double> &array1, Varray<double> &array2)
+fourier2grid(int gridID1, Varray<double> const &array1, Varray<double> &array2)
 {
   (void) gridID1;
   (void) array1;
@@ -150,7 +150,7 @@ fourier2grid(int gridID1, const Varray<double> &array1, Varray<double> &array2)
 }
 
 void
-grid2fourier(int gridID1, const Varray<double> &array1, int gridID2, Varray<double> &array2)
+grid2fourier(int gridID1, Varray<double> const &array1, int gridID2, Varray<double> &array2)
 {
   (void) gridID1;
   (void) gridID2;
