@@ -13,7 +13,7 @@ void grid2fourier(int gridID1, Varray<double> const &array1, int gridID2, Varray
 
 #ifdef HAVE_LIBFFTW3
 #include <fftw3.h>
-void filter_fftw(int nts, const std::vector<int> &fmasc, fftw_complex *fft_out, fftw_plan *p_T2S, fftw_plan *p_S2T);
+void filter_fftw(int nts, std::vector<int> const &fmasc, fftw_complex *fft_out, fftw_plan *p_T2S, fftw_plan *p_S2T);
 #endif
 
 #endif
