@@ -1,17 +1,17 @@
-#ifndef _CDO_GETOPT_H
-#define _CDO_GETOPT_H
+#ifndef CDO_GETOPT_H
+#define CDO_GETOPT_H
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif
 
 #include <map>
-#include <set>
 #include <vector>
 #include <string>
 #include <functional>
 #include <cstdio>
 #include <memory>
+#include <algorithm>
 
 #include "cdo_output.h"
 
@@ -29,23 +29,23 @@ struct cdo_option_argument
 
 struct cdo_option_2
 {
-
-  std::function<void(std::string argument)> effect = [](std::string) {
-    printf("ERROR");
+  std::function<void(std::string argument)> effect = [](std::string)
+  {
+    printf("ERROR effect has not been set. Called empty effect");
     exit(0);
   };
   bool hasArgument = false;
   bool abortOnExecute = false;
-  cdo_option_argument argument = cdo_option_argument();
-  std::vector<std::string> description = std::vector<std::string>();
-  std::string name = std::string();
-  std::string shortName = std::string();
+  cdo_option_argument argument = {};
+  std::vector<std::string> description = {};
+  std::string name = {};
+  std::string shortName = {};
   bool isInternal = false;
-  std::string linkedEnvironmentVariable = std::string();
+  std::string linkedEnvironmentVariable = {};
   std::string category = DEFAULT_CATEGORY;
 
   cdo_option_2 *
-  set_category(const std::string &p_category)
+  set_category(std::string const &p_category)
   {
     category = p_category;
     return this;
@@ -88,14 +88,14 @@ struct cdo_option_2
   }
 
   cdo_option_2 *
-  add_default(const std::string &p_default_value)
+  add_default(std::string const &p_default_value)
   {
     argument.default_value = p_default_value;
     return this;
   }
 
   cdo_option_2 *
-  describe_argument(const std::string &desc)
+  describe_argument(std::string const &desc)
   {
     hasArgument = true;
     argument.description = desc;
@@ -117,7 +117,7 @@ struct cdo_option_2
 
   template <typename... T>
   cdo_option_2 *
-  add_help(const std::string &arg, T... args)
+  add_help(std::string const &arg, T... args)
   {
     add_help(arg);
     add_help(args...);
@@ -129,6 +129,7 @@ struct cdo_option_2
   {
     return argument.value;
   }
+
   void
   execute()
   {
@@ -142,9 +143,10 @@ struct cdo_option_2
     abortOnExecute = aborts;
     return this;
   }
+  const cdo_option_2 *shortform(char p_shortform);
 
   cdo_option_2 *
-  add_env_var(const std::string &p_envVarName)
+  add_env_var(std::string const &p_envVarName)
   {
     linkedEnvironmentVariable = p_envVarName;
     return this;
@@ -155,54 +157,56 @@ struct cdo_option_2
   {
     const char *env_var = getenv(linkedEnvironmentVariable.c_str());
     if (env_var != nullptr)
+    {
+      if (hasArgument)
       {
-        if (hasArgument)
-          {
-            if (*env_var == '\0') { cdo_abort("Error: %s defined but has no value", linkedEnvironmentVariable); }
-            effect(std::string(env_var));
-          }
-        else { effect(std::string()); }
+        if (*env_var == '\0') { cdo_abort("Error: %s defined but has no value", linkedEnvironmentVariable); }
+        effect(std::string(env_var));
       }
+      else { effect(std::string()); }
+    }
   }
 };
 
 class CLIOptions
 {
 private:
-  static std::vector<std::shared_ptr<cdo_option_2>> optionRegistry;
-  static std::map<std::string, std::shared_ptr<cdo_option_2>> optionMap;
+  static std::map<std::string, std::unique_ptr<cdo_option_2>> optionMap;
 
-  static std::vector<std::shared_ptr<cdo_option_2>> envvarRegistry;
-  static std::map<std::string, std::shared_ptr<cdo_option_2>> envvarMap;
+  static std::map<std::string, std::unique_ptr<cdo_option_2>> envvarMap;
 
 public:
-  static const std::map<std::string, std::shared_ptr<cdo_option_2>> &
+  static const std::map<std::string, std::unique_ptr<cdo_option_2>> &
   get_options()
   {
     return optionMap;
   }
-  static const std::map<std::string, std::shared_ptr<cdo_option_2>> &
+  static const std::map<std::string, std::unique_ptr<cdo_option_2>> &
   get_envvars()
   {
     return envvarMap;
   }
-  static std::string pad_size_terminal(char padWith, const std::string &sourround = std::string());
+  static std::string pad_size_terminal(char padWith, std::string const &sourround = std::string());
   const static int EXIT_REQUESTED;
   const static int ABORT_REQUESTED;
   const static int padding;
   static bool print_settings;
   static bool print_envvars;
 
-  static int
-  parse(std::vector<std::string> p_argv);
+  static int parse(std::vector<std::string> p_argv);
   static void get_env_vars();
-  static std::shared_ptr<cdo_option_2> &option(const std::string &p_name, const std::string &p_short_form = std::string());
-  static std::shared_ptr<cdo_option_2> &envvar(const std::string &p_name);
-  static cdo_option_2 *option_from_envvar(const std::string &p_envvarName);
+  static std::unique_ptr<cdo_option_2> &option(std::string const &p_name);
+  static std::unique_ptr<cdo_option_2> &envvar(std::string const &p_name);
+  static cdo_option_2 *option_from_envvar(std::string const &p_envvarName);
+  static void
+  shortform(std::unique_ptr<cdo_option_2> &&long_form, std::string shortform)
+  {
+    optionMap[shortform] = std::move(long_form);
+  }
 
   static void print_available_options();
-  static std::string print_options_help(const std::string &p_category = DEFAULT_CATEGORY);
+  static std::string print_options_help(std::string const &p_category = DEFAULT_CATEGORY);
   static std::string print_envvar_help();
-  static void print_registry(const std::vector<std::shared_ptr<cdo_option_2>> &p_registry);
+  static void print_registry(const std::map<std::string, std::unique_ptr<cdo_option_2>> &p_registry);
 };
 #endif /* _CDO_GETOPT_H */
