@@ -7,11 +7,11 @@
 namespace cdo
 {
   constexpr double sqr(double x) noexcept { return x * x; }
-  constexpr double sqr_distance(const std::array<double, 3> &a, const std::array<double, 3> &b) noexcept
+  constexpr double sqr_distance(std::array<double, 3> const &a, std::array<double, 3> const &b) noexcept
   {
     return sqr(a[0] - b[0]) + sqr(a[1] - b[1]) + sqr(a[2] - b[2]);
   }
-  constexpr double sqr_distance(const double *a, const double *b) noexcept
+  constexpr double sqr_distance(double const (&a)[3], double const (&b)[3]) noexcept
   {
     return sqr(a[0] - b[0]) + sqr(a[1] - b[1]) + sqr(a[2] - b[2]);
   }
