@@ -74,6 +74,7 @@ bool CDO_Async_Read = false;
 int CDO_Reduce_Dim = false;
 int CDO_Append_History = true;
 bool CDO_Reset_History = false;
+bool PrintFilename = false;
 bool CDO_task = false;
 
 unsigned Random_Seed = 1;
@@ -87,6 +88,7 @@ int cdoChunkSizeDimX{ 0 };
 bool cdoOverwriteMode = false;
 bool cdoParIO = false;
 bool cdoRegulargrid = false;
+std::string cdoQueryParameter;
 std::vector<std::string> cdoVarnames;
 
 size_t
