@@ -70,9 +70,9 @@ print_debug_options()
 namespace cdo
 {
 void
-parse_debug_arguments(const std::vector<std::string> &tokens, unsigned &cdoDebugLevel, unsigned &cdiDebugLevel)
+parse_debug_arguments(std::vector<std::string> const &tokens, unsigned &cdoDebugLevel, unsigned &cdiDebugLevel)
 {
-  for (const auto &t : tokens)
+  for (auto const &t : tokens)
     {
       if (t.substr(0, 4).compare("ext=") == 0)
         {
@@ -249,7 +249,7 @@ checkForMissingLib(int filetype)
 }
 
 void
-cdi_open_error(int cdiErrno, const std::string &format, const char *path)
+cdi_open_error(int cdiErrno, std::string const &format, const char *path)
 {
   std::string context = cdo::getContext();
   MpMO::PrintCerr(Red("%s: ") + format + "\n" + std::string(context.size() + 2, ' ') + "%s", context, path,
@@ -267,7 +267,7 @@ cdi_open_error(int cdiErrno, const std::string &format, const char *path)
 }
 
 void
-query_user_exit(const std::string &argument)
+query_user_exit(std::string const &argument)
 {
   // modified code from NCO
 #define USR_RPL_MAX_LNG 10 /* Maximum length for user reply */
@@ -319,9 +319,9 @@ query_user_exit(const std::string &argument)
 }
 
 std::string
-cdo_argv_to_string(const std::vector<std::string> &argv)
+cdo_argv_to_string(std::vector<std::string> const &argv)
 {
   std::string s_argv = "";
-  for (const auto &x : argv) { s_argv += x + " "; }
+  for (auto const &x : argv) { s_argv += x + " "; }
   return s_argv;
 }
