@@ -14,33 +14,32 @@
 #include "cdi_lockedIO.h"
 #include "varray.h"
 
-int
-cdo_read_timestepmask(const std::string &maskfile, std::vector<bool> &imask)
+std::vector<bool>
+cdo_read_timestepmask(std::string const &maskFileName)
 {
-  auto streamID = stream_open_read_locked(maskfile.c_str());
+  auto streamID = stream_open_read_locked(maskFileName.c_str());
   auto vlistID = streamInqVlist(streamID);
   VarList varList(vlistID);
-  const auto &var0 = varList.vars[0];
+  auto const &var0 = varList.vars[0];
 
-  if (varList.numVars() > 1) cdo_abort("timestepmask %s contains more than one variable!", maskfile);
-  if (var0.nlevels > 1) cdo_abort("timestepmask %s has more than one level!", maskfile);
-  if (var0.gridsize > 1) cdo_abort("timestepmask %s has more than one gridpoint!", maskfile);
+  if (varList.numVars() > 1) cdo_abort("timestepmask %s contains more than one variable!", maskFileName);
+  if (var0.nlevels > 1) cdo_abort("timestepmask %s has more than one level!", maskFileName);
+  if (var0.gridsize > 1) cdo_abort("timestepmask %s has more than one gridpoint!", maskFileName);
 
-  auto nts = varList.numSteps();
-  if (nts == -1)
+  auto numSteps = varList.numSteps();
+  if (numSteps == -1)
     {
-      nts = 0;
-      while (streamInqTimestep(streamID, nts)) nts++;
+      numSteps = 0;
+      while (streamInqTimestep(streamID, numSteps)) numSteps++;
 
-      if (Options::cdoVerbose) cdo_print("%s: counted %i timeSteps in %s", __func__, nts, maskfile);
+      if (Options::cdoVerbose) cdo_print("%s: counted %i timeSteps in %s", __func__, numSteps, maskFileName);
 
       streamClose(streamID);
-      streamID = stream_open_read_locked(maskfile.c_str());
+      streamID = stream_open_read_locked(maskFileName.c_str());
     }
-  else if (Options::cdoVerbose) { cdo_print("%s: found %i timeSteps in %s", __func__, nts, maskfile); }
+  else if (Options::cdoVerbose) { cdo_print("%s: found %i timeSteps in %s", __func__, numSteps, maskFileName); }
 
-  int n = nts;
-  imask.resize(nts);
+  std::vector<bool> imask(numSteps);
 
   int tsID = 0;
   while (true)
@@ -63,54 +62,50 @@ cdo_read_timestepmask(const std::string &maskfile, std::vector<bool> &imask)
 
   streamClose(streamID);
 
-  return n;
+  return imask;
 }
 
-static void
-read_one_field(const char *text, const char *filename, Varray<double> &array)
+static Varray<double>
+read_one_field(const char *text, const char *filename)
 {
   auto streamID = stream_open_read_locked(filename);
   auto vlistID = streamInqVlist(streamID);
   VarList varList(vlistID);
-  const auto &var0 = varList.vars[0];
+  auto const &var0 = varList.vars[0];
 
   if (varList.numVars() > 1) cdo_abort("%s file %s contains more than one variable!", text, filename);
   if (var0.nlevels > 1) cdo_abort("%s file %s has more than one level!", text, filename);
   if (varList.maxFields() != 1) cdo_abort("%s file %s contains more than one field!", text, filename);
 
-  array.resize(var0.gridsize);
+  Varray<double> array(var0.gridsize);
 
   int varID, levelID;
   size_t numMissVals;
   streamInqField(streamID, &varID, &levelID);
   streamReadField(streamID, array.data(), &numMissVals);
   streamClose(streamID);
+
+  return array;
 }
 
-size_t
-cdo_read_mask(const char *maskfile, std::vector<bool> &imask)
+std::vector<bool>
+cdo_read_mask(const char *maskFileName)
 {
-  Varray<double> array;
-  read_one_field("Mask", maskfile, array);
-
+  auto array = read_one_field("Mask", maskFileName);
   auto gridsize = array.size();
-  imask.resize(gridsize);
-
+  std::vector<bool> imask(gridsize);
   for (size_t i = 0; i < gridsize; ++i) imask[i] = is_not_equal(array[i], 0);
 
-  return gridsize;
+  return imask;
 }
 
-size_t
-cdo_read_index(const char *indexfile, std::vector<int> &index)
+std::vector<int>
+cdo_read_index(const char *indexFileName)
 {
-  Varray<double> array;
-  read_one_field("Index", indexfile, array);
-
+  auto array = read_one_field("Index", indexFileName);
   auto gridsize = array.size();
-  index.resize(gridsize);
-
+  std::vector<int> index(gridsize);
   for (size_t i = 0; i < gridsize; ++i) index[i] = (int) std::lround(array[i]) - 1;
 
-  return gridsize;
+  return index;
 }
