@@ -3,8 +3,8 @@
 #include "cdo_syntax_error.h"
 #include "mpmo_color.h"
 
-InternalCdoSyntaxError::InternalCdoSyntaxError(std::vector<std::string>::const_iterator p_iter, const std::string &p_msg,
-                                               const std::string &p_file, const std::string &p_line)
+InternalCdoSyntaxError::InternalCdoSyntaxError(std::vector<std::string>::const_iterator p_iter, std::string const &p_msg,
+                                               std::string const &p_file, std::string const &p_line)
     : CdoException(p_msg, p_file, p_line), iter(p_iter)
 {
 }
