@@ -22,6 +22,8 @@
 #include "varray.h"
 #include "cdi_lockedIO.h"
 
+namespace
+{
 struct ZaxisDesciption
 {
   Varray<double> vals;
@@ -37,6 +39,7 @@ struct ZaxisDesciption
   std::string longname;
   std::string units;
 };
+}  // namespace
 
 int
 zaxisDefine(ZaxisDesciption zaxis)
@@ -59,12 +62,12 @@ zaxisDefine(ZaxisDesciption zaxis)
   if (zaxis.units.size()) cdiDefKeyString(zaxisID, CDI_GLOBAL, CDI_KEY_UNITS, zaxis.units.c_str());
 
   if (zaxis.type == ZAXIS_HYBRID || zaxis.type == ZAXIS_HYBRID_HALF)
-    {
-      if (zaxis.vctsize && zaxis.vct.size())
-        zaxisDefVct(zaxisID, (int) zaxis.vctsize, zaxis.vct.data());
-      else
-        cdo_warning("vct undefined!");
-    }
+  {
+    if (zaxis.vctsize && zaxis.vct.size())
+      zaxisDefVct(zaxisID, (int) zaxis.vctsize, zaxis.vct.data());
+    else
+      cdo_warning("vct undefined!");
+  }
 
   return zaxisID;
 }
@@ -79,20 +82,20 @@ struct KVMap
 }  // namespace
 
 static void
-zaxis_read_data(const std::vector<KVMap> &kvmap, ZaxisDesciption &zaxis, size_t &natts, const char *dname)
+zaxis_read_data(std::vector<KVMap> const &kvmap, ZaxisDesciption &zaxis, size_t &natts, const char *dname)
 {
   for (size_t ik = 0; ik < kvmap.size(); ++ik)
-    {
-      if (!kvmap[ik].isValid) continue;
+  {
+    if (!kvmap[ik].isValid) continue;
 
-      auto kv = kvmap[ik].kv;
-      const auto &key = kv->key;
-      size_t nvalues = kv->nvalues;
-      if (nvalues == 0) continue;
-      const auto &values = kv->values;
-      const auto &value = kv->values[0];
+    auto kv = kvmap[ik].kv;
+    auto const &key = kv->key;
+    size_t nvalues = kv->nvalues;
+    if (nvalues == 0) continue;
+    auto const &values = kv->values;
+    auto const &value = kv->values[0];
 
-      // clang-format off
+    // clang-format off
       if (key == "zaxistype")
         {
           auto zaxistype = parameter_to_word(value);
@@ -156,57 +159,57 @@ zaxis_read_data(const std::vector<KVMap> &kvmap, ZaxisDesciption &zaxis, size_t
           natts = ik;
           break;
         }
-      // clang-format on
-    }
+    // clang-format on
+  }
 }
 
 static void
-zaxis_read_attributes(size_t natts, const std::vector<KVMap> &kvmap, int zaxisID)
+zaxis_read_attributes(size_t natts, std::vector<KVMap> const &kvmap, int zaxisID)
 {
   const std::vector<std::string> reservedKeys
       = { "zaxistype", "size", "scalar", "vctsize", "name", "units", "longname", "levels", "lbounds", "ubounds", "vct" };
   const char *attkey0 = nullptr;
 
   for (size_t ik = natts; ik < kvmap.size(); ++ik)
+  {
+    if (!kvmap[ik].isValid) continue;
+
+    const auto kv = kvmap[ik].kv;
+    auto const &key = kv->key;
+    size_t nvalues = kv->nvalues;
+    if (nvalues == 0) continue;
+    auto const &values = kv->values;
+    auto const &value = kv->values[0];
+
+    if (ik == natts)
+      attkey0 = key.c_str();
+    else
     {
-      if (!kvmap[ik].isValid) continue;
-
-      const auto kv = kvmap[ik].kv;
-      const auto &key = kv->key;
-      size_t nvalues = kv->nvalues;
-      if (nvalues == 0) continue;
-      const auto &values = kv->values;
-      const auto &value = kv->values[0];
-
-      if (ik == natts)
-        attkey0 = key.c_str();
-      else
-        {
-          for (const auto &reservedKey : reservedKeys)
-            if (key == reservedKey)
-              cdo_abort("Found reserved keyword >%s< in attribute names! Check name or position of >%s<.", key, attkey0);
-        }
-
-      auto dtype = literals_find_datatype(nvalues, values);
-
-      if (dtype == CDI_DATATYPE_INT8 || dtype == CDI_DATATYPE_INT16 || dtype == CDI_DATATYPE_INT32)
-        {
-          std::vector<int> ivals(nvalues);
-          for (size_t i = 0; i < nvalues; ++i) ivals[i] = literal_to_int(values[i]);
-          cdiDefAttInt(zaxisID, CDI_GLOBAL, key.c_str(), dtype, nvalues, ivals.data());
-        }
-      else if (dtype == CDI_DATATYPE_FLT32 || dtype == CDI_DATATYPE_FLT64)
-        {
-          Varray<double> dvals(nvalues);
-          for (size_t i = 0; i < nvalues; ++i) dvals[i] = literal_to_double(values[i]);
-          cdiDefAttFlt(zaxisID, CDI_GLOBAL, key.c_str(), dtype, nvalues, dvals.data());
-        }
-      else
-        {
-          auto len = (int) value.size();
-          cdiDefAttTxt(zaxisID, CDI_GLOBAL, key.c_str(), len, value.c_str());
-        }
+      for (auto const &reservedKey : reservedKeys)
+        if (key == reservedKey)
+          cdo_abort("Found reserved keyword >%s< in attribute names! Check name or position of >%s<.", key, attkey0);
     }
+
+    auto dtype = literals_find_datatype(nvalues, values);
+
+    if (dtype == CDI_DATATYPE_INT8 || dtype == CDI_DATATYPE_INT16 || dtype == CDI_DATATYPE_INT32)
+    {
+      std::vector<int> ivals(nvalues);
+      for (size_t i = 0; i < nvalues; ++i) ivals[i] = literal_to_int(values[i]);
+      cdiDefAttInt(zaxisID, CDI_GLOBAL, key.c_str(), dtype, nvalues, ivals.data());
+    }
+    else if (dtype == CDI_DATATYPE_FLT32 || dtype == CDI_DATATYPE_FLT64)
+    {
+      Varray<double> dvals(nvalues);
+      for (size_t i = 0; i < nvalues; ++i) dvals[i] = literal_to_double(values[i]);
+      cdiDefAttFlt(zaxisID, CDI_GLOBAL, key.c_str(), dtype, nvalues, dvals.data());
+    }
+    else
+    {
+      auto len = (int) value.size();
+      cdiDefAttTxt(zaxisID, CDI_GLOBAL, key.c_str(), len, value.c_str());
+    }
+  }
 }
 
 int
@@ -226,17 +229,17 @@ zaxis_from_file(FILE *zfp, const char *filename)
   size_t ik = 0;
   const std::string firstKey = "zaxistype";
   for (auto &kv : kvlist)
-    {
-      if (ik == 0 && kv.key != firstKey) cdo_abort("First zaxis description keyword must be >%s< (found: %s)!", firstKey, kv.key);
+  {
+    if (ik == 0 && kv.key != firstKey) cdo_abort("First zaxis description keyword must be >%s< (found: %s)!", firstKey, kv.key);
 
-      if (kv.nvalues == 0) { cdo_warning("Z-axis description keyword %s has no values, skipped!", kv.key); }
-      else
-        {
-          kvmap[ik].isValid = true;
-          kvmap[ik].kv = &kv;
-        }
-      ik++;
+    if (kv.nvalues == 0) { cdo_warning("Z-axis description keyword %s has no values, skipped!", kv.key); }
+    else
+    {
+      kvmap[ik].isValid = true;
+      kvmap[ik].kv = &kv;
     }
+    ik++;
+  }
 
   ZaxisDesciption zaxis;
 
@@ -250,7 +253,7 @@ zaxis_from_file(FILE *zfp, const char *filename)
 }
 
 static void
-gen_zaxis_height(ZaxisDesciption &zaxis, const std::string &zaxisname)
+gen_zaxis_height(ZaxisDesciption &zaxis, std::string const &zaxisname)
 {
   int zaxistype = ZAXIS_HEIGHT;
 
@@ -258,7 +261,7 @@ gen_zaxis_height(ZaxisDesciption &zaxis, const std::string &zaxisname)
 
   double value = 0.0;
   std::vector<char> unitsString(zaxisname.size(), 0);
-  auto numVals = sscanf(zaxisname.c_str(), "height_%lf%s", &value, unitsString.data());
+  auto numVals = std::sscanf(zaxisname.c_str(), "height_%lf%s", &value, unitsString.data());
   // printf("%s: %d %g%s\n", zaxisname.c_str(), numVals, value, unitsString.data());
 
   if (numVals != 2) return;
@@ -274,14 +277,14 @@ gen_zaxis_height(ZaxisDesciption &zaxis, const std::string &zaxisname)
 
   auto len = units.size();
   if (len > 2 && units[len - 2] == '_' && units[len - 1] == 's')
-    {
-      zaxis.units.resize(len - 2);
-      zaxis.scalar = true;
-    }
+  {
+    zaxis.units.resize(len - 2);
+    zaxis.scalar = true;
+  }
 }
 
 int
-zaxis_from_name(const std::string &zaxisname)
+zaxis_from_name(std::string const &zaxisname)
 {
   int zaxisID = CDI_UNDEFID;
 
@@ -290,12 +293,12 @@ zaxis_from_name(const std::string &zaxisname)
   ZaxisDesciption zaxis;
 
   if (zaxisNameLC == "surface")  // surface
-    {
-      zaxis.type = ZAXIS_SURFACE;
-      zaxis.size = 1;
-      zaxis.vals.resize(zaxis.size);
-      zaxis.vals[0] = 0;
-    }
+  {
+    zaxis.type = ZAXIS_SURFACE;
+    zaxis.size = 1;
+    zaxis.vals.resize(zaxis.size);
+    zaxis.vals[0] = 0;
+  }
   else if (zaxisNameLC.starts_with("height")) { gen_zaxis_height(zaxis, zaxisNameLC); }
 
   if (zaxis.type != CDI_UNDEFID) zaxisID = zaxisDefine(zaxis);
@@ -314,75 +317,74 @@ cdo_define_zaxis(const char *pzaxisfile)
 
   int zaxisNumber = 1;
   if (len > 2 && zaxisfile[len - 2] == ':' && std::isdigit(zaxisfile[len - 1]))
-    {
-      zaxisNumber = zaxisfile[len - 1] - '0';
-      zaxisfile[len - 2] = 0;
-    }
+  {
+    zaxisNumber = zaxisfile[len - 1] - '0';
+    zaxisfile[len - 2] = 0;
+  }
 
   auto fileno = open(zaxisfile, O_RDONLY);
   if (fileno >= 0)
-    {
-      struct stat filestat;
-      if (fstat(fileno, &filestat) == 0) isreg = S_ISREG(filestat.st_mode);
-    }
+  {
+    struct stat filestat;
+    if (fstat(fileno, &filestat) == 0) isreg = S_ISREG(filestat.st_mode);
+  }
 
   if (fileno == -1 || !isreg)
-    {
-      if (isreg) close(fileno);
-      zaxisID = zaxis_from_name(zaxisfile);
-      if (zaxisID == CDI_UNDEFID) cdo_abort("Open failed on %s!", zaxisfile);
-    }
+  {
+    if (isreg) close(fileno);
+    zaxisID = zaxis_from_name(zaxisfile);
+    if (zaxisID == CDI_UNDEFID) cdo_abort("Open failed on %s!", zaxisfile);
+  }
   else
+  {
+    char buffer[4];
+    if (read(fileno, buffer, 4) != 4) cdo_sys_error("Read grid from %s failed!", zaxisfile);
+
+    close(fileno);
+
+    if (zaxisID == CDI_UNDEFID)
     {
-      char buffer[4];
-      if (read(fileno, buffer, 4) != 4) cdo_sys_error("Read grid from %s failed!", zaxisfile);
-
-      close(fileno);
-
-      if (zaxisID == CDI_UNDEFID)
-        {
-          Debug(cdoDebug, "Zaxis from CDI file");
-          open_lock();
-          auto streamID = streamOpenRead(zaxisfile);
-          open_unlock();
-          if (streamID >= 0)
-            {
-              auto vlistID = streamInqVlist(streamID);
-              auto numZaxes = vlistNumZaxis(vlistID);
-              if (zaxisNumber < 1 || zaxisNumber > numZaxes)
-                cdo_abort("Zaxis number %d not available in %s!", zaxisNumber, zaxisfile);
-              zaxisID = vlistZaxis(vlistID, zaxisNumber - 1);
-              streamClose(streamID);
-            }
-        }
-
-      if (zaxisID == CDI_UNDEFID)
-        {
-          Debug(cdoDebug, "zaxis from ASCII file");
-          auto zfp = std::fopen(zaxisfile, "r");
-          zaxisID = zaxis_from_file(zfp, zaxisfile);
-          std::fclose(zfp);
-        }
-
-      if (zaxisID == CDI_UNDEFID) cdo_abort("Invalid zaxis description file %s!", zaxisfile);
+      Debug(cdoDebug, "Zaxis from CDI file");
+      open_lock();
+      auto streamID = streamOpenRead(zaxisfile);
+      open_unlock();
+      if (streamID >= 0)
+      {
+        auto vlistID = streamInqVlist(streamID);
+        auto numZaxes = vlistNumZaxis(vlistID);
+        if (zaxisNumber < 1 || zaxisNumber > numZaxes) cdo_abort("Zaxis number %d not available in %s!", zaxisNumber, zaxisfile);
+        zaxisID = vlistZaxis(vlistID, zaxisNumber - 1);
+        streamClose(streamID);
+      }
     }
 
+    if (zaxisID == CDI_UNDEFID)
+    {
+      Debug(cdoDebug, "zaxis from ASCII file");
+      auto zfp = std::fopen(zaxisfile, "r");
+      zaxisID = zaxis_from_file(zfp, zaxisfile);
+      std::fclose(zfp);
+    }
+
+    if (zaxisID == CDI_UNDEFID) cdo_abort("Invalid zaxis description file %s!", zaxisfile);
+  }
+
   std::free(zaxisfile);
 
   return zaxisID;
 }
 
 int
-cdo_define_zaxis(const std::string &zaxisfile)
+cdo_define_zaxis(std::string const &zaxisfile)
 {
   return cdo_define_zaxis(zaxisfile.c_str());
 }
 
 void
-cdo_set_zaxes(const std::string &zaxisarg)
+cdo_set_zaxes(std::string const &zaxisarg)
 {
   auto zaxisNames = split_string(zaxisarg, ",");
-  for (const auto &zaxisName : zaxisNames) cdo_define_zaxis(zaxisName);
+  for (auto const &name : zaxisNames) cdo_define_zaxis(name);
 }
 
 static int
@@ -417,24 +419,24 @@ zaxis_to_ltype(int zaxisID)
 }
 
 void
-gen_layer_bounds(int nlev, const Varray<double> &levels, Varray<double> &lbounds, Varray<double> &ubounds)
+gen_layer_bounds(int nlev, Varray<double> const &levels, Varray<double> &lbounds, Varray<double> &ubounds)
 {
   if (nlev == 1)
-    {
-      lbounds[0] = 0.0;
-      ubounds[0] = 1.0;
-    }
+  {
+    lbounds[0] = 0.0;
+    ubounds[0] = 1.0;
+  }
   else
+  {
+    lbounds[0] = levels[0];
+    ubounds[nlev - 1] = levels[nlev - 1];
+    for (int i = 0; i < nlev - 1; ++i)
     {
-      lbounds[0] = levels[0];
-      ubounds[nlev - 1] = levels[nlev - 1];
-      for (int i = 0; i < nlev - 1; ++i)
-        {
-          auto bound = 0.5 * (levels[i] + levels[i + 1]);
-          lbounds[i + 1] = bound;
-          ubounds[i] = bound;
-        }
+      auto bound = 0.5 * (levels[i] + levels[i + 1]);
+      lbounds[i + 1] = bound;
+      ubounds[i] = bound;
     }
+  }
 }
 
 int
@@ -446,16 +448,16 @@ get_layer_thickness(bool useWeights, bool genBounds, int index, int zaxisID, int
 
   cdo_zaxis_inq_levels(zaxisID, levels.data());
   if (genBounds)
-    {
-      status = 2;
-      gen_layer_bounds(nlev, levels, lbounds, ubounds);
-    }
+  {
+    status = 2;
+    gen_layer_bounds(nlev, levels, lbounds, ubounds);
+  }
   else if (useWeights && zaxisInqLbounds(zaxisID, nullptr) && zaxisInqUbounds(zaxisID, nullptr))
-    {
-      status = 1;
-      zaxisInqLbounds(zaxisID, lbounds.data());
-      zaxisInqUbounds(zaxisID, ubounds.data());
-    }
+  {
+    status = 1;
+    zaxisInqLbounds(zaxisID, lbounds.data());
+    zaxisInqUbounds(zaxisID, ubounds.data());
+  }
 
   for (int i = 0; i < nlev; ++i) thickness[i] = std::fabs(ubounds[i] - lbounds[i]);
 
@@ -465,12 +467,12 @@ get_layer_thickness(bool useWeights, bool genBounds, int index, int zaxisID, int
   auto weightSum = varray_sum(nlev, weights);
 
   if (Options::cdoVerbose)
-    {
-      cdo_print("zaxisID=%d  nlev=%d  layersum=%g  weightsum=%g", index, nlev, layerSum, weightSum);
-      printf("         level     bounds   thickness  weight\n");
-      for (int i = 0; i < nlev; ++i)
-        printf("   %3d  %6g  %6g/%-6g  %6g  %6g\n", i + 1, levels[i], lbounds[i], ubounds[i], thickness[i], weights[i]);
-    }
+  {
+    cdo_print("zaxisID=%d  nlev=%d  layersum=%g  weightsum=%g", index, nlev, layerSum, weightSum);
+    printf("         level     bounds   thickness  weight\n");
+    for (int i = 0; i < nlev; ++i)
+      printf("   %3d  %6g  %6g/%-6g  %6g  %6g\n", i + 1, levels[i], lbounds[i], ubounds[i], thickness[i], weights[i]);
+  }
 
   return status;
 }
