@@ -62,7 +62,7 @@ static char *
 getElementName(char *pline, char *name)
 {
   while (std::isspace((int) *pline)) pline++;
-  auto len = strlen(pline);
+  auto len = std::strlen(pline);
   size_t pos = 0;
   while (pos < len && !std::isspace((int) *(pline + pos)) && *(pline + pos) != '=' && *(pline + pos) != ':') pos++;
 
@@ -77,7 +77,7 @@ static char *
 getElementValue(char *pline)
 {
   while (std::isspace((int) *pline)) pline++;
-  auto len = strlen(pline);
+  auto len = std::strlen(pline);
   if (*pline != '"' && *pline != '\'')
     for (size_t i = 1; i < len; ++i)
       if (pline[i] == '!')
@@ -110,15 +110,15 @@ parse_cmortable_buffer(PMList &pmlist, size_t buffersize, char *buffer)
       auto pline = line;
       while (std::isspace((int) *pline)) pline++;
       if (*pline == '#' || *pline == '!' || *pline == '\0') continue;
-      //  len = (int) strlen(pline);
+      //  len = (int) std::strlen(pline);
 
       int ientry = -1;
       for (ientry = 0; ientry < nentry; ++ientry)
-        if (std::strncmp(pline, listentry[ientry], strlen(listentry[ientry])) == 0) break;
+        if (std::strncmp(pline, listentry[ientry], std::strlen(listentry[ientry])) == 0) break;
 
       if (ientry < nentry)
         {
-          pline += strlen(listentry[ientry]);
+          pline += std::strlen(listentry[ientry]);
 
           if (kvlist.size())
             {
