@@ -15,10 +15,6 @@ constexpr double MAX_T = 400.;
 constexpr double MIN_Q = 0.0;
 constexpr double MAX_Q = 0.1;
 
-#ifndef M_LN10
-#define M_LN10 2.30258509299404568401799145468436421 /* log_e 10 */
-#endif
-
 #ifndef M_PI
 #define M_PI 3.14159265358979323846264338327950288 /* pi */
 #endif
