@@ -47,7 +47,7 @@ public:
   TimeUnits units = TimeUnits::SECONDS;
 
   TimeIncrement() {}
-  TimeIncrement(int64_t _period, TimeUnits _units) : period(_period), units(_units) {}
+  TimeIncrement(int64_t _period, TimeUnits _units) : period{ _period }, units{ _units } {}
 
   bool
   operator==(const TimeIncrement &timeIncr) const
@@ -64,10 +64,10 @@ public:
 
 struct CheckTimeIncr
 {
-  JulianDate julianDate0;
-  TimeIncrement timeIncr;
+  JulianDate julianDate0{};
+  TimeIncrement timeIncr{};
   CdiDate vDate0{};
-  bool printWarning = true;
+  bool printWarning{ true };
 };
 
 // clang-format off
@@ -80,14 +80,14 @@ DateTimeList
 {
 public:
   // clang-format off
-  DateTimeList() { init(); dtInfo.resize(2); }
-  void set_year(int _year) { this->year = _year; }
-  void set_stat(TimeStat _stat) { this->stat = _stat; }
-  void set_calendar(int _calendar) { this->calendar = _calendar; }
-  size_t get_size(){ return this->size; }
-  const std::vector<DateTimeInfo>& get_info() { return this->dtInfo; }
+  DateTimeList() { init(); m_dtInfo.resize(2); }
+  void set_year(int year) { m_year = year; }
+  void set_stat(TimeStat stat) { m_stat = stat; }
+  void set_calendar(int calendar) { m_calendar = calendar; }
+  size_t size(){ return m_size; }
+  std::vector<DateTimeInfo> const& info() { return m_dtInfo; }
   // clang-format on
-  CdiDateTime get_vDateTime(int tsID);
+  CdiDateTime vDateTime(int tsID);
   void shift();
 
   void taxis_set_next_timestep(int taxisID);
@@ -97,45 +97,45 @@ public:
   void stat_taxis_def_timestep(int taxisID);
 
 private:
-  size_t size{ 0 };
-  int year{ 0 };
-  int hasBounds{ -1 };
-  int calendar{ -1 };
-  TimeStat stat{ TimeStat::LAST };
-  DateTimeInfo timestat;
-  std::vector<DateTimeInfo> dtInfo;
+  size_t m_size{ 0 };
+  int m_year{ 0 };
+  int m_hasBounds{ -1 };
+  int m_calendar{ -1 };
+  TimeStat m_stat{ TimeStat::LAST };
+  DateTimeInfo m_timestat{};
+  std::vector<DateTimeInfo> m_dtInfo{};
 
   void init();
   void mean(int nsteps);
   void midhigh(int nsteps);
 };
 
-CdiDateTime datetime_avg(int calendar, int ndates, const std::vector<CdiDateTime> &cdiDateTimes);
-void set_timestat_date(const std::string &p_optarg);
+CdiDateTime datetime_avg(int calendar, int ndates, std::vector<CdiDateTime> const &cdiDateTimes);
+void set_timestat_date(std::string const &p_optarg);
 
 void adjust_month_and_year(int &month, int &year);
 
-double delta_time_step_0(int tsID, int calendar, const CdiDateTime &vDateTime, JulianDate &juldate0, double &deltat1);
+double delta_time_step_0(int tsID, int calendar, CdiDateTime const &vDateTime, JulianDate &juldate0, double &deltat1);
 
 TimeIncrement get_time_increment(double jdelta, CdiDate vDate0, CdiDate vDate1);
 
-void check_time_increment(int tsID, int calendar, const CdiDateTime &vDateTime, CheckTimeIncr &checkTimeIncr);
+void check_time_increment(int tsID, int calendar, CdiDateTime const &vDateTime, CheckTimeIncr &checkTimeIncr);
 
-int decode_month(const CdiDate &date);
-int decode_month_and_day(const CdiDate &date);
+int decode_month(CdiDate const &date);
+int decode_month_and_day(CdiDate const &date);
 
-int decode_day_of_year(const CdiDate &date);
-int decode_hour_of_year(const CdiDateTime &cdiDateTime, int maxHours);
-int decode_hour_of_day(const CdiDateTime &cdiDateTime, int maxHours);
-int decode_minute_of_day(const CdiDateTime &cdiDateTime, int maxMinutes);
+int decode_day_of_year(CdiDate const &date);
+int decode_hour_of_year(CdiDateTime const &cdiDateTime, int maxHours);
+int decode_hour_of_day(CdiDateTime const &cdiDateTime, int maxHours);
+int decode_minute_of_day(CdiDateTime const &cdiDateTime, int maxMinutes);
 
 void set_date_time(CdiDateTime &datetime1, CdiDateTime datetime2);
 
 const char *time_units_cstr(TimeUnits timeUnit);
 
-CdiDate decode_datestring(const std::string &dateString);
-CdiTime decode_timestring(const std::string &timeString);
-void decode_timeunits(const std::string &timeUnitsString, int &incrPeriod, int &incrUnits, int &timeUnits);
+CdiDate decode_datestring(std::string const &dateString);
+CdiTime decode_timestring(std::string const &timeString);
+void decode_timeunits(std::string const &timeUnitsString, int &incrPeriod, int &incrUnits, int &timeUnits);
 
 int day_of_year(int calendar, int64_t date);
 
