@@ -34,7 +34,7 @@ unsigned long day_of_year(int date);
  * @param field1 the 1st input field, also holds the result
  * @param field2 the 2nd input field
  */
-void vfarnum(Field &field1, const Field &field2);
+void vfarnum(Field &field1, Field const &field2);
 
 /**
  * Counts the number of consecutive nonumMissValsing values in a field.
@@ -50,7 +50,7 @@ void vfarnum(Field &field1, const Field &field2);
  * @param field1 the 1st input field, also holds the result
  * @param field2 the 2nd input field
  */
-void vfarnum2(Field &field1, const Field &field2);
+void vfarnum2(Field &field1, Field const &field2);
 
 /**
  * Counts the number of values in series of at least n consecutive
@@ -68,7 +68,7 @@ void vfarnum2(Field &field1, const Field &field2);
  * @param n      the number of consecutive values, must be an exact
  *               mathematical integer
  */
-void vfarnum3(Field &field1, const Field &field2, double n);
+void vfarnum3(Field &field1, Field const &field2, double n);
 
 /**
  * Selects field elements according to a given mask. The result of
@@ -83,7 +83,7 @@ void vfarnum3(Field &field1, const Field &field2, double n);
  * @param field1  the input field, also holds the result
  * @param field2  the mask
  */
-void vfarsel(Field &field1, const Field &field2);
+void vfarsel(Field &field1, Field const &field2);
 
 /**
  * Selects all field elements that are less than or equal to the
@@ -99,7 +99,7 @@ void vfarsel(Field &field1, const Field &field2);
  * @param field1 the input field, also holds the result
  * @param field2 the reference field
  */
-void vfarselle(Field &field1, const Field &field2);
+void vfarselle(Field &field1, Field const &field2);
 
 /**
  * Selects all field elements that are less than the
@@ -115,7 +115,7 @@ void vfarselle(Field &field1, const Field &field2);
  * @param field1 the input field, also holds the result
  * @param field2 the reference field
  */
-void vfarsellt(Field &field1, const Field &field2);
+void vfarsellt(Field &field1, Field const &field2);
 
 /**
  * Selects all field elements that are greater than or equal to
@@ -131,7 +131,7 @@ void vfarsellt(Field &field1, const Field &field2);
  * @param field1 the input field, also holds the result
  * @param field2 the reference field
  */
-void vfarselge(Field &field1, const Field &field2);
+void vfarselge(Field &field1, Field const &field2);
 
 /**
  * Selects all field elements that are greater than the
@@ -147,7 +147,7 @@ void vfarselge(Field &field1, const Field &field2);
  * @param field1 the input field, also holds the result
  * @param field2 the reference field
  */
-void vfarselgt(Field &field1, const Field &field2);
+void vfarselgt(Field &field1, Field const &field2);
 
 /**
  * Selects all field elements that are equal to the
@@ -163,7 +163,7 @@ void vfarselgt(Field &field1, const Field &field2);
  * @param field1 the input field, also holds the result
  * @param field2 the reference field
  */
-void vfarseleq(Field &field1, const Field &field2);
+void vfarseleq(Field &field1, Field const &field2);
 
 /**
  * Selects all field elements that are not equal to the
@@ -179,7 +179,7 @@ void vfarseleq(Field &field1, const Field &field2);
  * @param field1 the input field, also holds the result
  * @param field2 the reference field
  */
-void vfarselne(Field &field1, const Field &field2);
+void vfarselne(Field &field1, Field const &field2);
 
 /**
  * Selects all field elements that are less than or equal to a
@@ -287,7 +287,7 @@ void vfarselnec(Field &field, double c);
  * @param yvals     list of latitudes
  * @param onlyNorth boolean for processing only the norther hemisphere
  */
-void update_hist(FieldVector2D &field, int nlevels, size_t gridsize, const std::vector<double> &yvals, bool onlyNorth);
+void update_hist(FieldVector2D &field, int nlevels, size_t gridsize, std::vector<double> const &yvals, bool onlyNorth);
 
 /*
  * Compute the Gsl and its starting day
@@ -318,7 +318,7 @@ void compute_gsl(int nlevels, size_t gridsize, std::vector<double> &yvals, doubl
  * should be the last day of the corresponding year for norther and June, 30th
  * for southern hemisphere
  */
-void adjust_end_date(int nlevels, size_t gridsize, const std::vector<double> &yvals, double missval, int64_t ovdate,
+void adjust_end_date(int nlevels, size_t gridsize, std::vector<double> const &yvals, double missval, int64_t ovdate,
                      const FieldVector2D &startDateWithHist, FieldVector2D &endDateWithHist);
 /*
  * Calculates the mid of the year or month
@@ -328,5 +328,5 @@ void define_mid_of_time(int frequency, int taxisID, int year, int month, int Max
  * Write GSL related fields to an output stream
  */
 void write_gsl_stream(CdoStreamID ostreamID, int otaxisID, int otsID, int ovarID1, int ovarID2, int ivlistID1, int first_var_id,
-                      FieldVector &gslDuration, FieldVector &gslFirstDay, const CdiDateTime &vDateTime, int nlevels);
+                      FieldVector &gslDuration, FieldVector &gslFirstDay, CdiDateTime const &vDateTime, int nlevels);
 #endif /*ECAUTIL_H_*/
