@@ -14,7 +14,7 @@
 #include "expr_yacc.hh"
 
 // clang-format off
-auto expr_func_con_var = [](auto hasMV, auto n, auto mv, auto cVal, const auto &vIn, auto &vOut, auto binary_operator)
+auto expr_func_con_var = [](auto hasMV, auto n, auto mv, auto cVal, auto const &vIn, auto &vOut, auto binary_operator)
 {
   if (hasMV)
     {
@@ -38,7 +38,7 @@ auto expr_func_con_var = [](auto hasMV, auto n, auto mv, auto cVal, const auto &
     }
 };
 
-auto expr_mul_con_var = [](auto hasMV, auto n, auto mv, auto cVal, const auto &vIn, auto &vOut)
+auto expr_mul_con_var = [](auto hasMV, auto n, auto mv, auto cVal, auto const &vIn, auto &vOut)
 {
   if (hasMV)
     {
@@ -62,7 +62,7 @@ auto expr_mul_con_var = [](auto hasMV, auto n, auto mv, auto cVal, const auto &v
     }
 };
 
-auto expr_div_con_var = [](auto hasMV, auto n, auto mv, auto cVal, const auto &vIn, auto &vOut)
+auto expr_div_con_var = [](auto hasMV, auto n, auto mv, auto cVal, auto const &vIn, auto &vOut)
 {
   if (hasMV)
     {
@@ -86,7 +86,7 @@ auto expr_div_con_var = [](auto hasMV, auto n, auto mv, auto cVal, const auto &v
     }
 };
 
-auto expr_func_var_con = [](auto hasMV, auto n, auto mv, const auto &vIn, auto cVal, auto &vOut, auto binary_operator)
+auto expr_func_var_con = [](auto hasMV, auto n, auto mv, auto const &vIn, auto cVal, auto &vOut, auto binary_operator)
 {
   if (hasMV)
     {
@@ -110,7 +110,7 @@ auto expr_func_var_con = [](auto hasMV, auto n, auto mv, const auto &vIn, auto c
     }
 };
 
-auto expr_mul_var_con = [](auto hasMV, auto n, auto mv, const auto &vIn, auto cVal, auto &vOut)
+auto expr_mul_var_con = [](auto hasMV, auto n, auto mv, auto const &vIn, auto cVal, auto &vOut)
 {
   if (hasMV)
     {
@@ -134,7 +134,7 @@ auto expr_mul_var_con = [](auto hasMV, auto n, auto mv, const auto &vIn, auto cV
     }
 };
 
-auto expr_div_var_con = [](auto hasMV, auto n, auto mv, const auto &vIn, auto cVal, auto &vOut)
+auto expr_div_var_con = [](auto hasMV, auto n, auto mv, auto const &vIn, auto cVal, auto &vOut)
 {
   if (hasMV)
     {
@@ -158,7 +158,7 @@ auto expr_div_var_con = [](auto hasMV, auto n, auto mv, const auto &vIn, auto cV
     }
 };
 
-auto expr_func_var_var = [](auto hasMV, auto n, auto mv1, auto mv2, const auto &vIn1, const auto &vIn2, auto &vOut, auto binary_operator)
+auto expr_func_var_var = [](auto hasMV, auto n, auto mv1, auto mv2, auto const &vIn1, auto const &vIn2, auto &vOut, auto binary_operator)
 {
   if (hasMV)
     {
@@ -182,7 +182,7 @@ auto expr_func_var_var = [](auto hasMV, auto n, auto mv1, auto mv2, const auto &
     }
 };
 
-auto expr_mul_var_var = [](auto hasMV, auto n, auto mv1, auto mv2, const auto &vIn1, const auto &vIn2, auto &vOut)
+auto expr_mul_var_var = [](auto hasMV, auto n, auto mv1, auto mv2, auto const &vIn1, auto const &vIn2, auto &vOut)
 {
   if (hasMV)
     {
@@ -212,7 +212,7 @@ auto expr_mul_var_var = [](auto hasMV, auto n, auto mv1, auto mv2, const auto &v
     }
 };
 
-auto expr_div_var_var = [](auto hasMV, auto n, auto mv1, auto mv2, const auto &vIn1, const auto &vIn2, auto &vOut)
+auto expr_div_var_var = [](auto hasMV, auto n, auto mv1, auto mv2, auto const &vIn1, auto const &vIn2, auto &vOut)
 {
   if (hasMV)
     {
@@ -387,13 +387,13 @@ vert_weights(int zaxisID, size_t nlev, Varray<double> &weights)
   weights.resize(nlev, 1.0);
 
   if (nlev > 1)
+  {
+    static auto printWarning = true;
+    auto wstatus = get_layer_thickness(1, 0, 0, zaxisID, nlev, thickness, weights);
+    if (wstatus == 0 && printWarning)
     {
-      static auto printWarning = true;
-      auto wstatus = get_layer_thickness(1, 0, 0, zaxisID, nlev, thickness, weights);
-      if (wstatus == 0 && printWarning)
-        {
-          printWarning = false;
-          cdo_warning("Layer bounds not available, using constant vertical weights!");
-        }
+      printWarning = false;
+      cdo_warning("Layer bounds not available, using constant vertical weights!");
     }
+  }
 }
