@@ -1507,7 +1507,7 @@ yyreduce:
 
   case 9: /* stmt: VARIABLE ';'  */
 #line 70 "expr_yacc.y"
-                                   { (yyval.nPtr) = expr_opr('=', 2, expr_var((yyvsp[-1].varnm)), expr_var((yyvsp[-1].varnm))); }
+                                   { char *v = strdup((yyvsp[-1].varnm)); (yyval.nPtr) = expr_opr('=', 2, expr_var((yyvsp[-1].varnm)), expr_var(v)); }
 #line 1512 "expr_yacc.cc"
     break;
 
@@ -1938,6 +1938,8 @@ nodeType *expr_var(char *name)
   p->type = NodeEnum::typeVar;
   p->v = varNodeType(name);
 
+  free(name);
+
   return p;
 }
 
@@ -1964,6 +1966,8 @@ nodeType *expr_fun(char *fname, int nops, ...)
   p->v = funNodeType(fname, nops, args);
   va_end(args);
 
+  if (fname) free(fname);
+
   return p;
 }
 
