@@ -20,7 +20,7 @@
 namespace Factory
 {
 // string -> pair(CdoModule,std::function)
-typedef std::function<std::shared_ptr<Process>(int, std::string const &, const std::vector<std::string> &)> ModuleConstructor;
+typedef std::function<std::shared_ptr<Process>(int, std::string const &, std::vector<std::string> const &)> ModuleConstructor;
 
 struct FactoryEntry
 {
@@ -70,7 +70,7 @@ struct RegisterEntry
   create_constructor(const CdoModule &mod)
   {
     return
-        [&mod](int p_ID, std::string const &p_operName, const std::vector<std::string> &p_operatorArguments) -> std::shared_ptr<T> {
+        [&mod](int p_ID, std::string const &p_operName, std::vector<std::string> const &p_operatorArguments) -> std::shared_ptr<T> {
           Debug(FACTORY, "Creating process via factory function, %d = ID, %s = name, %s = mod_name", p_ID, p_operName, mod.name);
           auto new_process = std::make_shared<T>(p_ID, p_operName, p_operatorArguments, mod);
           return new_process;
