@@ -174,18 +174,18 @@ using FieldVector3D = std::vector<FieldVector2D>;
 using Field3DVector = std::vector<Field3D>;
 
 void field_fill(Field &field, double value);
-void field_ncopy(size_t n, const Field &fieldIn, Field &fieldOut);
-void field_copy(const Field &fieldIn, Field &fieldOut);
+void field_ncopy(size_t n, Field const &fieldIn, Field &fieldOut);
+void field_copy(Field const &fieldIn, Field &fieldOut);
 void field_copy(const Field3D &fieldIn, Field3D &fieldOut);
 void field_copy(const Field3D &fieldIn, int levelID, Field &fieldOut);
 void field_add(Field &field1, const Field3D &field2, int levelID);
-size_t field_num_NANs(const Field &field);
+size_t field_num_NANs(Field const &field);
 size_t field_num_mv(Field &field);
-MinMax field_min_max(const Field &field);
+MinMax field_min_max(Field const &field);
 
 template <class UnaryOperation>
 void
-field_transform(const Field &fieldIn, Field &fieldOut, UnaryOperation unary_op)
+field_transform(Field const &fieldIn, Field &fieldOut, UnaryOperation unary_op)
 {
   if (fieldIn.memType == MemType::Float && fieldOut.memType == MemType::Float)
     varray_transform(fieldIn.vec_f, fieldOut.vec_f, unary_op);
