@@ -21,7 +21,6 @@
 #include "cdo_history.h"
 #include "cdo_query.h"
 #include "cdo_timer.h"
-#include "process.h"
 #include "commandline.h"
 
 bool FileStream::TimerEnabled = false;
@@ -29,7 +28,7 @@ bool FileStream::TimerEnabled = false;
 static auto inputFileTypeIsNetCDF4 = false;
 #endif
 
-FileStream::FileStream(const std::string &p_fileName) : m_filename(p_fileName)
+FileStream::FileStream(std::string const &p_fileName) : m_filename(p_fileName)
 {
   m_name = p_fileName;
   m_fileID = CDI_UNDEFID;
@@ -46,16 +45,25 @@ FileStream::open_read()
 {
   int fileID = -1;
 
+  if (FileStream::timersEnabled()) cdo::readTimer.start();
   open_lock();
 
   if (m_filename.size() > 6 && m_filename.rfind("query:", 0) == 0)
-    {
-      CdiQuery *query = cdiQueryCreate();
-      auto path = set_query_parameter(m_filename.substr(6), query);
-      if (Options::cdoVerbose) cdiQueryPrint(query);
+  {
+    CdiQuery *query = cdiQueryCreate();
+    auto path = set_query_parameter(m_filename.substr(6), query);
+    if (Options::cdoVerbose) cdiQueryPrint(query);
 
-      fileID = streamOpenReadQuery(path.c_str(), query);
-    }
+    fileID = streamOpenReadQuery(path.c_str(), query);
+  }
+  else if (Options::cdoQueryParameter.size() > 0)
+  {
+    CdiQuery *query = cdiQueryCreate();
+    (void) set_query_parameter(Options::cdoQueryParameter, query);
+    if (Options::cdoVerbose) cdiQueryPrint(query);
+
+    fileID = streamOpenReadQuery(m_filename.c_str(), query);
+  }
   else { fileID = streamOpenRead(m_filename.c_str()); }
 
   if (fileID < 0) cdi_open_error(fileID, "Open failed on >%s<", m_filename.c_str());
@@ -73,6 +81,7 @@ FileStream::open_read()
   if (Options::numStreamWorker > 0) streamDefNumWorker(fileID, Options::numStreamWorker);
 
   open_unlock();
+  if (FileStream::timersEnabled()) cdo::readTimer.stop();
 
   return fileID;
 }
@@ -81,12 +90,12 @@ int
 FileStream::open_write(int p_filetype)
 {
   if (Options::cdoInteractive)
-    {
-      struct stat stbuf;
-      auto rstatus = stat(m_name.c_str(), &stbuf);
-      // If permanent file already exists, query user whether to overwrite or exit
-      if (rstatus != -1) query_user_exit(m_name);
-    }
+  {
+    struct stat stbuf;
+    auto rstatus = stat(m_name.c_str(), &stbuf);
+    // If permanent file already exists, query user whether to overwrite or exit
+    if (rstatus != -1) query_user_exit(m_name);
+  }
   if (p_filetype == CDI_UNDEFID) p_filetype = CDI_FILETYPE_GRB;
   /*
 #ifndef HAVE_NC4HDF5_THREADSAFE
@@ -117,6 +126,8 @@ FileStream::open_write(int p_filetype)
 
   Debug(FILE_STREAM, "fileID: %d  path: %s", m_fileID, m_name);
 
+  if (Options::PrintFilename) fprintf(stdout, "%s ", m_name.c_str());
+
   return m_cdoStreamID;
 }
 
@@ -147,96 +158,101 @@ void
 FileStream::def_vlist(int p_vlistID)
 {
   if (m_filetype == CDI_FILETYPE_NCZARR)
-    {
-      auto maxSteps = vlistNtsteps(p_vlistID);
-      if (maxSteps >= 0)
-        streamDefMaxSteps(m_fileID, maxSteps);
-      else
-        cdo_warning("Unknown number of timesteps, use operator setmaxsteps to set max. number of timesteps!");
-    }
+  {
+    auto maxSteps = vlistNtsteps(p_vlistID);
+    if (maxSteps >= 0)
+      streamDefMaxSteps(m_fileID, maxSteps);
+    else
+      cdo_warning("Unknown number of timesteps, use operator setmaxsteps to set max. number of timesteps!");
+  }
 
   cdo_append_history(p_vlistID, cdo::command_line());
 
   if (CdoDefault::DataType != CDI_UNDEFID)
+  {
+    auto nvars = vlistNvars(p_vlistID);
+    for (int varID = 0; varID < nvars; ++varID) vlistDefVarDatatype(p_vlistID, varID, CdoDefault::DataType);
+    if (CdoDefault::DataType == CDI_DATATYPE_FLT64 || CdoDefault::DataType == CDI_DATATYPE_FLT32)
     {
-      auto nvars = vlistNvars(p_vlistID);
-      for (int varID = 0; varID < nvars; ++varID) vlistDefVarDatatype(p_vlistID, varID, CdoDefault::DataType);
-      if (CdoDefault::DataType == CDI_DATATYPE_FLT64 || CdoDefault::DataType == CDI_DATATYPE_FLT32)
+      for (int varID = 0; varID < nvars; ++varID)
+      {
+        double addoffset = 0.0, scalefactor = 1.0;
+        auto haveAddoffset = (cdiInqKeyFloat(p_vlistID, varID, CDI_KEY_ADDOFFSET, &addoffset) == CDI_NOERR);
+        auto haveScalefactor = (cdiInqKeyFloat(p_vlistID, varID, CDI_KEY_SCALEFACTOR, &scalefactor) == CDI_NOERR);
+        if (haveAddoffset || haveScalefactor)
         {
-          for (int varID = 0; varID < nvars; ++varID)
-            {
-              double addoffset = 0.0, scalefactor = 1.0;
-              auto haveAddoffset = (cdiInqKeyFloat(p_vlistID, varID, CDI_KEY_ADDOFFSET, &addoffset) == CDI_NOERR);
-              auto haveScalefactor = (cdiInqKeyFloat(p_vlistID, varID, CDI_KEY_SCALEFACTOR, &scalefactor) == CDI_NOERR);
-              if (haveAddoffset || haveScalefactor)
-                {
-                  cdiDeleteKey(p_vlistID, varID, CDI_KEY_ADDOFFSET);
-                  cdiDeleteKey(p_vlistID, varID, CDI_KEY_SCALEFACTOR);
-                }
-            }
+          cdiDeleteKey(p_vlistID, varID, CDI_KEY_ADDOFFSET);
+          cdiDeleteKey(p_vlistID, varID, CDI_KEY_SCALEFACTOR);
         }
+      }
     }
+  }
 
   if (Options::nsb > 0)
-    {
-      auto nvars = vlistNvars(p_vlistID);
-      for (int varID = 0; varID < nvars; ++varID) vlistDefVarNSB(p_vlistID, varID, Options::nsb);
-    }
+  {
+    auto nvars = vlistNvars(p_vlistID);
+    for (int varID = 0; varID < nvars; ++varID) vlistDefVarNSB(p_vlistID, varID, Options::nsb);
+  }
 
   if (Options::cdoChunkType != CDI_UNDEFID)
-    {
-      auto numVars = vlistNvars(p_vlistID);
-      for (int varID = 0; varID < numVars; ++varID) cdiDefKeyInt(p_vlistID, varID, CDI_KEY_CHUNKTYPE, Options::cdoChunkType);
-      auto numGrids = vlistNumGrids(p_vlistID);
-      for (int index = 0; index < numGrids; ++index)
-        cdiDefKeyInt(vlistGrid(p_vlistID, index), CDI_GLOBAL, CDI_KEY_CHUNKTYPE, Options::cdoChunkType);
-    }
+  {
+    auto numVars = vlistNvars(p_vlistID);
+    for (int varID = 0; varID < numVars; ++varID) cdiDefKeyInt(p_vlistID, varID, CDI_KEY_CHUNKTYPE, Options::cdoChunkType);
+    auto numGrids = vlistNumGrids(p_vlistID);
+    for (int index = 0; index < numGrids; ++index)
+      cdiDefKeyInt(vlistGrid(p_vlistID, index), CDI_GLOBAL, CDI_KEY_CHUNKTYPE, Options::cdoChunkType);
+  }
 
   if (Options::cdoChunkSize != CDI_UNDEFID)
+  {
+    auto numVars = vlistNvars(p_vlistID);
+    constexpr int chunkKeys[] = { CDI_KEY_CHUNKSIZE_DIMT, CDI_KEY_CHUNKSIZE_DIMZ, CDI_KEY_CHUNKSIZE_DIMY, CDI_KEY_CHUNKSIZE_DIMX };
+    for (int varID = 0; varID < numVars; ++varID)
     {
-      auto numVars = vlistNvars(p_vlistID);
-      for (int varID = 0; varID < numVars; ++varID) cdiDefKeyInt(p_vlistID, varID, CDI_KEY_CHUNKSIZE, Options::cdoChunkSize);
-      auto numGrids = vlistNumGrids(p_vlistID);
-      for (int index = 0; index < numGrids; ++index)
-        cdiDefKeyInt(vlistGrid(p_vlistID, index), CDI_GLOBAL, CDI_KEY_CHUNKSIZE, Options::cdoChunkSize);
+      for (auto chunkKey : chunkKeys)
+      {
+        if (cdo::inq_key_int(p_vlistID, varID, chunkKey) != 0) cdiDeleteKey(p_vlistID, varID, chunkKey);
+      }
     }
 
+    for (int varID = 0; varID < numVars; ++varID) cdiDefKeyInt(p_vlistID, varID, CDI_KEY_CHUNKSIZE, Options::cdoChunkSize);
+    auto numGrids = vlistNumGrids(p_vlistID);
+    for (int index = 0; index < numGrids; ++index)
+      cdiDefKeyInt(vlistGrid(p_vlistID, index), CDI_GLOBAL, CDI_KEY_CHUNKSIZE, Options::cdoChunkSize);
+  }
+
   if (Options::cdoChunkSizeDimX != 0)
-    {
-      auto numVars = vlistNvars(p_vlistID);
-      for (int varID = 0; varID < numVars; ++varID)
-        cdiDefKeyInt(p_vlistID, varID, CDI_KEY_CHUNKSIZE_DIMX, Options::cdoChunkSizeDimX);
-    }
+  {
+    auto numVars = vlistNvars(p_vlistID);
+    for (int varID = 0; varID < numVars; ++varID) cdiDefKeyInt(p_vlistID, varID, CDI_KEY_CHUNKSIZE_DIMX, Options::cdoChunkSizeDimX);
+  }
 
   if (Options::cdoChunkSizeDimY != 0)
-    {
-      auto numVars = vlistNvars(p_vlistID);
-      for (int varID = 0; varID < numVars; ++varID)
-        cdiDefKeyInt(p_vlistID, varID, CDI_KEY_CHUNKSIZE_DIMY, Options::cdoChunkSizeDimY);
-    }
+  {
+    auto numVars = vlistNvars(p_vlistID);
+    for (int varID = 0; varID < numVars; ++varID) cdiDefKeyInt(p_vlistID, varID, CDI_KEY_CHUNKSIZE_DIMY, Options::cdoChunkSizeDimY);
+  }
 
   if (Options::cdoChunkSizeDimZ != 0)
-    {
-      auto numVars = vlistNvars(p_vlistID);
-      for (int varID = 0; varID < numVars; ++varID)
-        cdiDefKeyInt(p_vlistID, varID, CDI_KEY_CHUNKSIZE_DIMZ, Options::cdoChunkSizeDimZ);
-      auto numZaxis = vlistNumZaxis(p_vlistID);
-      for (int index = 0; index < numZaxis; ++index)
-        cdiDefKeyInt(vlistZaxis(p_vlistID, index), CDI_GLOBAL, CDI_KEY_CHUNKSIZE_DIMZ, Options::cdoChunkSizeDimZ);
-    }
+  {
+    auto numVars = vlistNvars(p_vlistID);
+    for (int varID = 0; varID < numVars; ++varID) cdiDefKeyInt(p_vlistID, varID, CDI_KEY_CHUNKSIZE_DIMZ, Options::cdoChunkSizeDimZ);
+    auto numZaxis = vlistNumZaxis(p_vlistID);
+    for (int index = 0; index < numZaxis; ++index)
+      cdiDefKeyInt(vlistZaxis(p_vlistID, index), CDI_GLOBAL, CDI_KEY_CHUNKSIZE_DIMZ, Options::cdoChunkSizeDimZ);
+  }
 
   if (Options::cdoChunkSizeDimT != 0)
-    {
-      auto numVars = vlistNvars(p_vlistID);
-      for (int varID = 0; varID < numVars; ++varID)
-        cdiDefKeyInt(p_vlistID, varID, CDI_KEY_CHUNKSIZE_DIMT, Options::cdoChunkSizeDimT);
-    }
+  {
+    auto numVars = vlistNvars(p_vlistID);
+    for (int varID = 0; varID < numVars; ++varID) cdiDefKeyInt(p_vlistID, varID, CDI_KEY_CHUNKSIZE_DIMT, Options::cdoChunkSizeDimT);
+  }
 
   if (Options::CMOR_Mode)
-    {
-      cdo_def_tracking_id(p_vlistID, "tracking_id");
-      cdo_def_creation_date(p_vlistID);
-    }
+  {
+    cdo_def_tracking_id(p_vlistID, "tracking_id");
+    cdo_def_creation_date(p_vlistID);
+  }
 
   if (Options::VersionInfo) cdiDefAttTxt(p_vlistID, CDI_GLOBAL, "CDO", (int) std::strlen(cdo_comment()), cdo_comment());
 
@@ -423,10 +439,10 @@ FileStream::close()
   m_vlistID = -1;
 
   if (m_datarangelist.size())
-    {
-      m_datarangelist.clear();
-      m_datarangelist.shrink_to_fit();
-    }
+  {
+    m_datarangelist.clear();
+    m_datarangelist.shrink_to_fit();
+  }
 }
 
 void
@@ -444,47 +460,47 @@ FileStream::defDatarangeList(int p_vlistID)
   m_datarangelist.resize(nvars);
 
   for (int varID = 0; varID < nvars; ++varID)
+  {
+    m_datarangelist[varID].gridsize = gridInqSize(vlistInqVarGrid(p_vlistID, varID));
+    m_datarangelist[varID].datatype = vlistInqVarDatatype(p_vlistID, varID);
+    m_datarangelist[varID].missval = vlistInqVarMissval(p_vlistID, varID);
+
+    double addoffset = 0.0, scalefactor = 1.0;
+    auto haveAddoffset = (cdiInqKeyFloat(p_vlistID, varID, CDI_KEY_ADDOFFSET, &addoffset) == CDI_NOERR);
+    auto haveScalefactor = (cdiInqKeyFloat(p_vlistID, varID, CDI_KEY_SCALEFACTOR, &scalefactor) == CDI_NOERR);
+    if (haveAddoffset) m_datarangelist[varID].addoffset = addoffset;
+    if (haveScalefactor) m_datarangelist[varID].scalefactor = scalefactor;
+
+    m_datarangelist[varID].checkDatarange = false;
+
+    auto datatype = m_datarangelist[varID].datatype;
+
+    if (filetype == CDI_FILETYPE_NC || filetype == CDI_FILETYPE_NC2 || filetype == CDI_FILETYPE_NC4 || filetype == CDI_FILETYPE_NC4C
+        || filetype == CDI_FILETYPE_NC5 || filetype == CDI_FILETYPE_NCZARR)
     {
-      m_datarangelist[varID].gridsize = gridInqSize(vlistInqVarGrid(p_vlistID, varID));
-      m_datarangelist[varID].datatype = vlistInqVarDatatype(p_vlistID, varID);
-      m_datarangelist[varID].missval = vlistInqVarMissval(p_vlistID, varID);
+      if (datatype == CDI_DATATYPE_UINT8
+          && (filetype == CDI_FILETYPE_NC || filetype == CDI_FILETYPE_NC2 || filetype == CDI_FILETYPE_NC5))
+      {
+        datatype = CDI_DATATYPE_INT16;
+        m_datarangelist[varID].datatype = datatype;
+      }
 
-      double addoffset = 0.0, scalefactor = 1.0;
-      auto haveAddoffset = (cdiInqKeyFloat(p_vlistID, varID, CDI_KEY_ADDOFFSET, &addoffset) == CDI_NOERR);
-      auto haveScalefactor = (cdiInqKeyFloat(p_vlistID, varID, CDI_KEY_SCALEFACTOR, &scalefactor) == CDI_NOERR);
-      if (haveAddoffset) m_datarangelist[varID].addoffset = addoffset;
-      if (haveScalefactor) m_datarangelist[varID].scalefactor = scalefactor;
+      if (datatype == CDI_DATATYPE_UINT16
+          && (filetype == CDI_FILETYPE_NC || filetype == CDI_FILETYPE_NC2 || filetype == CDI_FILETYPE_NC5))
+      {
+        datatype = CDI_DATATYPE_INT32;
+        m_datarangelist[varID].datatype = datatype;
+      }
 
-      m_datarangelist[varID].checkDatarange = false;
-
-      auto datatype = m_datarangelist[varID].datatype;
-
-      if (filetype == CDI_FILETYPE_NC || filetype == CDI_FILETYPE_NC2 || filetype == CDI_FILETYPE_NC4
-          || filetype == CDI_FILETYPE_NC4C || filetype == CDI_FILETYPE_NC5 || filetype == CDI_FILETYPE_NCZARR)
-        {
-          if (datatype == CDI_DATATYPE_UINT8
-              && (filetype == CDI_FILETYPE_NC || filetype == CDI_FILETYPE_NC2 || filetype == CDI_FILETYPE_NC5))
-            {
-              datatype = CDI_DATATYPE_INT16;
-              m_datarangelist[varID].datatype = datatype;
-            }
-
-          if (datatype == CDI_DATATYPE_UINT16
-              && (filetype == CDI_FILETYPE_NC || filetype == CDI_FILETYPE_NC2 || filetype == CDI_FILETYPE_NC5))
-            {
-              datatype = CDI_DATATYPE_INT32;
-              m_datarangelist[varID].datatype = datatype;
-            }
-
-          if (haveAddoffset || haveScalefactor)
-            {
-              if (datatype == CDI_DATATYPE_INT8 || datatype == CDI_DATATYPE_UINT8 || datatype == CDI_DATATYPE_INT16
-                  || datatype == CDI_DATATYPE_UINT16)
-                m_datarangelist[varID].checkDatarange = true;
-            }
-          else if (Options::CheckDatarange) { m_datarangelist[varID].checkDatarange = true; }
-        }
+      if (haveAddoffset || haveScalefactor)
+      {
+        if (datatype == CDI_DATATYPE_INT8 || datatype == CDI_DATATYPE_UINT8 || datatype == CDI_DATATYPE_INT16
+            || datatype == CDI_DATATYPE_UINT16)
+          m_datarangelist[varID].checkDatarange = true;
+      }
+      else if (Options::CheckDatarange) { m_datarangelist[varID].checkDatarange = true; }
     }
+  }
 
   m_vlistID = p_vlistID;  // used for -r/-a
 }
