@@ -8,7 +8,7 @@ class FileStream : public CdoStream
 {
 public:
   // Constructors
-  explicit FileStream(const std::string &p_fileStream);
+  explicit FileStream(std::string const &p_fileStream);
   // ---
 
   // CdoStream Interface functions
@@ -47,11 +47,13 @@ public:
 
   // FileStreamOnly
   int getFileID();
+
   static void
-  enableTimers(const bool p_enable)
+  enableTimers(bool p_enable)
   {
     FileStream::TimerEnabled = p_enable;
   }
+
   static bool
   timersEnabled()
   {
@@ -65,6 +67,7 @@ protected:
 private:
   std::string m_filename;
   void checkDatarange(int varID, double *array, size_t numMissVals);
+
 protected:
   FileStream() = default;
 };
