@@ -2,18 +2,18 @@
 // https://schneide.wordpress.com/2016/07/15/generating-an-icosphere-in-c
 
 #include "vector3d.h"
+#include "varray.h"
 #include <cstdio>
 #include <cstdint>
 
 #include <utility>
 #include <limits>
-#include <iostream>
 #include <array>
 #include <vector>
 
 using Index = uint64_t;
 using Vertex = Vector3d;
-using Triangle = std::array<Index, 3>;
+using Triangle = std::array<size_t, 3>;
 using TriangleList = std::vector<Triangle>;
 using VertexList = std::vector<Vertex>;
 
@@ -39,26 +39,25 @@ static VertexList vertices(12);
 static void
 init(void)
 {
-  constexpr auto pi_5 = M_PI * 0.2;
   // first define the vertices of the icosahedron
-  const auto z_w = 2.0 * std::acos(1.0 / (2.0 * std::sin(pi_5)));
-
-  // set poles first - it is simple
+  // set poles first
   vertices[0] = Vertex{ 0.0, 0.0, 1.0 };
   vertices[11] = Vertex{ 0.0, 0.0, -1.0 };
   // now set the vertices on the two latitude rings
   int i_mdist[10];
   for (int j = 1; j < 11; ++j) { i_mdist[(j % 2 == 0) ? (j / 2 + 4) : ((j + 1) / 2 - 1)] = -1 + (j - 1) - 10 * ((j - 1) / 7); }
 
+  constexpr auto pi_5 = M_PI * 0.2;
+  auto z_w = 2.0 * std::acos(1.0 / (2.0 * std::sin(pi_5)));
   for (int j = 1; j < 11; ++j)
-    {
-      // toggle the hemisphere
-      auto i_msgn = (j >= 6) ? -1.0 : 1.0;
-      // compute the meridian angle for the base vertex.
-      auto z_rlon = (1.0 + i_mdist[j - 1]) * pi_5;
-      // now initialize the coordinates
-      vertices[j] = Vertex{ std::sin(z_w) * std::cos(z_rlon), std::sin(z_w) * std::sin(z_rlon), std::cos(z_w) * i_msgn };
-    }
+  {
+    // toggle the hemisphere
+    auto i_msgn = (j >= 6) ? -1.0 : 1.0;
+    // compute the meridian angle for the base vertex.
+    auto z_rlon = (1.0 + i_mdist[j - 1]) * pi_5;
+    // now initialize the coordinates
+    vertices[j] = Vertex{ std::sin(z_w) * std::cos(z_rlon), std::sin(z_w) * std::sin(z_rlon), std::cos(z_w) * i_msgn };
+  }
 }
 
 // 20 triangles
@@ -82,31 +81,29 @@ vertex_for_edge(Lookup &lookup, VertexList &vertices, Index first, Index second)
 }
 
 static TriangleList
-subdivide(VertexList &vertices, const TriangleList &triangles)
+subdivide(VertexList &vertices, TriangleList const &triangles)
 {
-  Lookup lookup;
-  Triangle mid;
-
   auto n = triangles.size();
-  lookup.resize(n / 2 + 1);
+  Lookup lookup(n / 2 + 1);
   TriangleList result(4 * n);
+  Triangle mid;
   for (size_t i = 0; i < n; ++i)
-    {
-      const auto &each = triangles[i];
-      for (int edge = 0; edge < 3; edge++) { mid[edge] = vertex_for_edge(lookup, vertices, each[edge], each[(edge + 1) % 3]); }
+  {
+    auto const &each = triangles[i];
+    for (int edge = 0; edge < 3; edge++) { mid[edge] = vertex_for_edge(lookup, vertices, each[edge], each[(edge + 1) % 3]); }
 
-      result[i * 4 + 0] = { each[0], mid[0], mid[2] };
-      result[i * 4 + 1] = { each[1], mid[1], mid[0] };
-      result[i * 4 + 2] = { each[2], mid[2], mid[1] };
-      result[i * 4 + 3] = mid;
-    }
+    result[i * 4 + 0] = { each[0], mid[0], mid[2] };
+    result[i * 4 + 1] = { each[1], mid[1], mid[0] };
+    result[i * 4 + 2] = { each[2], mid[2], mid[1] };
+    result[i * 4 + 3] = mid;
+  }
 
   return result;
 }
 
 size_t
-gen_icosphere_coords(int subdivisions, bool withBounds, std::vector<double> &xvals, std::vector<double> &yvals,
-                     std::vector<double> &xbounds, std::vector<double> &ybounds)
+gen_icosphere_coords(int subdivisions, bool withBounds, Varray<double> &xvals, Varray<double> &yvals, Varray<double> &xbounds,
+                     Varray<double> &ybounds)
 {
   icosahedron::init();
   auto triangles = icosahedron::triangles;
@@ -114,10 +111,10 @@ gen_icosphere_coords(int subdivisions, bool withBounds, std::vector<double> &xva
 
   size_t numTriangles = std::pow(4, subdivisions) * 20;
   if (numTriangles > (size_t) std::numeric_limits<Index>::max())
-    {
-      fprintf(stderr, "Too many grid cells:%zu (limit=%zu)!\n", numTriangles, (size_t) std::numeric_limits<Index>::max());
-      exit(EXIT_FAILURE);
-    }
+  {
+    fprintf(stderr, "Too many grid cells:%zu (limit=%zu)!\n", numTriangles, (size_t) std::numeric_limits<Index>::max());
+    exit(EXIT_FAILURE);
+  }
 
   size_t numVerticies = std::pow(4, subdivisions) * 10 + 2;
   vertices.reserve(numVerticies);
@@ -129,27 +126,27 @@ gen_icosphere_coords(int subdivisions, bool withBounds, std::vector<double> &xva
   xvals.resize(numCells);
   yvals.resize(numCells);
   if (withBounds)
-    {
-      xbounds.resize(3 * numCells);
-      ybounds.resize(3 * numCells);
-    }
+  {
+    xbounds.resize(3 * numCells);
+    ybounds.resize(3 * numCells);
+  }
 
 #ifdef _OPENMP
 #pragma omp parallel for if (numCells > 999999) default(shared) schedule(static)
 #endif
   for (size_t i = 0; i < numCells; ++i)
-    {
-      const auto &t = triangles[i];
-      auto center = circum_center_mean(vertices[t[0]], vertices[t[1]], vertices[t[2]]);
-      xvals[i] = center.longitude();
-      yvals[i] = center.latitude();
-      if (withBounds)
-        for (size_t k = 0; k < 3; ++k)
-          {
-            xbounds[i * 3 + k] = vertices[t[k]].longitude();
-            ybounds[i * 3 + k] = vertices[t[k]].latitude();
-          }
-    }
+  {
+    auto const &t = triangles[i];
+    auto center = circum_center_mean(vertices[t[0]], vertices[t[1]], vertices[t[2]]);
+    xvals[i] = center.longitude();
+    yvals[i] = center.latitude();
+    if (withBounds)
+      for (size_t k = 0; k < 3; ++k)
+      {
+        xbounds[i * 3 + k] = vertices[t[k]].longitude();
+        ybounds[i * 3 + k] = vertices[t[k]].latitude();
+      }
+  }
 
   return numCells;
 }
