@@ -19,7 +19,7 @@
 UnstructMethod unstructMethod(UnstructMethod::undefined);
 
 void
-set_pointsearch_method(const std::string &methodStr)
+set_pointsearch_method(std::string const &methodStr)
 {
   // clang-format off
   if      (methodStr == "kdtree")     unstructMethod = UnstructMethod::kdtree;
@@ -50,13 +50,13 @@ grid_pointsearch_create_healpix(GridPointsearch &gps, const RemapGrid &remapGrid
 }
 
 static void
-grid_pointsearch_create_reg2d(GridPointsearch &gps, const RemapGrid &remapGrid)
+grid_pointsearch_create_reg2d(GridPointsearch &gps, RemapGrid const &remapGrid)
 {
   gps.reg2d = new PointsearchReg2d(remapGrid.centerLonsReg2d, remapGrid.centerLatsReg2d, gps.params);
 }
 
 static void
-pointsearch_create_unstruct(GridPointsearch &gps, const Varray<double> &lons, const Varray<double> &lats)
+pointsearch_create_unstruct(GridPointsearch &gps, Varray<double> const &lons, Varray<double> const &lats)
 {
   auto numPoints = lons.size();
   if (numPoints == 0) return;
@@ -99,14 +99,14 @@ grid_pointsearch_create(GridPointsearch &gps, const RemapGrid &remapGrid)
   if (remapGrid.type == RemapGridType::HealPix) { grid_pointsearch_create_healpix(gps, remapGrid); }
   else if (remapGrid.type == RemapGridType::Reg2D) { grid_pointsearch_create_reg2d(gps, remapGrid); }
   else
-    {
-      params.useBoundBox = true;
-      pointsearch_create_unstruct(gps, remapGrid.centerLons, remapGrid.centerLats);
-    }
+  {
+    params.useBoundBox = true;
+    pointsearch_create_unstruct(gps, remapGrid.centerLons, remapGrid.centerLats);
+  }
 }
 
 void
-grid_pointsearch_create_unstruct(GridPointsearch &gps, const Varray<double> &lons, const Varray<double> &lats, bool useBoundBox)
+grid_pointsearch_create_unstruct(GridPointsearch &gps, Varray<double> const &lons, Varray<double> const &lats, bool useBoundBox)
 {
   auto &params = gps.params;
   params.dims[0] = lons.size();
@@ -117,64 +117,63 @@ grid_pointsearch_create_unstruct(GridPointsearch &gps, const Varray<double> &lon
 }
 
 static size_t
-llindex_in_quad(size_t nx, size_t ny, size_t index, const PointLonLat &pointLL, const double *centerLons, const double *centerLats,
+llindex_in_quad(size_t nx, size_t ny, size_t index, PointLonLat const &pointLL, double const *centerLons, double const *centerLats,
                 bool isCyclic)
 {
   if (index != GPS_NOT_FOUND)
+  {
+    SquareCorners squareCorners;
+    for (int k = 0; k < 4; ++k)
     {
-      SquareCorners squareCorners;
-      for (int k = 0; k < 4; ++k)
-        {
-          // Determine neighbor addresses
-          auto j = index / nx;
-          auto i = index - j * nx;
-          if (k == 1 || k == 3) i = (i > 0) ? i - 1 : (isCyclic ? nx - 1 : 0);
-          if (k == 2 || k == 3) j = (j > 0) ? j - 1 : 0;
+      // Determine neighbor addresses
+      auto j = index / nx;
+      auto i = index - j * nx;
+      if (k == 1 || k == 3) i = (i > 0) ? i - 1 : (isCyclic ? nx - 1 : 0);
+      if (k == 2 || k == 3) j = (j > 0) ? j - 1 : 0;
 
-          if (point_in_quad(isCyclic, nx, ny, i, j, squareCorners, pointLL.get_lon(), pointLL.get_lat(), centerLons, centerLats))
-            return index;
-        }
+      if (point_in_quad(isCyclic, nx, ny, i, j, squareCorners, pointLL.lon(), pointLL.lat(), centerLons, centerLats)) return index;
     }
+  }
 
   return GPS_NOT_FOUND;
 }
 
 size_t
-grid_pointsearch_nearest(GridPointsearch &gps, const PointLonLat &pointLL, size_t *index, double *dist)
+grid_pointsearch_nearest(GridPointsearch &gps, PointLonLat const &pointLL, size_t *index, double *dist)
 {
   auto numIndices = gps.unstruct.search_nearest(pointLL, index, dist);
   if (numIndices > 0)
-    {
-      auto &params = gps.params;
-      auto indexResult = *index;
-      if (!params.extrapolation && params.isCurve)
-        indexResult = llindex_in_quad(params.dims[0], params.dims[1], *index, pointLL, gps.plons, gps.plats, params.isCyclic);
-      if (indexResult != GPS_NOT_FOUND) return 1;
-    }
+  {
+    auto &params = gps.params;
+    auto indexResult = *index;
+    if (!params.extrapolation && params.isCurve)
+      indexResult = llindex_in_quad(params.dims[0], params.dims[1], *index, pointLL, gps.plons, gps.plats, params.isCyclic);
+    if (indexResult != GPS_NOT_FOUND) return 1;
+  }
 
   return 0;
 }
 
 static void
-select_points_in_cell(GridPointsearch &gps, const PointLonLat &pointLL, size_t *indices, double *dist, size_t &numIndices)
+select_points_in_cell(GridPointsearch &gps, PointLonLat const &pointLL, size_t *indices, double *dist, size_t &numIndices)
 {
   auto maxIndices = numIndices;
   numIndices = 0;
   for (size_t i = 0; i < maxIndices; ++i)
+  {
+    auto &params = gps.params;
+    auto index = llindex_in_quad(params.dims[0], params.dims[1], indices[i], pointLL, gps.plons, gps.plats, params.isCyclic);
+    if (index != GPS_NOT_FOUND)
     {
-      auto &params = gps.params;
-      auto index = llindex_in_quad(params.dims[0], params.dims[1], indices[i], pointLL, gps.plons, gps.plats, params.isCyclic);
-      if (index != GPS_NOT_FOUND)
-        {
-          indices[numIndices] = indices[i];
-          dist[numIndices] = dist[i];
-          numIndices++;
-        }
+      indices[numIndices] = indices[i];
+      dist[numIndices] = dist[i];
+      numIndices++;
     }
+  }
 }
 
 size_t
-grid_pointsearch_qnearest(GridPointsearch &gps, const PointLonLat &pointLL, size_t nnn, size_t *indices, double *dist)
+grid_pointsearch_qnearest(GridPointsearch &gps, PointLonLat const &pointLL, size_t nnn, size_t *indices, double *dist)
 {
   auto numIndices = gps.unstruct.search_qnearest(pointLL, nnn, indices, dist);
 
