@@ -32,20 +32,20 @@ static FILE *fpold, *fpnew;
 #endif
 
 static long
-int_index(long n, const Varray<double> &x1, const double x2)
+int_index(long n, Varray<double> const &x1, const double x2)
 {
   long k;
   long klo = 0;
   long khi = n - 1;
 
   while (khi - klo > 1)
-    {
-      k = (khi + klo) / 2;
-      if (x1[k] > x2)
-        khi = k;
-      else
-        klo = k;
-    }
+  {
+    k = (khi + klo) / 2;
+    if (x1[k] > x2)
+      khi = k;
+    else
+      klo = k;
+  }
 
   /*
   for ( klo = 0; klo < n-1; klo++ )
@@ -70,12 +70,12 @@ esat(double temperature)
 
 template <typename T>
 static void
-hetaeta_sc(bool ltq, int lpsmod, long ij, long ngp, long nlev1, long nlev2, long nvars, const Varray<double> &af1,
-           const Varray<double> &bf1, const Varray<double> &etah2, const Varray<double> &af2, const Varray<double> &bf2,
-           const Varray<double> &w1, const Varray<double> &w2, const Varray<long> &jl1, const Varray<long> &jl2, const double *ah1,
-           const double *bh1, const Varray<double> &ps1, double epsm1i, const Varray<T> &q1, const Varray<T> &t1,
-           const Varray<double> &fis1, const Varray<double> &fis2, Varray<double> &ps2, const double *ah2, const double *bh2,
-           const Varray2D<T> &vars1, Varray2D<T> &vars2, Varray<T> &t2, Varray<T> &q2, Varray<double> &tscor, Varray<double> &pscor,
+hetaeta_sc(bool ltq, int lpsmod, long ij, long ngp, long nlev1, long nlev2, long nvars, Varray<double> const &af1,
+           Varray<double> const &bf1, Varray<double> const &etah2, Varray<double> const &af2, Varray<double> const &bf2,
+           Varray<double> const &w1, Varray<double> const &w2, Varray<long> const &jl1, Varray<long> const &jl2, const double *ah1,
+           const double *bh1, Varray<double> const &ps1, double epsm1i, Varray<T> const &q1, Varray<T> const &t1,
+           Varray<double> const &fis1, Varray<double> const &fis2, Varray<double> &ps2, const double *ah2, const double *bh2,
+           Varray2D<T> const &vars1, Varray2D<T> &vars2, Varray<T> &t2, Varray<T> &q2, Varray<double> &tscor, Varray<double> &pscor,
            Varray<double> &secor, long jblt, Varray<double> &ph1, Varray<double> &lnph1, Varray<double> &fi1, Varray<double> &pf1,
            Varray<double> &lnpf1, Varray<double> &tv1, Varray<double> &theta1, Varray<double> &rh1, Varray<double> &zvar,
            Varray<double> &ph2, Varray<double> &lnph2, Varray<double> &fi2, Varray<double> &pf2, Varray<double> &rh2,
@@ -96,48 +96,48 @@ hetaeta_sc(bool ltq, int lpsmod, long ij, long ngp, long nlev1, long nlev2, long
   ph1[0] = 0.0;
   lnph1[0] = -1.0;
   for (int k = 1; k < nlev1p1; ++k)
-    {
-      ph1[k] = ah1[k] + bh1[k] * ps1[ij];
-      lnph1[k] = std::log(ph1[k]);
-    }
+  {
+    ph1[k] = ah1[k] + bh1[k] * ps1[ij];
+    lnph1[k] = std::log(ph1[k]);
+  }
 
   for (int k = 0; k < nlev1; ++k)
-    {
-      pf1[k] = af1[k] + bf1[k] * ps1[ij];
-      lnpf1[k] = std::log(pf1[k]);
-    }
+  {
+    pf1[k] = af1[k] + bf1[k] * ps1[ij];
+    lnpf1[k] = std::log(pf1[k]);
+  }
 
   // virtual temperature, relative humidity, potential temperature
   if (ltq)
     for (int k = 0; k < nlev1; ++k)
-      {
-        auto ijk = k * ngp + ij;
-        auto zq1 = q1[ijk];
-        auto zt1 = t1[ijk];
-        tv1[k] = (1.0 + epsm1i * zq1) * zt1;
-        rh1[k] = zq1 * pf1[k] / (epsilon * esat(zt1));
-        theta1[k] = zt1 * std::pow(apr / pf1[k], rair_d_cpair);
-      }
+    {
+      auto ijk = k * ngp + ij;
+      auto zq1 = q1[ijk];
+      auto zt1 = t1[ijk];
+      tv1[k] = (1.0 + epsm1i * zq1) * zt1;
+      rh1[k] = zq1 * pf1[k] / (epsilon * esat(zt1));
+      theta1[k] = zt1 * std::pow(apr / pf1[k], rair_d_cpair);
+    }
 
   // ****** integrate hydrostatic equation, using interpolated orography
   if (ltq)
-    {
-      fi1[0] = 0.0;
-      fi1[nlev1] = fis1[ij];
-      for (int k = nlev1 - 1; k > 0; --k) { fi1[k] = fi1[k + 1] + rair * tv1[k] * (lnph1[k + 1] - lnph1[k]); }
-    }
+  {
+    fi1[0] = 0.0;
+    fi1[nlev1] = fis1[ij];
+    for (int k = nlev1 - 1; k > 0; --k) { fi1[k] = fi1[k + 1] + rair * tv1[k] * (lnph1[k + 1] - lnph1[k]); }
+  }
 #ifdef OUTPUT
   if (ij == OPOINT)
     for (int k = nlev1 - 1; k >= 0; --k)
-      {
-        auto ijk = k * ngp + ij;
-        double t = ltq ? t1[ijk] : 0;
-        double q = ltq ? q1[ijk] : 0;
-        double fi = ltq ? fi1[k] : 0;
-        fprintf(fpold, "%3d %18.10f %18.10f %18.10f %18.10f", k, fi / g, pf1[k], t, q);
-        for (int iv = 0; iv < nvars; ++iv) fprintf(fpold, " %18.10f", vars1[iv][ijk]);
-        fprintf(fpold, "\n");
-      }
+    {
+      auto ijk = k * ngp + ij;
+      double t = ltq ? t1[ijk] : 0;
+      double q = ltq ? q1[ijk] : 0;
+      double fi = ltq ? fi1[k] : 0;
+      fprintf(fpold, "%3d %18.10f %18.10f %18.10f %18.10f", k, fi / g, pf1[k], t, q);
+      for (int iv = 0; iv < nvars; ++iv) fprintf(fpold, " %18.10f", vars1[iv][ijk]);
+      fprintf(fpold, "\n");
+    }
 #endif
 
   /******* find new surface pressure
@@ -145,104 +145,104 @@ hetaeta_sc(bool ltq, int lpsmod, long ij, long ngp, long nlev1, long nlev2, long
            linear regression works not well for extrapolation
            separation necessary */
   if (ltq)
+  {
+    for (int k = nlev1 - 2; k > 0; --k)
     {
-      for (int k = nlev1 - 2; k > 0; --k)
-        {
-          // find index for regression, 1 <= jlev <= nlevec-2
-          jlev = k;
-          if (fis2[ij] < fi1[k]) break;
-        }
-
-      double zdff = fi1[jlev + 1] - fis2[ij];
-
-      // get the number of points used for estimation of regression coefficients
-      long jlevr = 0;
-      for (int k = jlev - 1; k > 0; --k)
-        {
-          jlevr = k;
-          double zdffl = fi1[k] - fi1[jlev + 1];
-          if (zdffl >= zdff) break;
-        }
-
-      long jnop = jlev + 1 - jlevr + 1;
-
-      /*
-        get coefficients of regression between Tv and lnP ::Tv = B*lnP + C
-        using three levels surounding new orography geopotential
-      */
-      double zsumt = 0.0, zsump = 0.0, zsumpp = 0.0, zsumtp = 0.0;
-
-      for (int k = jlevr; k <= jlev + 1; ++k)
-        {
-          zsumt += tv1[k];
-          zsump += lnpf1[k];
-          zsumpp += lnpf1[k] * lnpf1[k];
-          zsumtp += tv1[k] * lnpf1[k];
-        }
-
-      // final regression coefficients
-      double zb = jnop * zsumpp - zsump * zsump;
-      double zc = (zsumt * zsumpp - zsump * zsumtp) / zb;
-      zb = (jnop * zsumtp - zsump * zsumt) / zb;
-
-      // calculate preliminary surface pressure, adjust to middle level
-      double zps = lnph1[jlev];
-
-      // calculate preliminary pressure
-      if (std::fabs(zb) < 1.0e-20)
-        {
-          // constant virtual temperature near new surface
-          ps2[ij] = std::exp(zps + (fi1[jlev] - fis2[ij]) / (zc * rair));
-        }
-      else
-        {
-          // virtual temperatur not constant near new surface
-          double zbb = zc * zc + zb * (zps * (zb * zps + 2.0 * zc) + 2.0 * (fi1[jlev] - fis2[ij]) / rair);
-          ps2[ij] = std::exp((std::sqrt(zbb) - zc) / zb);
-        }
+      // find index for regression, 1 <= jlev <= nlevec-2
+      jlev = k;
+      if (fis2[ij] < fi1[k]) break;
     }
+
+    double zdff = fi1[jlev + 1] - fis2[ij];
+
+    // get the number of points used for estimation of regression coefficients
+    long jlevr = 0;
+    for (int k = jlev - 1; k > 0; --k)
+    {
+      jlevr = k;
+      double zdffl = fi1[k] - fi1[jlev + 1];
+      if (zdffl >= zdff) break;
+    }
+
+    long jnop = jlev + 1 - jlevr + 1;
+
+    /*
+      get coefficients of regression between Tv and lnP ::Tv = B*lnP + C
+      using three levels surounding new orography geopotential
+    */
+    double zsumt = 0.0, zsump = 0.0, zsumpp = 0.0, zsumtp = 0.0;
+
+    for (int k = jlevr; k <= jlev + 1; ++k)
+    {
+      zsumt += tv1[k];
+      zsump += lnpf1[k];
+      zsumpp += lnpf1[k] * lnpf1[k];
+      zsumtp += tv1[k] * lnpf1[k];
+    }
+
+    // final regression coefficients
+    double zb = jnop * zsumpp - zsump * zsump;
+    double zc = (zsumt * zsumpp - zsump * zsumtp) / zb;
+    zb = (jnop * zsumtp - zsump * zsumt) / zb;
+
+    // calculate preliminary surface pressure, adjust to middle level
+    double zps = lnph1[jlev];
+
+    // calculate preliminary pressure
+    if (std::fabs(zb) < 1.0e-20)
+    {
+      // constant virtual temperature near new surface
+      ps2[ij] = std::exp(zps + (fi1[jlev] - fis2[ij]) / (zc * rair));
+    }
+    else
+    {
+      // virtual temperatur not constant near new surface
+      double zbb = zc * zc + zb * (zps * (zb * zps + 2.0 * zc) + 2.0 * (fi1[jlev] - fis2[ij]) / rair);
+      ps2[ij] = std::exp((std::sqrt(zbb) - zc) / zb);
+    }
+  }
   else { ps2[ij] = ps1[ij]; }
 
   ph2[0] = 0.0;
   lnph2[0] = -1.0;
   for (int k = 1; k < nlev2p1; ++k)
-    {
-      ph2[k] = ah2[k] + bh2[k] * ps2[ij];
-      lnph2[k] = std::log(ph2[k]);
-    }
+  {
+    ph2[k] = ah2[k] + bh2[k] * ps2[ij];
+    lnph2[k] = std::log(ph2[k]);
+  }
 
   for (int k = 0; k < nlev2; ++k)
-    {
-      pf2[k] = af2[k] + bf2[k] * ps2[ij];
-      // lnpf2[k] = std::log(pf2[k]);
-    }
+  {
+    pf2[k] = af2[k] + bf2[k] * ps2[ij];
+    // lnpf2[k] = std::log(pf2[k]);
+  }
 
   // ****** find reference geopotential
 
   if (lpsmod && ltq)
+  {
+    // using old pressure at half levels, find first level below reference pressure
+    for (int k = 1; k < nlev1p1; ++k)
     {
-      // using old pressure at half levels, find first level below reference pressure
-      for (int k = 1; k < nlev1p1; ++k)
-        {
-          jlev = k;
-          if (ph1[k] > p_firef) break;
-        }
-
-      fiadj = fi1[jlev] + (fi1[jlev - 1] - fi1[jlev]) * std::log(ph1[jlev] / p_firef) / std::log(ph1[jlev] / ph1[jlev - 1]);
+      jlev = k;
+      if (ph1[k] > p_firef) break;
     }
 
+    fiadj = fi1[jlev] + (fi1[jlev - 1] - fi1[jlev]) * std::log(ph1[jlev] / p_firef) / std::log(ph1[jlev] / ph1[jlev - 1]);
+  }
+
   // ****** find the new boundary layer top
 
   // using the pressure from the old system
   double pbl_lim = ps1[ij] * eta_pbl;
   auto jjblt = nlev2 - 1;
   for (int k = nlev2 - 1; k > 0; --k)
-    {
-      // find the next upper level in new system
-      double pbl_lim_need = ps2[ij] * etah2[k];
-      if (pbl_lim > pbl_lim_need) break;
-      jjblt = jjblt - 1;
-    }
+  {
+    // find the next upper level in new system
+    double pbl_lim_need = ps2[ij] * etah2[k];
+    if (pbl_lim > pbl_lim_need) break;
+    jjblt = jjblt - 1;
+  }
 
   // correct the merging level
   if (jblt < jjblt) jjblt = jblt;
@@ -252,18 +252,18 @@ hetaeta_sc(bool ltq, int lpsmod, long ij, long ngp, long nlev1, long nlev2, long
 
   if (ltq)
     for (int k = jjblt; k < nlev2; ++k)
-      {
-        theta_pbl[k] = w1[k] * theta1[jl1[k]] + w2[k] * theta1[jl2[k]];
-        rh_pbl[k] = w1[k] * rh1[jl1[k]] + w2[k] * rh1[jl2[k]];
-      }
+    {
+      theta_pbl[k] = w1[k] * theta1[jl1[k]] + w2[k] * theta1[jl2[k]];
+      rh_pbl[k] = w1[k] * rh1[jl1[k]] + w2[k] * rh1[jl2[k]];
+    }
 
   for (int iv = 0; iv < nvars; ++iv)
     for (int k = jjblt; k < nlev2; ++k)
-      {
-        auto ijk1 = jl1[k] * ngp + ij;
-        auto ijk2 = jl2[k] * ngp + ij;
-        vars_pbl[iv][k] = w1[k] * vars1[iv][ijk1] + w2[k] * vars1[iv][ijk2];
-      }
+    {
+      auto ijk1 = jl1[k] * ngp + ij;
+      auto ijk2 = jl2[k] * ngp + ij;
+      vars_pbl[iv][k] = w1[k] * vars1[iv][ijk1] + w2[k] * vars1[iv][ijk2];
+    }
 
   /******* linear interpolation using pressure in free atmosphere
            pressure in new system using preliminary pressure */
@@ -273,46 +273,46 @@ hetaeta_sc(bool ltq, int lpsmod, long ij, long ngp, long nlev1, long nlev2, long
   for (int k = 0; k <= jjblt; ++k) { wgt[k] = (pf1[idx[k] + 1] - pf2[k]) / (pf1[idx[k] + 1] - pf1[idx[k]]); }
 
   if (ltq)
+  {
+    for (int k = 0; k < nlev1; ++k)
     {
-      for (int k = 0; k < nlev1; ++k)
-        {
-          auto ijk = k * ngp + ij;
-          zvar[k] = t1[ijk];
-        }
-
-      for (int k = 0; k <= jjblt; ++k)
-        {
-          auto klo = idx[k];
-          zt2[k] = wgt[k] * zvar[klo] + (1 - wgt[k]) * zvar[klo + 1];
-          rh2[k] = wgt[k] * rh1[klo] + (1 - wgt[k]) * rh1[klo + 1];
-        }
+      auto ijk = k * ngp + ij;
+      zvar[k] = t1[ijk];
     }
 
+    for (int k = 0; k <= jjblt; ++k)
+    {
+      auto klo = idx[k];
+      zt2[k] = wgt[k] * zvar[klo] + (1 - wgt[k]) * zvar[klo + 1];
+      rh2[k] = wgt[k] * rh1[klo] + (1 - wgt[k]) * rh1[klo + 1];
+    }
+  }
+
   for (int iv = 0; iv < nvars; ++iv)
+  {
+    for (int k = 0; k < nlev1; ++k)
     {
-      for (int k = 0; k < nlev1; ++k)
-        {
-          auto ijk = k * ngp + ij;
-          zvar[k] = vars1[iv][ijk];
-        }
-      for (int k = 0; k <= jjblt; ++k)
-        {
-          auto ijk = k * ngp + ij;
-          auto klo = idx[k];
-          vars2[iv][ijk] = wgt[k] * zvar[klo] + (1 - wgt[k]) * zvar[klo + 1];
-        }
+      auto ijk = k * ngp + ij;
+      zvar[k] = vars1[iv][ijk];
     }
+    for (int k = 0; k <= jjblt; ++k)
+    {
+      auto ijk = k * ngp + ij;
+      auto klo = idx[k];
+      vars2[iv][ijk] = wgt[k] * zvar[klo] + (1 - wgt[k]) * zvar[klo + 1];
+    }
+  }
 
   // ******* merge boundary layer and free atmosphere
 
   if (ltq)
-    {
-      // correction of potential temperature at top of PBL
-      dteta = zt2[jjblt] * std::pow(apr / pf2[jjblt], rair_d_cpair) - theta_pbl[jjblt];
+  {
+    // correction of potential temperature at top of PBL
+    dteta = zt2[jjblt] * std::pow(apr / pf2[jjblt], rair_d_cpair) - theta_pbl[jjblt];
 
-      // merge top layer values
-      rh2[jjblt] = 0.5 * (rh2[jjblt] + rh_pbl[jjblt]);
-    }
+    // merge top layer values
+    rh2[jjblt] = 0.5 * (rh2[jjblt] + rh_pbl[jjblt]);
+  }
 
   {
     auto ijk = jjblt * ngp + ij;
@@ -322,95 +322,94 @@ hetaeta_sc(bool ltq, int lpsmod, long ij, long ngp, long nlev1, long nlev2, long
   // correct boundary profile values
   if (ltq)
     for (int k = jjblt + 1; k < nlev2; ++k)
-      {
-        zt2[k] = (theta_pbl[k] + dteta) * std::pow(pf2[k] / apr, rair_d_cpair);
-        rh2[k] = rh_pbl[k];
-      }
+    {
+      zt2[k] = (theta_pbl[k] + dteta) * std::pow(pf2[k] / apr, rair_d_cpair);
+      rh2[k] = rh_pbl[k];
+    }
 
   for (int iv = 0; iv < nvars; ++iv)
     for (int k = jjblt + 1; k < nlev2; ++k)
-      {
-        auto ijk = k * ngp + ij;
-        vars2[iv][ijk] = vars_pbl[iv][k];
-      }
+    {
+      auto ijk = k * ngp + ij;
+      vars2[iv][ijk] = vars_pbl[iv][k];
+    }
 
   if (ltq)
     for (int k = 0; k < nlev2; ++k) { zq2[k] = rh2[k] * epsilon * esat(zt2[k]) / pf2[k]; }
 
   // reference level correction
   if (lpsmod && ltq)
+  {
+    // integrate hydrostatic equation with preliminary temperature and pressure
+    fi2[nlev2] = fis2[ij];
+    fi2[0] = -1.0;  // top not defined, infinity
+
+    // problem at top level, top pressure is zero per definition
+    for (int k = nlev2 - 1; k > 0; --k)
     {
-      // integrate hydrostatic equation with preliminary temperature and pressure
-      fi2[nlev2] = fis2[ij];
-      fi2[0] = -1.0;  // top not defined, infinity
-
-      // problem at top level, top pressure is zero per definition
-      for (int k = nlev2 - 1; k > 0; --k)
-        {
-          fi2[k] = fi2[k + 1] + rair * zt2[k] * (lnph2[k + 1] - lnph2[k]) * (1.0 + epsm1i * zq2[k]);
-        }
-
-      // search next level above reference level in new system
-      for (int k = nlev2 - 1; k > 0; --k)
-        {
-          jlev = k;
-          if (ph2[k] < p_firef) break;
-        }
-
-      // correct surface pressure
-      dfi = fiadj
-            - (fi2[jlev + 1]
-               + (fi2[jlev] - fi2[jlev + 1]) * std::log(ph2[jlev + 1] / p_firef) / std::log(ph2[jlev + 1] / ph2[jlev]));
-      double ztv = (1.0 + epsm1i * zq2[nlev2 - 1]) * zt2[nlev2 - 1];
-      ps2[ij] = ps2[ij] * std::exp(dfi / (rair * ztv));
+      fi2[k] = fi2[k + 1] + rair * zt2[k] * (lnph2[k + 1] - lnph2[k]) * (1.0 + epsm1i * zq2[k]);
     }
 
+    // search next level above reference level in new system
+    for (int k = nlev2 - 1; k > 0; --k)
+    {
+      jlev = k;
+      if (ph2[k] < p_firef) break;
+    }
+
+    // correct surface pressure
+    dfi = fiadj
+          - (fi2[jlev + 1] + (fi2[jlev] - fi2[jlev + 1]) * std::log(ph2[jlev + 1] / p_firef) / std::log(ph2[jlev + 1] / ph2[jlev]));
+    double ztv = (1.0 + epsm1i * zq2[nlev2 - 1]) * zt2[nlev2 - 1];
+    ps2[ij] = ps2[ij] * std::exp(dfi / (rair * ztv));
+  }
+
   // final calculation of specific humidity profiles
   if (ltq)
-    {
-      for (int k = 0; k < nlev2; ++k) pf2[k] = af2[k] + bf2[k] * ps2[ij];
-      for (int k = 0; k < nlev2; ++k) zq2[k] = rh2[k] * epsilon * esat(zt2[k]) / pf2[k];
-    }
+  {
+    for (int k = 0; k < nlev2; ++k) pf2[k] = af2[k] + bf2[k] * ps2[ij];
+    for (int k = 0; k < nlev2; ++k) zq2[k] = rh2[k] * epsilon * esat(zt2[k]) / pf2[k];
+  }
 
 #ifdef OUTPUT
   if (ij == OPOINT)
     for (int k = nlev2 - 1; k >= 0; --k)
-      {
-        auto ijk = k * ngp + ij;
-        double t = ltq ? t1[ijk] : 0;
-        double q = ltq ? q1[ijk] : 0;
-        double fi = ltq ? fi1[k] : 0;
-        fprintf(fpnew, "%3d %18.10f %18.10f %18.10f %18.10f", k, fi / g, pf2[k], t, q);
-        for (int iv = 0; iv < nvars; ++iv) fprintf(fpnew, " %18.10f", vars2[iv][ijk]);
-        fprintf(fpnew, "\n");
-      }
+    {
+      auto ijk = k * ngp + ij;
+      double t = ltq ? t1[ijk] : 0;
+      double q = ltq ? q1[ijk] : 0;
+      double fi = ltq ? fi1[k] : 0;
+      fprintf(fpnew, "%3d %18.10f %18.10f %18.10f %18.10f", k, fi / g, pf2[k], t, q);
+      for (int iv = 0; iv < nvars; ++iv) fprintf(fpnew, " %18.10f", vars2[iv][ijk]);
+      fprintf(fpnew, "\n");
+    }
 #endif
 
   if (ltq)
-    {
-      // calculate surface temperature correction (old version)
-      tscor[ij] = dteta * std::pow(ps2[ij] / apr, rair_d_cpair);
-      pscor[ij] = std::pow(ps2[ij] / ps1[ij], rair_d_cpair);
+  {
+    // calculate surface temperature correction (old version)
+    tscor[ij] = dteta * std::pow(ps2[ij] / apr, rair_d_cpair);
+    pscor[ij] = std::pow(ps2[ij] / ps1[ij], rair_d_cpair);
 
-      // correction term of static energy of lowest layer
-      secor[ij] = tv1[nlev1 - 1]
-                  * (cpair + rair * (1.0 - ph1[nlev1 - 1] / (ps1[ij] - ph1[nlev1 - 1]) * std::log(ps1[ij] / ph1[nlev1 - 1])));
-    }
+    // correction term of static energy of lowest layer
+    secor[ij] = tv1[nlev1 - 1]
+                * (cpair + rair * (1.0 - ph1[nlev1 - 1] / (ps1[ij] - ph1[nlev1 - 1]) * std::log(ps1[ij] / ph1[nlev1 - 1])));
+  }
 
   if (ltq)
     for (int k = 0; k < nlev2; ++k)
-      {
-        auto ijk = k * ngp + ij;
-        t2[ijk] = zt2[k];
-        q2[ijk] = zq2[k];
-      }
+    {
+      auto ijk = k * ngp + ij;
+      t2[ijk] = zt2[k];
+      q2[ijk] = zq2[k];
+    }
 }
 
 template <typename T>
 void
-hetaeta(bool ltq, int ngp, const Vmask &imiss, int nlev1, const double *ah1, const double *bh1, const Varray<double> &fis1,
-        const Varray<double> &ps1, const Varray<T> &t1, const Varray<T> &q1, int nlev2, const double *ah2, const double *bh2,
-        const Varray<double> &fis2, Varray<double> &ps2, Varray<T> &t2, Varray<T> &q2, int nvars, const Varray2D<T> &vars1,
+hetaeta(bool ltq, int ngp, Vmask const &imiss, int nlev1, const double *ah1, const double *bh1, Varray<double> const &fis1,
+        Varray<double> const &ps1, Varray<T> const &t1, Varray<T> const &q1, int nlev2, const double *ah2, const double *bh2,
+        Varray<double> const &fis2, Varray<double> &ps2, Varray<T> &t2, Varray<T> &q2, int nvars, Varray2D<T> const &vars1,
         Varray2D<T> &vars2, Varray<double> &tscor, Varray<double> &pscor, Varray<double> &secor)
 {
   long jlev = 0;
@@ -451,13 +450,13 @@ hetaeta(bool ltq, int ngp, const Vmask &imiss, int nlev1, const double *ah1, con
 
   Varray3D<double> vars_pbl(nthreads);
   if (nvars > 0)
+  {
+    for (int i = 0; i < nthreads; ++i)
     {
-      for (int i = 0; i < nthreads; ++i)
-        {
-          vars_pbl[i].resize(nvars);
-          for (int iv = 0; iv < nvars; ++iv) vars_pbl[i][iv].resize(nlev2);
-        }
+      vars_pbl[i].resize(nvars);
+      for (int iv = 0; iv < nvars; ++iv) vars_pbl[i][iv].resize(nlev2);
     }
+  }
 
   Varray<double> etah2(nlev2p1);
   Varray<double> af1(nlev1), bf1(nlev1), etaf1(nlev1);
@@ -472,86 +471,86 @@ hetaeta(bool ltq, int ngp, const Vmask &imiss, int nlev1, const double *ah1, con
   // input system
 
   for (int k = 0; k < nlev1; ++k)
-    {
-      af1[k] = 0.5 * (ah1[k] + ah1[k + 1]);
-      bf1[k] = 0.5 * (bh1[k] + bh1[k + 1]);
-    }
+  {
+    af1[k] = 0.5 * (ah1[k] + ah1[k + 1]);
+    bf1[k] = 0.5 * (bh1[k] + bh1[k + 1]);
+  }
 
   // etah1[nlev1] = ah1[nlev1]*aipr+bh1[nlev1];
   for (int k = 0; k < nlev1; ++k)
-    {
-      // etah1[k] = ah1[k] * aipr + bh1[k];
-      etaf1[k] = af1[k] * aipr + bf1[k];
-    }
+  {
+    // etah1[k] = ah1[k] * aipr + bh1[k];
+    etaf1[k] = af1[k] * aipr + bf1[k];
+  }
 
   // output system
 
   // calculates full level VCT
   for (int k = 0; k < nlev2; ++k)
-    {
-      af2[k] = 0.5 * (ah2[k] + ah2[k + 1]);
-      bf2[k] = 0.5 * (bh2[k] + bh2[k + 1]);
-    }
+  {
+    af2[k] = 0.5 * (ah2[k] + ah2[k + 1]);
+    bf2[k] = 0.5 * (bh2[k] + bh2[k + 1]);
+  }
 
   etah2[nlev2] = ah2[nlev2] * aipr + bh2[nlev2];
   auto jblt = nlev2;
   for (int k = nlev2 - 1; k >= 0; --k)
-    {
-      etah2[k] = ah2[k] * aipr + bh2[k];
-      etaf2[k] = af2[k] * aipr + bf2[k];
-      if (etah2[k] > eta_pbl) jblt = k;
-    }
+  {
+    etah2[k] = ah2[k] * aipr + bh2[k];
+    etaf2[k] = af2[k] * aipr + bf2[k];
+    if (etah2[k] > eta_pbl) jblt = k;
+  }
 
   // calculate weights for PBL interpolation
   for (int k = 0; k < nlev2; ++k)
+  {
+    // scan through new vertical levels set changes outside the full level eta's of old system to constant
+    if (etaf2[k] <= etaf1[0])
     {
-      // scan through new vertical levels set changes outside the full level eta's of old system to constant
-      if (etaf2[k] <= etaf1[0])
-        {
-          // at top of atmosphere
-          jl1[k] = 0;
-          jl2[k] = 1;
-          w2[k] = 0.0;
-        }
-      else if (etaf2[k] >= etaf1[nlev1 - 1])
-        {
-          // at surface of atmosphere
-          jl1[k] = nlev1 - 2;
-          jl2[k] = nlev1 - 1;
-          w2[k] = 1.0;
-        }
-      else
-        {
-          for (jlev = nlev1 - 2; jlev >= 1; jlev--)
-            {
-              jl1[k] = jlev;  // find nearest eta level below
-              if (etaf2[k] > etaf1[jlev]) break;
-            }
-          jl2[k] = jl1[k] + 1;
-          w2[k] = std::log(etaf2[k] / etaf1[jl1[k]]) / std::log(etaf1[jl2[k]] / etaf1[jl1[k]]);
-        }
-      w1[k] = 1.0 - w2[k];
+      // at top of atmosphere
+      jl1[k] = 0;
+      jl2[k] = 1;
+      w2[k] = 0.0;
     }
+    else if (etaf2[k] >= etaf1[nlev1 - 1])
+    {
+      // at surface of atmosphere
+      jl1[k] = nlev1 - 2;
+      jl2[k] = nlev1 - 1;
+      w2[k] = 1.0;
+    }
+    else
+    {
+      for (jlev = nlev1 - 2; jlev >= 1; jlev--)
+      {
+        jl1[k] = jlev;  // find nearest eta level below
+        if (etaf2[k] > etaf1[jlev]) break;
+      }
+      jl2[k] = jl1[k] + 1;
+      w2[k] = std::log(etaf2[k] / etaf1[jl1[k]]) / std::log(etaf1[jl2[k]] / etaf1[jl1[k]]);
+    }
+    w1[k] = 1.0 - w2[k];
+  }
 
   double epsm1i = 1.0 / epsilon - 1.0;
 
 #ifdef _OPENMP
 #pragma omp parallel for default(none) firstprivate(lpsmod) schedule(dynamic, 1)                                                  \
     shared(ngp, ph1, lnph1, fi1, pf1, lnpf1, tv1, theta1, rh1, zvar, ph2, lnph2, fi2, pf2, rh_pbl, zt2, zq2, theta_pbl, rh2, wgt, \
-           idx, vars_pbl, af1, bf1, etah2, af2, bf2, w1, w2, jl1, jl2, ltq, nvars, imiss, ah1, bh1, ps1, nlev1, epsm1i, q1, t1,   \
-           fis1, fis2, ps2, ah2, bh2, nlev2, vars1, vars2, t2, q2, tscor, pscor, secor, jblt)
+               idx, vars_pbl, af1, bf1, etah2, af2, bf2, w1, w2, jl1, jl2, ltq, nvars, imiss, ah1, bh1, ps1, nlev1, epsm1i, q1,   \
+               t1, fis1, fis2, ps2, ah2, bh2, nlev2, vars1, vars2, t2, q2, tscor, pscor, secor, jblt)
 #endif
   for (int ij = 0; ij < ngp; ++ij)
-    {
-      if ((imiss.size() > 0) && imiss[ij]) continue;
+  {
+    if ((imiss.size() > 0) && imiss[ij]) continue;
 
-      auto ompthID = cdo_omp_get_thread_num();
-      hetaeta_sc(ltq, lpsmod, ij, ngp, nlev1, nlev2, nvars, af1, bf1, etah2, af2, bf2, w1, w2, jl1, jl2, ah1, bh1, ps1, epsm1i, q1,
-                 t1, fis1, fis2, ps2, ah2, bh2, vars1, vars2, t2, q2, tscor, pscor, secor, jblt, ph1[ompthID], lnph1[ompthID],
-                 fi1[ompthID], pf1[ompthID], lnpf1[ompthID], tv1[ompthID], theta1[ompthID], rh1[ompthID], zvar[ompthID],
-                 ph2[ompthID], lnph2[ompthID], fi2[ompthID], pf2[ompthID], rh2[ompthID], wgt[ompthID], idx[ompthID],
-                 rh_pbl[ompthID], theta_pbl[ompthID], vars_pbl[ompthID], zt2[ompthID], zq2[ompthID]);
-    }
+    auto ompthID = cdo_omp_get_thread_num();
+    hetaeta_sc(ltq, lpsmod, ij, ngp, nlev1, nlev2, nvars, af1, bf1, etah2, af2, bf2, w1, w2, jl1, jl2, ah1, bh1, ps1, epsm1i, q1,
+               t1, fis1, fis2, ps2, ah2, bh2, vars1, vars2, t2, q2, tscor, pscor, secor, jblt, ph1[ompthID], lnph1[ompthID],
+               fi1[ompthID], pf1[ompthID], lnpf1[ompthID], tv1[ompthID], theta1[ompthID], rh1[ompthID], zvar[ompthID], ph2[ompthID],
+               lnph2[ompthID], fi2[ompthID], pf2[ompthID], rh2[ompthID], wgt[ompthID], idx[ompthID], rh_pbl[ompthID],
+               theta_pbl[ompthID], vars_pbl[ompthID], zt2[ompthID], zq2[ompthID]);
+  }
 
 #ifdef OUTPUT
   std::fclose(fpold);
@@ -562,15 +561,15 @@ hetaeta(bool ltq, int ngp, const Vmask &imiss, int nlev1, const double *ah1, con
 }
 
 // Explicit instantiation
-template void hetaeta(bool ltq, int ngp, const Vmask &imiss, int nlev1, const double *ah1, const double *bh1,
-                      const Varray<double> &fis1, const Varray<double> &ps1, const Varray<float> &t1, const Varray<float> &q1,
-                      int nlev2, const double *ah2, const double *bh2, const Varray<double> &fis2, Varray<double> &ps2,
-                      Varray<float> &t2, Varray<float> &q2, int nvars, const Varray2D<float> &vars1, Varray2D<float> &vars2,
+template void hetaeta(bool ltq, int ngp, Vmask const &imiss, int nlev1, const double *ah1, const double *bh1,
+                      Varray<double> const &fis1, Varray<double> const &ps1, Varray<float> const &t1, Varray<float> const &q1,
+                      int nlev2, const double *ah2, const double *bh2, Varray<double> const &fis2, Varray<double> &ps2,
+                      Varray<float> &t2, Varray<float> &q2, int nvars, Varray2D<float> const &vars1, Varray2D<float> &vars2,
                       Varray<double> &scor, Varray<double> &pscor, Varray<double> &secor);
-template void hetaeta(bool ltq, int ngp, const Vmask &imiss, int nlev1, const double *ah1, const double *bh1,
-                      const Varray<double> &fis1, const Varray<double> &ps1, const Varray<double> &t1, const Varray<double> &q1,
-                      int nlev2, const double *ah2, const double *bh2, const Varray<double> &fis2, Varray<double> &ps2,
-                      Varray<double> &t2, Varray<double> &q2, int nvars, const Varray2D<double> &vars1, Varray2D<double> &vars2,
+template void hetaeta(bool ltq, int ngp, Vmask const &imiss, int nlev1, const double *ah1, const double *bh1,
+                      Varray<double> const &fis1, Varray<double> const &ps1, Varray<double> const &t1, Varray<double> const &q1,
+                      int nlev2, const double *ah2, const double *bh2, Varray<double> const &fis2, Varray<double> &ps2,
+                      Varray<double> &t2, Varray<double> &q2, int nvars, Varray2D<double> const &vars1, Varray2D<double> &vars2,
                       Varray<double> &scor, Varray<double> &pscor, Varray<double> &secor);
 
 #ifdef TEST_HETAETA
@@ -669,22 +668,22 @@ main(int argc, char *argv[])
   for (int i = 0; i < 5; ++i) vars2[i].resize(NGP * 40);
 
   for (int ij = 0; ij < NGP; ++ij)
-    {
-      ps1[ij] = ips1;
-      fis1[ij] = ifis1;
-    }
+  {
+    ps1[ij] = ips1;
+    fis1[ij] = ifis1;
+  }
 
   for (int k = 0; k < 19; ++k)
     for (int ij = 0; ij < NGP; ++ij)
-      {
-        t1[k * NGP + ij] = it1[k];
-        q1[k * NGP + ij] = iq1[k];
-        vars1[0][k * NGP + ij] = iu1[k];
-        vars1[1][k * NGP + ij] = iv1[k];
-        vars1[2][k * NGP + ij] = icl1[k];
-        vars1[3][k * NGP + ij] = ici1[k];
-        vars1[4][k * NGP + ij] = icc1[k];
-      }
+    {
+      t1[k * NGP + ij] = it1[k];
+      q1[k * NGP + ij] = iq1[k];
+      vars1[0][k * NGP + ij] = iu1[k];
+      vars1[1][k * NGP + ij] = iv1[k];
+      vars1[2][k * NGP + ij] = icl1[k];
+      vars1[3][k * NGP + ij] = ici1[k];
+      vars1[4][k * NGP + ij] = icc1[k];
+    }
 
   for (int ij = 0; ij < NGP; ++ij) fis2[ij] = fis1[ij];
 
