@@ -135,8 +135,7 @@ void kd_nodepool_delete(kdNodePool_t *nodepool)
 }
 
 struct kdNode *
-kd_allocNode(struct kd_point *points, size_t pivot,
-             kdata_t *min, kdata_t *max, int axis, int dim)
+kd_allocNode(struct kd_point *points, size_t pivot, kdata_t *min, kdata_t *max, int axis, int dim)
 {
   struct kdNode *node;
 
@@ -154,8 +153,7 @@ kd_allocNode(struct kd_point *points, size_t pivot,
 }
 
 struct kdNode *
-kd_allocNodeP(kdNodePool *nodepool, struct kd_point *points, size_t pivot,
-             kdata_t *min, kdata_t *max, int axis, int dim)
+kd_allocNodeP(kdNodePool *nodepool, struct kd_point *points, size_t pivot, kdata_t *min, kdata_t *max, int axis, int dim)
 {
   struct kdNode *node;
 
@@ -227,21 +225,16 @@ void *kd_doBuildTree(void *threadarg)
   int sortaxis = depth % dim;
 
   if (nPoints == 1) {
-    if ((node = kd_allocNodeP(nodepool, points, 0, min, max, sortaxis, dim)) == NULL)
-      return NULL;
+    if ((node = kd_allocNodeP(nodepool, points, 0, min, max, sortaxis, dim)) == NULL) return NULL;
     node->index = points[0].index;
     return node;
   }
 
-  /*
-   * If this iteration is allowed to start more threads, we first
-   * use them to parallelize the sorting 
-   */
+  // If this iteration is allowed to start more threads, we first use them to parallelize the sorting 
   pmergesort(points, nPoints, sortaxis, max_threads);
 
   size_t pivot = nPoints / 2;
-  if ((node = kd_allocNodeP(nodepool, points, pivot, min, max, sortaxis, dim)) == NULL)
-    return NULL;
+  if ((node = kd_allocNodeP(nodepool, points, pivot, min, max, sortaxis, dim)) == NULL) return NULL;
 
   memcpy(tmpMaxLeft, max, dim * sizeof(kdata_t));
   tmpMaxLeft[sortaxis] = node->location[sortaxis];
