@@ -17,7 +17,7 @@ weightingMethod_to_string(WeightingMethod method)
 }
 
 WeightingMethod
-string_to_weightingMethod(const std::string &methodStr)
+string_to_weightingMethod(std::string const &methodStr)
 {
   if (methodStr == "avg") return WeightingMethod::arithmeticAverage;
   if (methodStr == "dist") return WeightingMethod::distanceWeighted;
@@ -31,18 +31,18 @@ string_to_weightingMethod(const std::string &methodStr)
 }
 
 void
-KnnData::apply_mask(const Vmask &gridMask)
+KnnData::apply_mask(Vmask const &gridMask)
 {
   size_t n = 0;
   for (size_t i = 0; i < m_numNeighbors; ++i)
+  {
+    if (gridMask[m_indices[i]])
     {
-      if (gridMask[m_indices[i]])
-        {
-          m_indices[n] = m_indices[i];
-          m_dist[n] = m_dist[i];
-          n++;
-        }
+      m_indices[n] = m_indices[i];
+      m_dist[n] = m_dist[i];
+      n++;
     }
+  }
 
   m_numNeighbors = n;
 }
@@ -62,40 +62,40 @@ KnnData::store_distance(size_t index, double distance, size_t maxNeighbors)
   m_numNeighbors = maxNeighbors;
 
   if (maxNeighbors == 1)
+  {
+    if (distance_is_less(distance, m_dist[0], index, m_indices[0]))
     {
-      if (distance_is_less(distance, m_dist[0], index, m_indices[0]))
-        {
-          m_indices[0] = index;
-          m_dist[0] = distance;
-        }
+      m_indices[0] = index;
+      m_dist[0] = distance;
     }
+  }
   else
+  {
+    for (size_t i = 0; i < maxNeighbors; ++i)
     {
-      for (size_t i = 0; i < maxNeighbors; ++i)
+      if (distance_is_less(distance, m_dist[i], index, m_indices[i]))
+      {
+        for (size_t n = maxNeighbors - 1; n > i; --n)
         {
-          if (distance_is_less(distance, m_dist[i], index, m_indices[i]))
-            {
-              for (size_t n = maxNeighbors - 1; n > i; --n)
-                {
-                  m_indices[n] = m_indices[n - 1];
-                  m_dist[n] = m_dist[n - 1];
-                }
-              m_indices[i] = index;
-              m_dist[i] = distance;
-              break;
-            }
+          m_indices[n] = m_indices[n - 1];
+          m_dist[n] = m_dist[n - 1];
         }
+        m_indices[i] = index;
+        m_dist[i] = distance;
+        break;
+      }
     }
+  }
 }
 
 size_t
 KnnData::compute_weights_avg()
 {
   if (m_numNeighbors)
-    {
-      double weight = 1.0 / m_numNeighbors;
-      for (size_t i = 0; i < m_numNeighbors; ++i) { m_dist[i] = weight; }
-    }
+  {
+    double weight = 1.0 / m_numNeighbors;
+    for (size_t i = 0; i < m_numNeighbors; ++i) { m_dist[i] = weight; }
+  }
 
   return m_numNeighbors;
 }
@@ -106,10 +106,10 @@ KnnData::compute_weights_dist()
   // Compute weights based on inverse distance
   double distTotal = 0.0;  // sum of neighbor distances (for normalizing)
   for (size_t i = 0; i < m_numNeighbors; ++i)
-    {
-      m_dist[i] = 1.0 / m_dist[i];
-      distTotal += m_dist[i];
-    }
+  {
+    m_dist[i] = 1.0 / m_dist[i];
+    distTotal += m_dist[i];
+  }
   // Normalize weights
   for (size_t i = 0; i < m_numNeighbors; ++i) { m_dist[i] = m_dist[i] / distTotal; }
 
@@ -122,10 +122,10 @@ KnnData::compute_weights_linear()
   // Compute weights based on linear interpolation
   double distTotal = 0.0;  // sum of neighbor distances (for normalizing)
   for (size_t i = 0; i < m_numNeighbors; ++i)
-    {
-      m_dist[i] = intlin(m_dist[i], m_weight0, 0, m_weightR, m_searchRadius);
-      distTotal += m_dist[i];
-    }
+  {
+    m_dist[i] = intlin(m_dist[i], m_weight0, 0, m_weightR, m_searchRadius);
+    distTotal += m_dist[i];
+  }
   // Normalize weights
   for (size_t i = 0; i < m_numNeighbors; ++i) { m_dist[i] = m_dist[i] / distTotal; }
 
@@ -156,22 +156,22 @@ KnnData::compute_weights_gauss()
   // w_i = e^(C * d_i^2)
   double weights_sum = 0.0;
   for (size_t i = 0; i < n; ++i)
-    {
-      weights[i] = std::exp(scale * weights[i]);
-      weights_sum += weights[i];
-    }
+  {
+    weights[i] = std::exp(scale * weights[i]);
+    weights_sum += weights[i];
+  }
 
   // If the sum of the weights is very low, which can happen in case
   // the target point is very far away from the group source points.
-  if (fabs(weights_sum) < 1e-9)
-    {
-      // Due to limited accuracy the exact contribution of each source
-      // point cannot be computed. Therefore, the normalisation would
-      // generate NaN's. Hence we fall back to inverse distance weighted
-      // averge for this target point.
-      compute_weights_dist();
-      return n;
-    }
+  if (std::fabs(weights_sum) < 1e-9)
+  {
+    // Due to limited accuracy the exact contribution of each source
+    // point cannot be computed. Therefore, the normalisation would
+    // generate NaN's. Hence we fall back to inverse distance weighted
+    // averge for this target point.
+    compute_weights_dist();
+    return n;
+  }
 
   // d) scale weights such that SUM(w_i) == 1
   for (size_t i = 0; i < n; ++i) m_dist[i] = weights[i] / weights_sum;
