@@ -7,7 +7,7 @@
 #ifndef LISTBUF_H
 #define LISTBUF_H
 
-#include <stdio.h>
+#include <cstdio>
 #include <sys/stat.h>
 #include <string>
 #include <vector>
@@ -23,19 +23,19 @@ public:
   {
     int filedes = fileno(fp);
     struct stat buf;
-    const size_t filesize = (fstat(filedes, &buf) == 0) ? (size_t) buf.st_size : 0;
+    size_t filesize = (fstat(filedes, &buf) == 0) ? (size_t) buf.st_size : 0;
     if (filesize == 0)
-      {
-        fprintf(stderr, "ListBuffer: empty stream: %s\n", _name);
-        return -1;
-      }
+    {
+      std::fprintf(stderr, "ListBuffer: empty stream: %s\n", _name);
+      return -1;
+    }
 
     this->buffer.resize(filesize);
-    if (fread(buffer.data(), 1, filesize, fp) != filesize)
-      {
-        fprintf(stderr, "ListBuffer: read failed on %s!\n", _name);
-        return -1;
-      }
+    if (std::fread(buffer.data(), 1, filesize, fp) != filesize)
+    {
+      std::fprintf(stderr, "ListBuffer: read failed on %s!\n", _name);
+      return -1;
+    }
 
     if (_name) this->name = _name;
 
