@@ -20,17 +20,16 @@ struct ModListOptions
   std::map<const std::string, int> opt
       = { { s_obase, false }, { s_arbIn, false }, { s_filesOnly, false }, { s_onlyFirst, false }, { s_noOutput, false } };
 
-  bool requested(const std::string &name);
+  bool requested(std::string const &name);
   bool mod_info_requested();
-  bool parse_request(const std::string &requestString);
+  bool parse_request(std::string const &requestString);
 };
 
-std::string get_operator_description(const std::string &p_current_op_name, const std::vector<std::string> &p_help);
+std::string get_operator_description(std::string const &p_current_op_name, std::vector<std::string> const &p_help);
 void operator_print_list(ModListOptions &p_modListOpt);
 std::pair<std::map<std::string, std::vector<std::string>>, std::map<std::string, std::pair<std::string, std::vector<std::string>>>>
 create_help_sections(const CdoHelp &p_help);
 
-void cdo_print_help(const char **help);
-void cdo_print_help(const std::string &help);
-void cdo_print_help(const CdoHelp &p_help);
+void cdo_print_help(std::string const &help);
+
 #endif
