@@ -26,7 +26,8 @@ struct par_io_t
   size_t numMissVals;
   double *array;
   int array_size;
-  int recID, nrecs;
+  int fieldID;
+  int numFields;
   read_arg_t read_arg;
 #ifdef HAVE_LIBPTHREAD
   pthread_t thrID;
@@ -34,6 +35,6 @@ struct par_io_t
 #endif
 };
 
-void par_read_record(CdoStreamID streamID, int *varID, int *levelID, double *array, size_t *numMissVals, par_io_t *parIO);
+void par_read_field(CdoStreamID streamID, int *varID, int *levelID, double *array, size_t *numMissVals, par_io_t *parIO);
 
 #endif /* PAR_IO_H */
