@@ -15,8 +15,6 @@
 #include <cdi.h>
 
 #include "cdo_output.h"
-#include "cdo_options.h"
-#include "compare.h"
 #include "util_string.h"
 #include "constants.h"
 #include "const.h"
@@ -28,10 +26,10 @@ parameter_to_word(const char *cstring)
   auto len = std::strlen(cstring);
 
   for (size_t i = 0; i < len; ++i)
-    {
-      int c = cstring[i];
-      if (iscntrl(c) || isblank(c)) cdo_abort("Word parameter >%s< contains invalid character at position %zu!", cstring, i + 1);
-    }
+  {
+    int c = cstring[i];
+    if (iscntrl(c) || isblank(c)) cdo_abort("Word parameter >%s< contains invalid character at position %zu!", cstring, i + 1);
+  }
 
   if (len == 0) cdo_abort("Word parameter >%s< is empty!", cstring);
 
@@ -45,21 +43,21 @@ parameter_error(const char *name, const char *cstring, const char *endptr)
 }
 
 long
-parameter_to_bytes(const std::string &string)
+parameter_to_bytes(std::string const &string)
 {
   char *endptr = nullptr;
   auto numBytes = strtoimax(string.c_str(), &endptr, 10);
   if (*endptr)
+  {
+    switch (tolower((int) *endptr))
     {
-      switch (tolower((int) *endptr))
-        {
-          // clang-format off
-        case 'k': numBytes *= 1024;       endptr++; break;
-        case 'm': numBytes *= 1048576;    endptr++; break;
-        case 'g': numBytes *= 1073741824; endptr++; break;
-          // clang-format on
-        }
+        // clang-format off
+      case 'k': numBytes *= 1024;       endptr++; break;
+      case 'm': numBytes *= 1048576;    endptr++; break;
+      case 'g': numBytes *= 1073741824; endptr++; break;
+        // clang-format on
     }
+  }
   if (*endptr) parameter_error("Bytes", string.c_str(), endptr);
   int len = string.size();
   if ((string[0] != '-' && len > 19) || len > 20)
@@ -71,7 +69,7 @@ double
 parameter_to_double(const char *const cstring)
 {
   char *endptr = nullptr;
-  auto fval = strtod(cstring, &endptr);
+  auto fval = std::strtod(cstring, &endptr);
   if (*endptr == 'f') endptr++;
   if (*endptr) parameter_error("Float", cstring, endptr);
   return fval;
@@ -120,21 +118,21 @@ int
 parameter_to_intlist(const char *const cstring)
 {
   char *endptr = nullptr;
-  auto ival = (int) strtol(cstring, &endptr, 10);
+  auto ival = (int) std::strtol(cstring, &endptr, 10);
   if (*endptr && *endptr != '/' && (endptr - cstring) == 0) parameter_error("Integer", cstring, endptr);
   return ival;
 }
 
-const std::string &
-parameter_to_word(const std::string &string)
+std::string const &
+parameter_to_word(std::string const &string)
 {
   auto len = string.size();
 
   for (size_t i = 0; i < len; ++i)
-    {
-      int c = string[i];
-      if (iscntrl(c) || isblank(c)) cdo_abort("Word parameter >%s< contains invalid character at position %zu!", string, i + 1);
-    }
+  {
+    int c = string[i];
+    if (iscntrl(c) || isblank(c)) cdo_abort("Word parameter >%s< contains invalid character at position %zu!", string, i + 1);
+  }
 
   if (len == 0) cdo_abort("Word parameter >%s< is empty!", string);
 
@@ -142,7 +140,7 @@ parameter_to_word(const std::string &string)
 }
 
 bool
-parameter_to_bool(const std::string &string)
+parameter_to_bool(std::string const &string)
 {
   auto lstring = string_to_lower(string);
 
@@ -155,73 +153,73 @@ parameter_to_bool(const std::string &string)
 }
 
 double
-parameter_to_double(const std::string &string)
+parameter_to_double(std::string const &string)
 {
   return parameter_to_double(string.c_str());
 }
 
 int
-parameter_to_int(const std::string &string)
+parameter_to_int(std::string const &string)
 {
   return parameter_to_int(string.c_str());
 }
 
 long
-parameter_to_long(const std::string &string)
+parameter_to_long(std::string const &string)
 {
   return parameter_to_long(string.c_str());
 }
 
 size_t
-parameter_to_size_t(const std::string &string)
+parameter_to_size_t(std::string const &string)
 {
   return parameter_to_size_t(string.c_str());
 }
 
 int
-parameter_to_intlist(const std::string &string)
+parameter_to_intlist(std::string const &string)
 {
   return parameter_to_intlist(string.c_str());
 }
 
 double
-radius_str_to_meter(const std::string &string)
+radius_str_to_meter(std::string const &string)
 {
   char *endptr = nullptr;
-  auto radius = strtod(string.c_str(), &endptr);
+  auto radius = std::strtod(string.c_str(), &endptr);
 
   if (*endptr != 0)
-    {
-      if (std::strncmp(endptr, "km", 2) == 0)
-        radius *= 1000;
-      else if (std::strncmp(endptr, "m", 1) == 0)
-        ;
-      else
-        cdo_abort("Float parameter >%s< contains invalid character at position %d!", string, (int) (endptr - string.c_str() + 1));
-    }
+  {
+    if (std::strncmp(endptr, "km", 2) == 0)
+      radius *= 1000;
+    else if (std::strncmp(endptr, "m", 1) == 0)
+      ;
+    else
+      cdo_abort("Float parameter >%s< contains invalid character at position %d!", string, (int) (endptr - string.c_str() + 1));
+  }
 
   return radius;
 }
 
 double
-radius_str_to_deg(const std::string &string)
+radius_str_to_deg(std::string const &string)
 {
   char *endptr = nullptr;
-  auto radius = strtod(string.c_str(), &endptr);
+  auto radius = std::strtod(string.c_str(), &endptr);
 
   if (*endptr != 0)
-    {
-      if (std::strncmp(endptr, "km", 2) == 0)
-        radius = 360 * ((radius * 1000) / (2.0 * PlanetRadiusDefault * M_PI));
-      else if (std::strncmp(endptr, "m", 1) == 0)
-        radius = 360 * ((radius) / (2.0 * PlanetRadiusDefault * M_PI));
-      else if (std::strncmp(endptr, "deg", 3) == 0)
-        ;
-      else if (std::strncmp(endptr, "rad", 3) == 0)
-        radius *= RAD2DEG;
-      else
-        cdo_abort("Float parameter >%s< contains invalid character at position %d!", string, (int) (endptr - string.c_str() + 1));
-    }
+  {
+    if (std::strncmp(endptr, "km", 2) == 0)
+      radius = 360 * ((radius * 1000) / (2.0 * PlanetRadiusDefault * M_PI));
+    else if (std::strncmp(endptr, "m", 1) == 0)
+      radius = 360 * ((radius) / (2.0 * PlanetRadiusDefault * M_PI));
+    else if (std::strncmp(endptr, "deg", 3) == 0)
+      ;
+    else if (std::strncmp(endptr, "rad", 3) == 0)
+      radius *= RAD2DEG;
+    else
+      cdo_abort("Float parameter >%s< contains invalid character at position %d!", string, (int) (endptr - string.c_str() + 1));
+  }
 
   if (radius > 180.0) radius = 180.0;
 
@@ -238,7 +236,7 @@ string_to_param(const char *const paramstr)
 }
 
 int
-string_to_param(const std::string &paramstr)
+string_to_param(std::string const &paramstr)
 {
   return string_to_param(paramstr.c_str());
 }
@@ -267,43 +265,43 @@ param_to_string(int param)
 /* time/date/season converisons */
 /* =================================================================================== */
 void
-season_to_months(const std::string &season, int *imonths)
+season_to_months(std::string const &season, int *imonths)
 {
   const char *const smons = "JFMAMJJASONDJFMAMJJASOND";
   const int imons[] = { 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12 };
   assert(std::strlen(smons) == (sizeof(imons) / sizeof(int)));
 
   if (season == "ANN")
-    {
-      for (size_t k = 0; k < 12; ++k) imonths[k + 1] = 1;
-    }
+  {
+    for (size_t k = 0; k < 12; ++k) imonths[k + 1] = 1;
+  }
   else
+  {
+    auto len = season.size();
+    if (len > 12) cdo_abort("Too many months %d (limit=12)!", (int) len);
+    char *const season_u = strdup(season.c_str());
+    cstr_to_upper(season_u);
+    const char *const sstr = std::strstr(smons, season_u);
+    std::free(season_u);
+    if (sstr != nullptr)
     {
-      auto len = season.size();
-      if (len > 12) cdo_abort("Too many months %d (limit=12)!", (int) len);
-      char *const season_u = strdup(season.c_str());
-      cstr_to_upper(season_u);
-      const char *const sstr = std::strstr(smons, season_u);
-      std::free(season_u);
-      if (sstr != nullptr)
-        {
-          size_t ks = (size_t) (sstr - smons);
-          size_t ke = ks + len;
-          for (size_t k = ks; k < ke; ++k) imonths[imons[k]]++;
-        }
-      else { cdo_abort("Season %s not available!", season); }
+      size_t ks = (size_t) (sstr - smons);
+      size_t ke = ks + len;
+      for (size_t k = ks; k < ke; ++k) imonths[imons[k]]++;
     }
+    else { cdo_abort("Season %s not available!", season); }
+  }
 }
 
 double
-datestr_to_double(const std::string &datestr, int opt)
+datestr_to_double(std::string const &datestr, int opt)
 {
   for (size_t i = 0, n = datestr.size(); i < n; ++i)
-    {
-      int c = datestr[i];
-      if (!(std::isdigit(c) || c == '-' || c == ':' || c == '.' || c == 'T'))
-        cdo_abort("Date string >%s< contains invalid character at position %zu!", datestr, i + 1);
-    }
+  {
+    int c = datestr[i];
+    if (!(std::isdigit(c) || c == '-' || c == ':' || c == '.' || c == 'T'))
+      cdo_abort("Date string >%s< contains invalid character at position %zu!", datestr, i + 1);
+  }
 
   if (not string_contains(datestr, '-')) { return parameter_to_double(datestr); }
   if (datestr[0] == '-' && not string_contains(datestr.c_str() + 1, '-')) { return parameter_to_double(datestr); }
@@ -311,22 +309,22 @@ datestr_to_double(const std::string &datestr, int opt)
   int year = 1;
   unsigned month = 1, day = 1, hour = 0, minute = 0, second = 0;
   if (opt)
-    {
-      hour = 23;
-      minute = 59;
-      second = 59;
-    }
+  {
+    hour = 23;
+    minute = 59;
+    second = 59;
+  }
 
   if (string_contains(datestr, 'T'))
-    {
-      auto status = std::sscanf(datestr.c_str(), "%d-%u-%uT%u:%u:%u", &year, &month, &day, &hour, &minute, &second);
-      if (status != 6) cdo_abort("Invalid date string >%s<!", datestr);
-    }
+  {
+    auto status = std::sscanf(datestr.c_str(), "%d-%u-%uT%u:%u:%u", &year, &month, &day, &hour, &minute, &second);
+    if (status != 6) cdo_abort("Invalid date string >%s<!", datestr);
+  }
   else
-    {
-      auto status = std::sscanf(datestr.c_str(), "%d-%u-%u", &year, &month, &day);
-      if (status != 3) cdo_abort("Invalid date string >%s<!", datestr);
-    }
+  {
+    auto status = std::sscanf(datestr.c_str(), "%d-%u-%u", &year, &month, &day);
+    if (status != 3) cdo_abort("Invalid date string >%s<!", datestr);
+  }
 
   if (month > 12 || day > 31) cdo_abort("Date components out of bounds >%s<!", datestr);
   if (hour > 24 || minute > 60 || second > 60) cdo_abort("Time components out of bounds >%s<!", datestr);
@@ -341,93 +339,101 @@ datestr_to_double(const std::string &datestr, int opt)
 
 // argv conversions ==============================================
 std::vector<int>
-cdo_argv_to_intarr(const std::vector<std::string> &argv)
+cdo_argv_to_intarr(std::vector<std::string> const &argv)
 {
   std::vector<int> v;
 
-  for (const auto &argument : argv)
-    {
-      int first, last, inc;
-      split_intstring(argument, first, last, inc);
+  for (auto const &argument : argv)
+  {
+    int first, last, inc;
+    split_intstring(argument, first, last, inc);
 
-      if (inc >= 0)
-        {
-          for (auto ival = first; ival <= last; ival += inc) v.push_back(ival);
-        }
-      else
-        {
-          for (auto ival = first; ival >= last; ival += inc) v.push_back(ival);
-        }
+    if (inc >= 0)
+    {
+      for (auto ival = first; ival <= last; ival += inc) v.push_back(ival);
     }
+    else
+    {
+      for (auto ival = first; ival >= last; ival += inc) v.push_back(ival);
+    }
+  }
 
   return v;
 }
 
 std::vector<double>
-cdo_argv_to_fltarr(const std::vector<std::string> &argv)
+cdo_argv_to_fltarr(std::vector<std::string> const &argv)
 {
   std::vector<double> v;
 
-  for (const auto &argument : argv)
+  for (auto const &argument : argv)
+  {
+    auto len = (int) argument.size();
+    int i;
+    for (i = 0; i < len; ++i)
+      if (argument[i] != '/' && argument[i] != '-' && argument[i] != '.' && !std::isdigit(argument[i])) break;
+
+    if (i != len) { v.push_back(parameter_to_double(argument)); }
+    else
     {
-      auto len = (int) argument.size();
-      int i;
-      for (i = 0; i < len; ++i)
-        if (argument[i] != '/' && argument[i] != '-' && argument[i] != '.' && !std::isdigit(argument[i])) break;
+      double first, last, inc;
+      split_fltstring(argument, first, last, inc);
 
-      if (i != len) { v.push_back(parameter_to_double(argument)); }
+      if (inc >= 0)
+      {
+        for (double fval = first; fval <= last; fval += inc) v.push_back(fval);
+      }
       else
-        {
-          double first, last, inc;
-          split_fltstring(argument, first, last, inc);
-
-          if (inc >= 0)
-            {
-              for (double fval = first; fval <= last; fval += inc) v.push_back(fval);
-            }
-          else
-            {
-              for (double fval = first; fval >= last; fval += inc) v.push_back(fval);
-            }
-        }
+      {
+        for (double fval = first; fval >= last; fval += inc) v.push_back(fval);
+      }
     }
+  }
 
   return v;
 }
 
+static const char *
+skip_word(const char *inStr, const char *word)
+{
+  auto len = std::strlen(word);
+  if (len <= std::strlen(inStr) && std::strncmp(word, inStr, len) == 0) { inStr += len; }
+  return inStr;
+}
+
 static void
 split_intstring(const char *const intstr, int &first, int &last, int &inc)
 {
   auto startptr = intstr;
   char *endptr = nullptr;
-  auto ival = (int) strtol(startptr, &endptr, 10);
+  auto ival = (int) std::strtol(startptr, &endptr, 10);
   if (*endptr != 0 && *endptr != '/' && (endptr - startptr) == 0) parameter_error("Integer", startptr, endptr);
   first = ival;
   last = ival;
   inc = 1;
 
   if (*endptr == '/')
-    {
-      startptr = endptr + 1;
-      endptr = nullptr;
-      ival = (int) strtol(startptr, &endptr, 10);
-      if (*endptr != 0 && *endptr != '/' && (endptr - startptr) == 0) parameter_error("Integer", startptr, endptr);
-      last = ival;
-      if (first > last) inc = -1;
+  {
+    startptr = skip_word(endptr + 1, "to/");
+    endptr = nullptr;
+    ival = (int) std::strtol(startptr, &endptr, 10);
+    if (*endptr != 0 && *endptr != '/' && (endptr - startptr) == 0) parameter_error("Integer", startptr, endptr);
+    last = ival;
+    if (first > last) inc = -1;
 
-      if (*endptr == '/')
-        {
-          startptr = endptr + 1;
-          endptr = nullptr;
-          ival = (int) strtol(startptr, &endptr, 10);
-          if (*endptr != 0 && (endptr - startptr) == 0) parameter_error("Integer", startptr, endptr);
-          inc = ival;
-        }
+    if (*endptr == '/')
+    {
+      startptr = skip_word(endptr + 1, "by/");
+      endptr = nullptr;
+      ival = (int) std::strtol(startptr, &endptr, 10);
+      if (*endptr != 0 && (endptr - startptr) == 0) parameter_error("Integer", startptr, endptr);
+      inc = ival;
     }
+  }
 }
 
 void
-split_intstring(const std::string &intstr, int &first, int &last, int &inc)
+split_intstring(std::string const &intstr, int &first, int &last, int &inc)
 {
   split_intstring(intstr.c_str(), first, last, inc);
 }
@@ -437,83 +443,83 @@ split_fltstring(const char *const intstr, double &first, double &last, double &i
 {
   auto startptr = intstr;
   char *endptr = nullptr;
-  auto fval = strtod(startptr, &endptr);
+  auto fval = std::strtod(startptr, &endptr);
   if (*endptr != 0 && *endptr != '/' && (endptr - startptr) == 0) parameter_error("Float", startptr, endptr);
   first = fval;
   last = fval;
   inc = 1;
 
   if (*endptr == '/')
-    {
-      startptr = endptr + 1;
-      endptr = nullptr;
-      fval = strtod(startptr, &endptr);
-      if (*endptr != 0 && *endptr != '/' && (endptr - startptr) == 0) parameter_error("Float", startptr, endptr);
-      last = fval;
-      if (first > last) inc = -1;
+  {
+    startptr = skip_word(endptr + 1, "to/");
+    endptr = nullptr;
+    fval = std::strtod(startptr, &endptr);
+    if (*endptr != 0 && *endptr != '/' && (endptr - startptr) == 0) parameter_error("Float", startptr, endptr);
+    last = fval;
+    if (first > last) inc = -1;
 
-      if (*endptr == '/')
-        {
-          startptr = endptr + 1;
-          endptr = nullptr;
-          fval = strtod(startptr, &endptr);
-          if (*endptr != 0 && (endptr - startptr) == 0) parameter_error("Float", startptr, endptr);
-          inc = fval;
-        }
+    if (*endptr == '/')
+    {
+      startptr = skip_word(endptr + 1, "by/");
+      endptr = nullptr;
+      fval = std::strtod(startptr, &endptr);
+      if (*endptr != 0 && (endptr - startptr) == 0) parameter_error("Float", startptr, endptr);
+      inc = fval;
     }
+  }
 }
 
 void
-split_fltstring(const std::string &fltstr, double &first, double &last, double &inc)
+split_fltstring(std::string const &fltstr, double &first, double &last, double &inc)
 {
   split_fltstring(fltstr.c_str(), first, last, inc);
 }
 
 template <>
 int
-convert(const std::string &str_value)
+convert(std::string const &str_value)
 {
   return parameter_to_int(str_value.c_str());
 }
 
 template <>
 double
-convert(const std::string &str_value)
+convert(std::string const &str_value)
 {
   return parameter_to_double(str_value.c_str());
 }
 
 template <>
 bool
-convert(const std::string &str_value)
+convert(std::string const &str_value)
 {
   return parameter_to_bool(str_value);
 }
 
 template <>
 long
-convert(const std::string &str_value)
+convert(std::string const &str_value)
 {
   return parameter_to_long(str_value.c_str());
 }
 
 template <>
 size_t
-convert(const std::string &str_value)
+convert(std::string const &str_value)
 {
   return parameter_to_size_t(str_value.c_str());
 }
 
 template <>
 std::string
-convert(const std::string &str_value)
+convert(std::string const &str_value)
 {
   return parameter_to_word(str_value.c_str());
 }
 
 template <>
 FillMethod
-convert(const std::string &str_value)
+convert(std::string const &str_value)
 {
   auto fillMethod = string_to_fillmethod(parameter_to_word(str_value));
 
