@@ -1,8 +1,4 @@
-#include <map>
-#include <set>
-#include <iostream>
 #include <functional>
-#include <iomanip>
 #include <vector>
 #include <stack>
 
@@ -28,7 +24,7 @@ namespace Util
 {
 
 void
-extract_name_and_argument(const std::string &command, std::string &operatorName, std::string &operatorArgument)
+extract_name_and_argument(std::string const &command, std::string &operatorName, std::string &operatorArgument)
 {
   constexpr char delimiter = ',';
 
@@ -36,10 +32,10 @@ extract_name_and_argument(const std::string &command, std::string &operatorName,
 
   size_t len = command.find(delimiter);
   if (len == std::string::npos)
-    {
-      len = command.size();
-      operatorArgument = "";
-    }
+  {
+    len = command.size();
+    operatorArgument = "";
+  }
   else { operatorArgument = command.substr(len + 1, std::string::npos); }
 
   operatorName = command.substr(start, len - start);
@@ -52,19 +48,19 @@ tab()
 }
 
 std::vector<std::string>
-generate_tokens(const std::string &p_oper)
+generate_tokens(std::string const &p_oper)
 {
   std::vector<std::string> result = {};
 
   auto end = p_oper.find(' ');
   auto start = 0;
   while (end != std::string::npos)
-    {
-      auto oper = p_oper.substr(start, end - start);
-      result.push_back(oper);
-      start = end + 1;
-      end = p_oper.find(' ', start);
-    }
+  {
+    auto oper = p_oper.substr(start, end - start);
+    result.push_back(oper);
+    start = end + 1;
+    end = p_oper.find(' ', start);
+  }
   auto oper = p_oper.substr(start, end - start);
   result.push_back(oper);
 
@@ -83,13 +79,13 @@ void
 append(std::shared_ptr<T> &parent, std::shared_ptr<T> &child)
 {
   try
-    {
-      parent->append(child);
-    }
+  {
+    parent->append(child);
+  }
   catch (NodeAttachException &e)
-    {
-      THROW(InternalCdoSyntaxError, e.iter, e.what());
-    }
+  {
+    THROW(InternalCdoSyntaxError, e.iter, e.what());
+  }
 }
 
 }  // namespace Util
@@ -184,7 +180,7 @@ public:
   void
   pop()
   {
-    const auto &node = stack.back();
+    auto const &node = stack.back();
     debug_parser("poping node: %s", node->oper);
     if (node->constraints.streamInCnt == -1) { cntVariableInputs--; }
     debug_parser("poping node: %s", node->oper);
@@ -195,16 +191,16 @@ public:
   finished()
   {
     for (auto &n : stack)
+    {
+      if (n->constraints.streamInCnt == -1)
       {
-        if (n->constraints.streamInCnt == -1)
-          {
-            if (n->children.size() == 0) { return false; }
-          }
-        else
-          {
-            if ((size_t) n->constraints.streamInCnt != n->children.size()) { return false; }
-          }
+        if (n->children.size() == 0) { return false; }
       }
+      else
+      {
+        if ((size_t) n->constraints.streamInCnt != n->children.size()) { return false; }
+      }
+    }
     return true;
   }
 
@@ -253,17 +249,17 @@ handle_node(Parser &parser, ARGV_ITERATOR &cur_arg)
   debug_parser("handling Node %s", *(cur_arg));
   auto node = create_node(cur_arg);
   if (!parser.empty())
-    {
-      std::shared_ptr<Node> &parent = parser.top();
-      debug_parser("adding %s as leaf to %s", node->oper, parent->oper);
-      Util::append(parent, node);
-      if (parent->is_done()) parser.pop();
-    }
+  {
+    std::shared_ptr<Node> &parent = parser.top();
+    debug_parser("adding %s as leaf to %s", node->oper, parent->oper);
+    Util::append(parent, node);
+    if (parent->is_done()) parser.pop();
+  }
   else
-    {
-      debug_parser("stack empty: adding to root: %s", Yellow(node->oper));
-      parser.add_root(node);
-    }
+  {
+    debug_parser("stack empty: adding to root: %s", Yellow(node->oper));
+    parser.add_root(node);
+  }
   parser.push(node);
 
   debug_parser("removing finished from stack");
@@ -299,19 +295,19 @@ handle_apply_end(PARSER_STACK &p_parser_stack, ARGV_ITERATOR &p_cur_arg)
   auto result = Subgroup(p_cur_arg);
 
   if (to_be_applied->constraints.streamInCnt != 1)
-    {
-      THROW(InternalCdoSyntaxError, to_be_applied->iter, errmsg_only_1_to_1_operators);
-    }
+  {
+    THROW(InternalCdoSyntaxError, to_be_applied->iter, errmsg_only_1_to_1_operators);
+  }
 
   for (auto &r : roots)
-    {
-      debug_parser("copy: %s", to_be_applied->oper);
-      auto new_root = to_be_applied->copy();
-      debug_parser("add: %s to %s", r->oper, to_be_applied->oper);
-      new_root->add_leaf(r);
-      debug_parser("adding new root %s to root", new_root->oper);
-      result.add_root(new_root);
-    }
+  {
+    debug_parser("copy: %s", to_be_applied->oper);
+    auto new_root = to_be_applied->copy();
+    debug_parser("add: %s to %s", r->oper, to_be_applied->oper);
+    new_root->add_leaf(r);
+    debug_parser("adding new root %s to root", new_root->oper);
+    result.add_root(new_root);
+  }
 
   debug_parser("%s", p_parser_stack.top().to_string());
   debug_parser("%s", Util::result_to_string(result.get_roots(), "result: "));
@@ -330,9 +326,9 @@ static void
 handle_old_apply(ARGV_ITERATOR &p_cur_arg, ARGV_ITERATOR end, PARSER_STACK &parser_stack)
 {
   if (p_cur_arg + 1 == end || (*(p_cur_arg + 1))[0] != '[')
-    {
-      THROW(InternalCdoSyntaxError, p_cur_arg, errmsg_apply_requires_bracket);
-    }
+  {
+    THROW(InternalCdoSyntaxError, p_cur_arg, errmsg_apply_requires_bracket);
+  }
   debug_parser("%s", Red("Handling old Apply"));
   std::string currentArgv = (*p_cur_arg);
   const auto pos = currentArgv.find(',');
@@ -347,18 +343,18 @@ handle_old_apply(ARGV_ITERATOR &p_cur_arg, ARGV_ITERATOR end, PARSER_STACK &pars
   staticParserCounter = parser_stack.size();
   auto &parser = parser_stack.top();
   while (iterCur != iterEnd)
+  {
+    try
     {
-      try
-        {
-          auto node = create_operator_node(iterCur);
-          parser.add_root(node);  // TODO: why root???
-        }
-      catch (InternalCdoSyntaxError &e)
-        {
-          THROW(InternalCdoSyntaxError, p_cur_arg, e.what());
-        }
-      iterCur++;
+      auto node = create_operator_node(iterCur);
+      parser.add_root(node);  // TODO: why root???
     }
+    catch (InternalCdoSyntaxError &e)
+    {
+      THROW(InternalCdoSyntaxError, p_cur_arg, e.what());
+    }
+    iterCur++;
+  }
   debug_parser("Result tokenizer: %s", Yellow(parser.to_string()));
   handle_apply(++p_cur_arg, parser_stack);
 }
@@ -378,14 +374,14 @@ handle_sub_group_end(ARGV_ITERATOR &p_cur_arg, PARSER_STACK &p_parser_stack)
   if (p_parser_stack.size() == 1) { THROW(InternalCdoSyntaxError, p_cur_arg, errmsg_missing_sub_group); }
 
   if (p_parser_stack.top().handlingApply)
-    {
-      staticParserCounter++;
-      handle_apply_end(p_parser_stack, p_cur_arg);
-      staticParserCounter--;
-      /* Since handle appy end takes the two needed groups of the stack and replaces them with its results we can
-       * simply carry on after executing the required steps for the apply handling
-       * */
-    }
+  {
+    staticParserCounter++;
+    handle_apply_end(p_parser_stack, p_cur_arg);
+    staticParserCounter--;
+    /* Since handle appy end takes the two needed groups of the stack and replaces them with its results we can
+     * simply carry on after executing the required steps for the apply handling
+     * */
+  }
 
   debug_parser(Red("handling sub group end"));
   auto finished_group = p_parser_stack.top();
@@ -394,25 +390,25 @@ handle_sub_group_end(ARGV_ITERATOR &p_cur_arg, PARSER_STACK &p_parser_stack)
   auto &cur_parser = p_parser_stack.top();
   if (finished_group.get_roots().empty()) { THROW(InternalCdoSyntaxError, p_cur_arg, errmsg_empty_subgroup); }
   if (cur_parser.empty())
-    {
-      // passing on all root to roots of next parser in case of variable input operators, apply and too many brackets
-      // This also allows to ignore double brackets e.g -merge [ [ -topo -topo ] ]
-      for (const auto &node : finished_group.get_roots()) { cur_parser.add_root(node); }
-    }
+  {
+    // passing on all root to roots of next parser in case of variable input operators, apply and too many brackets
+    // This also allows to ignore double brackets e.g -merge [ [ -topo -topo ] ]
+    for (auto const &node : finished_group.get_roots()) { cur_parser.add_root(node); }
+  }
   else
+  {
+    debug_parser("adding to %s", cur_parser.top()->oper);
+
+    if (cur_parser.top()->children.size() != 0) { THROW(InternalCdoSyntaxError, cur_parser.top()->iter++, errmsg_mixed_input); }
+    for (auto &node : finished_group.get_roots())
     {
-      debug_parser("adding to %s", cur_parser.top()->oper);
-
-      if (cur_parser.top()->children.size() != 0) { THROW(InternalCdoSyntaxError, cur_parser.top()->iter++, errmsg_mixed_input); }
-      for (auto &node : finished_group.get_roots())
-        {
-          if (node->has_required_inputs()) { THROW(InternalCdoSyntaxError, node->iter, errmsg_missing_inputs); }
-          else { Util::append(cur_parser.top(), node); }
-        }
-
-      cur_parser.cntVariableInputs--;
-      cur_parser.pop();
+      if (node->has_required_inputs()) { THROW(InternalCdoSyntaxError, node->iter, errmsg_missing_inputs); }
+      else { Util::append(cur_parser.top(), node); }
     }
+
+    cur_parser.cntVariableInputs--;
+    cur_parser.pop();
+  }
   staticParserCounter = p_parser_stack.size();
 }
 
@@ -420,15 +416,15 @@ static void
 iterate(PARSER_STACK &parser_stack, ARGV_ITERATOR &cur_arg, const ARGV_ITERATOR &end)
 {
   for (auto &arg = cur_arg; arg != end; arg++)
-    {
-      debug_parser("current arg: %s", Green(*arg));
-      if (*arg == "[") { handle_sub_group(arg, parser_stack); }
-      else if (*arg == "]") { handle_sub_group_end(arg, parser_stack); }
-      else if (*arg == ":") { handle_apply(arg, parser_stack); }
-      else if ((*arg).find("-apply,") == 0) { handle_old_apply(arg, end, parser_stack); }
-      else if ((*arg).find("-apply") == 0) { THROW(InternalCdoSyntaxError, arg, errmsg_apply_missing_argument); }
-      else { handle_node(parser_stack.top(), cur_arg); }
-    }
+  {
+    debug_parser("current arg: %s", Green(*arg));
+    if (*arg == "[") { handle_sub_group(arg, parser_stack); }
+    else if (*arg == "]") { handle_sub_group_end(arg, parser_stack); }
+    else if (*arg == ":") { handle_apply(arg, parser_stack); }
+    else if ((*arg).find("-apply,") == 0) { handle_old_apply(arg, end, parser_stack); }
+    else if ((*arg).find("-apply") == 0) { THROW(InternalCdoSyntaxError, arg, errmsg_apply_missing_argument); }
+    else { handle_node(parser_stack.top(), cur_arg); }
+  }
 }
 
 std::vector<std::shared_ptr<Node>>
@@ -462,36 +458,36 @@ run(std::vector<std::string> &p_argv)
   if (parser_stack.size() > 1) { THROW(InternalCdoSyntaxError, parser_stack.top().start, errmsg_bracket_not_closed); }
 
   if (parser_stack.top().get_roots().size() > 0)
-    {
-      const ARGV_ITERATOR &target_iterator = parser_stack.top().get_roots()[0]->iter;
-      THROW(InternalCdoSyntaxError, target_iterator, errmsg_unprocessed_inputs);
-    }
+  {
+    const ARGV_ITERATOR &target_iterator = parser_stack.top().get_roots()[0]->iter;
+    THROW(InternalCdoSyntaxError, target_iterator, errmsg_unprocessed_inputs);
+  }
   if (parser_stack.top().finished() == false)
-    {
-      THROW(InternalCdoSyntaxError, parser_stack.top().top()->iter, errmsg_missing_inputs);
-    }
+  {
+    THROW(InternalCdoSyntaxError, parser_stack.top().top()->iter, errmsg_missing_inputs);
+  }
 
   // all thats left should be files or obase for the output files
   std::vector<std::shared_ptr<Node>> node_structure = {};
   if (first_operator->constraints.streamOutCnt != 0)
+  {
+    while (cur_arg != end)
     {
-      while (cur_arg != end)
-        {
-          if (*cur_arg == "[" || *cur_arg == "]" || *cur_arg == ":" || (*cur_arg).find("-apply") == 0)
-            {
-              THROW(InternalCdoSyntaxError, cur_arg, errmsg_keyword_output);
-            }
-          else
-            {
-              bool isOutFile = true;
-              debug_parser("creating new out file: %s", *cur_arg);
-              auto outFileNode = std::make_shared<Node>(cur_arg, Node::NodeType::OUTFILE);
-              node_structure.push_back(outFileNode);
-              Util::append(outFileNode, first_operator);
-              cur_arg++;
-            }
-        }
+      if (*cur_arg == "[" || *cur_arg == "]" || *cur_arg == ":" || (*cur_arg).find("-apply") == 0)
+      {
+        THROW(InternalCdoSyntaxError, cur_arg, errmsg_keyword_output);
+      }
+      else
+      {
+        bool isOutFile = true;
+        debug_parser("creating new out file: %s", *cur_arg);
+        auto outFileNode = std::make_shared<Node>(cur_arg, Node::NodeType::OUTFILE);
+        node_structure.push_back(outFileNode);
+        Util::append(outFileNode, first_operator);
+        cur_arg++;
+      }
     }
+  }
   else { node_structure = { first_operator }; }
 
   return node_structure;
@@ -501,16 +497,16 @@ _parse(std::vector<std::string> p_argv)
 {
   std::vector<std::shared_ptr<Node>> res = {};
   try
-    {
-      res = run(p_argv);
-      Debug("%s", Blue(Util::result_to_string(res)));
-      return res;
-    }
+  {
+    res = run(p_argv);
+    Debug("%s", Blue(Util::result_to_string(res)));
+    return res;
+  }
   catch (InternalCdoSyntaxError &e)
-    {
-      Debug("Error");
-      throw CdoSyntaxError(e, p_argv);
-    }
+  {
+    Debug("Error");
+    throw CdoSyntaxError(e, p_argv);
+  }
   Debug("we got here");
   return res;
 }
@@ -520,25 +516,25 @@ parse(std::vector<std::string> p_argv, const char *(*context)(void) )
 {
   std::vector<std::shared_ptr<Node>> res = {};
   try
-    {
-      return _parse(p_argv);
-    }
+  {
+    return _parse(p_argv);
+  }
   catch (const CdoSyntaxError &e)
-    {
-      cdo_abort("\n%s", e.what());
-    }
+  {
+    cdo_abort("\n%s", e.what());
+  }
 
   catch (const MissingOutFileException &e)
-    {
-      std::string errLine = Red("\033[4m" + p_argv[0] + "\033[0m") + " ";
-      auto prompt = std::string(context());
-      for (auto it = p_argv.begin() + 1; it < p_argv.end(); it++) { errLine += *it + " "; }
-      cdo_abort("%s %s", e.what());
-    }
+  {
+    std::string errLine = Red("\033[4m" + p_argv[0] + "\033[0m") + " ";
+    auto prompt = std::string(context());
+    for (auto it = p_argv.begin() + 1; it < p_argv.end(); it++) { errLine += *it + " "; }
+    cdo_abort("%s %s", e.what());
+  }
   catch (...)
-    {
-      cdo_abort("Unhandled exception");
-    }
+  {
+    cdo_abort("Unhandled exception");
+  }
   return res;
 }
 
