@@ -22,7 +22,7 @@ public:
 
   /* not used because result differ from search() and unstruct::search()
   void
-  search_1nn(const PointLonLat &pointLL, knnDataType &knnData, double searchRadius)
+  search_1nn(PointLonLat const &pointLL, knnDataType &knnData, double searchRadius)
   {
     size_t index = (size_t) hp_lonlat_to_index(m_hpParams, pointLL.get_lon(), pointLL.get_lat());
 
@@ -37,9 +37,9 @@ public:
    */
 
   void
-  search(const PointLonLat &pointLL, KnnData &knnData, double searchRadius)
+  search(PointLonLat const &pointLL, KnnData &knnData, double searchRadius)
   {
-    auto index = hp_lonlat_to_index(m_hpParams, pointLL.get_lon(), pointLL.get_lat());
+    auto index = hp_lonlat_to_index(m_hpParams, pointLL.lon(), pointLL.lat());
 
     int64_t neighbours[8];
     hp_get_neighbours(m_hpParams, index, neighbours);
@@ -56,27 +56,27 @@ public:
     store_distance_healpix(searchRadius, pointLL, knnData, numIndices, indices, lons, lats);
 
     if (knnData.m_needCoords)
+    {
+      gcLLtoXYZ(pointLL.lon(), pointLL.lat(), knnData.m_tgtCoord);
+      auto numNeighbors = knnData.m_numNeighbors;
+      for (size_t i = 0; i < numNeighbors; ++i)
       {
-        gcLLtoXYZ(pointLL.get_lon(), pointLL.get_lat(), knnData.m_tgtCoord);
-        auto numNeighbors = knnData.m_numNeighbors;
-        for (size_t i = 0; i < numNeighbors; ++i)
-          {
-            double lon, lat;
-            hp_index_to_lonlat(m_hpParams, knnData.m_indices[i], &lon, &lat);
-            gcLLtoXYZ(lon, lat, knnData.m_srcCoords[i]);
-          }
+        double lon, lat;
+        hp_index_to_lonlat(m_hpParams, knnData.m_indices[i], &lon, &lat);
+        gcLLtoXYZ(lon, lat, knnData.m_srcCoords[i]);
       }
+    }
   }
 
 private:
   HpParams m_hpParams;
 
   void
-  store_distance_healpix(double searchRadius, const PointLonLat &pointLL, KnnData &knnData, size_t numIndices, size_t *indices,
+  store_distance_healpix(double searchRadius, PointLonLat const &pointLL, KnnData &knnData, size_t numIndices, size_t *indices,
                          double *lons, double *lats)
   {
     double tgtCoord[3];
-    gcLLtoXYZ(pointLL.get_lon(), pointLL.get_lat(), tgtCoord);
+    gcLLtoXYZ(pointLL.lon(), pointLL.lat(), tgtCoord);
 
     auto sqrSearchRadius = cdo::sqr(searchRadius);
 
@@ -84,18 +84,18 @@ private:
     double srcCoord[3];
     size_t numWeights = 0;
     for (size_t i = 0; i < numIndices; ++i)
+    {
+      gcLLtoXYZ(lons[i], lats[i], srcCoord);
+      // Find distance to this point
+      double sqrDistance = (float) cdo::sqr_distance(tgtCoord, srcCoord);
+      // Store the index and distance if this is one of the smallest so far
+      if (sqrDistance <= sqrSearchRadius)
       {
-        gcLLtoXYZ(lons[i], lats[i], srcCoord);
-        // Find distance to this point
-        double sqrDistance = (float) cdo::sqr_distance(tgtCoord, srcCoord);
-        // Store the index and distance if this is one of the smallest so far
-        if (sqrDistance <= sqrSearchRadius)
-          {
-            indices[numWeights] = indices[i];
-            distances[numWeights] = std::sqrt(sqrDistance);
-            numWeights++;
-          }
+        indices[numWeights] = indices[i];
+        distances[numWeights] = std::sqrt(sqrDistance);
+        numWeights++;
       }
+    }
 
     auto maxNeighbors = std::min(numWeights, knnData.maxNeighbors());
     for (size_t i = 0; i < numWeights; ++i) { knnData.store_distance(indices[i], distances[i], maxNeighbors); }
