@@ -20,7 +20,7 @@
 class PointsearchKDtree : public PointsearchStrategy
 {
 public:
-  PointsearchKDtree(const Varray<double> &lons, const Varray<double> &lats, const PointsearchParams &params) : m_params{ params }
+  PointsearchKDtree(Varray<double> const &lons, Varray<double> const &lats, const PointsearchParams &params) : m_params{ params }
   {
     create(lons, lats);
   }
@@ -30,7 +30,7 @@ public:
   }
 
   size_t
-  search_nearest(const PointLonLat &pointLL, size_t *index, double *dist) override
+  search_nearest(PointLonLat const &pointLL, size_t *index, double *dist) override
   {
     if (m_kdtree == nullptr) return 0;
 
@@ -38,7 +38,7 @@ public:
     auto sqrDist = sqrDistMax;
 
     double tgtPoint[3];
-    gcLLtoXYZ(pointLL.get_lon(), pointLL.get_lat(), tgtPoint);
+    gcLLtoXYZ(pointLL.lon(), pointLL.lat(), tgtPoint);
 
     if (!m_params.extrapolation)
       for (int i = 0; i < 3; ++i)
@@ -46,17 +46,17 @@ public:
 
     const auto node = kd_nearest(m_kdtree->node, tgtPoint, &sqrDist, 3);
     if (node && sqrDist < sqrDistMax)
-      {
-        *index = node->index;
-        *dist = std::sqrt(sqrDist);
-        return 1;
-      }
+    {
+      *index = node->index;
+      *dist = std::sqrt(sqrDist);
+      return 1;
+    }
 
     return 0;
   }
 
   size_t
-  search_qnearest(const PointLonLat &pointLL, size_t nnn, size_t *indices, double *dist) override
+  search_qnearest(PointLonLat const &pointLL, size_t nnn, size_t *indices, double *dist) override
   {
     size_t numIndices = 0;
 
@@ -65,7 +65,7 @@ public:
     auto sqrDistMax = cdo::sqr(m_params.searchRadius);
 
     kdata_t tgtPoint[3];
-    gcLLtoXYZ(pointLL.get_lon(), pointLL.get_lat(), tgtPoint);
+    gcLLtoXYZ(pointLL.lon(), pointLL.lat(), tgtPoint);
 
     if (!m_params.extrapolation)
       for (int i = 0; i < 3; ++i)
@@ -74,34 +74,34 @@ public:
     kdata_t sqrDist = sqrDistMax;
     auto result = kd_qnearest(m_kdtree->node, tgtPoint, &sqrDist, nnn, 3);
     if (result)
+    {
+      resItem *p;
+      while (pqremove_min(result, &p))
       {
-        resItem *p;
-        while (pqremove_min(result, &p))
-          {
-            if (p->dist_sq < sqrDistMax)
-              {
-                indices[numIndices] = p->node->index;
-                dist[numIndices] = std::sqrt(p->dist_sq);
-                numIndices++;
-              }
+        if (p->dist_sq < sqrDistMax)
+        {
+          indices[numIndices] = p->node->index;
+          dist[numIndices] = std::sqrt(p->dist_sq);
+          numIndices++;
+        }
 
-            free(p);  // Free the result node taken from the heap
-          }
-        free(result->d);  // free the heap
-        free(result);     // and free the heap information structure
+        free(p);  // Free the result node taken from the heap
       }
+      free(result->d);  // free the heap
+      free(result);     // and free the heap information structure
+    }
 
     return numIndices;
   }
 
 private:
-  float m_min[3] = { 0 };
-  float m_max[3] = { 0 };
+  float m_min[3]{};
+  float m_max[3]{};
   kdTree_t *m_kdtree{ nullptr };
   const PointsearchParams &m_params;
 
   void
-  create(const Varray<double> &lons, const Varray<double> &lats)
+  create(Varray<double> const &lons, Varray<double> const &lats)
   {
     auto n = lons.size();
     std::vector<kd_point> pointlist(n);
@@ -111,16 +111,16 @@ private:
     kdata_t max[3] = { -1.e9, -1.e9, -1.e9 };
 
 #ifdef HAVE_OPENMP45
-#pragma omp parallel for if (n > cdoMinLoopSize) schedule(static) reduction(min : min[:3]) reduction(max : max[:3])
+#pragma omp parallel for if (n > cdoMinLoopSize) schedule(static) reduction(min : min[ : 3]) reduction(max : max[ : 3])
 #endif
     for (size_t i = 0; i < n; ++i)
-      {
-        auto &point = pointlist[i].point;
-        gcLLtoXYZ(lons[i], lats[i], point);
-        min_point(min, point);
-        max_point(max, point);
-        pointlist[i].index = i;
-      }
+    {
+      auto &point = pointlist[i].point;
+      gcLLtoXYZ(lons[i], lats[i], point);
+      min_point(min, point);
+      max_point(max, point);
+      pointlist[i].index = i;
+    }
 
     if (!m_params.useBoundBox) min[0] = min[1] = min[2] = -1;
     if (!m_params.useBoundBox) max[0] = max[1] = max[2] = 1;
