@@ -1,10 +1,8 @@
 #ifndef PRINTINFO_H
 #define PRINTINFO_H
 
-#include <stdio.h>
-#include <inttypes.h>
-
-#include "process_int.h"
+#include <string>
+#include <cdoStream.h>
 
 std::string date_to_string(CdiDate date);
 std::string time_to_string(CdiTime time);
