@@ -19,7 +19,6 @@
 #include "cdo_default_values.h"
 #include "process.h"
 #include "cdo_output.h"
-#include "factory.h"
 
 thread_local Process *localProcess;
 
@@ -33,10 +32,10 @@ int
 cdo_filetype(void)
 {
   if (CdoDefault::FileType == CDI_UNDEFID)
-    {
-      CdoDefault::FileType = CDI_FILETYPE_GRB;
-      if (Options::cdoVerbose) cdo_print("Set default filetype to GRIB1");
-    }
+  {
+    CdoDefault::FileType = CDI_FILETYPE_GRB;
+    if (Options::cdoVerbose) cdo_print("Set default filetype to GRIB1");
+  }
 
   return CdoDefault::FileType;
 }
@@ -56,10 +55,10 @@ cdo_stream_inq_timestep(CdoStreamID p_pstreamptr, int tsID)
   Debug(PROCESS_INT, "%s pstreamID %d", p_pstreamptr->m_name, p_pstreamptr->get_id());
   auto numFields = p_pstreamptr->inq_timestep(tsID);
   if (numFields && tsID == p_pstreamptr->getTsID())
-    {
-      localProcess->ntimesteps++;
-      Debug(PROCESS_INT, "Timestep cnt for localProcess: %s: %d", localProcess->prompt, localProcess->ntimesteps);
-    }
+  {
+    localProcess->ntimesteps++;
+    Debug(PROCESS_INT, "Timestep cnt for localProcess: %s: %d", localProcess->prompt, localProcess->ntimesteps);
+  }
   return numFields;
 }
 
@@ -75,7 +74,7 @@ cdo_operator_argc(void)
   return localProcess->get_oper_argc();
 }
 
-const std::string &
+std::string const &
 cdo_operator_argv(size_t idx)
 {
   auto argc = localProcess->get_oper_argc();
@@ -84,7 +83,7 @@ cdo_operator_argv(size_t idx)
   return localProcess->m_oargv[idx];
 }
 
-const std::vector<std::string> &
+std::vector<std::string> const &
 cdo_get_oper_argv()
 {
   return localProcess->m_oargv;
@@ -116,10 +115,9 @@ get_input()
   std::string fline = "";
 
   do {
-      std::getline(std::cin, line);
-      fline += line;
-    }
-  while (std::string(line).find("\\") != std::string::npos);
+    std::getline(std::cin, line);
+    fline += line;
+  } while (std::string(line).find("\\") != std::string::npos);
 
   return fline;
 }
@@ -128,24 +126,24 @@ void
 operator_input_arg(const char *enter)
 {
   while (true)
+  {
+    if (localProcess->get_oper_argc() != 0) return;
+
+    if (enter) print_enter(localProcess->prompt, enter);
+    std::stringstream stringStream(get_input());
+
+    std::string line;
+    while (std::getline(stringStream, line))
     {
-      if (localProcess->get_oper_argc() != 0) return;
-
-      if (enter) print_enter(localProcess->prompt, enter);
-      std::stringstream stringStream(get_input());
-
-      std::string line;
-      while (std::getline(stringStream, line))
-        {
-          std::size_t prev = 0, pos;
-          while ((pos = line.find_first_of(", \\", prev)) != std::string::npos)
-            {
-              if (pos > prev) localProcess->m_oargv.push_back(line.substr(prev, pos - prev));
-              prev = pos + 1;
-            }
-          if (prev < line.length()) localProcess->m_oargv.push_back(line.substr(prev, std::string::npos));
-        }
+      std::size_t prev = 0, pos;
+      while ((pos = line.find_first_of(", \\", prev)) != std::string::npos)
+      {
+        if (pos > prev) localProcess->m_oargv.push_back(line.substr(prev, pos - prev));
+        prev = pos + 1;
+      }
+      if (prev < line.length()) localProcess->m_oargv.push_back(line.substr(prev, std::string::npos));
     }
+  }
 }
 
 int
@@ -222,9 +220,9 @@ cdo_open_write(int p_outStreamIDX, int filetype)
 
   int outStreamIDX = p_outStreamIDX - localProcess->inputStreams.size();
   if (outStreamIDX > localProcess->get_stream_cnt_out() || outStreamIDX < 0)
-    {
-      cdo_abort("outstream %d of %d not found. Called with streamIdx = %d", outStreamIDX, localProcess->m_ID, p_outStreamIDX);
-    }
+  {
+    cdo_abort("outstream %d of %d not found. Called with streamIdx = %d", outStreamIDX, localProcess->m_ID, p_outStreamIDX);
+  }
 
   const auto outStream = localProcess->outputStreams[outStreamIDX];
   outStream->open_write(filetype);
@@ -261,9 +259,9 @@ const std::shared_ptr<Process>
 cdoGetInputChild(int p_inID)
 {
   for (const std::shared_ptr<Process> &processPtr : localProcess->childProcesses)
-    {
-      if (processPtr->has_out_stream(localProcess->inputStreams[p_inID])) return processPtr;
-    }
+  {
+    if (processPtr->has_out_stream(localProcess->inputStreams[p_inID])) return processPtr;
+  }
   return nullptr;
 }
 
@@ -279,15 +277,15 @@ cdo_get_stream_name(int p_streamIndex)
   const char *streamName = nullptr;
   Debug(PROCESS_INT, "stridx %d", p_streamIndex);
   if (p_streamIndex >= static_cast<int>(localProcess->inputStreams.size()))
-    {
-      Debug(PROCESS_INT, "Getting output stream name %d", p_streamIndex);
-      streamName = cdoGetOutStreamName();
-    }
+  {
+    Debug(PROCESS_INT, "Getting output stream name %d", p_streamIndex);
+    streamName = cdoGetOutStreamName();
+  }
   else
-    {
-      Debug(PROCESS_INT, "Getting input stream name %d", p_streamIndex);
-      streamName = cdoGetInStreamName(p_streamIndex);
-    }
+  {
+    Debug(PROCESS_INT, "Getting input stream name %d", p_streamIndex);
+    streamName = cdoGetInStreamName(p_streamIndex);
+  }
 
   Debug(PROCESS_INT, "StreamName is: %s", streamName);
 
@@ -299,9 +297,9 @@ cdo_get_command_from_in_stream(int p_streamIndex)
 {
   const std::shared_ptr<Process> process = cdoGetInputChild(p_streamIndex);
   if (!process)  // then this should be a file and cdo_get_stream_name can handle this
-    {
-      return cdo_get_stream_name(p_streamIndex);
-    }
+  {
+    return cdo_get_stream_name(p_streamIndex);
+  }
   return process->operatorName;
 }
 
@@ -453,32 +451,26 @@ cdo_read_field(CdoStreamID streamID, Field3D &field, int levelID, size_t *numMis
 // - - - - - - -
 
 void
-cdo_copy_field(CdoStreamID pstreamPtrDest, CdoStreamID pstreamPtrSrc)
+cdo_copy_field(CdoStreamID pstreamSrc, CdoStreamID pstreamDest)
 {
-  Debug(PROCESS_INT, "pstreamIDdest = %d pstreamIDsrc = %d", pstreamPtrDest->get_id(), pstreamPtrSrc->get_id());
-  pstreamPtrDest->copy_field(pstreamPtrSrc);
+  Debug(PROCESS_INT, "pstreamIDdest = %d pstreamIDsrc = %d", pstreamDest->get_id(), pstreamSrc->get_id());
+  pstreamDest->copy_field(pstreamSrc);
 }
 
 // - - - - - - -
 
 std::pair<int, int>
-cdo_inq_field(CdoStreamID pstreamptr)
+cdo_inq_field(CdoStreamID p_streamID)
 {
   int varID = -1, levelID = -1;
-  pstreamptr->inq_field(&varID, &levelID);
+  p_streamID->inq_field(&varID, &levelID);
   return std::make_pair(varID, levelID);
 }
 
 void
-cdo_inq_field(CdoStreamID pstreamptr, int *varID, int *levelID)
+cdo_def_field(CdoStreamID p_streamID, int varID, int levelID)
 {
-  pstreamptr->inq_field(varID, levelID);
-}
-
-void
-cdo_def_field(CdoStreamID pstreamptr, int varID, int levelID)
-{
-  pstreamptr->def_field(varID, levelID);
+  p_streamID->def_field(varID, levelID);
 }
 // - - - - - - -
 
@@ -507,9 +499,9 @@ void
 cdo_set_nan(double missval, size_t gridsize, double *array)
 {
   if (std::isnan(missval))
-    {
-      constexpr double newMissval = -9.e33;
-      for (size_t i = 0; i < gridsize; ++i)
-        if (fp_is_equal(array[i], missval)) array[i] = newMissval;
-    }
+  {
+    constexpr double newMissval = -9.e33;
+    for (size_t i = 0; i < gridsize; ++i)
+      if (fp_is_equal(array[i], missval)) array[i] = newMissval;
+  }
 }
