@@ -8,14 +8,14 @@
 #include <atomic>
 
 #include "cpp_lib.h"
-#include "process_int.h"
-#include "cdo_timer.h"
-#include <mpim_grid.h>
 #include "cdo_options.h"
+#include "cdo_output.h"
+#include "cdo_timer.h"
+#include "cdo_omp.h"
+#include <mpim_grid.h>
 #include "remap.h"
 #include "remap_store_link.h"
 #include "progress.h"
-#include "cdo_omp.h"
 
 // bicubic interpolation
 
@@ -48,7 +48,7 @@ bicubic_set_weights(double xfrac, double yfrac, double (&weights)[4][4])
   // clang-format on
 }
 
-int num_src_points(const Vmask &mask, const size_t (&indices)[4], double (&lats)[4]);
+int num_src_points(Vmask const &mask, const size_t (&indices)[4], double (&lats)[4]);
 
 static void
 renormalize_weights(const double (&lats)[4], double (&weights)[4][4])
@@ -68,7 +68,7 @@ bicubic_sort_weights_by_index_zip(size_t (&indices)[4], double (&weights)[4][4])
 {
   auto r = std::views::zip(indices, weights);
   std::sort(r.begin(), r.end, [](auto a, auto b) {
-    auto [ai, aw] = a;  // std::tuple
+    auto [ai, aw] = a;
     auto [bi, bw] = b;
     return (ai < bi);
   });
@@ -89,18 +89,18 @@ bicubic_sort_weights_by_index(size_t (&indices)[4], double (&weights)[4][4])
   std::array<IndexWeightX, numWeights> indexWeights;
 
   for (size_t i = 0; i < numWeights; ++i)
-    {
-      indexWeights[i].index = indices[i];
-      for (int k = 0; k < 4; ++k) indexWeights[i].weight[k] = weights[i][k];
-    }
+  {
+    indexWeights[i].index = indices[i];
+    for (int k = 0; k < 4; ++k) indexWeights[i].weight[k] = weights[i][k];
+  }
 
-  ranges::sort(indexWeights, {}, &IndexWeightX::index);
+  std::ranges::sort(indexWeights, {}, &IndexWeightX::index);
 
   for (size_t i = 0; i < numWeights; ++i)
-    {
-      indices[i] = indexWeights[i].index;
-      for (int k = 0; k < 4; ++k) weights[i][k] = indexWeights[i].weight[k];
-    }
+  {
+    indices[i] = indexWeights[i].index;
+    for (int k = 0; k < 4; ++k) weights[i][k] = indexWeights[i].weight[k];
+  }
 }
 
 static void
@@ -121,10 +121,10 @@ bicubic_warning()
 {
   static auto printWarning = true;
   if (Options::cdoVerbose || printWarning)
-    {
-      printWarning = false;
-      cdo_warning("Bicubic interpolation failed for some grid points - used a distance-weighted average instead!");
-    }
+  {
+    printWarning = false;
+    cdo_warning("Bicubic interpolation failed for some grid points - used a distance-weighted average instead!");
+  }
 }
 
 // -----------------------------------------------------------------------
@@ -133,7 +133,7 @@ bicubic_warning()
 void
 remap_bicubic_weights(RemapSearch &rsearch, RemapVars &rv)
 {
-  auto const srcGrid = rsearch.srcGrid;
+  auto const *srcGrid = rsearch.srcGrid;
   auto tgtGrid = rsearch.tgtGrid;
 
   if (Options::cdoVerbose) cdo_print("Called %s()", __func__);
@@ -157,58 +157,58 @@ remap_bicubic_weights(RemapSearch &rsearch, RemapVars &rv)
 #pragma omp parallel for default(shared)
 #endif
   for (size_t tgtCellIndex = 0; tgtCellIndex < tgtGridSize; ++tgtCellIndex)
+  {
+    atomicCount++;
+    auto ompthID = cdo_omp_get_thread_num();
+    if (ompthID == 0 && tgtGridSize > progressMinSize) progress.update((double) atomicCount / tgtGridSize);
+
+    weightLinks[tgtCellIndex].nlinks = 0;
+
+    if (!tgtGrid->mask[tgtCellIndex]) continue;
+
+    auto pointLL = remapgrid_get_lonlat(tgtGrid, tgtCellIndex);
+
+    SquareCorners squareCorners;
+    double weights[4][4];  //  bicubic weights for four corners
+
+    // Find nearest square of grid points on source grid
+    auto searchResult = remap_search_square(rsearch, pointLL, squareCorners);
+
+    // Check to see if points are mask points
+    if (searchResult > 0) searchResult = remap_check_mask_indices(squareCorners.indices, srcGrid->mask);
+
+    // If point found, find local xfrac/yfrac coordinates for weights
+    if (searchResult > 0)
     {
-      atomicCount++;
-      auto ompthID = cdo_omp_get_thread_num();
-      if (ompthID == 0 && tgtGridSize > progressMinSize) progress.update((double) atomicCount / tgtGridSize);
+      tgtGrid->cellFrac[tgtCellIndex] = 1.0;
 
-      weightLinks[tgtCellIndex].nlinks = 0;
-
-      if (!tgtGrid->mask[tgtCellIndex]) continue;
-
-      auto pointLL = remapgrid_get_lonlat(tgtGrid, tgtCellIndex);
-
-      SquareCorners squareCorners;
-      double weights[4][4];  //  bicubic weights for four corners
-
-      // Find nearest square of grid points on source grid
-      auto searchResult = remap_search_square(rsearch, pointLL, squareCorners);
-
-      // Check to see if points are mask points
-      if (searchResult > 0) searchResult = remap_check_mask_indices(squareCorners.indices, srcGrid->mask);
-
-      // If point found, find local xfrac/yfrac coordinates for weights
-      if (searchResult > 0)
-        {
-          tgtGrid->cellFrac[tgtCellIndex] = 1.0;
-
-          auto [xfrac, yfrac] = remap_find_weights(pointLL, squareCorners);
-          if (xfrac >= 0.0 && yfrac >= 0.0)
-            {
-              // Successfully found xfrac, yfrac - compute weights
-              bicubic_set_weights(xfrac, yfrac, weights);
-              store_weightlinks_bicubic(squareCorners.indices, weights, tgtCellIndex, weightLinks);
-            }
-          else
-            {
-              bicubic_warning();
-              searchResult = -1;
-            }
-        }
-
-      // Search for bicubic failed - use a distance-weighted average instead
-      // (this is typically near the pole) Distance was stored in srcLats!
-      if (searchResult < 0)
-        {
-          if (num_src_points(srcGrid->mask, squareCorners.indices, squareCorners.lats) > 0)
-            {
-              tgtGrid->cellFrac[tgtCellIndex] = 1.0;
-              renormalize_weights(squareCorners.lats, weights);
-              store_weightlinks_bicubic(squareCorners.indices, weights, tgtCellIndex, weightLinks);
-            }
-        }
+      auto [xfrac, yfrac] = remap_find_weights(pointLL, squareCorners);
+      if (xfrac >= 0.0 && yfrac >= 0.0)
+      {
+        // Successfully found xfrac, yfrac - compute weights
+        bicubic_set_weights(xfrac, yfrac, weights);
+        store_weightlinks_bicubic(squareCorners.indices, weights, tgtCellIndex, weightLinks);
+      }
+      else
+      {
+        bicubic_warning();
+        searchResult = -1;
+      }
     }
 
+    // Search for bicubic failed - use a distance-weighted average instead
+    // (this is typically near the pole) Distance was stored in srcLats!
+    if (searchResult < 0)
+    {
+      if (num_src_points(srcGrid->mask, squareCorners.indices, squareCorners.lats) > 0)
+      {
+        tgtGrid->cellFrac[tgtCellIndex] = 1.0;
+        renormalize_weights(squareCorners.lats, weights);
+        store_weightlinks_bicubic(squareCorners.indices, weights, tgtCellIndex, weightLinks);
+      }
+    }
+  }
+
   weight_links_4_to_remap_links(tgtGridSize, weightLinks, rv);
 
   rv.numLinksPerValue = 4;
@@ -221,11 +221,11 @@ remap_bicubic_weights(RemapSearch &rsearch, RemapVars &rv)
 // -----------------------------------------------------------------------
 template <typename T>
 static T
-bicubic_remap(const Varray<T> &srcArray, const double (&wgt)[4][4], const size_t (&ind)[4], const RemapGradients &gradients)
+bicubic_remap(Varray<T> const &srcArray, const double (&wgt)[4][4], const size_t (&ind)[4], const RemapGradients &gradients)
 {
-  const auto &glat = gradients.lat;
-  const auto &glon = gradients.lon;
-  const auto &glatlon = gradients.latLon;
+  auto const &glat = gradients.lat;
+  auto const &glon = gradients.lon;
+  auto const &glatlon = gradients.latLon;
 
   double tgtPoint = 0.0;
   for (int i = 0; i < 4; ++i)
@@ -236,7 +236,7 @@ bicubic_remap(const Varray<T> &srcArray, const double (&wgt)[4][4], const size_t
 
 template <typename T1, typename T2>
 static void
-remap_bicubic(const Varray<T1> &srcArray, Varray<T2> &tgtArray, double srcMissval, size_t numMissVals, RemapSearch &rsearch)
+remap_bicubic(Varray<T1> const &srcArray, Varray<T2> &tgtArray, double srcMissval, size_t numMissVals, RemapSearch &rsearch)
 {
   T1 missval = srcMissval;
   auto srcGrid = rsearch.srcGrid;
@@ -267,64 +267,64 @@ remap_bicubic(const Varray<T1> &srcArray, Varray<T2> &tgtArray, double srcMissva
 #pragma omp parallel for default(shared)
 #endif
   for (size_t tgtCellIndex = 0; tgtCellIndex < tgtGridSize; ++tgtCellIndex)
+  {
+    atomicCount++;
+    auto ompthID = cdo_omp_get_thread_num();
+    if (ompthID == 0 && tgtGridSize > progressMinSize) progress.update((double) atomicCount / tgtGridSize);
+
+    auto &tgtValue = tgtArray[tgtCellIndex];
+    tgtValue = missval;
+
+    if (!tgtGrid->mask[tgtCellIndex]) continue;
+
+    auto pointLL = remapgrid_get_lonlat(tgtGrid, tgtCellIndex);
+
+    SquareCorners squareCorners;
+    double weights[4][4];  //  bicubic weights for four corners
+
+    // Find nearest square of grid points on source grid
+    auto searchResult = remap_search_square(rsearch, pointLL, squareCorners);
+
+    // Check to see if points are mask points
+    if (searchResult > 0) searchResult = remap_check_mask_indices(squareCorners.indices, srcGridMask);
+
+    // If point found, find local xfrac/yfrac coordinates for weights
+    if (searchResult > 0)
     {
-      atomicCount++;
-      auto ompthID = cdo_omp_get_thread_num();
-      if (ompthID == 0 && tgtGridSize > progressMinSize) progress.update((double) atomicCount / tgtGridSize);
-
-      auto &tgtValue = tgtArray[tgtCellIndex];
-      tgtValue = missval;
-
-      if (!tgtGrid->mask[tgtCellIndex]) continue;
-
-      auto pointLL = remapgrid_get_lonlat(tgtGrid, tgtCellIndex);
-
-      SquareCorners squareCorners;
-      double weights[4][4];  //  bicubic weights for four corners
-
-      // Find nearest square of grid points on source grid
-      auto searchResult = remap_search_square(rsearch, pointLL, squareCorners);
-
-      // Check to see if points are mask points
-      if (searchResult > 0) searchResult = remap_check_mask_indices(squareCorners.indices, srcGridMask);
-
-      // If point found, find local xfrac/yfrac coordinates for weights
-      if (searchResult > 0)
-        {
-          auto [xfrac, yfrac] = remap_find_weights(pointLL, squareCorners);
-          if (xfrac >= 0.0 && yfrac >= 0.0)
-            {
-              // Successfully found xfrac, yfrac - compute weights
-              bicubic_set_weights(xfrac, yfrac, weights);
-              bicubic_sort_weights(squareCorners.indices, weights);
-              tgtValue = bicubic_remap(srcArray, weights, squareCorners.indices, gradients);
-            }
-          else
-            {
-              bicubic_warning();
-              searchResult = -1;
-            }
-        }
-
-      // Search for bicubic failed - use a distance-weighted average instead
-      // (this is typically near the pole) Distance was stored in srcLats!
-      if (searchResult < 0)
-        {
-          if (srcGridMask.size() == 0 || num_src_points(srcGridMask, squareCorners.indices, squareCorners.lats) > 0)
-            {
-              renormalize_weights(squareCorners.lats, weights);
-              bicubic_sort_weights(squareCorners.indices, weights);
-              tgtValue = bicubic_remap(srcArray, weights, squareCorners.indices, gradients);
-            }
-        }
+      auto [xfrac, yfrac] = remap_find_weights(pointLL, squareCorners);
+      if (xfrac >= 0.0 && yfrac >= 0.0)
+      {
+        // Successfully found xfrac, yfrac - compute weights
+        bicubic_set_weights(xfrac, yfrac, weights);
+        bicubic_sort_weights(squareCorners.indices, weights);
+        tgtValue = bicubic_remap(srcArray, weights, squareCorners.indices, gradients);
+      }
+      else
+      {
+        bicubic_warning();
+        searchResult = -1;
+      }
     }
 
+    // Search for bicubic failed - use a distance-weighted average instead
+    // (this is typically near the pole) Distance was stored in srcLats!
+    if (searchResult < 0)
+    {
+      if (srcGridMask.size() == 0 || num_src_points(srcGridMask, squareCorners.indices, squareCorners.lats) > 0)
+      {
+        renormalize_weights(squareCorners.lats, weights);
+        bicubic_sort_weights(squareCorners.indices, weights);
+        tgtValue = bicubic_remap(srcArray, weights, squareCorners.indices, gradients);
+      }
+    }
+  }
+
   if (Options::cdoVerbose) cdo_print("%s: %.2f seconds", __func__, timer.elapsed());
 }  // remap_bicubic
 
 void
-remap_bicubic(RemapSearch &remapSearch, const Field &field1, Field &field2)
+remap_bicubic(RemapSearch &remapSearch, Field const &field1, Field &field2)
 {
-  auto func = [&](const auto &v1, auto &v2) { remap_bicubic(v1, v2, field1.missval, field1.numMissVals, remapSearch); };
+  auto func = [&](auto const &v1, auto &v2) { remap_bicubic(v1, v2, field1.missval, field1.numMissVals, remapSearch); };
   field_operation2(func, field1, field2);
 }
