@@ -26,7 +26,7 @@ struct  // RemapGrid
 RemapGrid
 // clang-format on
 {
-  std::string name;
+  std::string name{};
   RemapGridType type{ RemapGridType::Undefined };
   int gridID{ -1 };
   int tmpgridID{ -1 };
@@ -36,7 +36,7 @@ RemapGrid
 
   int nside{ 0 };
   HpOrder order{ HpOrder::Undef };
-  HpParams hpParams;
+  HpParams hpParams{};
 
   bool needCellCorners{ false };
   bool useCellCorners{ false };  // use corners for bounding boxes
@@ -44,24 +44,24 @@ RemapGrid
   bool doExtrapolate{ false };
   bool isCyclic{ false };
 
-  size_t dims[2] = { 0, 0 };  // size of grid dimension
+  size_t dims[2]{};  // size of grid dimension
 
-  int nvgp{ 0 };     // size of vgpm
-  Varray<int> vgpm;  // flag which cells are valid
-  Vmask mask;        // flag which cells participate
+  int nvgp{ 0 };       // size of vgpm
+  Varray<int> vgpm{};  // flag which cells are valid
+  Vmask mask{};        // flag which cells participate
 
-  Varray<double> centerLonsReg2d;  // reg2d lon/lat coordinates for
-  Varray<double> centerLatsReg2d;  // each grid center in radians
-  Varray<double> cornerLonsReg2d;  // reg2d lon/lat coordinates for
-  Varray<double> cornerLatsReg2d;  // each grid corner in radians
+  Varray<double> centerLonsReg2d{};  // reg2d lon/lat coordinates for
+  Varray<double> centerLatsReg2d{};  // each grid center in radians
+  Varray<double> cornerLonsReg2d{};  // reg2d lon/lat coordinates for
+  Varray<double> cornerLatsReg2d{};  // each grid corner in radians
 
-  Varray<double> centerLons;  // lon/lat coordinates for
-  Varray<double> centerLats;  // each grid center in radians
-  Varray<double> cornerLons;  // lon/lat coordinates for
-  Varray<double> cornerLats;  // each grid corner in radians
+  Varray<double> centerLons{};  // lon/lat coordinates for
+  Varray<double> centerLats{};  // each grid center in radians
+  Varray<double> cornerLons{};  // lon/lat coordinates for
+  Varray<double> cornerLats{};  // each grid corner in radians
 
-  Varray<double> cellArea;  // total area of each grid cell
-  Varray<double> cellFrac;  // fractional area of grid cells participating in remapping
+  Varray<double> cellArea{};  // total area of each grid cell
+  Varray<double> cellFrac{};  // fractional area of grid cells participating in remapping
 };
 
 #endif /* REMAP_GRID_H */
