@@ -13,9 +13,9 @@
 #include <mpim_grid.h>
 
 void
-grid2spec(const SP_Transformation &spTrans, int gridIDin, const Varray<double> &arrayIn, int gridIDout, Varray<double> &arrayOut)
+grid2spec(const SP_Transformation &spTrans, int gridIDin, Varray<double> const &arrayIn, int gridIDout, Varray<double> &arrayOut)
 {
-  const auto &fcTrans = spTrans.fcTrans;
+  auto const &fcTrans = spTrans.fcTrans;
   long nlev = 1;
   long ntr = gridInqTrunc(gridIDout);
   long nlon = gridInqXsize(gridIDin);
@@ -34,9 +34,9 @@ grid2spec(const SP_Transformation &spTrans, int gridIDin, const Varray<double> &
 }
 
 void
-spec2grid(const SP_Transformation &spTrans, int gridIDin, const Varray<double> &arrayIn, int gridIDout, Varray<double> &arrayOut)
+spec2grid(const SP_Transformation &spTrans, int gridIDin, Varray<double> const &arrayIn, int gridIDout, Varray<double> &arrayOut)
 {
-  const auto &fcTrans = spTrans.fcTrans;
+  auto const &fcTrans = spTrans.fcTrans;
   long nlev = 1;
   long ntr = gridInqTrunc(gridIDin);
   long nlon = gridInqXsize(gridIDout);
@@ -55,7 +55,7 @@ spec2grid(const SP_Transformation &spTrans, int gridIDin, const Varray<double> &
 }
 
 void
-four2spec(const SP_Transformation &spTrans, int gridIDin, const Varray<double> &arrayIn, int gridIDout, Varray<double> &arrayOut)
+four2spec(const SP_Transformation &spTrans, int gridIDin, Varray<double> const &arrayIn, int gridIDout, Varray<double> &arrayOut)
 {
   (void) gridIDin;
   long nlev = 1;
@@ -68,7 +68,7 @@ four2spec(const SP_Transformation &spTrans, int gridIDin, const Varray<double> &
 }
 
 void
-spec2four(const SP_Transformation &spTrans, int gridIDin, const Varray<double> &arrayIn, int gridIDout, Varray<double> &arrayOut)
+spec2four(const SP_Transformation &spTrans, int gridIDin, Varray<double> const &arrayIn, int gridIDout, Varray<double> &arrayOut)
 {
   long nlev = 1;
   long ntr = gridInqTrunc(gridIDin);
@@ -81,7 +81,7 @@ spec2four(const SP_Transformation &spTrans, int gridIDin, const Varray<double> &
 }
 
 void
-four2grid(const FC_Transformation &fcTrans, int gridIDin, const Varray<double> &arrayIn, int gridIDout, Varray<double> &arrayOut)
+four2grid(const FC_Transformation &fcTrans, int gridIDin, Varray<double> const &arrayIn, int gridIDout, Varray<double> &arrayOut)
 {
   long nlev = 1;
   long ntr = gridInqTrunc(gridIDin);
@@ -97,7 +97,7 @@ four2grid(const FC_Transformation &fcTrans, int gridIDin, const Varray<double> &
 }
 
 void
-grid2four(const FC_Transformation &fcTrans, int gridIDin, const Varray<double> &arrayIn, int gridIDout, Varray<double> &arrayOut)
+grid2four(const FC_Transformation &fcTrans, int gridIDin, Varray<double> const &arrayIn, int gridIDout, Varray<double> &arrayOut)
 {
   long nlev = 1;
   long ntr = gridInqTrunc(gridIDout);
@@ -113,7 +113,7 @@ grid2four(const FC_Transformation &fcTrans, int gridIDin, const Varray<double> &
 }
 
 void
-spec2spec(int gridIDin, const Varray<double> &arrayIn, int gridIDout, Varray<double> &arrayOut)
+spec2spec(int gridIDin, Varray<double> const &arrayIn, int gridIDout, Varray<double> &arrayOut)
 {
   long ntrIn = gridInqTrunc(gridIDin);
   long ntrOut = gridInqTrunc(gridIDout);
@@ -122,7 +122,7 @@ spec2spec(int gridIDin, const Varray<double> &arrayIn, int gridIDout, Varray<dou
 }
 
 void
-speccut(int gridIDin, const Varray<double> &arrayIn, Varray<double> &arrayOut, const Varray<int> &waves)
+speccut(int gridIDin, Varray<double> const &arrayIn, Varray<double> &arrayOut, Varray<int> const &waves)
 {
   long ntr = gridInqTrunc(gridIDin);
 
@@ -130,7 +130,7 @@ speccut(int gridIDin, const Varray<double> &arrayIn, Varray<double> &arrayOut, c
 }
 
 void
-trans_uv2dv(const SP_Transformation &spTrans, long nlev, int gridID1, const Varray<double> &gu, const Varray<double> &gv,
+trans_uv2dv(const SP_Transformation &spTrans, long nlev, int gridID1, Varray<double> const &gu, Varray<double> const &gv,
             int gridID2, Varray<double> &sd, Varray<double> &svo)
 {
   if (gridInqType(gridID1) != GRID_GAUSSIAN)
@@ -139,7 +139,7 @@ trans_uv2dv(const SP_Transformation &spTrans, long nlev, int gridID1, const Varr
   if (gridInqType(gridID2) != GRID_SPECTRAL)
     cdo_abort("unexpected grid2 type: %s instead of spectral", gridNamePtr(gridInqType(gridID2)));
 
-  const auto &fcTrans = spTrans.fcTrans;
+  auto const &fcTrans = spTrans.fcTrans;
   long ntr = gridInqTrunc(gridID2);
   long nlon = gridInqXsize(gridID1);
   long nlat = gridInqYsize(gridID1);
@@ -150,15 +150,15 @@ trans_uv2dv(const SP_Transformation &spTrans, long nlev, int gridID1, const Varr
   Varray<double> fpwork2(nlat * nfc * nlev);
 
   if (fcTrans.use_fftw)
-    {
-      gp2fc(gu.data(), fpwork1.data(), nlat, nlon, nlev, nfc);
-      gp2fc(gv.data(), fpwork2.data(), nlat, nlon, nlev, nfc);
-    }
+  {
+    gp2fc(gu.data(), fpwork1.data(), nlat, nlon, nlev, nfc);
+    gp2fc(gv.data(), fpwork2.data(), nlat, nlon, nlev, nfc);
+  }
   else
-    {
-      gp2fc(fcTrans.vtrig.data(), fcTrans.ifax, gu.data(), fpwork1.data(), nlat, nlon, nlev, nfc);
-      gp2fc(fcTrans.vtrig.data(), fcTrans.ifax, gv.data(), fpwork2.data(), nlat, nlon, nlev, nfc);
-    }
+  {
+    gp2fc(fcTrans.vtrig.data(), fcTrans.ifax, gu.data(), fpwork1.data(), nlat, nlon, nlev, nfc);
+    gp2fc(fcTrans.vtrig.data(), fcTrans.ifax, gv.data(), fpwork2.data(), nlat, nlon, nlev, nfc);
+  }
 
   scaluv(fpwork1.data(), spTrans.coslat.data(), nlat, nfc * nlev);
   scaluv(fpwork2.data(), spTrans.coslat.data(), nlat, nfc * nlev);
@@ -167,15 +167,15 @@ trans_uv2dv(const SP_Transformation &spTrans, long nlev, int gridID1, const Varr
 }
 
 void
-trans_dv2uv(const SP_Transformation &spTrans, const DV_Transformation &dvTrans, long nlev, int gridID1, const Varray<double> &sd,
-            const Varray<double> &svo, int gridID2, Varray<double> &gu, Varray<double> &gv)
+trans_dv2uv(const SP_Transformation &spTrans, const DV_Transformation &dvTrans, long nlev, int gridID1, Varray<double> const &sd,
+            Varray<double> const &svo, int gridID2, Varray<double> &gu, Varray<double> &gv)
 {
   if (gridInqType(gridID1) != GRID_SPECTRAL)
     cdo_warning("unexpected grid1 type: %s instead of spectral", gridNamePtr(gridInqType(gridID1)));
   if (gridInqType(gridID2) != GRID_GAUSSIAN)
     cdo_warning("unexpected grid2 type: %s instead of Gaussian", gridNamePtr(gridInqType(gridID2)));
 
-  const auto &fcTrans = spTrans.fcTrans;
+  auto const &fcTrans = spTrans.fcTrans;
   long ntr = gridInqTrunc(gridID1);
   long nlon = gridInqXsize(gridID2);
   long nlat = gridInqYsize(gridID2);
