@@ -177,27 +177,27 @@ public:
 
 void dv2ps(const double *div, double *pot, long nlev, long ntr);
 
-void trans_uv2dv(const SP_Transformation &spTrans, long nlev, int gridID1, const Varray<double> &gu, const Varray<double> &gv,
+void trans_uv2dv(const SP_Transformation &spTrans, long nlev, int gridID1, Varray<double> const &gu, Varray<double> const &gv,
                  int gridID2, Varray<double> &sd, Varray<double> &svo);
 
 void trans_dv2uv(const SP_Transformation &spTrans, const DV_Transformation &dvTrans, long nlev, int gridID1,
-                 const Varray<double> &sd, const Varray<double> &svo, int gridID2, Varray<double> &gu, Varray<double> &gv);
+                 Varray<double> const &sd, Varray<double> const &svo, int gridID2, Varray<double> &gu, Varray<double> &gv);
 
-void grid2spec(const SP_Transformation &spTrans, int gridIDin, const Varray<double> &arrayIn, int gridIDout,
+void grid2spec(const SP_Transformation &spTrans, int gridIDin, Varray<double> const &arrayIn, int gridIDout,
                Varray<double> &arrayOut);
-void spec2grid(const SP_Transformation &spTrans, int gridIDin, const Varray<double> &arrayIn, int gridIDout,
+void spec2grid(const SP_Transformation &spTrans, int gridIDin, Varray<double> const &arrayIn, int gridIDout,
                Varray<double> &arrayOut);
-void four2spec(const SP_Transformation &spTrans, int gridIDin, const Varray<double> &arrayIn, int gridIDout,
+void four2spec(const SP_Transformation &spTrans, int gridIDin, Varray<double> const &arrayIn, int gridIDout,
                Varray<double> &arrayOut);
-void spec2four(const SP_Transformation &spTrans, int gridIDin, const Varray<double> &arrayIn, int gridIDout,
+void spec2four(const SP_Transformation &spTrans, int gridIDin, Varray<double> const &arrayIn, int gridIDout,
                Varray<double> &arrayOut);
-void four2grid(const FC_Transformation &fcTrans, int gridIDin, const Varray<double> &arrayIn, int gridIDout,
+void four2grid(const FC_Transformation &fcTrans, int gridIDin, Varray<double> const &arrayIn, int gridIDout,
                Varray<double> &arrayOut);
-void grid2four(const FC_Transformation &fcTrans, int gridIDin, const Varray<double> &arrayIn, int gridIDout,
+void grid2four(const FC_Transformation &fcTrans, int gridIDin, Varray<double> const &arrayIn, int gridIDout,
                Varray<double> &arrayOut);
 
-void spec2spec(int gridIDin, const Varray<double> &arrayIn, int gridIDout, Varray<double> &arrayOut);
-void speccut(int gridIDin, const Varray<double> &arrayIn, Varray<double> &arrayOut, const Varray<int> &waves);
+void spec2spec(int gridIDin, Varray<double> const &arrayIn, int gridIDout, Varray<double> &arrayOut);
+void speccut(int gridIDin, Varray<double> const &arrayIn, Varray<double> &arrayOut, Varray<int> const &waves);
 
 void spcut(const double *arrayIn, double *arrayOut, long ntr, const int *waves);
 
