@@ -17,21 +17,21 @@ namespace cdo
 {
 
 int
-define_table(const std::string &tablearg)
+define_table(std::string const &tablearg)
 {
   auto tablename = tablearg.c_str();
 
   auto tableID = FileUtils::file_exists(tablename) ? tableRead(tablename) : CDI_UNDEFID;
 
   if (tableID == CDI_UNDEFID)
+  {
+    auto const &tablepath = getenv_string("CD_TABLEPATH");
+    if (tablepath.size())
     {
-      const auto &tablepath = getenv_string("CD_TABLEPATH");
-      if (tablepath.size())
-        {
-          std::string tablefile = tablepath + "/" + tablename;
-          if (FileUtils::file_exists(tablefile)) tableID = tableRead(tablefile.c_str());
-        }
+      std::string tablefile = tablepath + "/" + tablename;
+      if (FileUtils::file_exists(tablefile)) tableID = tableRead(tablefile.c_str());
     }
+  }
 
   if (tableID == CDI_UNDEFID) tableID = tableInq(-1, 0, tablename);
 
@@ -49,11 +49,11 @@ predefined_tables(int p_padding)
   int numTables = tableInqNumber();
   std::string tables{ "Predefined tables: " };
   for (int id = 0; id < numTables; id++)
-    {
-      if (id % 7 == 6) tables += std::string("\n") + std::string(padding, ' ');
-      if ((name = tableInqNamePtr(id))) tables += std::string(name);
-      if (id < numTables - 1) tables += ",";
-    }
+  {
+    if (id % 7 == 6) tables += std::string("\n") + std::string(padding, ' ');
+    if ((name = tableInqNamePtr(id))) tables += std::string(name);
+    if (id < numTables - 1) tables += ",";
+  }
   return tables;
 }
 
