@@ -6,10 +6,10 @@
 
 namespace FileUtils
 {
-bool file_exists(const std::string &fileName);
-bool user_file_overwrite(const std::string &fileName);
+bool file_exists(std::string const &fileName);
+bool user_file_overwrite(std::string const &fileName);
 off_t size(const char *filename);
-std::string gen_suffix(int filetype, int vlistID, const std::string &refenceName);
+std::string gen_suffix(int filetype, int vlistID, std::string const &refenceName);
 }  // namespace FileUtils
 
 #endif
