@@ -28,18 +28,18 @@ get_operator_argv(std::string operatorArguments)
 
   auto pos = operatorArguments.find(delimiter);
   if (pos != std::string::npos)
-    {
-      // remove operator name
-      operatorArguments.erase(0, pos + 1);
+  {
+    // remove operator name
+    operatorArguments.erase(0, pos + 1);
 
-      while ((pos = operatorArguments.find(delimiter)) != std::string::npos)
-        {
-          argument_vector.push_back(operatorArguments.substr(0, pos));
-          Debug(ARGUMENTS, "added argument %s", argument_vector.back());
-          operatorArguments.erase(0, pos + 1);
-        }
-      argument_vector.push_back(operatorArguments);
+    while ((pos = operatorArguments.find(delimiter)) != std::string::npos)
+    {
+      argument_vector.push_back(operatorArguments.substr(0, pos));
+      Debug(ARGUMENTS, "added argument %s", argument_vector.back());
+      operatorArguments.erase(0, pos + 1);
     }
+    argument_vector.push_back(operatorArguments);
+  }
   return argument_vector;
 }
 
@@ -55,23 +55,23 @@ split_args(std::string operatorArguments)
   std::size_t pos_start = 0;
   std::size_t arg_start = 0;
   while ((pos = operatorArguments.find(delimiter, pos_start)) != std::string::npos)
+  {
+    if (operatorArguments[pos - 1] != '\\')
     {
-      if (operatorArguments[pos - 1] != '\\')
-        {
-          auto new_arg = operatorArguments.substr(arg_start, pos - arg_start);
-          auto escape_pos = new_arg.find("\\,");
-          if (escape_pos != std::string::npos) { new_arg.replace(escape_pos, 2, ","); }
-          argument_vector.push_back(new_arg);
-          Debug(ARGUMENTS, "added argument %s", argument_vector.back());
-          arg_start = pos + 1;
-        }
-      else
-        {
-          operatorArguments.erase(pos - 1, 1);
-          pos -= 1;
-        }
-      pos_start = pos + 1;
+      auto new_arg = operatorArguments.substr(arg_start, pos - arg_start);
+      auto escape_pos = new_arg.find("\\,");
+      if (escape_pos != std::string::npos) { new_arg.replace(escape_pos, 2, ","); }
+      argument_vector.push_back(new_arg);
+      Debug(ARGUMENTS, "added argument %s", argument_vector.back());
+      arg_start = pos + 1;
     }
+    else
+    {
+      operatorArguments.erase(pos - 1, 1);
+      pos -= 1;
+    }
+    pos_start = pos + 1;
+  }
   if (arg_start == operatorArguments.size()) { throw std::runtime_error("',' is not followed by any operator argument"); }
   argument_vector.push_back(operatorArguments.substr(arg_start, operatorArguments.size() - arg_start));
   Debug(ARGUMENTS, "added argument %s", argument_vector.back());
@@ -79,7 +79,7 @@ split_args(std::string operatorArguments)
 }
 
 std::string
-getenv_string(const std::string &envVar)
+getenv_string(std::string const &envVar)
 {
   std::string envString;
   auto envCstring = getenv(envVar.c_str());
@@ -88,7 +88,7 @@ getenv_string(const std::string &envVar)
 }
 
 std::vector<std::string>
-split_string(const std::string &str, const std::string &delimiter)
+split_string(std::string const &str, std::string const &delimiter)
 {
   std::regex regex(delimiter);
   return { std::sregex_token_iterator(str.begin(), str.end(), regex, -1), std::sregex_token_iterator() };
@@ -151,7 +151,7 @@ get_scientific(double p_float_string)
 char *
 double_to_att_str(int digits, char *attstr, size_t len, double value)
 {
-  const auto ret = std::snprintf(attstr, len, "%#.*g", digits, value);
+  auto ret = std::snprintf(attstr, len, "%#.*g", digits, value);
   assert(ret != -1 && ret < (int) len);
   trim_flt(attstr);
   return attstr;
@@ -191,22 +191,22 @@ calendar_to_cstr(int calendar)
 }
 
 bool
-string_is_float(const std::string &str)
+string_is_float(std::string const &str)
 {
   if (str.empty() || std::isspace(str[0])) return 0;
 
   char *ptr = nullptr;
-  strtod(str.c_str(), &ptr);
+  std::strtod(str.c_str(), &ptr);
   return (*ptr == '\0');
 }
 
 bool
-string_is_int(const std::string &str)
+string_is_int(std::string const &str)
 {
   if (str.empty() || std::isspace(str[0])) return 0;
 
   char *ptr = nullptr;
-  strtol(str.c_str(), &ptr, 10);
+  std::strtol(str.c_str(), &ptr, 10);
   return (*ptr == '\0');
 }
 
@@ -218,19 +218,19 @@ string_is_int(const std::string &str)
  * list is returned with the result boolean.
  **/
 std::tuple<bool, std::vector<std::string>>
-tokenize_comma_seperated_int_list(const std::string &args)
+tokenize_comma_seperated_int_list(std::string const &args)
 {
   auto tokens = split_string(args, ",");
   bool res = true;
-  for (const auto &t : tokens)
+  for (auto const &t : tokens)
+  {
+    if (!string_is_int(t))
     {
-      if (!string_is_int(t))
-        {
-          res = false;
-          tokens = {};
-          break;
-        }
+      res = false;
+      tokens = {};
+      break;
     }
+  }
   return { res, tokens };
 }
 
@@ -242,10 +242,10 @@ cstr_replace_char(char *str_in, char orig_char, char rep_char)
   if (std::strchr(str_in, orig_char) == nullptr) return;
 
   while (*str_in != '\0')
-    {
-      if (*str_in == orig_char) *str_in = rep_char;
-      str_in++;
-    }
+  {
+    if (*str_in == orig_char) *str_in = rep_char;
+    str_in++;
+  }
 
   return;
 }
