@@ -24,10 +24,10 @@ void
 height_to_pressure(const double *heightLevels, double *pressureLevels, int numLevels)
 {
   for (int k = 0; k < numLevels; ++k)
-    {
-      // heightLevels: height in meters
-      pressureLevels[k] = SCALESLP * std::exp(heightLevels[k] / SCALEHEIGHT);
-    }
+  {
+    // heightLevels: height in meters
+    pressureLevels[k] = SCALESLP * std::exp(heightLevels[k] / SCALEHEIGHT);
+  }
 }
 /*
 void
@@ -38,30 +38,30 @@ pressure_to_height(const double *pressureLevels, double *heightLevels, int numLe
 */
 template <typename T>
 void
-vct_to_hybrid_pressure(T *restrict fullPress, T *halfPress, const Varray<double> &vct, const T *restrict ps, long nhlev, long ngp)
+vct_to_hybrid_pressure(T *restrict fullPress, T *halfPress, Varray<double> const &vct, const T *restrict ps, long nhlev, long ngp)
 {
   assert(ps != nullptr);
 
   auto halfpresure = halfPress;
   for (long lh = 0; lh < nhlev; lh++)
-    {
-      auto zp = vct[lh];
-      auto ze = vct[lh + nhlev + 1];
-      for (long i = 0; i < ngp; ++i) halfpresure[i] = zp + ze * ps[i];
-      halfpresure += ngp;
-    }
+  {
+    auto zp = vct[lh];
+    auto ze = vct[lh + nhlev + 1];
+    for (long i = 0; i < ngp; ++i) halfpresure[i] = zp + ze * ps[i];
+    halfpresure += ngp;
+  }
   array_copy(ngp, ps, halfpresure);
 
   if (fullPress)
-    {
-      halfpresure = halfPress;
-      for (long i = 0; i < ngp * nhlev; ++i) fullPress[i] = 0.5 * (halfpresure[i] + halfpresure[i + ngp]);
-    }
+  {
+    halfpresure = halfPress;
+    for (long i = 0; i < ngp * nhlev; ++i) fullPress[i] = 0.5 * (halfpresure[i] + halfpresure[i + ngp]);
+  }
 }
 
-template void vct_to_hybrid_pressure(float *fullPress, float *halfPress, const Varray<double> &vct, const float *ps, long nhlev,
+template void vct_to_hybrid_pressure(float *fullPress, float *halfPress, Varray<double> const &vct, const float *ps, long nhlev,
                                      long ngp);
-template void vct_to_hybrid_pressure(double *fullPress, double *halfPress, const Varray<double> &vct, const double *ps, long nhlev,
+template void vct_to_hybrid_pressure(double *fullPress, double *halfPress, Varray<double> const &vct, const double *ps, long nhlev,
                                      long ngp);
 
 void
@@ -72,32 +72,30 @@ extrapolate_P(double *restrict slp, const double *restrict halfPress, const doub
   auto zrg = 1.0 / PlanetGrav;
 
   for (long j = 0; j < ngp; ++j)
+  {
+    if (geop[j] < 0.0001 && geop[j] > -0.0001) { slp[j] = halfPress[j]; }
+    else
     {
-      if (geop[j] < 0.0001 && geop[j] > -0.0001) { slp[j] = halfPress[j]; }
-      else
-        {
-          auto alpha = PlanetRD * zlapse * zrg;
-          auto tstar = (1.0 + alpha * (halfPress[j] / fullPress[j] - 1.0)) * temp[j];
+      auto alpha = PlanetRD * zlapse * zrg;
+      auto tstar = (1.0 + alpha * (halfPress[j] / fullPress[j] - 1.0)) * temp[j];
 
-          if (tstar < 255.0) tstar = 0.5 * (255.0 + tstar);
+      if (tstar < 255.0) { tstar = 0.5 * (255.0 + tstar); }
 
-          auto tmsl = tstar + zlapse * zrg * geop[j];
-          if (tmsl > 290.5 && tstar > 290.5)
-            {
-              tstar = 0.5 * (290.5 + tstar);
-              tmsl = tstar;
-            }
+      auto tmsl = tstar + zlapse * zrg * geop[j];
+      if (tmsl > 290.5 && tstar > 290.5)
+      {
+        tstar = 0.5 * (290.5 + tstar);
+        tmsl = tstar;
+      }
 
-          if (tmsl - tstar < 0.000001 && tstar - tmsl < 0.000001)
-            alpha = 0.0;
-          else if (geop[j] > 0.0001 || geop[j] < -0.0001)
-            alpha = PlanetRD * (tmsl - tstar) / geop[j];
+      if (tmsl - tstar < 0.000001 && tstar - tmsl < 0.000001) { alpha = 0.0; }
+      else if (geop[j] > 0.0001 || geop[j] < -0.0001) { alpha = PlanetRD * (tmsl - tstar) / geop[j]; }
 
-          auto zprt = geop[j] / (PlanetRD * tstar);
-          auto zprtal = zprt * alpha;
-          slp[j] = halfPress[j] * std::exp(zprt * (1.0 - zprtal * (0.5 - zprtal / 3.0)));
-        }
+      auto zprt = geop[j] / (PlanetRD * tstar);
+      auto zprtal = zprt * alpha;
+      slp[j] = halfPress[j] * std::exp(zprt * (1.0 - zprtal * (0.5 - zprtal / 3.0)));
     }
+  }
 }
 
 static inline double
@@ -115,38 +113,38 @@ extrapolate_T(double pres, double halfPress, double fullPress, double geop, doub
   auto ztmsl = tstar + zlapse * zrg * geop;
 
   if (ztmsl > 290.5 && tstar > 290.5)
-    {
-      tstar = 0.5 * (290.5 + tstar);
-      // ztmsl = tstar;
-    }
+  {
+    tstar = 0.5 * (290.5 + tstar);
+    // ztmsl = tstar;
+  }
 
   // if (ztmsl > 290.5 && tstar <= 290.5) ztmsl = 290.5;
 
   if (pres <= halfPress) { peval = ((halfPress - pres) * temp + (pres - fullPress) * tstar) / (halfPress - fullPress); }
   else
+  {
+    ztmsl = z1;
+    tstar = ztsz;
+    auto zhts = geop * zrg;
+
+    if (zhts > 2000. && z1 > 298.0)
     {
-      ztmsl = z1;
-      tstar = ztsz;
-      auto zhts = geop * zrg;
-
-      if (zhts > 2000. && z1 > 298.0)
-        {
-          ztmsl = 298.0;
-          if (zhts < 2500.0) ztmsl = 0.002 * ((2500.0 - zhts) * z1 + (zhts - 2000.0) * ztmsl);
-        }
-
-      double zalph;
-      if ((ztmsl - tstar) < 0.000001)
-        zalph = 0.;
-      else if (geop > 0.0001 || geop < -0.0001)
-        zalph = PlanetRD * (ztmsl - tstar) / geop;
-      else
-        zalph = PlanetRD * zlapse * zrg;
-
-      auto zalp = zalph * std::log(pres / halfPress);
-      peval = tstar * (1.0 + zalp * (1.0 + zalp * (0.5 + 0.16666666667 * zalp)));
+      ztmsl = 298.0;
+      if (zhts < 2500.0) ztmsl = 0.002 * ((2500.0 - zhts) * z1 + (zhts - 2000.0) * ztmsl);
     }
 
+    double zalph;
+    if ((ztmsl - tstar) < 0.000001)
+      zalph = 0.;
+    else if (geop > 0.0001 || geop < -0.0001)
+      zalph = PlanetRD * (ztmsl - tstar) / geop;
+    else
+      zalph = PlanetRD * zlapse * zrg;
+
+    auto zalp = zalph * std::log(pres / halfPress);
+    peval = tstar * (1.0 + zalp * (1.0 + zalp * (0.5 + 0.16666666667 * zalp)));
+  }
+
   return peval;
 }
 
@@ -164,14 +162,14 @@ extrapolate_Z(double pres, double halfPress, double fullPress, double geop, doub
   auto tmsl = tstar + zlapse * zrg * geop;
 
   if (tmsl > ztlim && tstar > ztlim)
-    {
-      tstar = 0.5 * (ztlim + tstar);
-      tmsl = tstar;
-    }
+  {
+    tstar = 0.5 * (ztlim + tstar);
+    tmsl = tstar;
+  }
 
   if (tmsl > ztlim && tstar <= ztlim) tmsl = ztlim;
 
-  if (tmsl - tstar < 0.000001 && tstar - tmsl < 0.000001)
+  if ((tmsl - tstar) < 0.000001 && (tstar - tmsl) < 0.000001)
     alpha = 0.0;
   else if (geop > 0.0001 || geop < -0.0001)
     alpha = PlanetRD * (tmsl - tstar) / geop;
@@ -191,32 +189,32 @@ vertical_interp_T(const T *restrict geop, const T *restrict gt, T *pt, const T *
 #pragma omp parallel for default(shared)
 #endif
   for (long lp = 0; lp < nplev; lp++)
-    {
-      auto pres = plev[lp];
-      const int *restrict vertIndexLev = vertIndex + lp * ngp;
-      auto ptl = pt + lp * ngp;
+  {
+    auto pres = plev[lp];
+    const int *restrict vertIndexLev = vertIndex + lp * ngp;
+    auto ptl = pt + lp * ngp;
 
-      for (long i = 0; i < ngp; ++i)
+    for (long i = 0; i < ngp; ++i)
+    {
+      long nl = vertIndexLev[i];
+      if (nl < 0) { ptl[i] = missval; }
+      else
+      {
+        if (nl > nhlev - 2)
         {
-          long nl = vertIndexLev[i];
-          if (nl < 0) { ptl[i] = missval; }
-          else
-            {
-              if (nl > nhlev - 2)
-                {
-                  ptl[i] = extrapolate_T(pres, halfPress[nhlev * ngp + i], fullPress[(nhlev - 1) * ngp + i], geop[i],
-                                         gt[(nhlev - 1) * ngp + i]);
-                }
-              else
-                {
-                  auto nh = nl + 1;
-                  ptl[i] = gt[nl * ngp + i]
-                           + (pres - fullPress[nl * ngp + i]) * (gt[nh * ngp + i] - gt[nl * ngp + i])
-                                 / (fullPress[nh * ngp + i] - fullPress[nl * ngp + i]);
-                }
-            }
+          ptl[i] = extrapolate_T(pres, halfPress[nhlev * ngp + i], fullPress[(nhlev - 1) * ngp + i], geop[i],
+                                 gt[(nhlev - 1) * ngp + i]);
         }
+        else
+        {
+          auto nh = nl + 1;
+          ptl[i] = gt[nl * ngp + i]
+                   + (pres - fullPress[nl * ngp + i]) * (gt[nh * ngp + i] - gt[nl * ngp + i])
+                         / (fullPress[nh * ngp + i] - fullPress[nl * ngp + i]);
+        }
+      }
     }
+  }
 }
 
 // Explicit instantiation
@@ -243,34 +241,34 @@ vertical_interp_Z(const T *restrict geop, const T *restrict gz, T *pz, const T *
 #pragma omp parallel for default(shared)
 #endif
   for (long lp = 0; lp < nplev; lp++)
+  {
+    auto pres = plev[lp];
+    const int *restrict vertIndexLev = vertIndex + lp * ngp;
+    auto pzl = pz + lp * ngp;
+
+    for (long i = 0; i < ngp; ++i)
     {
-      auto pres = plev[lp];
-      const int *restrict vertIndexLev = vertIndex + lp * ngp;
-      auto pzl = pz + lp * ngp;
+      long nl = vertIndexLev[i];
+      if (nl < 0) { pzl[i] = missval; }
+      else
+      {
+        if (pres > halfPress[(nl + 1) * ngp + i]) nl++;
 
-      for (long i = 0; i < ngp; ++i)
+        if (nl > nhlev - 1)
         {
-          long nl = vertIndexLev[i];
-          if (nl < 0) { pzl[i] = missval; }
-          else
-            {
-              if (pres > halfPress[(nl + 1) * ngp + i]) nl++;
-
-              if (nl > nhlev - 1)
-                {
-                  pzl[i] = extrapolate_Z(pres, halfPress[nhlev * ngp + i], fullPress[(nhlev - 1) * ngp + i], geop[i],
-                                         gt[(nhlev - 1) * ngp + i]);
-                }
-              else
-                {
-                  auto nh = nl + 1;
-                  pzl[i] = gz[nl * ngp + i]
-                           + (pres - halfPress[nl * ngp + i]) * (gz[nh * ngp + i] - gz[nl * ngp + i])
-                                 / (halfPress[nh * ngp + i] - halfPress[nl * ngp + i]);
-                }
-            }
+          pzl[i] = extrapolate_Z(pres, halfPress[nhlev * ngp + i], fullPress[(nhlev - 1) * ngp + i], geop[i],
+                                 gt[(nhlev - 1) * ngp + i]);
         }
+        else
+        {
+          auto nh = nl + 1;
+          pzl[i] = gz[nl * ngp + i]
+                   + (pres - halfPress[nl * ngp + i]) * (gz[nh * ngp + i] - gz[nl * ngp + i])
+                         / (halfPress[nh * ngp + i] - halfPress[nl * ngp + i]);
+        }
+      }
     }
+  }
 }
 
 // Explicit instantiation
@@ -299,37 +297,37 @@ vertical_interp_X(const T *restrict arrayIn3D, T *restrict arrayOut3D, const T *
                   const double *restrict levels, long numLevels, long numGP, long nhlev, double missval)
 {
   if (numLevels > 3)
-    {
+  {
 #ifdef _OPENMP
 #pragma omp parallel for default(shared)
 #endif
-      for (long levIndex = 0; levIndex < numLevels; levIndex++)
-        {
-          auto level = levels[levIndex];
-          const int *restrict vertIndex = vertIndex3D + levIndex * numGP;
-          auto *restrict arrayOut2D = arrayOut3D + levIndex * numGP;
-          for (long i = 0; i < numGP; ++i)
-            {
-              arrayOut2D[i] = vertical_interp_X_kernel(arrayIn3D, levels3D, vertIndex[i] * numGP + i, level, numGP, nhlev, missval);
-            }
-        }
+    for (long levIndex = 0; levIndex < numLevels; levIndex++)
+    {
+      auto level = levels[levIndex];
+      const int *restrict vertIndex = vertIndex3D + levIndex * numGP;
+      auto *restrict arrayOut2D = arrayOut3D + levIndex * numGP;
+      for (long i = 0; i < numGP; ++i)
+      {
+        arrayOut2D[i] = vertical_interp_X_kernel(arrayIn3D, levels3D, vertIndex[i] * numGP + i, level, numGP, nhlev, missval);
+      }
     }
+  }
   else
+  {
+    for (long levIndex = 0; levIndex < numLevels; levIndex++)
     {
-      for (long levIndex = 0; levIndex < numLevels; levIndex++)
-        {
-          auto level = levels[levIndex];
-          const int *restrict vertIndex = vertIndex3D + levIndex * numGP;
-          auto *restrict arrayOut2D = arrayOut3D + levIndex * numGP;
+      auto level = levels[levIndex];
+      const int *restrict vertIndex = vertIndex3D + levIndex * numGP;
+      auto *restrict arrayOut2D = arrayOut3D + levIndex * numGP;
 #ifdef _OPENMP
 #pragma omp parallel for default(shared)
 #endif
-          for (long i = 0; i < numGP; ++i)
-            {
-              arrayOut2D[i] = vertical_interp_X_kernel(arrayIn3D, levels3D, vertIndex[i] * numGP + i, level, numGP, nhlev, missval);
-            }
-        }
+      for (long i = 0; i < numGP; ++i)
+      {
+        arrayOut2D[i] = vertical_interp_X_kernel(arrayIn3D, levels3D, vertIndex[i] * numGP + i, level, numGP, nhlev, missval);
+      }
     }
+  }
 }
 
 // Explicit instantiation
@@ -344,34 +342,34 @@ void
 gen_vert_index(int *vertIndex, const double *restrict plev, const T *restrict levels3D, long ngp, int nplev, int nhlev,
                bool lreverse)
 {
-  ranges::fill_n(vertIndex, ngp * nplev, 0);
+  std::ranges::fill_n(vertIndex, ngp * nplev, 0);
 
 #ifdef _OPENMP
 #pragma omp parallel for default(shared)
 #endif
   for (int lp = 0; lp < nplev; lp++)
+  {
+    T pres = plev[lp];
+    auto *restrict vertIndexLev = vertIndex + lp * ngp;
+    for (int lh = 0; lh < nhlev; lh++)
     {
-      T pres = plev[lp];
-      auto *restrict vertIndexLev = vertIndex + lp * ngp;
-      for (int lh = 0; lh < nhlev; lh++)
+      const auto *restrict fullpx = levels3D + lh * ngp;
+      if (lreverse)
+      {
+        for (long i = 0; i < ngp; ++i)
         {
-          const auto *restrict fullpx = levels3D + lh * ngp;
-          if (lreverse)
-            {
-              for (long i = 0; i < ngp; ++i)
-                {
-                  if (pres < fullpx[i]) vertIndexLev[i] = lh;
-                }
-            }
-          else
-            {
-              for (long i = 0; i < ngp; ++i)
-                {
-                  if (pres > fullpx[i]) vertIndexLev[i] = lh;
-                }
-            }
+          if (pres < fullpx[i]) vertIndexLev[i] = lh;
         }
+      }
+      else
+      {
+        for (long i = 0; i < ngp; ++i)
+        {
+          if (pres > fullpx[i]) vertIndexLev[i] = lh;
+        }
+      }
     }
+  }
 }
 
 // Explicit instantiation
@@ -389,34 +387,34 @@ gen_vert_index_mv(int *vertIndex, const double *restrict plev, long ngp, int npl
 #pragma omp parallel for default(shared)
 #endif
   for (int lp = 0; lp < nplev; lp++)
-    {
-      pnumMissVals[lp] = 0;
-      T pres = plev[lp];
-      auto *restrict vertIndexLev = vertIndex + lp * ngp;
+  {
+    pnumMissVals[lp] = 0;
+    T pres = plev[lp];
+    auto *restrict vertIndexLev = vertIndex + lp * ngp;
 
-      if (lreverse)
+    if (lreverse)
+    {
+      for (long i = 0; i < ngp; ++i)
+      {
+        if (pres < psProg[i])
         {
-          for (long i = 0; i < ngp; ++i)
-            {
-              if (pres < psProg[i])
-                {
-                  vertIndexLev[i] = -1;
-                  pnumMissVals[lp]++;
-                }
-            }
-        }
-      else
-        {
-          for (long i = 0; i < ngp; ++i)
-            {
-              if (pres > psProg[i])
-                {
-                  vertIndexLev[i] = -1;
-                  pnumMissVals[lp]++;
-                }
-            }
+          vertIndexLev[i] = -1;
+          pnumMissVals[lp]++;
         }
+      }
     }
+    else
+    {
+      for (long i = 0; i < ngp; ++i)
+      {
+        if (pres > psProg[i])
+        {
+          vertIndexLev[i] = -1;
+          pnumMissVals[lp]++;
+        }
+      }
+    }
+  }
 }
 
 // Explicit instantiation
