@@ -7,6 +7,7 @@
 #include <cdi.h>
 
 #include <cstring>
+#include <string>
 
 #include "cdi_uuid.h"
 #include "cdo_options.h"
@@ -15,31 +16,31 @@
 constexpr int MaxLen = 120;
 
 static void
-printDblsPrefixAutoBrk(FILE *fp, int dig, const char *prefix, size_t n, const double vals[], size_t extbreak)
+printDblsPrefixAutoBrk(FILE *fp, int dig, std::string const &prefix, size_t n, std::vector<double> const &vals, size_t extbreak)
 {
-  int nbyte0 = std::strlen(prefix);
-  fputs(prefix, fp);
+  int nbyte0 = (int) prefix.size();
+  fputs(prefix.c_str(), fp);
   int nbyte = nbyte0;
   for (size_t i = 0; i < n; ++i)
+  {
+    if (nbyte > MaxLen || (i && i == extbreak))
     {
-      if (nbyte > MaxLen || (i && i == extbreak))
-        {
-          fprintf(fp, "\n%*s", nbyte0, "");
-          nbyte = nbyte0;
-        }
-      nbyte += fprintf(fp, "%.*g ", dig, vals[i]);
+      fprintf(fp, "\n%*s", nbyte0, "");
+      nbyte = nbyte0;
     }
+    nbyte += fprintf(fp, "%.*g ", dig, vals[i]);
+  }
   fputs("\n", fp);
 }
 
 static void
-zaxisPrintKernel(int zaxisID, FILE *fp)
+zaxis_print_kernel(int zaxisID, FILE *fp)
 {
   auto type = zaxisInqType(zaxisID);
   auto nlevels = zaxisInqSize(zaxisID);
   int datatype = CDI_UNDEFID;
   cdiInqKeyInt(zaxisID, CDI_GLOBAL, CDI_KEY_DATATYPE, &datatype);
-  size_t nvals = (size_t) zaxisInqLevels(zaxisID, nullptr);
+  auto nvals = (size_t) zaxisInqLevels(zaxisID, nullptr);
 
   auto dig = (datatype == CDI_DATATYPE_FLT64) ? Options::CDO_dbl_digits : Options::CDO_flt_digits;
 
@@ -64,56 +65,56 @@ zaxisPrintKernel(int zaxisID, FILE *fp)
   if (nvals) vals.resize(nvals);
 
   if (nvals)
-    {
-      zaxisInqLevels(zaxisID, vals.data());
-      printDblsPrefixAutoBrk(fp, dig, "levels    = ", nvals, vals.data(), 0);
-    }
+  {
+    zaxisInqLevels(zaxisID, vals.data());
+    printDblsPrefixAutoBrk(fp, dig, "levels    = ", nvals, vals, 0);
+  }
   else if (type == ZAXIS_CHAR)
+  {
+    auto clen = zaxisInqCLen(zaxisID);
+    char **cvals = nullptr;
+    zaxisInqCVals(zaxisID, &cvals);
+    fprintf(fp, "levels    = \n");
+    for (int i = 0; i < nlevels; ++i)
     {
-      auto clen = zaxisInqCLen(zaxisID);
-      char **cvals = nullptr;
-      zaxisInqCVals(zaxisID, &cvals);
-      fprintf(fp, "levels    = \n");
-      for (int i = 0; i < nlevels; ++i)
-        {
-          fprintf(fp, "     [%2d] = %.*s\n", i, clen, cvals[i]);
-          std::free(cvals[i]);
-        }
-      if (cvals) std::free(cvals);
+      fprintf(fp, "     [%2d] = %.*s\n", i, clen, cvals[i]);
+      std::free(cvals[i]);
     }
+    if (cvals) std::free(cvals);
+  }
 
   if (zaxisInqLbounds(zaxisID, nullptr) && zaxisInqUbounds(zaxisID, nullptr))
-    {
-      zaxisInqLbounds(zaxisID, vals.data());
-      printDblsPrefixAutoBrk(fp, dig, "lbounds   = ", nvals, vals.data(), 0);
+  {
+    zaxisInqLbounds(zaxisID, vals.data());
+    printDblsPrefixAutoBrk(fp, dig, "lbounds   = ", nvals, vals, 0);
 
-      zaxisInqUbounds(zaxisID, vals.data());
-      printDblsPrefixAutoBrk(fp, dig, "ubounds   = ", nvals, vals.data(), 0);
-    }
+    zaxisInqUbounds(zaxisID, vals.data());
+    printDblsPrefixAutoBrk(fp, dig, "ubounds   = ", nvals, vals, 0);
+  }
 
   if (type == ZAXIS_HYBRID || type == ZAXIS_HYBRID_HALF)
+  {
+    auto vctsize = zaxisInqVctSize(zaxisID);
+    if (vctsize)
     {
-      auto vctsize = zaxisInqVctSize(zaxisID);
-      if (vctsize)
-        {
-          fprintf(fp, "vctsize   = %d\n", vctsize);
-          std::vector<double> vct(vctsize);
-          zaxisInqVct(zaxisID, vct.data());
-          printDblsPrefixAutoBrk(fp, dig, "vct       = ", vctsize, vct.data(), vctsize / 2);
-        }
+      fprintf(fp, "vctsize   = %d\n", vctsize);
+      std::vector<double> vct(vctsize);
+      zaxisInqVct(zaxisID, vct.data());
+      printDblsPrefixAutoBrk(fp, dig, "vct       = ", vctsize, vct, vctsize / 2);
     }
+  }
 
   if (type == ZAXIS_REFERENCE)
+  {
+    unsigned char uuid[CDI_UUID_SIZE] = { 0 };
+    int length = CDI_UUID_SIZE;
+    cdiInqKeyBytes(zaxisID, CDI_GLOBAL, CDI_KEY_UUID, uuid, &length);
+    if (!cdiUUIDIsNull(uuid))
     {
-      unsigned char uuid[CDI_UUID_SIZE] = { 0 };
-      int length = CDI_UUID_SIZE;
-      cdiInqKeyBytes(zaxisID, CDI_GLOBAL, CDI_KEY_UUID, uuid, &length);
-      if (!cdiUUIDIsNull(uuid))
-        {
-          char uuidStr[uuidNumHexChars + 1] = { 0 };
-          if (cdiUUID2Str(uuid, uuidStr) == uuidNumHexChars) fprintf(fp, "uuid      = %s\n", uuidStr);
-        }
+      char uuidStr[uuidNumHexChars + 1] = { 0 };
+      if (cdiUUID2Str(uuid, uuidStr) == uuidNumHexChars) fprintf(fp, "uuid      = %s\n", uuidStr);
     }
+  }
 
   cdo_print_attributes(fp, zaxisID, CDI_GLOBAL, 0);
 }
@@ -121,5 +122,5 @@ zaxisPrintKernel(int zaxisID, FILE *fp)
 void
 cdoPrintZaxis(int zaxisID)
 {
-  zaxisPrintKernel(zaxisID, stdout);
+  zaxis_print_kernel(zaxisID, stdout);
 }
